@@ -35,37 +35,40 @@ sub go {
     my $XML_HEADER="XML key";
     my $FUNC_HEADER="C function exported to Guile";
     my $keyword_env=$keyword;
+    my $type_void=0;
 
     $keyword_env =~ s/-/_/g;
     $keyword_env = uc("LW6_$keyword_env");
 
+    if ($keyword eq "config-file" ||
+	$keyword eq "prefix" ||
+	$keyword eq "mod-dir" ||
+	$keyword eq "data-dir" ||
+	$keyword eq "map-dir" ||
+	$keyword eq "script-file") {
+	# we only keep user-dir, log-file and map-path
+	# indeed these values are excluded from the XML config file
+	$type_void=1;
+    }
+
     SWITCH: {
+	open(CMD,"$path_to_binary --about=$keyword |");
+	$type_void=1 if <CMD> !~ /^Type/;
+	close(CMD);
+
 	printf("\@subsection $keyword\n");
-	if ($mode eq "cmd") {
-	    if ($keyword eq "about") {
-		# the only command-only keyword with an argument
-		printf("\@deffn {$CMD_HEADER} \@code{--about=<keyword>}\n");
-		last SWITCH;
-	    }
-	    printf("\@deffn {$CMD_HEADER} \@code{--$keyword}\n");
-	    last SWITCH;
-	}
 	if ($mode eq "func") {
 	    printf("\@deffn {$FUNC_HEADER} \@code{$keyword}\n");
 	    last SWITCH;
 	}
-	printf("\@deffn {$CMD_HEADER} \@code{--$keyword=<value>}\n");
-	printf("\@deffnx {$ENV_HEADER} \@code{$keyword_env}\n");
-	if ($keyword eq "config-file" ||
-	    $keyword eq "prefix" ||
-	    $keyword eq "mod-dir" ||
-	    $keyword eq "data-dir" ||
-	    $keyword eq "map-dir" ||
-	    $keyword eq "script-file") {
-	    # we only keep user-dir, log-file and map-path
-	    # indeed these values are excluded from the XML config file
-	    last SWITCH;
+	if ($type_void) {
+	    printf("\@deffn {$CMD_HEADER} \@code{--$keyword}\n");
+	} else {
+	    printf("\@deffn {$CMD_HEADER} \@code{--$keyword=<value>}\n");
 	}
+	last SWITCH if $mode eq "cmd";
+	printf("\@deffnx {$ENV_HEADER} \@code{$keyword_env}\n");
+	last SWITCH if $type_void;
 	printf("\@deffnx {$XML_HEADER} \@code{$keyword}\n");
     }
 
