@@ -38,7 +38,7 @@ typedef struct _lw6cfg_context_s
   int argc;
   char **argv;
   char *config_file;
-  lw6sys_assoc_t *options;
+  lw6sys_hash_t *options;
 }
 _lw6cfg_context_t;
 
