@@ -39,8 +39,7 @@ load_callback (void *callback_data, char *element, char *key, char *value)
 
   if (lw6cfg_must_be_saved (key))
     {
-      lw6sys_assoc_set (&(cfg_context->options), key,
-			lw6sys_str_copy (value));
+      lw6sys_hash_set (cfg_context->options, key, lw6sys_str_copy (value));
     }
   else
     {
