@@ -32,7 +32,7 @@ _lw6cfg_option_exists (_lw6cfg_context_t * context, char *key)
 {
   int ret = 0;
 
-  ret = lw6sys_assoc_has_key (context->options, key);
+  ret = lw6sys_hash_has_key (context->options, key);
 
   return ret;
 }
@@ -48,7 +48,7 @@ _lw6cfg_get_option (_lw6cfg_context_t * context, char *key)
 {
   char *ret = "";
 
-  ret = (char *) lw6sys_assoc_get (context->options, key);
+  ret = (char *) lw6sys_hash_get (context->options, key);
 
   if (!ret)
     {
@@ -72,7 +72,7 @@ _lw6cfg_set_option (_lw6cfg_context_t * context, char *key, char *value)
   value_converted = lw6cfg_format_guess_type (key, value);
   if (value_converted)
     {
-      lw6sys_assoc_set (&(context->options), key, (void *) value_converted);
+      lw6sys_hash_set (context->options, key, (void *) value_converted);
     }
 }
 
