@@ -33,11 +33,12 @@ lw6cfg_must_be_saved (char *key)
 {
   int ret = 1;
 
-  if (lw6hlp_match (key, "config-file") ||
-      lw6hlp_match (key, "prefix") ||
-      lw6hlp_match (key, "mod-dir") ||
-      lw6hlp_match (key, "data-dir") ||
-      lw6hlp_match (key, "map-dir") || lw6hlp_match (key, "script-file"))
+  if (lw6hlp_match (key, LW6DEF_CONFIG_FILE) ||
+      lw6hlp_match (key, LW6DEF_PREFIX) ||
+      lw6hlp_match (key, LW6DEF_MOD_DIR) ||
+      lw6hlp_match (key, LW6DEF_DATA_DIR) ||
+      lw6hlp_match (key, LW6DEF_MAP_DIR)
+      || lw6hlp_match (key, LW6DEF_SCRIPT_FILE))
     {
       /*
        * These options must not be save in the config file, doing so
@@ -66,9 +67,9 @@ _lw6cfg_save (_lw6cfg_context_t * cfg_context, char *filename)
       lw6sys_print_xml_header (f,
 			       _
 			       ("This is the main Liquid War 6 config file. Here you'll be able to tweak many, if not all, parameters in the game. Some of these values simply reflect changes you can make through the interface, some are not even present in the menus. What is sure is that if you can modify it by clicking somewhere in the game interface, it can surely be done here too. Note that this file is overwritten every time you run the game, your own comments and personnal touch in it will simply be squashed and disappear. But of course the values you set will be kept. All entries should be documented in the file. If in doubt, documentation is online on http://www.gnu.org/software/liquidwar6/manual/"));
-      lw6sys_assoc_sort_and_map (cfg_context->options,
-				 (lw6sys_assoc_t_CALLBACK_FUNC)
-				 lw6cfg_write_xml_guess_type, (void *) f);
+      lw6sys_hash_sort_and_map (cfg_context->options,
+				(lw6sys_assoc_callback_func_t)
+				lw6cfg_write_xml_guess_type, (void *) f);
       lw6sys_print_xml_footer (f);
       fclose (f);
       ret = 1;
