@@ -39,7 +39,8 @@ _lw6cfg_init (int argc, char *argv[])
       cfg_context->config_file = lw6sys_get_config_file (argc, argv);
       if (cfg_context->config_file)
 	{
-	  cfg_context->options = lw6sys_assoc_new (lw6sys_free_callback);
+	  cfg_context->options =
+	    lw6sys_hash_new (lw6sys_free_callback, LW6HLP_APPROX_NB_ENTRIES);
 	  if (cfg_context->options)
 	    {
 	      cfg_context->argc = argc;
@@ -92,7 +93,7 @@ _lw6cfg_quit (_lw6cfg_context_t * cfg_context)
   if (cfg_context)
     {
       LW6SYS_FREE (cfg_context->config_file);
-      lw6sys_assoc_free (cfg_context->options);
+      lw6sys_hash_free (cfg_context->options);
       LW6SYS_FREE (cfg_context);
     }
 }
@@ -138,16 +139,16 @@ lw6cfg_reset (int argc, char *argv[])
 	  value = lw6sys_get_user_dir (argc, argv);
 	  if (value)
 	    {
-	      lw6cfg_set_option (cfg_context, "user-dir", value);
+	      lw6cfg_set_option (cfg_context, LW6DEF_USER_DIR, value);
 	      LW6SYS_FREE (value);
 	    }
 	  value = lw6sys_get_log_file (argc, argv);
 	  if (value)
 	    {
-	      lw6cfg_set_option (cfg_context, "log-file", value);
+	      lw6cfg_set_option (cfg_context, LW6DEF_LOG_FILE, value);
 	      LW6SYS_FREE (value);
 	    }
-	  lw6cfg_set_option (cfg_context, "map-path", "");
+	  lw6cfg_set_option (cfg_context, LW6DEF_MAP_PATH, "");
 	  lw6cfg_save (cfg_context, config_file);
 	  lw6cfg_quit (cfg_context);
 	}
