@@ -31,7 +31,7 @@
 #define TEST_ARGV0 "abc"
 #define TEST_ARGV1 "--fullscreen"
 #define TEST_ARGV2 "--width=800"
-#define TEST_UNIFIED_KEY_YES "width"
+#define TEST_UNIFIED_KEY_YES LW6DEF_WIDTH
 #define TEST_UNIFIED_KEY_NO "unknown"
 
 /*
