@@ -113,7 +113,7 @@ lw6cfg_unified_get_value (int argc, char *argv[], char *key)
  *
  * Gets the user dir, taking all parameters in account, that's to
  * say the "LW6_USER_DIR" env value, the "--user-dir" command-line
- * paramater and the "user-dir" config file entry.
+ * paramater and the LW6DEF_USER_DIR config file entry.
  *
  * Return value: the directory path, might be NULL, must be freed.
  */
@@ -122,7 +122,7 @@ lw6cfg_unified_get_user_dir (int argc, char *argv[])
 {
   char *ret;
 
-  ret = lw6cfg_unified_get_value (argc, argv, "user-dir");
+  ret = lw6cfg_unified_get_value (argc, argv, LW6DEF_USER_DIR);
   if (!ret)
     {
       ret = lw6sys_get_user_dir (argc, argv);
@@ -139,7 +139,7 @@ lw6cfg_unified_get_user_dir (int argc, char *argv[])
  *
  * Gets the user dir, taking all parameters in account, that's to
  * say the "LW6_LOG_FILE" env value, the "--log-file" command-line
- * paramater and the "log-file" config file entry.
+ * paramater and the LW6DEF_LOG_FILE config file entry.
  *
  * Return value: the directory path, might be NULL, must be freed.
  */
@@ -148,7 +148,7 @@ lw6cfg_unified_get_log_file (int argc, char *argv[])
 {
   char *ret;
 
-  ret = lw6cfg_unified_get_value (argc, argv, "log-file");
+  ret = lw6cfg_unified_get_value (argc, argv, LW6DEF_LOG_FILE);
   if (!ret)
     {
       ret = lw6sys_get_log_file (argc, argv);
@@ -165,7 +165,7 @@ lw6cfg_unified_get_log_file (int argc, char *argv[])
  *
  * Gets the user dir, taking all parameters in account, that's to
  * say the "LW6_MAP_PATH" env value, the "--map-path" command-line
- * paramater and the "map-path" config file entry.
+ * paramater and the LW6DEF_MAP_PATH config file entry.
  *
  * Return value: the directory path, might be NULL, must be freed.
  */
@@ -179,7 +179,7 @@ lw6cfg_unified_get_map_path (int argc, char *argv[])
   map_path = lw6sys_get_map_path (argc, argv);
   if (map_path)
     {
-      map_path_config = get_option (argc, argv, "map-path");
+      map_path_config = get_option (argc, argv, LW6DEF_MAP_PATH);
       if (map_path_config)
 	{
 	  tmp = map_path;
