@@ -31,7 +31,7 @@
 #include "cfg-internal.h"
 
 char *
-lw6cfg_xml_element (LW6HLP_TYPE type)
+lw6cfg_xml_element (lw6hlp_type_t type)
 {
   char *xml_type = "";
 
@@ -242,7 +242,7 @@ write_xml (FILE * f, char *type, char *key, char *value)
   char *pos = NULL;
   char *guessed_type = NULL;
   char *help_string = NULL;
-  LW6HLP_TYPE hlp_type = LW6HLP_TYPE_STR;
+  lw6hlp_type_t hlp_type = LW6HLP_TYPE_STR;
 
   if (lw6cfg_must_be_saved (key))
     {
