@@ -45,7 +45,7 @@ extern int lw6cfg_parse_command_line (void *context);
 extern int lw6cfg_merge_env (void *cfg_context);
 
 // cfg-format.c
-extern char *lw6cfg_format (char *key, char *value, LW6HLP_TYPE type);
+extern char *lw6cfg_format (char *key, char *value, lw6hlp_type_t type);
 extern char *lw6cfg_format_guess_type (char *key, char *value);
 
 /*
@@ -91,7 +91,7 @@ extern char *lw6cfg_unified_get_map_path (int argc, char *argv[]);
 /*
  * Functions in xml.c
  */
-extern char *lw6cfg_xml_element (LW6HLP_TYPE type);
+extern char *lw6cfg_xml_element (lw6hlp_type_t type);
 extern void lw6cfg_read_xml_int (char *xml_key, char *xml_value,
 				 char *target_key, int *value);
 extern void lw6cfg_read_xml_bool (char *xml_key, char *xml_value,
