@@ -27,7 +27,7 @@
 #include "cli.h"
 
 static void
-_warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("cli backend function \"%s\" is not defined"), func_name);
@@ -36,7 +36,7 @@ _warning (char *func_name)
 int
 lw6cli_init (lw6cli_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
@@ -44,10 +44,10 @@ lw6cli_init (lw6cli_backend_t * backend)
     }
   else
     {
-      _warning ("init");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return backend->cli_context ? 1 : 0;
 }
@@ -55,7 +55,7 @@ lw6cli_init (lw6cli_backend_t * backend)
 void
 lw6cli_quit (lw6cli_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->quit)
     {
@@ -64,10 +64,10 @@ lw6cli_quit (lw6cli_backend_t * backend)
     }
   else
     {
-      _warning ("quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -75,7 +75,7 @@ lw6cli_can_handle (lw6cli_backend_t * backend, char *server_url)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->can_handle)
     {
@@ -83,10 +83,10 @@ lw6cli_can_handle (lw6cli_backend_t * backend, char *server_url)
     }
   else
     {
-      _warning ("can_handle");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -97,7 +97,7 @@ lw6cli_connect (lw6cli_backend_t * backend, char *server_url,
 {
   lw6cli_connection_t *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->connect)
     {
@@ -107,10 +107,10 @@ lw6cli_connect (lw6cli_backend_t * backend, char *server_url,
     }
   else
     {
-      _warning ("connect");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -118,7 +118,7 @@ lw6cli_connect (lw6cli_backend_t * backend, char *server_url,
 void
 lw6cli_close (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->close)
     {
@@ -126,10 +126,10 @@ lw6cli_close (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
     }
   else
     {
-      _warning ("close");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -138,7 +138,7 @@ lw6cli_send (lw6cli_backend_t * backend, lw6cli_connection_t * connection,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->send)
     {
@@ -146,10 +146,10 @@ lw6cli_send (lw6cli_backend_t * backend, lw6cli_connection_t * connection,
     }
   else
     {
-      _warning ("send");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -159,7 +159,7 @@ lw6cli_recv (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->recv)
     {
@@ -167,10 +167,10 @@ lw6cli_recv (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
     }
   else
     {
-      _warning ("recv");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -180,7 +180,7 @@ lw6cli_is_alive (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_alive)
     {
@@ -188,10 +188,10 @@ lw6cli_is_alive (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
     }
   else
     {
-      _warning ("is_alive");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -201,7 +201,7 @@ lw6cli_repr (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->repr)
     {
@@ -209,10 +209,10 @@ lw6cli_repr (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
     }
   else
     {
-      _warning ("repr");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -222,7 +222,7 @@ lw6cli_error (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->error)
     {
@@ -230,10 +230,10 @@ lw6cli_error (lw6cli_backend_t * backend, lw6cli_connection_t * connection)
     }
   else
     {
-      _warning ("error");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
