@@ -24,38 +24,51 @@
 #include "config.h"
 #endif
 
-#include <string.h>
-
 #include "cli.h"
 
+#ifdef LW6_ALLINONE
+#include "mod-tcp/mod-tcp.h"
+#include "mod-udp/mod-udp.h"
+#include "mod-http/mod-http.h"
+#endif
+
 lw6sys_assoc_t *
 lw6cli_get_backends (int argc, char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
-  char *path;
+#ifdef LW6_ALLINONE
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
 
-  ret = lw6sys_assoc_new (NULL);
+  ret = lw6sys_assoc_new (lw6sys_free_callback);
   if (ret)
     {
-      path = lw6dyn_path_find_backend (argc, argv, "cli", "tcp");
-      if (path)
+      module_pedigree = mod_tcp_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "tcp", (void *) _("TCP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
-      path = lw6dyn_path_find_backend (argc, argv, "cli", "udp");
-      if (path)
+      module_pedigree = mod_udp_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "udp", (void *) _("UDP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
-      path = lw6dyn_path_find_backend (argc, argv, "cli", "http");
-      if (path)
+#ifdef MOD_HTTP
+      module_pedigree = mod_http_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "http", (void *) _("HTTP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
+#endif
     }
+#else
+  ret = lw6dyn_list_backends (argc, argv, "cli");
+#endif
 
   return ret;
 }
@@ -64,6 +77,34 @@ lw6cli_backend_t *
 lw6cli_create_backend (int argc, char *argv[], char *name)
 {
   lw6cli_backend_t *backend = NULL;
+
+#ifdef LW6_ALLINONE
+  if (name && !strcmp (name, "tcp"))
+    {
+      backend = mod_tcp_create_backend ();
+    }
+  if (name && !strcmp (name, "udp"))
+    {
+      backend = mod_udp_create_backend ();
+    }
+#ifdef MOD_HTTP
+  if (name && !strcmp (name, "http"))
+    {
+      backend = mod_http_create_backend ();
+    }
+#endif
+
+  if (backend)
+    {
+      backend->argc = argc;
+      backend->argv = argv;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("client backend \"%s\" does not exist"), name);
+    }
+#else
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
   backend_handle = lw6dyn_dlopen_backend (argc, argv, "cli", name);
@@ -73,7 +114,8 @@ lw6cli_create_backend (int argc, char *argv[], char *name)
       char *init_func_name;
       lw6cli_backend_t *(*init_func) ();
 
-      init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
+      init_func_name =
+	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
 	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
@@ -85,7 +127,7 @@ lw6cli_create_backend (int argc, char *argv[], char *name)
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _
-			  ("unable to find function \"%s\" in server backend \"%s\""),
+			  ("unable to find function \"%s\" in client backend \"%s\""),
 			  init_func_name, name);
 	    }
 
@@ -103,7 +145,19 @@ lw6cli_create_backend (int argc, char *argv[], char *name)
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to open server backend \"%s\""), name);
+		  _("unable to open client backend \"%s\""), name);
+    }
+#endif
+
+  if (backend)
+    {
+      static u_int32_t seq_id = 0;
+
+      backend->id = 0;
+      while (!(backend->id))
+	{
+	  backend->id = ++seq_id;
+	}
     }
 
   return backend;
@@ -112,6 +166,8 @@ lw6cli_create_backend (int argc, char *argv[], char *name)
 void
 lw6cli_destroy_backend (lw6cli_backend_t * backend)
 {
+#ifndef LW6_ALLINONE
   lw6dyn_dlclose_backend (backend->dl_handle);
+#endif
   LW6SYS_FREE (backend);
 }
