@@ -158,6 +158,33 @@ _error (void *cli_context, lw6cli_connection_t * connection)
   return ret;
 }
 
+lw6sys_module_pedigree_t *
+mod_http_get_pedigree ()
+{
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  module_pedigree =
+    (lw6sys_module_pedigree_t *)
+    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  if (module_pedigree)
+    {
+      module_pedigree->id = "http";
+      module_pedigree->category = "cli";
+      module_pedigree->name = _("HTTP (Curl)");
+      module_pedigree->readme =
+	_
+	("A network client which uses Curl to encapsulate the LW6 protocol into HTTP requests.");
+      module_pedigree->version = VERSION;
+      module_pedigree->copyright =
+	"Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
+      module_pedigree->date = __DATE__;
+      module_pedigree->time = __TIME__;
+    }
+
+  return module_pedigree;
+}
+
 lw6cli_backend_t *
 mod_http_create_backend ()
 {
