@@ -28,6 +28,10 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include <unistd.h>
+/*
+ * Need stdio.h for some old readline headers, see bug #24315 on Savannah
+ */
+#include <stdio.h>
 #include <readline/readline.h>
 #endif
 
@@ -39,6 +43,10 @@ void
 lw6cns_handler_install (void (*callback) (char *line))
 {
 #ifdef LW6_CONSOLE
+  fflush (stdin);
+  fflush (stdout);
+  fflush (stderr);
+
   lw6sys_log (LW6SYS_LOG_INFO, _("opening console"));
 
   rl_set_keyboard_input_timeout (1);
