@@ -74,6 +74,24 @@ test_handler ()
   return ret;
 }
 
+/*
+ * Testing support functions
+ */
+static int
+test_support ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("console support -> %d"), lw6cns_support ());
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 int
 lw6cns_test ()
 {
@@ -87,7 +105,7 @@ lw6cns_test ()
       lw6sys_test ();
     }
 
-  ret = test_handler ();
+  ret = test_handler () && test_support ();
 
   return ret;
 }
