@@ -37,6 +37,11 @@ extern void lw6cns_handler_remove ();
  */
 extern void lw6cns_history_add_if_needed (char *line);
 
+/*
+ * Functions in support.c
+ */
+extern int lw6cns_support ();
+
 /*
  * Functions in test.c
  */
