@@ -26,8 +26,11 @@
 
 #include "../sys/sys.h"
 #include "dyn.h"
+#include "dyn-internal.h"
+
+char *_LW6DYN_DEVEL_DEPTH_STRINGS[_LW6DYN_DEVEL_NB_DEPTHS] =
+  { "", "../", "../../", "../../../" };
 
-#define BACKEND_DEVEL_NB_DEPTHS 4
 #define BACKEND_DEVEL_PATH_FORMAT "%ssrc/lib/%s/mod-%s/.libs/libmod_%s-%s.so"
 #define BACKEND_SYSTEM_PATH_FORMAT "%s/%s/libmod_%s-%s.so"
 
@@ -35,14 +38,13 @@ static char *
 make_devel_backend_path (char *top_level_lib, char *backend_name, int depth)
 {
   char *ret = NULL;
-  static char *depth_strings[BACKEND_DEVEL_NB_DEPTHS] =
-    { "", "../", "../../", "../../../" };
 
-  if (depth >= 0 && depth < BACKEND_DEVEL_NB_DEPTHS)
+  if (depth >= 0 && depth < _LW6DYN_DEVEL_NB_DEPTHS)
     {
       ret =
-	lw6sys_new_sprintf (BACKEND_DEVEL_PATH_FORMAT, depth_strings[depth],
-			    top_level_lib, backend_name, backend_name,
+	lw6sys_new_sprintf (BACKEND_DEVEL_PATH_FORMAT,
+			    _LW6DYN_DEVEL_DEPTH_STRINGS[depth], top_level_lib,
+			    backend_name, backend_name,
 			    lw6sys_build_get_version ());
     }
 
@@ -78,7 +80,7 @@ make_system_backend_path (int argc, char *argv[], char *top_level_lib,
  *   "cli", "gfx", "snd" or "srv". This will tell the function to search
  *   for the .so file in the correct subdirectory. Think of this as a
  *   category.
- * @backend: the actual name of the backend, this is the name of the
+ * @backend_name: the actual name of the backend, this is the name of the
  *   .so file, between "libmod_" and ".so". For instance, to find
  *   "libmod_gl.so", the right argument is "gl".
  *
@@ -94,47 +96,50 @@ lw6dyn_path_find_backend (int argc, char *argv[], char *top_level_lib,
 			  char *backend_name)
 {
   char *ret = NULL;
-  char *backend_path = NULL;
+  char *system_backend_path = NULL;
+  char *devel_backend_path = NULL;
   int depth;
 
   if (!ret)
     {
-      backend_path =
+      system_backend_path =
 	make_system_backend_path (argc, argv, top_level_lib, backend_name);
-      if (backend_path)
+      if (system_backend_path)
 	{
-	  if (lw6sys_file_exists (backend_path))
+	  if (lw6sys_file_exists (system_backend_path))
 	    {
-	      ret = lw6sys_str_copy (backend_path);
+	      ret = lw6sys_str_copy (system_backend_path);
 	    }
 	  else
+	    {
+	      for (depth = 0; depth < _LW6DYN_DEVEL_NB_DEPTHS && !ret;
+		   ++depth)
+		{
+		  if (!ret)
+		    {
+		      devel_backend_path =
+			make_devel_backend_path (top_level_lib, backend_name,
+						 depth);
+		      if (devel_backend_path)
+			{
+			  if (lw6sys_file_exists (devel_backend_path))
+			    {
+			      ret = lw6sys_str_copy (devel_backend_path);
+			    }
+			  LW6SYS_FREE (devel_backend_path);
+			}
+		    }
+		}
+	    }
+
+	  if (!ret)
 	    {
 	      // module not found at all
 	      lw6sys_log (LW6SYS_LOG_NOTICE,
 			  _("couldn't find backend %s/%s in %s"),
-			  top_level_lib, backend_name, backend_path);
-	    }
-	  LW6SYS_FREE (backend_path);
-	}
-    }
-
-  if (!ret)
-    {
-      for (depth = 0; depth < BACKEND_DEVEL_NB_DEPTHS && !ret; ++depth)
-	{
-	  if (!ret)
-	    {
-	      backend_path =
-		make_devel_backend_path (top_level_lib, backend_name, depth);
-	      if (backend_path)
-		{
-		  if (lw6sys_file_exists (backend_path))
-		    {
-		      ret = lw6sys_str_copy (backend_path);
-		    }
-		  LW6SYS_FREE (backend_path);
-		}
+			  top_level_lib, backend_name, system_backend_path);
 	    }
+	  LW6SYS_FREE (system_backend_path);
 	}
     }
 
