@@ -33,6 +33,51 @@
 #define TEST_ARGV0 "program"
 #define TEST_ARGV1 "--toto=this-is-a-test"
 
+static void
+display_module (void *func_data, char *key, void *value)
+{
+  int *found;
+  char *id;
+  char *name;
+
+  found = (int *) func_data;
+  id = key;
+  name = (char *) value;
+  (*found) = 1;
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("module \"%s/%s\" \"%s\" found"),
+	      TEST_DYN_TOP_LEVEL_LIB, id, name);
+}
+
+static int
+test_list ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_assoc_t *list = NULL;
+    int found = 0;
+    int argc = TEST_ARGC;
+    char *argv[] = { TEST_ARGV0, TEST_ARGV1 };
+
+    list = lw6dyn_list_backends (argc, argv, TEST_DYN_TOP_LEVEL_LIB);
+    if (list)
+      {
+	lw6sys_assoc_map (list, display_module, (void *) &found);
+	lw6sys_assoc_free (list);
+      }
+    if (!found)
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING, _("no module found for \"%s\""),
+		    TEST_DYN_TOP_LEVEL_LIB);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+
+  return ret;
+}
+
 /*
  * Testing path functions
  */
@@ -65,6 +110,15 @@ test_path ()
   return ret;
 }
 
+/**
+ * lw6dyn_test
+ *
+ * Runs the @dyn module test suite, testing most (if not all...)
+ * functions. Will try to load libraries and query them for
+ * standard LW6-expected functions.
+ *
+ * Return value: 1 if test is successfull, 0 on error.
+ */
 int
 lw6dyn_test ()
 {
@@ -78,7 +132,7 @@ lw6dyn_test ()
       lw6sys_test ();
     }
 
-  ret = test_path ();
+  ret = test_list () && test_path ();
 
   return ret;
 }
