@@ -27,6 +27,9 @@
 
 #include "../sys/sys.h"
 
+#define LW6DYN_GET_PEDIGREE_FUNC_FORMAT "mod_%s_get_pedigree"
+#define LW6DYN_CREATE_BACKEND_FUNC_FORMAT "mod_%s_create_backend"
+
 typedef struct lw6dyn_dl_handle_s
 {
   lt_dlhandle handle;
@@ -34,25 +37,24 @@ typedef struct lw6dyn_dl_handle_s
 }
 lw6dyn_dl_handle_t;
 
-/*
- * Functions in dl.c
- */
+/* dyn-dl.c */
+extern lw6dyn_dl_handle_t *lw6dyn_dlopen_backend_so (char *so_file);
 extern lw6dyn_dl_handle_t *lw6dyn_dlopen_backend (int argc, char *argv[],
 						  char *top_level_lib,
 						  char *backend_name);
 extern int lw6dyn_dlclose_backend (lw6dyn_dl_handle_t * handle);
 extern void *lw6dyn_dlsym (lw6dyn_dl_handle_t * handle, char *func_name);
 
-/*
- * Functions in path.c
- */
+/* dyn-list.c */
+extern lw6sys_assoc_t *lw6dyn_list_backends (int argc, char *argv[],
+					     char *top_level_lib);
+
+/* dyn-path.c */
 extern char *lw6dyn_path_find_backend (int argc, char *argv[],
 				       char *top_level_lib,
 				       char *backend_name);
 
-/*
- * Functions in test.c
- */
+/* dyn-test.c */
 extern int lw6dyn_test ();
 
 #endif
