@@ -27,7 +27,7 @@
 #include "gfx.h"
 
 static void
-_warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("gfx backend function \"%s\" is not defined"), func_name);
@@ -36,7 +36,7 @@ _warning (char *func_name)
 void
 lw6gfx_display_background (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_background)
     {
@@ -44,17 +44,17 @@ lw6gfx_display_background (lw6gfx_backend_t * backend, lw6gui_look_t * look)
     }
   else
     {
-      _warning ("display_background");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_hud (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		    lw6ker_game_state_t * game_state)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_hud)
     {
@@ -62,10 +62,10 @@ lw6gfx_display_hud (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("display_hud_fg");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -73,7 +73,7 @@ lw6gfx_poll_key (lw6gfx_backend_t * backend, lw6gui_keypress_t * keypress)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_key)
     {
@@ -81,12 +81,12 @@ lw6gfx_poll_key (lw6gfx_backend_t * backend, lw6gui_keypress_t * keypress)
     }
   else
     {
-      _warning ("poll_key");
+      _warning (__FUNCTION__);
     }
 
   return ret;
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -94,7 +94,7 @@ lw6gfx_is_key_esc (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_esc)
     {
@@ -102,10 +102,10 @@ lw6gfx_is_key_esc (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_esc");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -115,7 +115,7 @@ lw6gfx_is_key_enter (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_enter)
     {
@@ -123,10 +123,10 @@ lw6gfx_is_key_enter (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_enter");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -136,7 +136,7 @@ lw6gfx_is_key_up (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_up)
     {
@@ -144,10 +144,10 @@ lw6gfx_is_key_up (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_up");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -157,7 +157,7 @@ lw6gfx_is_key_down (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_down)
     {
@@ -165,10 +165,10 @@ lw6gfx_is_key_down (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_down");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -178,7 +178,7 @@ lw6gfx_is_key_left (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_left)
     {
@@ -186,10 +186,10 @@ lw6gfx_is_key_left (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_left");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -199,7 +199,7 @@ lw6gfx_is_key_right (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_key_right)
     {
@@ -207,10 +207,10 @@ lw6gfx_is_key_right (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("is_key_right");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -220,7 +220,7 @@ lw6gfx_poll_quit (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_quit)
     {
@@ -228,10 +228,10 @@ lw6gfx_poll_quit (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("poll_quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -239,7 +239,7 @@ lw6gfx_poll_quit (lw6gfx_backend_t * backend)
 void
 lw6gfx_send_quit (lw6gfx_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->send_quit)
     {
@@ -247,10 +247,29 @@ lw6gfx_send_quit (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("send_quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
+void
+lw6gfx_get_default_keys_state (lw6gfx_backend_t * backend, int *up, int *down,
+			       int *left, int *right, int *esc, int *enter)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->get_default_keys_state)
+    {
+      backend->get_default_keys_state (backend->gfx_context, up, down, left,
+				       right, esc, enter);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -258,7 +277,7 @@ lw6gfx_get_key_state (lw6gfx_backend_t * backend, int keysym)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_key_state)
     {
@@ -266,10 +285,10 @@ lw6gfx_get_key_state (lw6gfx_backend_t * backend, int keysym)
     }
   else
     {
-      _warning ("get_key_state");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -279,7 +298,7 @@ lw6gfx_poll_mouse_move (lw6gfx_backend_t * backend, int *x, int *y)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_mouse_move)
     {
@@ -287,10 +306,10 @@ lw6gfx_poll_mouse_move (lw6gfx_backend_t * backend, int *x, int *y)
     }
   else
     {
-      _warning ("poll_mouse_move");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -300,7 +319,7 @@ lw6gfx_poll_mouse_button_left (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_mouse_button_left)
     {
@@ -308,10 +327,10 @@ lw6gfx_poll_mouse_button_left (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("poll_mouse_button_left");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -321,7 +340,7 @@ lw6gfx_poll_mouse_button_right (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_mouse_button_right)
     {
@@ -329,10 +348,10 @@ lw6gfx_poll_mouse_button_right (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("poll_mouse_button_right");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -342,7 +361,7 @@ lw6gfx_poll_mouse_wheel_up (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_mouse_wheel_up)
     {
@@ -350,10 +369,10 @@ lw6gfx_poll_mouse_wheel_up (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("poll_mouse_wheel_up");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -363,7 +382,7 @@ lw6gfx_poll_mouse_wheel_down (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_mouse_wheel_down)
     {
@@ -371,10 +390,10 @@ lw6gfx_poll_mouse_wheel_down (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("poll_mouse_wheel_down");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -383,7 +402,7 @@ void
 lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x, int *y,
 			int *button_left, int *button_right)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_mouse_state)
     {
@@ -392,10 +411,48 @@ lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x, int *y,
     }
   else
     {
-      _warning ("get_mouse_state");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
+int
+lw6gfx_warp_mouse (lw6gfx_backend_t * backend, int x, int y)
+{
+  int ret = 0;
+
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->warp_mouse)
+    {
+      ret = backend->warp_mouse (backend->gfx_context, x, y);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+
+  return ret;
+}
+
+void
+lw6gfx_show_mouse (lw6gfx_backend_t * backend, int state)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->show_mouse)
+    {
+      backend->show_mouse (backend->gfx_context, state);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -403,7 +460,7 @@ lw6gfx_poll_joystick_up (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_joystick_up)
     {
@@ -411,10 +468,10 @@ lw6gfx_poll_joystick_up (lw6gfx_backend_t * backend, int i)
     }
   else
     {
-      _warning ("poll_joystick_up");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -424,7 +481,7 @@ lw6gfx_poll_joystick_down (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_joystick_down)
     {
@@ -432,10 +489,10 @@ lw6gfx_poll_joystick_down (lw6gfx_backend_t * backend, int i)
     }
   else
     {
-      _warning ("poll_joystick_down");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -445,7 +502,7 @@ lw6gfx_poll_joystick_left (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_joystick_left)
     {
@@ -453,10 +510,10 @@ lw6gfx_poll_joystick_left (lw6gfx_backend_t * backend, int i)
     }
   else
     {
-      _warning ("poll_joystick_left");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -466,7 +523,7 @@ lw6gfx_poll_joystick_right (lw6gfx_backend_t * backend, int i)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_joystick_right)
     {
@@ -474,10 +531,10 @@ lw6gfx_poll_joystick_right (lw6gfx_backend_t * backend, int i)
     }
   else
     {
-      _warning ("poll_joystick_right");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -487,7 +544,7 @@ lw6gfx_poll_joystick_button (lw6gfx_backend_t * backend, int i, int b)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->poll_joystick_button)
     {
@@ -495,37 +552,39 @@ lw6gfx_poll_joystick_button (lw6gfx_backend_t * backend, int i, int b)
     }
   else
     {
-      _warning ("poll_joystick_button");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
 
 void
 lw6gfx_get_joystick_state (lw6gfx_backend_t * backend, int *x, int *y,
-			   int *button, int i, int b)
+			   int *button_a, int *button_b, int i, int b1,
+			   int b2)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_joystick_state)
     {
-      backend->get_joystick_state (backend->gfx_context, x, y, button, i, b);
+      backend->get_joystick_state (backend->gfx_context, x, y, button_a,
+				   button_b, i, b1, b2);
     }
   else
     {
-      _warning ("get_joystick_state");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_log (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		    char **log_list)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_log)
     {
@@ -533,16 +592,16 @@ lw6gfx_display_log (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("display_log");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_fps (lw6gfx_backend_t * backend, lw6gui_look_t * look, int fps)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_fps)
     {
@@ -550,17 +609,17 @@ lw6gfx_display_fps (lw6gfx_backend_t * backend, lw6gui_look_t * look, int fps)
     }
   else
     {
-      _warning ("display_fps");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_map_preview (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			    lw6map_level_t * level)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_map_preview)
     {
@@ -568,17 +627,17 @@ lw6gfx_display_map_preview (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("display_map_preview");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_map_zones (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			  lw6ker_game_struct_t * game_struct)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_map_zones)
     {
@@ -586,17 +645,17 @@ lw6gfx_display_map_zones (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("display_map_zones");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 			     lw6ker_game_state_t * game_state, int team_id)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_map_gradient)
     {
@@ -605,17 +664,17 @@ lw6gfx_display_map_gradient (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("display_map_gradient");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_game (lw6gfx_backend_t * backend,
 		     lw6gui_look_t * look, lw6ker_game_state_t * game_state)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_game)
     {
@@ -623,49 +682,47 @@ lw6gfx_display_game (lw6gfx_backend_t * backend,
     }
   else
     {
-      _warning ("display_game");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
-lw6gfx_pick_map_coord (lw6gfx_backend_t * backend, lw6gui_look_t * look,
-		       int *map_x, int *map_y,
-		       lw6ker_game_state_t * game_state, int screen_x,
-		       int screen_y)
+lw6gfx_display_cursors (lw6gfx_backend_t * backend,
+			lw6gui_look_t * look,
+			lw6ker_game_state_t * game_state)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
-  if (backend->pick_map_coord)
+  if (backend->display_cursors)
     {
-      backend->pick_map_coord (backend->gfx_context, look, map_x, map_y,
-			       game_state, screen_x, screen_y);
+      backend->display_cursors (backend->gfx_context, look, game_state);
     }
   else
     {
-      _warning ("pick_map_coord");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_display_menu (lw6gfx_backend_t * backend, lw6gui_look_t * look,
-		     lw6gui_menu_t * menu)
+		     lw6gui_menu_t * menu, float progress)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->display_menu)
     {
-      backend->display_menu (backend->gfx_context, look, menu);
+      backend->display_menu (backend->gfx_context, look, menu, progress);
     }
   else
     {
-      _warning ("display_menu");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
@@ -673,7 +730,7 @@ lw6gfx_pick_menuitem (lw6gfx_backend_t * backend, lw6gui_look_t * look,
 		      int *position, int *scroll, lw6gui_menu_t * menu,
 		      int screen_x, int screen_y)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->pick_menuitem)
     {
@@ -682,10 +739,10 @@ lw6gfx_pick_menuitem (lw6gfx_backend_t * backend, lw6gui_look_t * look,
     }
   else
     {
-      _warning ("pick_menuitem");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -695,7 +752,7 @@ lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->warp_mouse_on_menuitem)
     {
@@ -704,18 +761,36 @@ lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
     }
   else
     {
-      _warning ("warp_mouse_on_menuitem");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
 
+void
+lw6gfx_center_menu (lw6gfx_backend_t * backend,
+		    lw6gui_look_t * look, lw6gui_menu_t * menu, int position)
+{
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->center_menu)
+    {
+      backend->center_menu (backend->gfx_context, look, menu, position);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+}
+
 void
 lw6gfx_prepare_buffer (lw6gfx_backend_t * backend, lw6gui_look_t * look)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->prepare_buffer)
     {
@@ -723,16 +798,16 @@ lw6gfx_prepare_buffer (lw6gfx_backend_t * backend, lw6gui_look_t * look)
     }
   else
     {
-      _warning ("prepare_buffer");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_swap_buffers (lw6gfx_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->swap_buffers)
     {
@@ -740,41 +815,66 @@ lw6gfx_swap_buffers (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("swap_buffers");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
 lw6gfx_init (lw6gfx_backend_t * backend, int width,
 	     int height, int fullscreen,
 	     void (*resize_callback) (int width, int height, int fullscreen),
-	     int ticks)
+	     int ticks, int key_repeat_delay, int key_repeat_interval)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
       backend->gfx_context =
 	backend->init (backend->argc, backend->argv, width, height,
-		       fullscreen, resize_callback, ticks);
+		       fullscreen, resize_callback, ticks, key_repeat_delay,
+		       key_repeat_interval);
     }
   else
     {
-      _warning ("init");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return backend->gfx_context ? 1 : 0;
 }
 
+int
+lw6gfx_set_key_repeat (lw6gfx_backend_t * backend, int key_repeat_delay,
+		       int key_repeat_interval)
+{
+  int ret = 0;
+
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
+
+  if (backend->set_key_repeat)
+    {
+      ret =
+	backend->set_key_repeat (backend->gfx_context, key_repeat_delay,
+				 key_repeat_interval);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+
+  LW6SYS_BACKEND_FUNCTION_END;
+
+  return ret;
+}
+
 void
 lw6gfx_get_low_resolution (lw6gfx_backend_t * backend, int *width,
 			   int *height)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_low_resolution)
     {
@@ -782,17 +882,17 @@ lw6gfx_get_low_resolution (lw6gfx_backend_t * backend, int *width,
     }
   else
     {
-      _warning ("get_low_resolution");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_get_standard_resolution (lw6gfx_backend_t * backend, int *width,
 				int *height)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_standard_resolution)
     {
@@ -800,17 +900,17 @@ lw6gfx_get_standard_resolution (lw6gfx_backend_t * backend, int *width,
     }
   else
     {
-      _warning ("get_standard_resolution");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_get_high_resolution (lw6gfx_backend_t * backend, int *width,
 			    int *height)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_high_resolution)
     {
@@ -818,10 +918,10 @@ lw6gfx_get_high_resolution (lw6gfx_backend_t * backend, int *width,
     }
   else
     {
-      _warning ("get_high_resolution");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -833,7 +933,7 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->set_video_mode)
     {
@@ -843,10 +943,10 @@ lw6gfx_set_video_mode (lw6gfx_backend_t * backend, int width, int height,
     }
   else
     {
-      _warning ("set_video_mode");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -857,7 +957,7 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_video_mode)
     {
@@ -867,10 +967,10 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
     }
   else
     {
-      _warning ("get_video_mode");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -878,7 +978,7 @@ lw6gfx_get_video_mode (lw6gfx_backend_t * backend, int *width, int *height,
 void
 lw6gfx_quit (lw6gfx_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->quit)
     {
@@ -887,16 +987,16 @@ lw6gfx_quit (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6gfx_delay (lw6gfx_backend_t * backend, int ms)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->delay)
     {
@@ -904,10 +1004,10 @@ lw6gfx_delay (lw6gfx_backend_t * backend, int ms)
     }
   else
     {
-      _warning ("delay");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -915,7 +1015,7 @@ lw6gfx_get_ticks (lw6gfx_backend_t * backend)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->get_ticks)
     {
@@ -923,10 +1023,10 @@ lw6gfx_get_ticks (lw6gfx_backend_t * backend)
     }
   else
     {
-      _warning ("get_ticks");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
