@@ -25,23 +25,34 @@
 #endif
 
 #include "gfx.h"
+#ifdef LW6_ALLINONE
+#include "mod-gl/mod-gl.h"
+#endif
 
 lw6sys_assoc_t *
 lw6gfx_get_backends (int argc, char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
-  char *path;
 
-  ret = lw6sys_assoc_new (NULL);
+#ifdef LW6_ALLINONE
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  ret = lw6sys_assoc_new (lw6sys_free_callback);
   if (ret)
     {
-      path = lw6dyn_path_find_backend (argc, argv, "gfx", "gl");
-      if (path)
+#ifdef MOD_GL
+      module_pedigree = mod_gl_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "gl", (void *) _("SDL/OpenGL"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
+#endif
     }
+#else
+  ret = lw6dyn_list_backends (argc, argv, "gfx");
+#endif
 
   return ret;
 }
@@ -50,6 +61,25 @@ lw6gfx_backend_t *
 lw6gfx_create_backend (int argc, char *argv[], char *name)
 {
   lw6gfx_backend_t *backend = NULL;
+#ifdef LW6_ALLINONE
+#ifdef MOD_GL
+  if (name && !strcmp (name, "gl"))
+    {
+      backend = mod_gl_create_backend ();
+    }
+#endif
+
+  if (backend)
+    {
+      backend->argc = argc;
+      backend->argv = argv;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("graphical backend \"%s\" does not exist"), name);
+    }
+#else
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
   backend_handle = lw6dyn_dlopen_backend (argc, argv, "gfx", name);
@@ -59,7 +89,8 @@ lw6gfx_create_backend (int argc, char *argv[], char *name)
       char *init_func_name;
       lw6gfx_backend_t *(*init_func) ();
 
-      init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
+      init_func_name =
+	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
 	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
@@ -91,6 +122,18 @@ lw6gfx_create_backend (int argc, char *argv[], char *name)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to open gfx backend \"%s\""), name);
     }
+#endif
+
+  if (backend)
+    {
+      static u_int32_t seq_id = 0;
+
+      backend->id = 0;
+      while (!(backend->id))
+	{
+	  backend->id = ++seq_id;
+	}
+    }
 
   return backend;
 }
@@ -98,6 +141,8 @@ lw6gfx_create_backend (int argc, char *argv[], char *name)
 void
 lw6gfx_destroy_backend (lw6gfx_backend_t * backend)
 {
+#ifndef LW6_ALLINONE
   lw6dyn_dlclose_backend (backend->dl_handle);
+#endif
   LW6SYS_FREE (backend);
 }
