@@ -28,6 +28,8 @@
 
 #define TEST_WIDTH 640
 #define TEST_HEIGHT 480
+#define TEST_KEY_REPEAT1 500
+#define TEST_KEY_REPEAT2 200
 #define TEST_DELAY 10
 #define TEST_DURATION_SETUP 100
 #define TEST_DURATION_BACKGROUND 2000
@@ -85,7 +87,7 @@ test_init (lw6gfx_backend_t * backend)
 
     ret = ret
       && lw6gfx_init (backend, TEST_WIDTH, TEST_HEIGHT, 0, resize_callback,
-		      0);
+		      0, TEST_KEY_REPEAT1, TEST_KEY_REPEAT2);
     ticks = lw6gfx_get_ticks (backend);
     while (lw6gfx_get_ticks (backend) < ticks + TEST_DURATION_SETUP
 	   && !lw6gfx_poll_quit (backend))
@@ -183,7 +185,11 @@ test_menu (lw6gfx_backend_t * backend)
 	      {
 		lw6gfx_prepare_buffer (backend, look);
 		lw6gfx_display_background (backend, look);
-		lw6gfx_display_menu (backend, look, menu);
+		lw6gfx_display_menu (backend, look, menu,
+				     ((float)
+				      (lw6gfx_get_ticks (backend) -
+				       ticks)) /
+				     ((float) TEST_DURATION_MENU));
 		lw6gfx_swap_buffers (backend);
 		lw6gfx_delay (backend, TEST_DELAY);
 	      }
