@@ -38,6 +38,7 @@ typedef struct lw6gfx_backend_s
   void *gfx_context;
   int argc;
   char **argv;
+  u_int32_t id;
 
   void (*display_background) (void *gfx_context, lw6gui_look_t * look);
   void (*display_hud) (void *gfx_context, lw6gui_look_t * look,
@@ -51,6 +52,9 @@ typedef struct lw6gfx_backend_s
   int (*is_key_right) (void *gfx_context, int keysym);
   int (*poll_quit) (void *gfx_context);
   void (*send_quit) (void *gfx_context);
+  void (*get_default_keys_state) (void *gfx_context, int *up, int *down,
+				  int *left, int *right, int *esc,
+				  int *enter);
   int (*get_key_state) (void *gfx_context, int keysym);
   int (*poll_mouse_move) (void *gfx_context, int *x, int *y);
   int (*poll_mouse_button_left) (void *gfx_context);
@@ -59,13 +63,16 @@ typedef struct lw6gfx_backend_s
   int (*poll_mouse_wheel_down) (void *gfx_context);
   void (*get_mouse_state) (void *gfx_context, int *x, int *y,
 			   int *button_left, int *button_right);
+  int (*warp_mouse) (void *gfx_context, int x, int y);
+  void (*show_mouse) (void *gfx_context, int state);
   int (*poll_joystick_up) (void *gfx_context, int i);
   int (*poll_joystick_down) (void *gfx_context, int i);
   int (*poll_joystick_left) (void *gfx_context, int i);
   int (*poll_joystick_right) (void *gfx_context, int i);
   int (*poll_joystick_button) (void *gfx_context, int i, int b);
   void (*get_joystick_state) (void *gfx_context, int *x, int *y,
-			      int *button, int i, int b);
+			      int *button_a, int *button_b, int i, int b1,
+			      int b2);
   void (*display_log) (void *gfx_context, lw6gui_look_t * look,
 		       char **log_list);
   void (*display_fps) (void *gfx_context, lw6gui_look_t * look, int fps);
@@ -78,23 +85,26 @@ typedef struct lw6gfx_backend_s
 				int team_id);
   void (*display_game) (void *gfx_context, lw6gui_look_t * look,
 			lw6ker_game_state_t * game_state);
-  void (*pick_map_coord) (void *gfx_context, lw6gui_look_t * look, int *map_x,
-			  int *map_y, lw6ker_game_state_t * game_state,
-			  int screen_x, int screen_y);
+  void (*display_cursors) (void *gfx_context, lw6gui_look_t * look,
+			   lw6ker_game_state_t * game_state);
   void (*display_menu) (void *gfx_context, lw6gui_look_t * look,
-			lw6gui_menu_t * menu);
+			lw6gui_menu_t * menu, float progress);
   void (*pick_menuitem) (void *gfx_context, lw6gui_look_t * look,
 			 int *position, int *scroll, lw6gui_menu_t * menu,
 			 int screen_x, int screen_y);
   int (*warp_mouse_on_menuitem) (void *gfx_context, lw6gui_look_t * look,
 				 lw6gui_menu_t * menu, int position);
+  void (*center_menu) (void *gfx_context, lw6gui_look_t * look,
+		       lw6gui_menu_t * menu, int position);
   void (*prepare_buffer) (void *gfx_context, lw6gui_look_t * look);
   void (*swap_buffers) (void *gfx_context);
   void *(*init) (int argc, char *argv[], int width, int height,
 		 int fullscreen, void (*resize_callback) (int width,
 							  int height,
 							  int fullscreen),
-		 int ticks);
+		 int ticks, int key_repeat_delay, int key_repeat_interval);
+  int (*set_key_repeat) (void *gfx_context, int key_repeat_delay,
+			 int key_repeat_interval);
   void (*get_low_resolution) (void *gfx_context, int *width, int *height);
   void (*get_standard_resolution) (void *gfx_context, int *width,
 				   int *height);
@@ -132,6 +142,9 @@ extern int lw6gfx_is_key_left (lw6gfx_backend_t * backend, int keysym);
 extern int lw6gfx_is_key_right (lw6gfx_backend_t * backend, int keysym);
 extern int lw6gfx_poll_quit (lw6gfx_backend_t * backend);
 extern void lw6gfx_send_quit (lw6gfx_backend_t * backend);
+extern void lw6gfx_get_default_keys_state (lw6gfx_backend_t * backend,
+					   int *up, int *down, int *left,
+					   int *right, int *esc, int *enter);
 extern int lw6gfx_get_key_state (lw6gfx_backend_t * backend, int keysym);
 extern int lw6gfx_poll_mouse_move (lw6gfx_backend_t * backend, int *x,
 				   int *y);
@@ -142,6 +155,8 @@ extern int lw6gfx_poll_mouse_wheel_down (lw6gfx_backend_t * backend);
 extern void lw6gfx_get_mouse_state (lw6gfx_backend_t * backend, int *x,
 				    int *y, int *button_left,
 				    int *button_right);
+extern int lw6gfx_warp_mouse (lw6gfx_backend_t * backend, int x, int y);
+extern void lw6gfx_show_mouse (lw6gfx_backend_t * backend, int state);
 extern int lw6gfx_poll_joystick_up (lw6gfx_backend_t * backend, int i);
 extern int lw6gfx_poll_joystick_down (lw6gfx_backend_t * backend, int i);
 extern int lw6gfx_poll_joystick_left (lw6gfx_backend_t * backend, int i);
@@ -149,7 +164,8 @@ extern int lw6gfx_poll_joystick_right (lw6gfx_backend_t * backend, int i);
 extern int lw6gfx_poll_joystick_button (lw6gfx_backend_t * backend, int i,
 					int b);
 extern void lw6gfx_get_joystick_state (lw6gfx_backend_t * backend, int *x,
-				       int *y, int *button, int i, int b);
+				       int *y, int *button_a, int *button_b,
+				       int i, int b1, int b2);
 extern void lw6gfx_display_log (lw6gfx_backend_t * backend,
 				lw6gui_look_t * look, char **log_list);
 extern void lw6gfx_display_fps (lw6gfx_backend_t * backend,
@@ -167,13 +183,12 @@ extern void lw6gfx_display_map_gradient (lw6gfx_backend_t * backend,
 extern void lw6gfx_display_game (lw6gfx_backend_t * backend,
 				 lw6gui_look_t * look,
 				 lw6ker_game_state_t * game_state);
-extern void lw6gfx_pick_map_coord (lw6gfx_backend_t * backend,
-				   lw6gui_look_t * look, int *map_x,
-				   int *map_y,
-				   lw6ker_game_state_t * game_state,
-				   int screen_x, int screen_y);
+extern void lw6gfx_display_cursors (lw6gfx_backend_t * backend,
+				    lw6gui_look_t * look,
+				    lw6ker_game_state_t * game_state);
 extern void lw6gfx_display_menu (lw6gfx_backend_t * backend,
-				 lw6gui_look_t * look, lw6gui_menu_t * menu);
+				 lw6gui_look_t * look, lw6gui_menu_t * menu,
+				 float progress);
 extern void lw6gfx_pick_menuitem (lw6gfx_backend_t * backend,
 				  lw6gui_look_t * look, int *position,
 				  int *scroll, lw6gui_menu_t * menu,
@@ -181,6 +196,9 @@ extern void lw6gfx_pick_menuitem (lw6gfx_backend_t * backend,
 extern int lw6gfx_warp_mouse_on_menuitem (lw6gfx_backend_t * backend,
 					  lw6gui_look_t * look,
 					  lw6gui_menu_t * menu, int position);
+extern void lw6gfx_center_menu (lw6gfx_backend_t * backend,
+				lw6gui_look_t * look, lw6gui_menu_t * menu,
+				int position);
 extern void lw6gfx_prepare_buffer (lw6gfx_backend_t * backend,
 				   lw6gui_look_t * look);
 extern void lw6gfx_swap_buffers (lw6gfx_backend_t * backend);
@@ -188,7 +206,11 @@ extern int lw6gfx_init (lw6gfx_backend_t * backend, int width,
 			int height, int fullscreen,
 			void (*resize_callback) (int width,
 						 int height, int fullscreen),
-			int ticks);
+			int ticks, int key_repeat_delay,
+			int key_repeat_interval);
+extern int lw6gfx_set_key_repeat (lw6gfx_backend_t * backend,
+				  int key_repeat_delay,
+				  int key_repeat_interval);
 extern void lw6gfx_get_low_resolution (lw6gfx_backend_t * backend, int *width,
 				       int *height);
 extern void lw6gfx_get_standard_resolution (lw6gfx_backend_t * backend,
