@@ -27,7 +27,7 @@
 #include "gl-background.h"
 
 static void
-warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("background backend function \"%s\" is not defined"));
@@ -43,7 +43,7 @@ mod_gl_background_init (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("background_init");
+      _warning (__FUNCTION__);
     }
 
   return backend->background_context ? 1 : 0;
@@ -59,7 +59,7 @@ mod_gl_background_quit (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("background_quit");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -74,6 +74,6 @@ mod_gl_background_display (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("background_display");
+      _warning (__FUNCTION__);
     }
 }
