@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,12 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-#include <GL/glu.h>
-#include <SDL/SDL_image.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
+#include <string.h>
+
 #include "../../../gfx.h"
 #include "../../../../cfg/cfg.h"
 #include "gl-bubbles.h"
@@ -78,8 +77,8 @@ load_consts (mod_gl_utils_context_t * utils_context,
 
       ret =
 	lw6cfg_read_key_value_xml_file (const_file, read_callback,
-					(void *) &(bubbles_context->
-						   const_data));
+					(void *)
+					&(bubbles_context->const_data));
 
       LW6SYS_FREE (const_file);
     }
@@ -150,23 +149,15 @@ load_textures (mod_gl_utils_context_t * utils_context,
 	       _mod_gl_background_bubbles_context_t * bubbles_context)
 {
   int ret = 0;
+  lw6gui_look_t *default_look;
 
-  ret =
-    ((bubbles_context->texture_data.background =
-      mod_gl_utils_load_texture (utils_context,
-				 bubbles_context->image_data.background)) !=
-     0)
-    &&
-    ((bubbles_context->texture_data.bubble =
-      mod_gl_utils_load_texture (utils_context,
-				 bubbles_context->image_data.bubble)) != 0);
-
-  if (!ret)
+  default_look = lw6gui_look_new (NULL);
+  if (default_look)
     {
-      /*
-       * If we can't load textures, we simply exit the game...
-       */
-      exit (1);
+      ret =
+	_mod_gl_background_bubbles_colorize (utils_context, bubbles_context,
+					     default_look);
+      lw6gui_look_free (default_look);
     }
 
   return ret;
