@@ -60,8 +60,8 @@ _mod_gl_background_bubbles_texture_data_t;
 typedef struct _mod_gl_background_bubbles_lastest_colors_s
 {
   int colorize;
-  lw6map_color_couple_t base;
-  lw6map_color_couple_t alternate;
+  lw6map_color_couple_t root;
+  lw6map_color_couple_t stuff;
 }
 _mod_gl_background_bubbles_latest_colors_t;
 
