@@ -20,11 +20,12 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <time.h>
 
-#include "config.h"
 #include "../../../gfx.h"
 #include "gl-floating.h"
 #include "gl-floating-internal.h"
