@@ -27,7 +27,7 @@
 #include "gl-hud.h"
 
 static void
-warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("hud backend function \"%s\" is not defined"));
@@ -43,7 +43,7 @@ mod_gl_hud_init (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("hud_init");
+      _warning (__FUNCTION__);
     }
 
   return backend->hud_context ? 1 : 0;
@@ -59,7 +59,7 @@ mod_gl_hud_quit (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("hud_quit");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -75,6 +75,6 @@ mod_gl_hud_display (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("hud_display");
+      _warning (__FUNCTION__);
     }
 }
