@@ -20,10 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <stdio.h>
-#include <string.h>
-
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../../../gfx.h"
 #include "gl-tactical.h"
 #include "gl-tactical-internal.h"
