@@ -45,7 +45,7 @@ read_callback (void *callback_data, char *element, char *key, char *value)
       lw6cfg_read_xml_int (key, value, "max-displayed-items",
 			   &const_data->max_displayed_items);
       lw6cfg_read_xml_int (key, value, "slices1", &const_data->slices1);
-      lw6cfg_read_xml_int (key, value, "slices_min", &const_data->slices_min);
+      lw6cfg_read_xml_int (key, value, "slices-min", &const_data->slices_min);
       lw6cfg_read_xml_int (key, value, "stacks", &const_data->stacks);
       lw6cfg_read_xml_int (key, value, "oscil-period",
 			   &const_data->oscil_period);
@@ -62,7 +62,8 @@ read_callback (void *callback_data, char *element, char *key, char *value)
     {
       lw6cfg_read_xml_float (key, value, "radius1", &const_data->radius1);
       lw6cfg_read_xml_float (key, value, "between1", &const_data->between1);
-      lw6cfg_read_xml_float (key, value, "height", &const_data->height);
+      lw6cfg_read_xml_float (key, value, "cyl-height",
+			     &const_data->cyl_height);
       lw6cfg_read_xml_float (key, value, "oscil-range1",
 			     &const_data->oscil_range1);
       lw6cfg_read_xml_float (key, value, "rotate-offset",
@@ -71,6 +72,12 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 			     &const_data->sphere_radius1);
       lw6cfg_read_xml_float (key, value, "sphere-between1",
 			     &const_data->sphere_between1);
+      lw6cfg_read_xml_float (key, value, "progress-offset",
+			     &const_data->progress_offset);
+      lw6cfg_read_xml_float (key, value, "progress-radius",
+			     &const_data->progress_radius);
+      lw6cfg_read_xml_float (key, value, "progress-cyl-height",
+			     &const_data->progress_cyl_height);
     }
 }
 
