@@ -101,8 +101,8 @@ get_bg_color (lw6gui_look_t * look, lw6gui_menuitem_t * menuitem)
 	{
 	  // todo, get it from config...
 	  color =
-	    mod_gl_utils_color_8_to_sdl (look->style.
-					 team_colors[menuitem->value]);
+	    mod_gl_utils_color_8_to_sdl (look->
+					 style.team_colors[menuitem->value]);
 	}
       else
 	{
@@ -158,13 +158,13 @@ draw_button (mod_gl_utils_context_t * utils_context,
 				   fg_color, bg_color);
 	  if (text_surface != NULL)
 	    {
-	      utils_context->surface_counter.new_counter++;
+	      utils_context->surface_counter.new_counter++;	// TTF_Render...
 	      outline_surface =
 		mod_gl_utils_create_surface (utils_context,
 					     text_surface->w +
 					     2 *
-					     utils_context->const_data.
-					     menu_font_size,
+					     utils_context->
+					     const_data.menu_font_size,
 					     MOD_GL_UTILS_MENU_TEXTURE_H);
 	      if (outline_surface != NULL)
 		{
@@ -297,7 +297,7 @@ void
 _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
 			       _mod_gl_menu_cylinder_context_t *
 			       cylinder_context, lw6gui_look_t * look,
-			       lw6gui_menu_t * menu)
+			       lw6gui_menu_t * menu, float progress)
 {
   int i, j, n;
   int blink_state;
@@ -309,8 +309,8 @@ _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
   prepare_view (utils_context, cylinder_context);
 
   lw6gui_menu_update_display_range (menu,
-				    cylinder_context->const_data.
-				    max_displayed_items);
+				    cylinder_context->
+				    const_data.max_displayed_items);
 
   blink_state =
     mod_gl_utils_get_ticks (utils_context) /
@@ -333,14 +333,19 @@ _mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
 		    blink_state ? 0 : 1,
 		    cylinder_context->const_data.nb_spheres);
     }
+  if (progress > 0.0f && progress < 1.0f)	// strict, to disable it when complete
+    {
+      _mod_gl_menu_cylinder_draw_progress (utils_context, cylinder_context,
+					   look, progress);
+    }
 }
 
 void
 mod_gl_menu_cylinder_display (mod_gl_utils_context_t * utils_context,
 			      void *cylinder_context, lw6gui_look_t * look,
-			      lw6gui_menu_t * menu)
+			      lw6gui_menu_t * menu, float progress)
 {
   _mod_gl_menu_cylinder_display (utils_context,
 				 (_mod_gl_menu_cylinder_context_t *)
-				 cylinder_context, look, menu);
+				 cylinder_context, look, menu, progress);
 }
