@@ -56,7 +56,7 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
   if (cyl != NULL)
     {
       float radius;
-      float height;
+      float cyl_height;
       int slices;
       float y;
       float dy;
@@ -67,8 +67,8 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 	}
 
       radius = cylinder_context->const_data.radius1 / n;
-      height =
-	cylinder_context->const_data.height *
+      cyl_height =
+	cylinder_context->const_data.cyl_height *
 	((float) utils_context->screen.width) /
 	((float) utils_context->screen.height);
       y =
@@ -81,9 +81,7 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
 								   (utils_context)))
 								 /
 								 ((float)
-								  cylinder_context->
-								  const_data.
-								  oscil_period))
+								  cylinder_context->const_data.oscil_period))
 								+
 								(((float) i) /
 								 ((float)
@@ -97,11 +95,11 @@ _mod_gl_menu_cylinder_draw_cylinder (mod_gl_utils_context_t * utils_context,
       glMatrixMode (GL_MODELVIEW);
       glPushMatrix ();
       glLoadIdentity ();
-      glTranslatef (-height / 2.0f, 0.0f, -1.0f);
+      glTranslatef (-cyl_height / 2.0f, 0.0f, -1.0f);
       glRotatef (90.0f, 0.0f, 1.0f, 0.0f);
       glTranslatef (0.0f, y + dy, 0.0f);
 
-      gluCylinder (cyl, radius, radius, height, slices,
+      gluCylinder (cyl, radius, radius, cyl_height, slices,
 		   cylinder_context->const_data.stacks);
 
       glMatrixMode (GL_MODELVIEW);
