@@ -30,7 +30,7 @@ typedef struct _mod_gl_menu_cylinder_const_data_s
   int max_displayed_items;
   float radius1;
   float between1;
-  float height;
+  float cyl_height;
   int slices1;
   int slices_min;
   int stacks;
@@ -43,6 +43,9 @@ typedef struct _mod_gl_menu_cylinder_const_data_s
   int sphere_slices1;
   int sphere_slices_min;
   int sphere_blink_period;
+  float progress_offset;
+  float progress_radius;
+  float progress_cyl_height;
 }
 _mod_gl_menu_cylinder_const_data_t;
 
@@ -52,6 +55,16 @@ typedef struct _mod_gl_menu_cylinder_context_s
 }
 _mod_gl_menu_cylinder_context_t;
 
+/*
+ * In center.c
+ */
+extern void
+_mod_gl_menu_cylinder_center_on_menuitem (mod_gl_utils_context_t *
+					  utils_context,
+					  _mod_gl_menu_cylinder_context_t
+					  * cylinder_context,
+					  lw6gui_look_t * look,
+					  lw6gui_menu_t * menu, int position);
 /*
  * In display.c
  */
@@ -60,7 +73,8 @@ extern void _mod_gl_menu_cylinder_display (mod_gl_utils_context_t *
 					   _mod_gl_menu_cylinder_context_t *
 					   cylinder_context,
 					   lw6gui_look_t * look,
-					   lw6gui_menu_t * menu);
+					   lw6gui_menu_t * menu,
+					   float progress);
 
 /*
  * In data.c
@@ -105,6 +119,17 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
 				 int *position, int *scroll,
 				 lw6gui_menu_t * menu, int screen_x,
 				 int screen_y);
+
+/*
+ * In progress.c
+ */
+extern void _mod_gl_menu_cylinder_draw_progress (mod_gl_utils_context_t *
+						 utils_context,
+						 _mod_gl_menu_cylinder_context_t
+						 * cylinder_context,
+						 lw6gui_look_t * look,
+						 float progress);
+
 /*
  * In setup.c
  */
