@@ -111,8 +111,8 @@ _mod_gl_menu_cylinder_pick_item (mod_gl_utils_context_t * utils_context,
   GLint select_hits;
 
   lw6gui_menu_update_display_range (menu,
-				    cylinder_context->const_data.
-				    max_displayed_items);
+				    cylinder_context->
+				    const_data.max_displayed_items);
 
   glSelectBuffer (SELECT_BUFFER_SIZE, select_buffer);
   glRenderMode (GL_SELECT);
