@@ -39,8 +39,8 @@ draw_point_x_y_z (float x, float y, float z)
   glPushMatrix ();
   glLoadIdentity ();
   glTranslatef (x, y, z);
-  glBegin (GL_POINT);
-  glVertex3f (0, 0, 0);
+  glBegin (GL_POINTS);
+  glVertex3f (0.0f, 0.0f, 0.0f);
   glEnd ();
   glMatrixMode (GL_MODELVIEW);
   glPopMatrix ();
@@ -63,8 +63,8 @@ _mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t *
   float mouse_x, mouse_y;
 
   lw6gui_menu_update_display_range (menu,
-				    cylinder_context->const_data.
-				    max_displayed_items);
+				    cylinder_context->
+				    const_data.max_displayed_items);
 
   memset (feedback_buffer, 0, sizeof (GLfloat) * WARP_BUFFER_SIZE);
   mod_gl_utils_set_render_mode_3d_warp (utils_context);
@@ -80,8 +80,8 @@ _mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t *
 
       glFeedbackBuffer (WARP_BUFFER_SIZE, GL_2D, feedback_buffer);
       glRenderMode (GL_FEEDBACK);
-      draw_point_x_y_z (0, y, -1.0f);
-      feedback_size = glRenderMode (GL_FEEDBACK);
+      draw_point_x_y_z (0.0f, y, -1.0f);
+      feedback_size = glRenderMode (GL_RENDER);
 
       if (feedback_size >= WARP_BUFFER_SIZE)
 	{
@@ -101,6 +101,11 @@ _mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t *
 		utils_context->screen.height - mouse_y;
 	    }
 	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_DEBUG, _("unable to warp on menuitem %d"),
+		      position);
+	}
     }
 
   return ret;
