@@ -27,17 +27,30 @@
 #include "../../gl-utils/gl-utils.h"
 #include "../gl-menu.h"
 
+/*
+ * In backend.c
+ */
 extern mod_gl_menu_backend_t
   * mod_gl_menu_cylinder_create_backend (mod_gl_utils_context_t *
 					 utils_context);
 
+/*
+ * In center.c
+ */
+extern void mod_gl_menu_cylinder_center (mod_gl_utils_context_t *
+					 utils_context,
+					 void *cylinder_context,
+					 lw6gui_look_t * look,
+					 lw6gui_menu_t * menu, int position);
+
 /*
  * In display.c
  */
 extern void mod_gl_menu_cylinder_display (mod_gl_utils_context_t *
 					  utils_context, void *menu_context,
 					  lw6gui_look_t * look,
-					  lw6gui_menu_t * menu);
+					  lw6gui_menu_t * menu,
+					  float progress);
 
 /*
  * In pick.c
@@ -67,4 +80,15 @@ extern int mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t
 							lw6gui_menu_t * menu,
 							int position);
 
+/*
+ * In warp.c
+ */
+extern int mod_gl_menu_cylinder_warp_mouse_on_menuitem (mod_gl_utils_context_t
+							* utils_context,
+							void
+							*cylinder_context,
+							lw6gui_look_t * look,
+							lw6gui_menu_t * menu,
+							int position);
+
 #endif
