@@ -27,7 +27,7 @@
 #include "gl-menu.h"
 
 static void
-warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("menu backend function \"%s\" is not defined"));
@@ -43,7 +43,7 @@ mod_gl_menu_init (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("menu_init");
+      _warning (__FUNCTION__);
     }
 
   return backend->menu_context ? 1 : 0;
@@ -59,22 +59,23 @@ mod_gl_menu_quit (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("menu_quit");
+      _warning (__FUNCTION__);
     }
 }
 
 void
 mod_gl_menu_display (mod_gl_utils_context_t * utils_context,
 		     mod_gl_menu_backend_t * backend, lw6gui_look_t * look,
-		     lw6gui_menu_t * menu)
+		     lw6gui_menu_t * menu, float progress)
 {
   if (backend->display)
     {
-      backend->display (utils_context, backend->menu_context, look, menu);
+      backend->display (utils_context, backend->menu_context, look, menu,
+			progress);
     }
   else
     {
-      warning ("menu_display");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -92,7 +93,7 @@ mod_gl_menu_pick_item (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("menu_pick_item");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -112,8 +113,24 @@ mod_gl_menu_warp_mouse_on_menuitem (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("menu_warp_mouse_on_menuitem");
+      _warning (__FUNCTION__);
     }
 
   return ret;
 }
+
+void
+mod_gl_menu_center (mod_gl_utils_context_t * utils_context,
+		    mod_gl_menu_backend_t * backend,
+		    lw6gui_look_t * look, lw6gui_menu_t * menu, int position)
+{
+  if (backend->center)
+    {
+      backend->center (utils_context, backend->menu_context,
+		       look, menu, position);
+    }
+  else
+    {
+      _warning (__FUNCTION__);
+    }
+}
