@@ -37,7 +37,7 @@ mod_gl_utils_colorize_image (mod_gl_utils_context_t *
   int x, y;
   lw6sys_color_8_t color_8;
   lw6sys_color_hsv_t color_hsv;
-  float a;
+  int a;
 
   colorized_image =
     mod_gl_utils_create_surface (utils_context, image->w, image->h);
