@@ -44,6 +44,10 @@ read_callback (void *callback_data, char *element, char *key, char *value)
     {
       lw6cfg_read_xml_int (key, value, "menu-font-size",
 			   &const_data->menu_font_size);
+      lw6cfg_read_xml_int (key, value, "hud-font-size",
+			   &const_data->hud_font_size);
+      lw6cfg_read_xml_int (key, value, "cursor-font-size",
+			   &const_data->cursor_font_size);
       lw6cfg_read_xml_int (key, value, "system-font-size",
 			   &const_data->system_font_size);
       lw6cfg_read_xml_int (key, value, "system-font-dw",
@@ -62,6 +66,8 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 
   if (!strcmp (element, "float"))
     {
+      lw6cfg_read_xml_float (key, value, "mode-sleep",
+			     &const_data->mode_sleep);
       lw6cfg_read_xml_float (key, value, "quit-sleep",
 			     &const_data->quit_sleep);
       lw6cfg_read_xml_float (key, value, "persp-fovy",
