@@ -156,17 +156,13 @@ unload_font (TTF_Font * font)
     {
       TTF_CloseFont (font);
     }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("trying to close NULL font"));
-    }
 }
 
 /*
  * Loads fonts
  */
 int
-mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
+_mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
 {
   int ret = 0;
 
@@ -177,6 +173,14 @@ mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
       load_font (utils_context, FONT_FILE,
 		 utils_context->const_data.menu_font_size)) != NULL)
     &&
+    ((utils_context->font_data.hud =
+      load_font (utils_context, FONT_FILE,
+		 utils_context->const_data.hud_font_size)) != NULL)
+    &&
+    ((utils_context->font_data.cursor =
+      load_font (utils_context, FONT_FILE,
+		 utils_context->const_data.cursor_font_size)) != NULL)
+    &&
     ((utils_context->font_data.system =
       load_font (utils_context, FONT_FILE,
 		 utils_context->const_data.system_font_size)) != NULL);
@@ -196,10 +200,12 @@ mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context)
  * Unload fonts, free memory
  */
 void
-mod_gl_utils_unload_fonts (mod_gl_utils_context_t * utils_context)
+_mod_gl_utils_unload_fonts (mod_gl_utils_context_t * utils_context)
 {
-  unload_font (utils_context->font_data.menu);
   unload_font (utils_context->font_data.system);
+  unload_font (utils_context->font_data.cursor);
+  unload_font (utils_context->font_data.hud);
+  unload_font (utils_context->font_data.menu);
 
   memset (&utils_context->font_data, 0, sizeof (mod_gl_utils_font_data_t));
 }
@@ -216,7 +222,7 @@ mod_gl_utils_load_data (mod_gl_utils_context_t * utils_context)
   ret =
     ((utils_context->texture_data.to_delete = lw6sys_list_new (NULL)) != NULL)
     && _mod_gl_utils_load_consts (utils_context)
-    && mod_gl_utils_load_fonts (utils_context);
+    && _mod_gl_utils_load_fonts (utils_context);
 
   look = lw6gui_look_new (NULL);
   if (look)
@@ -242,12 +248,15 @@ mod_gl_utils_unload_data (mod_gl_utils_context_t * utils_context)
   mod_gl_utils_clear_texturecache (utils_context);
 
   mod_gl_utils_delete_scheduled_textures (utils_context);
-  LW6SYS_FREE (utils_context->texture_data.to_delete);
+  if (utils_context->texture_data.to_delete)
+    {
+      LW6SYS_FREE (utils_context->texture_data.to_delete);
+    }
 
   memset (&utils_context->texture_data, 0,
 	  sizeof (mod_gl_utils_texture_data_t));
 
-  mod_gl_utils_unload_fonts (utils_context);
+  _mod_gl_utils_unload_fonts (utils_context);
 
   mod_gl_utils_texture_1x1_clear (utils_context);
 
