@@ -162,16 +162,18 @@ check_joystick_button_index (int b)
   return ret;
 }
 
-void
+static void
 update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		      int axis, int value)
 {
   mod_gl_utils_joystick_state_t *joystick_state = NULL;
+  int ticks;
 
   if (check_joystick_index (which))
     {
       joystick_state =
 	&(utils_context->joysticks_state.joystick_state[which]);
+      ticks = mod_gl_utils_get_ticks (utils_context);
       switch (axis)
 	{
 	case 0:
@@ -181,6 +183,8 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		{
 		  joystick_state->left.pressed = 1;
 		  (joystick_state->left.queue)++;
+		  joystick_state->left.last_press = ticks;
+		  joystick_state->left.last_repeat = 0;
 		}
 	      else
 		{
@@ -197,6 +201,8 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		{
 		  joystick_state->right.pressed = 1;
 		  (joystick_state->right.queue)++;
+		  joystick_state->right.last_press = ticks;
+		  joystick_state->right.last_repeat = 0;
 		}
 	      else
 		{
@@ -215,6 +221,8 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		{
 		  joystick_state->up.pressed = 1;
 		  (joystick_state->up.queue)++;
+		  joystick_state->up.last_press = ticks;
+		  joystick_state->up.last_repeat = 0;
 		}
 	      else
 		{
@@ -232,6 +240,8 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
 		{
 		  joystick_state->down.pressed = 1;
 		  (joystick_state->down.queue)++;
+		  joystick_state->down.last_press = ticks;
+		  joystick_state->down.last_repeat = 0;
 		}
 	      else
 		{
@@ -248,33 +258,34 @@ update_joystick_axis (mod_gl_utils_context_t * utils_context, int which,
     }
 }
 
-void
-joystick_button_down (mod_gl_utils_joysticks_state_t * joysticks_state,
-		      int i, int b)
+static void
+joystick_button_down (mod_gl_utils_context_t * utils_context, int i, int b)
 {
   mod_gl_utils_joystick_state_t *joystick_state;
 
   if (check_joystick_index (i))
     {
-      joystick_state = &(joysticks_state->joystick_state[i]);
+      joystick_state = &(utils_context->joysticks_state.joystick_state[i]);
 
       if (check_joystick_button_index (b))
 	{
 	  joystick_state->buttons[b].pressed = 1;
 	  joystick_state->buttons[b].queue++;
+	  joystick_state->buttons[b].last_press =
+	    mod_gl_utils_get_ticks (utils_context);
+	  joystick_state->buttons[b].last_repeat = 0;
 	}
     }
 }
 
-void
-joystick_button_up (mod_gl_utils_joysticks_state_t * joysticks_state,
-		    int i, int b)
+static void
+joystick_button_up (mod_gl_utils_context_t * utils_context, int i, int b)
 {
   mod_gl_utils_joystick_state_t *joystick_state;
 
   if (check_joystick_index (i))
     {
-      joystick_state = &(joysticks_state->joystick_state[i]);
+      joystick_state = &(utils_context->joysticks_state.joystick_state[i]);
 
       if (check_joystick_button_index (b))
 	{
@@ -283,6 +294,60 @@ joystick_button_up (mod_gl_utils_joysticks_state_t * joysticks_state,
     }
 }
 
+static void
+update_button_repeat (mod_gl_utils_button_state_t * button_state, int ticks,
+		      int delay, int interval)
+{
+  if (button_state->pressed)
+    {
+      if ((delay > 0 && button_state->last_repeat == 0
+	   && button_state->last_press <= ticks - delay) || (interval > 0
+							     &&
+							     button_state->
+							     last_repeat != 0
+							     && button_state->
+							     last_repeat <=
+							     ticks -
+							     interval))
+	{
+	  (button_state->queue)++;
+	  button_state->last_repeat = ticks;
+	}
+    }
+}
+
+static void
+update_joystick_repeat (mod_gl_utils_context_t * utils_context)
+{
+  int i, b, ticks, delay, interval;
+
+  ticks = mod_gl_utils_get_ticks (utils_context);
+  delay = utils_context->repeat_settings.delay;
+  interval = utils_context->repeat_settings.interval;
+  for (i = 0; i < MOD_GL_NB_JOYSTICKS; ++i)
+    {
+      update_button_repeat (&
+			    (utils_context->joysticks_state.joystick_state[i].
+			     left), ticks, delay, interval);
+      update_button_repeat (&
+			    (utils_context->joysticks_state.joystick_state[i].
+			     right), ticks, delay, interval);
+      update_button_repeat (&
+			    (utils_context->joysticks_state.joystick_state[i].
+			     up), ticks, delay, interval);
+      update_button_repeat (&
+			    (utils_context->joysticks_state.joystick_state[i].
+			     down), ticks, delay, interval);
+      for (b = 0; b < MOD_GL_NB_JOYSTICK_BUTTONS; ++b)
+	{
+	  update_button_repeat (&
+				(utils_context->joysticks_state.
+				 joystick_state[i].buttons[b]), ticks, delay,
+				interval);
+	}
+    }
+}
+
 static void
 log_event (SDL_Event * event)
 {
@@ -402,19 +467,17 @@ log_event (SDL_Event * event)
 static int
 poll (mod_gl_utils_context_t * utils_context)
 {
-  int ret;
+  int ret = 0;
   mod_gl_utils_keyboard_state_t *keyboard_state =
     &utils_context->keyboard_state;
   mod_gl_utils_mouse_state_t *mouse_state = &utils_context->mouse_state;
-  mod_gl_utils_joysticks_state_t *joysticks_state =
-    &utils_context->joysticks_state;
 
   SDL_Event event;
 
-  ret = SDL_PollEvent (&event) ? 1 : 0;
-
-  if (ret)
+  while (SDL_PollEvent (&event))
     {
+      ret = 1;
+
       log_event (&event);
       switch (event.type)
 	{
@@ -447,11 +510,11 @@ poll (mod_gl_utils_context_t * utils_context)
 				event.jaxis.axis, event.jaxis.value);
 	  break;
 	case SDL_JOYBUTTONDOWN:
-	  joystick_button_down (joysticks_state, event.jbutton.which,
+	  joystick_button_down (utils_context, event.jbutton.which,
 				event.jbutton.button);
 	  break;
 	case SDL_JOYBUTTONUP:
-	  joystick_button_up (joysticks_state, event.jbutton.which,
+	  joystick_button_up (utils_context, event.jbutton.which,
 			      event.jbutton.button);
 	  break;
 	case SDL_VIDEORESIZE:
@@ -459,7 +522,7 @@ poll (mod_gl_utils_context_t * utils_context)
 					  event.resize.h);
 	  break;
 	case SDL_VIDEOEXPOSE:
-	  mod_gl_utils_sync_mode (utils_context);
+	  mod_gl_utils_sync_mode (utils_context, 0);
 	  break;
 	}
     }
@@ -512,7 +575,7 @@ mod_gl_utils_poll_key (mod_gl_utils_context_t * utils_context,
 int
 mod_gl_utils_is_key_esc (mod_gl_utils_context_t * utils_context, int keysym)
 {
-  return (keysym == SDLK_ESCAPE);
+  return ((keysym == SDLK_ESCAPE) || (keysym == SDLK_HOME));
 }
 
 int
@@ -584,6 +647,43 @@ mod_gl_utils_get_key_state (mod_gl_utils_context_t * utils_context,
   return ret;
 }
 
+void
+mod_gl_utils_get_default_keys_state (mod_gl_utils_context_t * utils_context,
+				     int *up, int *down, int *left,
+				     int *right, int *esc, int *enter)
+{
+  if (up)
+    {
+      (*up) = mod_gl_utils_get_key_state (utils_context, SDLK_UP) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_KP8);
+    }
+  if (down)
+    {
+      (*down) = mod_gl_utils_get_key_state (utils_context, SDLK_DOWN) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_KP2);
+    }
+  if (left)
+    {
+      (*left) = mod_gl_utils_get_key_state (utils_context, SDLK_LEFT) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_KP4);
+    }
+  if (right)
+    {
+      (*right) = mod_gl_utils_get_key_state (utils_context, SDLK_RIGHT) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_KP6);
+    }
+  if (esc)
+    {
+      (*esc) = mod_gl_utils_get_key_state (utils_context, SDLK_ESCAPE) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_HOME);
+    }
+  if (enter)
+    {
+      (*enter) = mod_gl_utils_get_key_state (utils_context, SDLK_RETURN) ||
+	mod_gl_utils_get_key_state (utils_context, SDLK_KP_ENTER);
+    }
+}
+
 /*
  * Returns true if mouse is moved. Even if not moved, x & y
  * contains the position of the mouse.
@@ -669,6 +769,27 @@ mod_gl_utils_get_mouse_state (mod_gl_utils_context_t * utils_context,
   (*button_right) = mouse_state->button_right.pressed;
 }
 
+int
+mod_gl_utils_warp_mouse (mod_gl_utils_context_t * utils_context, int x, int y)
+{
+  int ret = 0;
+
+  if (x >= 0 && x < utils_context->screen.width && y >= 0
+      && y < utils_context->screen.height)
+    {
+      ret = 1;
+      SDL_WarpMouse (x, y);
+    }
+
+  return ret;
+}
+
+void
+mod_gl_utils_show_mouse (mod_gl_utils_context_t * utils_context, int state)
+{
+  SDL_ShowCursor (state ? SDL_ENABLE : SDL_DISABLE);
+}
+
 static SDL_Joystick *
 get_joystick (mod_gl_utils_context_t * utils_context, int i)
 {
@@ -693,11 +814,12 @@ mod_gl_utils_poll_joystick_up (mod_gl_utils_context_t * utils_context, int i)
       if (check_joystick_index (i))
 	{
 	  poll (utils_context);
+	  update_joystick_repeat (utils_context);
 
 	  ret =
 	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  up));
+			 (utils_context->joysticks_state.
+			  joystick_state[i].up));
 	}
     }
 
@@ -715,11 +837,12 @@ mod_gl_utils_poll_joystick_down (mod_gl_utils_context_t * utils_context,
       if (check_joystick_index (i))
 	{
 	  poll (utils_context);
+	  update_joystick_repeat (utils_context);
 
 	  ret =
 	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  down));
+			 (utils_context->joysticks_state.
+			  joystick_state[i].down));
 	}
     }
 
@@ -737,11 +860,12 @@ mod_gl_utils_poll_joystick_left (mod_gl_utils_context_t * utils_context,
       if (check_joystick_index (i))
 	{
 	  poll (utils_context);
+	  update_joystick_repeat (utils_context);
 
 	  ret =
 	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  left));
+			 (utils_context->joysticks_state.
+			  joystick_state[i].left));
 	}
     }
 
@@ -759,11 +883,12 @@ mod_gl_utils_poll_joystick_right (mod_gl_utils_context_t * utils_context,
       if (check_joystick_index (i))
 	{
 	  poll (utils_context);
+	  update_joystick_repeat (utils_context);
 
 	  ret =
 	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  right));
+			 (utils_context->joysticks_state.
+			  joystick_state[i].right));
 	}
     }
 
@@ -781,11 +906,12 @@ mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
       if (check_joystick_index (i) && check_joystick_button_index (b))
 	{
 	  poll (utils_context);
+	  update_joystick_repeat (utils_context);
 
 	  ret =
 	    poll_button (&
-			 (utils_context->joysticks_state.joystick_state[i].
-			  buttons[b]));
+			 (utils_context->joysticks_state.
+			  joystick_state[i].buttons[b]));
 	}
     }
 
@@ -795,16 +921,30 @@ mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
 void
 mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 				 utils_context, int *x, int *y,
-				 int *button, int i, int b)
+				 int *button_a, int *button_b, int i, int b1,
+				 int b2)
 {
   SDL_Joystick *joystick = NULL;
   int num_axes;
   int axe_value;
   int num_buttons;
 
-  (*x) = 0;
-  (*y) = 0;
-  (*button) = 0;
+  if (x)
+    {
+      (*x) = 0;
+    }
+  if (y)
+    {
+      (*y) = 0;
+    }
+  if (button_a)
+    {
+      (*button_a) = 0;
+    }
+  if (button_b)
+    {
+      (*button_b) = 0;
+    }
 
   if (utils_context->joysticks_state.supported)
     {
@@ -815,15 +955,19 @@ mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 
 	  if (num_axes >= 1)
 	    {
-	      axe_value = SDL_JoystickGetAxis (joystick, 0);
-	      if (axe_value > utils_context->const_data.joystick_limit_right)
+	      if (x)
 		{
-		  (*x) = 1;
-		}
-	      else if (axe_value <
-		       utils_context->const_data.joystick_limit_left)
-		{
-		  (*x) = -1;
+		  axe_value = SDL_JoystickGetAxis (joystick, 0);
+		  if (axe_value >
+		      utils_context->const_data.joystick_limit_right)
+		    {
+		      (*x) = 1;
+		    }
+		  else if (axe_value <
+			   utils_context->const_data.joystick_limit_left)
+		    {
+		      (*x) = -1;
+		    }
 		}
 	    }
 	  else
@@ -836,15 +980,19 @@ mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 
 	  if (num_axes >= 2)
 	    {
-	      axe_value = SDL_JoystickGetAxis (joystick, 1);
-	      if (axe_value > utils_context->const_data.joystick_limit_down)
+	      if (y)
 		{
-		  (*y) = 1;
-		}
-	      else if (axe_value <
-		       utils_context->const_data.joystick_limit_up)
-		{
-		  (*y) = -1;
+		  axe_value = SDL_JoystickGetAxis (joystick, 1);
+		  if (axe_value >
+		      utils_context->const_data.joystick_limit_down)
+		    {
+		      (*y) = 1;
+		    }
+		  else if (axe_value <
+			   utils_context->const_data.joystick_limit_up)
+		    {
+		      (*y) = -1;
+		    }
 		}
 	    }
 	  else
@@ -855,22 +1003,61 @@ mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 			  num_axes, i);
 	    }
 
-	  if (check_joystick_button_index (b))
+	  if (check_joystick_button_index (b1))
 	    {
 	      num_buttons = SDL_JoystickNumButtons (joystick);
 
-	      if (num_buttons >= b)
+	      if (num_buttons >= b1)
 		{
-		  (*button) = SDL_JoystickGetButton (joystick, b);
+		  if (button_a)
+		    {
+		      (*button_a) = SDL_JoystickGetButton (joystick, b1);
+		    }
 		}
 	      else
 		{
 		  lw6sys_log (LW6SYS_LOG_INFO,
 			      _
 			      ("only %d buttons for joystick %d, button %d can't be fetched"),
-			      num_buttons, i, b);
+			      num_buttons, i, b1);
+		}
+	    }
+
+	  if (check_joystick_button_index (b2))
+	    {
+	      num_buttons = SDL_JoystickNumButtons (joystick);
+
+	      if (num_buttons >= b2)
+		{
+		  if (button_b)
+		    {
+		      (*button_b) = SDL_JoystickGetButton (joystick, b2);
+		    }
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_INFO,
+			      _
+			      ("only %d buttons for joystick %d, button %d can't be fetched"),
+			      num_buttons, i, b2);
 		}
 	    }
 	}
     }
 }
+
+int
+mod_gl_utils_set_key_repeat (mod_gl_utils_context_t * utils_context,
+			     int key_repeat_delay, int key_repeat_interval)
+{
+  int ret = 0;
+
+  if (key_repeat_delay >= 0 && key_repeat_interval >= 0)
+    {
+      utils_context->repeat_settings.delay = key_repeat_delay;
+      utils_context->repeat_settings.interval = key_repeat_interval;
+      SDL_EnableKeyRepeat (key_repeat_delay, key_repeat_interval);
+    }
+
+  return ret;
+}
