@@ -56,7 +56,7 @@ update_game_surface (mod_gl_utils_context_t * utils_context,
 	      fighter = &(game_state->map_state.armies.fighters[fighter_id]);
 	      mod_gl_utils_putpixel (surface, x - x0, y - y0,
 				     mod_gl_utils_get_shaded_color_for_fighter
-				     (utils_context, fighter->team_id,
+				     (utils_context, fighter->team_color,
 				      fighter->health));
 	    }
 	  else
@@ -72,11 +72,10 @@ mod_gl_utils_update_game_texture (mod_gl_utils_context_t * utils_context,
 				  SDL_Surface * surface,
 				  GLuint texture,
 				  lw6ker_game_state_t * game_state,
-				  lw6map_param_t * map_param,
 				  lw6gui_look_t * look, int layer_id)
 {
   mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
-				      &(map_param->style));
+				      &(look->style));
   update_game_surface (utils_context, surface, game_state, look,
 		       layer_id, 0, 0, game_state->map_state.shape.w,
 		       game_state->map_state.shape.h);
@@ -98,7 +97,6 @@ mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
 					mod_gl_utils_texture_array_t *
 					texture_array,
 					lw6ker_game_state_t * game_state,
-					lw6map_param_t * map_param,
 					lw6gui_look_t * look, int layer_id)
 {
   int n_x, n_y;
@@ -114,7 +112,7 @@ mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
 	game_state->rounds;
 
       mod_gl_utils_update_team_color_map (&(utils_context->team_color_map),
-					  &(map_param->style));
+					  &(look->style));
 
       for (n_y = 0; n_y < surface_array->layout.n_h; ++n_y)
 	{
