@@ -31,4 +31,10 @@
 extern int _mod_gl_utils_load_consts (mod_gl_utils_context_t * context);
 extern void _mod_gl_utils_unload_consts (mod_gl_utils_context_t * context);
 
+/*
+ * In data.c
+ */
+extern int _mod_gl_utils_load_fonts (mod_gl_utils_context_t * context);
+extern void _mod_gl_utils_unload_fonts (mod_gl_utils_context_t * context);
+
 #endif
