@@ -46,6 +46,8 @@ mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
   /* Flags we will pass into SDL_SetVideoMode. */
   int flags = 0;
 
+  lw6sys_sleep (utils_context->const_data.mode_sleep);
+
   utils_context->resize_callback = resize_callback;
 
   /* Let's get some video information. */
@@ -173,6 +175,10 @@ mod_gl_utils_set_video_mode (mod_gl_utils_context_t * utils_context,
    */
   mod_gl_utils_set_render_mode_2d (utils_context);
 
+  resize_callback (width, height, fullscreen);
+
+  lw6sys_sleep (utils_context->const_data.mode_sleep);
+
   return 1;
 }
 
@@ -263,22 +269,31 @@ mod_gl_utils_sync_viewport (mod_gl_utils_context_t * utils_context)
  * Force mode.
  */
 int
-mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context)
+mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context, int force)
 {
   int ret = 0;
-  int width;
-  int height;
-  int fullscreen;
-  int flags;
+  int width = 0;
+  int height = 0;
+  int fullscreen = 0;
+  int flags = 0;
 
   mod_gl_utils_get_video_mode (utils_context, &width, &height, &fullscreen);
   flags = SDL_OPENGL | (fullscreen ? SDL_FULLSCREEN : SDL_RESIZABLE);
 
-  if (SDL_SetVideoMode (width, height, utils_context->screen.bpp, flags) == 0)
+  if (force)
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("unable to sync screen %dx%d fullscreen=%d"), width,
-		  height, fullscreen);
+      if (SDL_SetVideoMode (width, height, utils_context->screen.bpp, flags)
+	  == 0)
+	{
+	  mod_gl_utils_sync_viewport (utils_context);
+	  ret = 1;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("unable to sync screen %dx%d fullscreen=%d"), width,
+		      height, fullscreen);
+	}
     }
   else
     {
