@@ -49,7 +49,7 @@ mod_gl_utils_prepare_buffer (mod_gl_utils_context_t * utils_context,
 
   mod_gl_utils_sync_viewport (utils_context);
 
-  lw6sys_color_8_to_f (&bg_color, look->style.background_color_base.bg);
+  lw6sys_color_8_to_f (&bg_color, look->style.background_color_root.bg);
   glClearColor (bg_color.r, bg_color.g, bg_color.b, bg_color.a);
   glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 }
