@@ -56,8 +56,8 @@ mod_gl_utils_surface_array_init (mod_gl_utils_context_t *
 		  surface =
 		    mod_gl_utils_create_surface (utils_context,
 						 surface_array->layout.w[n_x],
-						 surface_array->layout.
-						 h[n_y]);
+						 surface_array->
+						 layout.h[n_y]);
 		  if (surface)
 		    {
 		      mod_gl_utils_set_surface_array_surface (surface_array,
