@@ -380,14 +380,18 @@ mod_gl_utils_delete_scheduled_textures (mod_gl_utils_context_t * gfx_context)
 {
   GLuint *texture_ptr = NULL;
 
-  while (!lw6sys_list_is_empty (gfx_context->texture_data.to_delete))
+  if (gfx_context->texture_data.to_delete != NULL)
     {
-      texture_ptr =
-	(GLuint *) lw6sys_lifo_pop (&(gfx_context->texture_data.to_delete));
-      if (texture_ptr != NULL)
+      while (!lw6sys_list_is_empty (gfx_context->texture_data.to_delete))
 	{
-	  mod_gl_utils_delete_texture (gfx_context, *texture_ptr);
-	  LW6SYS_FREE (texture_ptr);
+	  texture_ptr =
+	    (GLuint *)
+	    lw6sys_lifo_pop (&(gfx_context->texture_data.to_delete));
+	  if (texture_ptr != NULL)
+	    {
+	      mod_gl_utils_delete_texture (gfx_context, *texture_ptr);
+	      LW6SYS_FREE (texture_ptr);
+	    }
 	}
     }
 }
