@@ -59,28 +59,28 @@ mod_gl_utils_texture_1x1_update (mod_gl_utils_context_t * utils_context,
 
   utils_context->textures_1x1.menu_fg =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_default.
-					    fg);
+					    look->style.
+					    menu_color_default.fg);
   utils_context->textures_1x1.menu_bg =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_default.
-					    bg);
+					    look->style.
+					    menu_color_default.bg);
   utils_context->textures_1x1.menu_fg_disabled =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_disabled.
-					    fg);
+					    look->style.
+					    menu_color_disabled.fg);
   utils_context->textures_1x1.menu_bg_disabled =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_disabled.
-					    bg);
+					    look->style.
+					    menu_color_disabled.bg);
   utils_context->textures_1x1.menu_fg_selected =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_selected.
-					    fg);
+					    look->style.
+					    menu_color_selected.fg);
   utils_context->textures_1x1.menu_bg_selected =
     mod_gl_utils_texture_1x1_color2texture (utils_context,
-					    look->style.menu_color_selected.
-					    bg);
+					    look->style.
+					    menu_color_selected.bg);
 
   return ret;
 }
@@ -101,25 +101,25 @@ mod_gl_utils_texture_1x1_clear (mod_gl_utils_context_t * utils_context)
   if (glIsTexture (utils_context->textures_1x1.menu_fg_disabled))
     {
       mod_gl_utils_delete_texture (utils_context,
-				   utils_context->textures_1x1.
-				   menu_fg_disabled);
+				   utils_context->
+				   textures_1x1.menu_fg_disabled);
     }
   if (glIsTexture (utils_context->textures_1x1.menu_bg_disabled))
     {
       mod_gl_utils_delete_texture (utils_context,
-				   utils_context->textures_1x1.
-				   menu_bg_disabled);
+				   utils_context->
+				   textures_1x1.menu_bg_disabled);
     }
   if (glIsTexture (utils_context->textures_1x1.menu_fg_selected))
     {
       mod_gl_utils_delete_texture (utils_context,
-				   utils_context->textures_1x1.
-				   menu_fg_selected);
+				   utils_context->
+				   textures_1x1.menu_fg_selected);
     }
   if (glIsTexture (utils_context->textures_1x1.menu_bg_selected))
     {
       mod_gl_utils_delete_texture (utils_context,
-				   utils_context->textures_1x1.
-				   menu_bg_selected);
+				   utils_context->
+				   textures_1x1.menu_bg_selected);
     }
 }
