@@ -57,8 +57,8 @@ mod_gl_utils_texture_array_init (mod_gl_utils_context_t *
 		  surface =
 		    mod_gl_utils_create_surface (utils_context,
 						 texture_array->layout.w[n_x],
-						 texture_array->layout.
-						 h[n_y]);
+						 texture_array->
+						 layout.h[n_y]);
 		  if (surface)
 		    {
 		      texture =
