@@ -65,11 +65,3 @@ mod_gl_utils_get_ticks (mod_gl_utils_context_t * utils_context)
 {
   return SDL_GetTicks () + utils_context->timer_data.ticks_offset;
 }
-
-/*
-  int
-  mod_gl_get_ticks (void *context)
-  {
-  return mod_gl_utils_get_ticks ((mod_gl_utils_context_t *) context);
-  }
-*/
