@@ -47,12 +47,13 @@ mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t * utils_context,
 				     float *map_x1, float *map_y1,
 				     float *map_x2, float *map_y2,
 				     int shape_w, int shape_h,
-				     lw6map_param_t * map_param)
+				     lw6gui_look_t * look)
 {
   int view_x, view_y, view_w, view_h;
   float map_w, map_h;
   float map_ratio;
   float view_ratio;
+  float zoom;
 
   mod_gl_utils_viewport_calc_view_area (utils_context, &view_x, &view_y,
 					&view_w, &view_h);
@@ -60,7 +61,7 @@ mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t * utils_context,
   map_ratio = ((float) shape_w) / ((float) shape_h);
   view_ratio = ((float) view_w) / ((float) view_h);
 
-  if (map_param->style.keep_ratio)
+  if (look->style.keep_ratio)
     {
       if (map_ratio > view_ratio)
 	{
@@ -79,11 +80,27 @@ mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t * utils_context,
       map_h = view_h;
     }
 
-  map_w *= map_param->style.zoom;
-  map_h *= map_param->style.zoom;
+  zoom = look->dynamic_zoom * look->style.zoom;
+  map_w *= zoom;
+  map_h *= zoom;
 
   (*map_x1) = view_x + (view_w - map_w) / 2.0f;
   (*map_x2) = (*map_x1) + map_w;
   (*map_y1) = view_y + (view_h - map_h) / 2.0f;
   (*map_y2) = (*map_y1) + map_h;
 }
+
+void
+mod_gl_utils_viewport_calc_map_pos (mod_gl_utils_context_t * utils_context,
+				    float *map_x, float *map_y,
+				    int x, int y, int w, int h,
+				    lw6gui_look_t * look)
+{
+  float map_x1 = 0.0f, map_x2 = 0.0f, map_y1 = 0.0f, map_y2 = 0.0f;
+
+  mod_gl_utils_viewport_calc_map_area (utils_context, &map_x1, &map_y1,
+				       &map_x2, &map_y2, w, h, look);
+
+  *map_x = map_x1 + (x * (map_x2 - map_x1)) / w;
+  *map_y = map_y1 + (y * (map_y2 - map_y1)) / h;
+}
