@@ -112,7 +112,7 @@ typedef struct mod_gl_utils_screen_s
 }
 mod_gl_utils_screen_t;
 
-typedef enum MOD_GL_UTILS_RENDER_MODE_ENUM
+typedef enum mod_gl_utils_render_mode_e
 {
   MOD_GL_UTILS_RENDER_NONE = 0,
   MOD_GL_UTILS_RENDER_2D = 1,
@@ -122,7 +122,7 @@ typedef enum MOD_GL_UTILS_RENDER_MODE_ENUM
   MOD_GL_UTILS_RENDER_3D_PICK = 5,
   MOD_GL_UTILS_RENDER_3D_WARP = 6
 }
-MOD_GL_UTILS_RENDER_MODE;
+mod_gl_utils_render_mode_t;
 
 typedef struct mod_gl_utils_rect_array_s
 {
@@ -162,6 +162,8 @@ typedef struct mod_gl_utils_button_state_s
 {
   int pressed;
   int queue;
+  int last_press;
+  int last_repeat;
 }
 mod_gl_utils_button_state_t;
 
@@ -210,8 +212,10 @@ mod_gl_utils_texture_data_t;
 
 typedef struct mod_gl_utils_font_data_s
 {
-  TTF_Font *system;
   TTF_Font *menu;
+  TTF_Font *hud;
+  TTF_Font *cursor;
+  TTF_Font *system;
 }
 mod_gl_utils_font_data_t;
 
@@ -260,11 +264,14 @@ typedef struct mod_gl_utils_const_data_s
   /*
    * Set by the utils module itself
    */
+  float mode_sleep;
   float quit_sleep;
   float persp_fovy;
   float persp_znear;
   float persp_zfar;
   int menu_font_size;
+  int hud_font_size;
+  int cursor_font_size;
   int system_font_size;
   int system_font_dh;
   int system_font_dw;
@@ -285,7 +292,7 @@ typedef struct mod_gl_utils_const_data_s
 }
 mod_gl_utils_const_data_t;
 
-typedef struct MOD_GL_UTILS_TEXTURES_1X1
+typedef struct mod_gl_utils_texture_1x1_s
 {
   /*
    * Set by the background module
@@ -297,7 +304,7 @@ typedef struct MOD_GL_UTILS_TEXTURES_1X1
   GLuint menu_fg_selected;
   GLuint menu_bg_selected;
 }
-MOD_GL_UTILS_TEXTURES_1X1;
+mod_gl_utils_texture_1x1_t;
 
 typedef struct mod_gl_utils_team_color_map_s
 {
@@ -320,6 +327,13 @@ typedef struct mod_gl_utils_last_action_s
 }
 mod_gl_utils_last_action_t;
 
+typedef struct mod_gl_utils_repeat_settings_s
+{
+  int delay;
+  int interval;
+}
+mod_gl_utils_repeat_settings_t;
+
 typedef struct mod_gl_utils_context_s
 {
   void (*resize_callback) (int width, int height, int fullscreen);
@@ -328,7 +342,7 @@ typedef struct mod_gl_utils_context_s
   mod_gl_utils_mem_counter_t texture_counter;
   mod_gl_utils_caps_t caps;
   mod_gl_utils_screen_t screen;
-  MOD_GL_UTILS_RENDER_MODE render_mode;
+  mod_gl_utils_render_mode_t render_mode;
   mod_gl_utils_texture_data_t texture_data;
   mod_gl_utils_font_data_t font_data;
   mod_gl_utils_keyboard_state_t keyboard_state;
@@ -336,12 +350,13 @@ typedef struct mod_gl_utils_context_s
   mod_gl_utils_joysticks_state_t joysticks_state;
   mod_gl_utils_quit_state_t quit_state;
   mod_gl_utils_const_data_t const_data;
-  MOD_GL_UTILS_TEXTURES_1X1 textures_1x1;
+  mod_gl_utils_texture_1x1_t textures_1x1;
   mod_gl_utils_menucache_array_t menucache_array;
   mod_gl_utils_texturecache_array_t texturecache_array;
   mod_gl_utils_team_color_map_t team_color_map;
   mod_gl_utils_timer_data_t timer_data;
   mod_gl_utils_last_action_t last_action;
+  mod_gl_utils_repeat_settings_t repeat_settings;
 }
 mod_gl_utils_context_t;
 
@@ -383,6 +398,9 @@ extern GLuint mod_gl_utils_load_texture (mod_gl_utils_context_t *
 					 SDL_Surface * surface);
 extern void mod_gl_utils_unload_texture (mod_gl_utils_context_t *
 					 utils_context, int texture);
+extern int mod_gl_utils_load_fonts (mod_gl_utils_context_t * utils_context);
+extern void mod_gl_utils_unload_fonts (mod_gl_utils_context_t *
+				       utils_context);
 extern int mod_gl_utils_load_data (mod_gl_utils_context_t * utils_context);
 extern void mod_gl_utils_unload_data (mod_gl_utils_context_t * utils_context);
 
@@ -413,6 +431,11 @@ extern int mod_gl_utils_poll_quit (mod_gl_utils_context_t * utils_context);
 extern void mod_gl_utils_send_quit (mod_gl_utils_context_t * utils_context);
 extern int mod_gl_utils_get_key_state (mod_gl_utils_context_t * utils_context,
 				       int keysym);
+extern void mod_gl_utils_get_default_keys_state (mod_gl_utils_context_t *
+						 utils_context, int *up,
+						 int *down, int *left,
+						 int *right, int *esc,
+						 int *enter);
 extern int mod_gl_utils_poll_mouse_move (mod_gl_utils_context_t *
 					 utils_context, int *x, int *y);
 extern int mod_gl_utils_poll_mouse_button_left (mod_gl_utils_context_t *
@@ -427,6 +450,10 @@ extern void mod_gl_utils_get_mouse_state (mod_gl_utils_context_t *
 					  utils_context, int *x, int *y,
 					  int *button_left,
 					  int *button_right);
+extern int mod_gl_utils_warp_mouse (mod_gl_utils_context_t *
+				    utils_context, int x, int y);
+extern void mod_gl_utils_show_mouse (mod_gl_utils_context_t * utils_context,
+				     int state);
 extern int mod_gl_utils_poll_joystick_up (mod_gl_utils_context_t *
 					  utils_context, int i);
 extern int mod_gl_utils_poll_joystick_down (mod_gl_utils_context_t *
@@ -439,7 +466,11 @@ extern int mod_gl_utils_poll_joystick_button (mod_gl_utils_context_t *
 					      utils_context, int i, int b);
 extern void mod_gl_utils_get_joystick_state (mod_gl_utils_context_t *
 					     utils_context, int *x, int *y,
-					     int *button, int i, int b);
+					     int *button_a, int *button_b,
+					     int i, int b1, int b2);
+extern int mod_gl_utils_set_key_repeat (mod_gl_utils_context_t *
+					utils_context, int key_repeat_delay,
+					int key_repeat_interval);
 
 /*
  * In font.c
@@ -479,7 +510,6 @@ extern void mod_gl_utils_update_game_texture (mod_gl_utils_context_t *
 					      GLuint texture,
 					      lw6ker_game_state_t *
 					      game_state,
-					      lw6map_param_t * map_param,
 					      lw6gui_look_t * look,
 					      int layer_id);
 extern void mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
@@ -490,8 +520,6 @@ extern void mod_gl_utils_update_game_texture_array (mod_gl_utils_context_t *
 						    * texture_array,
 						    lw6ker_game_state_t *
 						    game_state,
-						    lw6map_param_t *
-						    map_param,
 						    lw6gui_look_t *
 						    look, int layer_id);
 
@@ -543,7 +571,8 @@ extern int mod_gl_utils_get_video_mode (mod_gl_utils_context_t *
 					int *height, int *fullscreen);
 extern int mod_gl_utils_sync_viewport (mod_gl_utils_context_t *
 				       utils_context);
-extern int mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context);
+extern int mod_gl_utils_sync_mode (mod_gl_utils_context_t * utils_context,
+				   int force);
 
 /*
  * In menucache.c
@@ -857,7 +886,12 @@ extern void mod_gl_utils_viewport_calc_map_area (mod_gl_utils_context_t *
 						 float *map_y1, float *map_x2,
 						 float *map_y2, int shape_w,
 						 int shape_h,
-						 lw6map_param_t * map_param);
+						 lw6gui_look_t * look);
+extern void mod_gl_utils_viewport_calc_map_pos (mod_gl_utils_context_t *
+						utils_context, float *map_x,
+						float *map_y, int x, int y,
+						int w, int h,
+						lw6gui_look_t * look);
 
 /*
  * In zones.c
