@@ -43,7 +43,7 @@ mod_gl_view_flat_create_backend (mod_gl_utils_context_t * utils_context)
       backend->display_zones = mod_gl_view_flat_display_zones;
       backend->display_gradient = mod_gl_view_flat_display_gradient;
       backend->display_game = mod_gl_view_flat_display_game;
-      backend->pick_map_coord = mod_gl_view_flat_pick_map_coord;
+      backend->display_cursors = mod_gl_view_flat_display_cursors;
       backend->init = mod_gl_view_flat_init;
       backend->quit = mod_gl_view_flat_quit;
     }
