@@ -42,6 +42,14 @@ read_callback (void *callback_data, char *element, char *key, char *value)
 
   if (!strcmp (element, "int"))
     {
+      lw6cfg_read_xml_int (key, value, "cursor-blink-period",
+			   &const_data->cursor_blink_period);
+      lw6cfg_read_xml_int (key, value, "cursor-texture-size",
+			   &const_data->cursor_texture_size);
+      lw6cfg_read_xml_int (key, value, "cursor-border-width",
+			   &const_data->cursor_border_width);
+      lw6cfg_read_xml_int (key, value, "cursor-blur-width",
+			   &const_data->cursor_blur_width);
       lw6cfg_read_xml_int (key, value, "tile-size-map",
 			   &const_data->tile_size_map);
       lw6cfg_read_xml_int (key, value, "tile-size-armies",
