@@ -31,8 +31,8 @@
 #include "gl-flat-internal.h"
 
 static void
-set_map_options (mod_gl_utils_context_t * utils_context,
-		 _mod_gl_view_flat_context_t * flat_context)
+set_map_rules (mod_gl_utils_context_t * utils_context,
+	       _mod_gl_view_flat_context_t * flat_context)
 {
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_LINEAR);
   glTexParameteri (GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
@@ -47,7 +47,7 @@ display_texture_ex (mod_gl_utils_context_t * utils_context,
 		    float scale_w, float scale_h)
 {
   glBindTexture (GL_TEXTURE_2D, texture);
-  set_map_options (utils_context, flat_context);
+  set_map_rules (utils_context, flat_context);
 
   glMatrixMode (GL_TEXTURE);
   glPushMatrix ();
@@ -71,7 +71,7 @@ static void
 display_texture (mod_gl_utils_context_t * utils_context,
 		 _mod_gl_view_flat_context_t * flat_context,
 		 int texture_w, int texture_h, int shape_w, int shape_h,
-		 GLuint texture, lw6map_param_t * map_param)
+		 GLuint texture, lw6gui_look_t * look)
 {
   float x1, y1, x2, y2, scale_w, scale_h;
 
@@ -79,7 +79,7 @@ display_texture (mod_gl_utils_context_t * utils_context,
   scale_h = mod_gl_utils_texture_scale (texture_h);
 
   mod_gl_utils_viewport_calc_map_area (utils_context, &x1, &y1, &x2, &y2,
-				       shape_w, shape_h, map_param);
+				       shape_w, shape_h, look);
 
   display_texture_ex (utils_context,
 		      flat_context,
@@ -94,7 +94,7 @@ display_texture_array (mod_gl_utils_context_t * utils_context,
 		       int shape_w,
 		       int shape_h,
 		       mod_gl_utils_texture_array_t * texture_array,
-		       lw6map_param_t * param)
+		       lw6gui_look_t * look)
 {
   float x1, y1, x2, y2, w, h, coef_x, coef_y;
   float scale_w, scale_h;
@@ -105,7 +105,7 @@ display_texture_array (mod_gl_utils_context_t * utils_context,
   float min_x, min_y, max_x, max_y;
 
   mod_gl_utils_viewport_calc_map_area (utils_context, &x1, &y1, &x2, &y2,
-				       shape_w, shape_h, param);
+				       shape_w, shape_h, look);
   w = x2 - x1;
   h = y2 - y1;
   coef_x = w / texture_array_w;
@@ -192,7 +192,7 @@ display_map_preview (mod_gl_utils_context_t * utils_context,
 			 flat_context->game_context.map.level->texture.shape.
 			 h,
 			 &(flat_context->game_context.map.map_texture_array),
-			 &(level->param));
+			 look);
 }
 
 void
@@ -245,7 +245,7 @@ display_map_zones (mod_gl_utils_context_t * utils_context,
 	{
 	  display_texture (utils_context, flat_context, map_struct->shape.w,
 			   map_struct->shape.h, level->texture.shape.w,
-			   level->texture.shape.h, texture, &(level->param));
+			   level->texture.shape.h, texture, look);
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -305,7 +305,7 @@ display_map_gradient (mod_gl_utils_context_t * utils_context,
 	{
 	  display_texture (utils_context, flat_context, map_state->shape.w,
 			   map_state->shape.h, level->texture.shape.w,
-			   level->texture.shape.h, texture, &(level->param));
+			   level->texture.shape.h, texture, look);
 
 	  mod_gl_utils_schedule_delete_texture (utils_context, texture);
 	}
@@ -357,8 +357,7 @@ mod_gl_view_flat_display_gradient (mod_gl_utils_context_t * utils_context,
 static void
 display_armies (mod_gl_utils_context_t * utils_context,
 		_mod_gl_view_flat_context_t *
-		flat_context, lw6gui_look_t * look,
-		lw6map_param_t * map_param)
+		flat_context, lw6gui_look_t * look)
 {
   int i;
 
@@ -373,8 +372,7 @@ display_armies (mod_gl_utils_context_t * utils_context,
 						armies.
 						armies_texture_arrays[i]),
 					      flat_context->game_context.
-					      armies.game_state, map_param,
-					      look, i);
+					      armies.game_state, look, i);
       display_texture_array (utils_context, flat_context,
 			     flat_context->game_context.armies.game_state->
 			     map_state.shape.w,
@@ -385,7 +383,7 @@ display_armies (mod_gl_utils_context_t * utils_context,
 			     flat_context->game_context.map.level->texture.
 			     shape.h,
 			     &(flat_context->game_context.armies.
-			       armies_texture_arrays[i]), map_param);
+			       armies_texture_arrays[i]), look);
     }
 }
 
@@ -398,10 +396,12 @@ display_armies (mod_gl_utils_context_t * utils_context,
 static void
 display_game (mod_gl_utils_context_t * utils_context,
 	      _mod_gl_view_flat_context_t *
-	      flat_context, lw6gui_look_t * look, lw6map_level_t * level)
+	      flat_context, lw6gui_look_t * look,
+	      lw6ker_game_state_t * game_state)
 {
-  display_map_preview (utils_context, flat_context, look, level);
-  display_armies (utils_context, flat_context, look, &(level->param));
+  display_map_preview (utils_context, flat_context, look,
+		       game_state->game_struct->level);
+  display_armies (utils_context, flat_context, look);
 }
 
 void
@@ -427,7 +427,7 @@ _mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
       glColor3f (1.0, 1.0, 1.0);
       glEnable (GL_TEXTURE_2D);	// for texture
 
-      display_game (utils_context, flat_context, look, level);
+      display_game (utils_context, flat_context, look, game_state);
     }
 }
 
@@ -441,3 +441,103 @@ mod_gl_view_flat_display_game (mod_gl_utils_context_t * utils_context,
 				  (_mod_gl_view_flat_context_t *)
 				  flat_context, look, game_state);
 }
+
+static void
+display_cursor_texture (mod_gl_utils_context_t * utils_context,
+			_mod_gl_view_flat_context_t * flat_context,
+			float x, float y, float w, float h, GLuint texture)
+{
+  display_texture_ex (utils_context, flat_context,
+		      texture, x - w / 2.0f, y - h / 2.0f, x + w / 2.0f,
+		      y + h / 2.0f, 1.0f, 1.0f);
+}
+
+static void
+display_cursor (mod_gl_utils_context_t * utils_context,
+		_mod_gl_view_flat_context_t * flat_context,
+		lw6gui_look_t * look,
+		int i, int x, int y, lw6sys_wh_t * shape, int even_odd)
+{
+
+  float cursor_x = 0.0f;
+  float cursor_y = 0.0f;
+  float cursor_w = 0.0f;
+  float cursor_h = 0.0f;
+
+  mod_gl_utils_viewport_calc_map_pos (utils_context, &cursor_x, &cursor_y,
+				      x, y, shape->w, shape->h, look);
+  cursor_w = cursor_h =
+    (utils_context->screen.width +
+     utils_context->screen.height) * flat_context->const_data.cursor_size *
+    look->style.cursor_size;
+  lw6sys_log (LW6SYS_LOG_DEBUG,
+	      _("display cursor %d %0.1f , %0.1f - %0.1f x %0.1f"), i,
+	      cursor_x, cursor_y, cursor_w, cursor_h);
+  display_cursor_texture (utils_context, flat_context, cursor_x, cursor_y,
+			  cursor_w, cursor_h, even_odd ?
+			  flat_context->cursors_context.
+			  cursor[i].texture_even : flat_context->
+			  cursors_context.cursor[i].texture_odd);
+}
+
+static void
+display_cursors (mod_gl_utils_context_t * utils_context,
+		 _mod_gl_view_flat_context_t *
+		 flat_context,
+		 lw6gui_look_t * look, lw6ker_game_state_t * game_state)
+{
+  int i;
+  lw6ker_cursor_t *cursor;
+  int blink_state;
+
+  lw6sys_log (LW6SYS_LOG_DEBUG, _("display cursors"));
+  blink_state =
+    mod_gl_utils_get_ticks (utils_context) /
+    (flat_context->const_data.cursor_blink_period / 2) % 2;
+  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
+    {
+      cursor = &(game_state->map_state.cursor_array.cursors[i]);
+      if (cursor->enabled)
+	{
+	  display_cursor (utils_context, flat_context, look,
+			  i, cursor->pos.x, cursor->pos.y,
+			  &game_state->map_state.shape, blink_state);
+	}
+    }
+}
+
+void
+_mod_gl_view_flat_display_cursors (mod_gl_utils_context_t * utils_context,
+				   _mod_gl_view_flat_context_t *
+				   flat_context,
+				   lw6gui_look_t * look,
+				   lw6ker_game_state_t * game_state)
+{
+  if (utils_context && flat_context && game_state)
+    {
+      _mod_gl_view_flat_cursors_context_update (utils_context,
+						&flat_context->
+						cursors_context,
+						&flat_context->const_data,
+						look, game_state);
+
+      mod_gl_utils_set_render_mode_2d_blend (utils_context);
+
+      glColor3f (1.0, 1.0, 1.0);
+      glEnable (GL_TEXTURE_2D);	// for texture
+
+      display_cursors (utils_context, flat_context, look, game_state);
+    }
+}
+
+void
+mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
+				  utils_context,
+				  void *flat_context,
+				  lw6gui_look_t * look,
+				  lw6ker_game_state_t * game_state)
+{
+  _mod_gl_view_flat_display_cursors (utils_context,
+				     (_mod_gl_view_flat_context_t *)
+				     flat_context, look, game_state);
+}
