@@ -49,9 +49,30 @@ typedef struct _mod_gl_view_flat_game_context_s
 }
 _mod_gl_view_flat_game_context_t;
 
+typedef struct _mod_gl_view_flat_cursor_context_s
+{
+  u_int16_t cursor_id;
+  char letter;
+  int team_color;
+  GLuint texture_even;
+  GLuint texture_odd;
+}
+_mod_gl_view_flat_cursor_context_t;
+
+typedef struct _mod_gl_view_flat_cursors_context_s
+{
+  lw6map_color_couple_t color;
+  _mod_gl_view_flat_cursor_context_t cursor[LW6MAP_MAX_NB_CURSORS];
+}
+_mod_gl_view_flat_cursors_context_t;
+
 typedef struct _mod_gl_view_flat_const_data_s
 {
   float cursor_size;
+  int cursor_blink_period;
+  int cursor_texture_size;
+  int cursor_border_width;
+  int cursor_blur_width;
   int tile_size_map;
   int tile_size_armies;
 }
@@ -60,10 +81,57 @@ _mod_gl_view_flat_const_data_t;
 typedef struct _mod_gl_view_flat_context_s
 {
   _mod_gl_view_flat_game_context_t game_context;
+  _mod_gl_view_flat_cursors_context_t cursors_context;
   _mod_gl_view_flat_const_data_t const_data;
 }
 _mod_gl_view_flat_context_t;
 
+/*
+ * In cursorcontext.c
+ */
+extern int _mod_gl_view_flat_cursor_context_init (mod_gl_utils_context_t *
+						  utils_context,
+						  _mod_gl_view_flat_cursor_context_t
+						  * cursor_context,
+						  _mod_gl_view_flat_const_data_t
+						  * const_data,
+						  lw6gui_look_t * look,
+						  lw6ker_cursor_t * cursor);
+extern int _mod_gl_view_flat_cursor_context_update (mod_gl_utils_context_t *
+						    utils_context,
+						    _mod_gl_view_flat_cursor_context_t
+						    * cursor_context,
+						    _mod_gl_view_flat_const_data_t
+						    * const_data,
+						    lw6gui_look_t * look,
+						    lw6ker_cursor_t * cursor);
+extern int _mod_gl_view_flat_cursor_context_clear (mod_gl_utils_context_t *
+						   utils_context,
+						   _mod_gl_view_flat_cursor_context_t
+						   * cursor_context);
+extern int _mod_gl_view_flat_cursors_context_init (mod_gl_utils_context_t *
+						   utils_context,
+						   _mod_gl_view_flat_cursors_context_t
+						   * cursors_context,
+						   _mod_gl_view_flat_const_data_t
+						   * const_data,
+						   lw6gui_look_t * look,
+						   lw6ker_game_state_t *
+						   game_state);
+extern int _mod_gl_view_flat_cursors_context_update (mod_gl_utils_context_t *
+						     utils_context,
+						     _mod_gl_view_flat_cursors_context_t
+						     * cursors_context,
+						     _mod_gl_view_flat_const_data_t
+						     * const_data,
+						     lw6gui_look_t * look,
+						     lw6ker_game_state_t *
+						     game_state);
+extern int _mod_gl_view_flat_cursors_context_clear (mod_gl_utils_context_t *
+						    utils_context,
+						    _mod_gl_view_flat_cursors_context_t
+						    * cursors_context);
+
 /*
  * In data.c
  */
@@ -107,6 +175,13 @@ extern void _mod_gl_view_flat_display_game (mod_gl_utils_context_t *
 					    flat_context,
 					    lw6gui_look_t * look,
 					    lw6ker_game_state_t * game_state);
+extern void _mod_gl_view_flat_display_cursors (mod_gl_utils_context_t *
+					       utils_context,
+					       _mod_gl_view_flat_context_t *
+					       flat_context,
+					       lw6gui_look_t * look,
+					       lw6ker_game_state_t *
+					       game_state);
 
 /*
  * In gamecontext.c
@@ -184,20 +259,6 @@ _mod_gl_view_flat_game_context_update_armies (mod_gl_utils_context_t *
 					      lw6ker_game_state_t *
 					      game_state);
 
-/*
- * in pick.c
- */
-extern void _mod_gl_view_flat_pick_map_coord (mod_gl_utils_context_t *
-					      utils_context,
-					      _mod_gl_view_flat_context_t *
-					      flat_context,
-					      lw6gui_look_t * look,
-					      int *map_x,
-					      int *map_y,
-					      lw6ker_game_state_t *
-					      game_state,
-					      int screen_x, int screen_y);
-
 /*
  * In setup.c
  */
