@@ -43,18 +43,19 @@ _mod_gl_view_flat_init (mod_gl_utils_context_t * utils_context)
   flat_context =
     (_mod_gl_view_flat_context_t *)
     LW6SYS_CALLOC (sizeof (_mod_gl_view_flat_context_t));
-  if (!flat_context)
+
+  if (flat_context)
     {
-      /*
-       * No use to continue if this basic malloc fails...
-       */
-      exit (1);
+      if (!_mod_gl_view_flat_load_data (utils_context, flat_context))
+	{
+	  LW6SYS_FREE (flat_context);
+	  flat_context = NULL;
+	}
     }
 
-  if (!_mod_gl_view_flat_load_data (utils_context, flat_context))
+  if (!flat_context)
     {
-      LW6SYS_FREE (flat_context);
-      flat_context = NULL;
+      lw6sys_log (LW6SYS_LOG_ERROR, _("unable to init flat_context"));
     }
 
   return flat_context;
@@ -77,6 +78,8 @@ _mod_gl_view_flat_quit (mod_gl_utils_context_t * utils_context,
 
   _mod_gl_view_flat_game_context_clear (utils_context, flat_context,
 					&(flat_context->game_context));
+  _mod_gl_view_flat_cursors_context_clear (utils_context,
+					   &(flat_context->cursors_context));
 
   LW6SYS_FREE (flat_context);
 }
