@@ -27,7 +27,7 @@
 #include "gl-view.h"
 
 static void
-warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("view backend function \"%s\" is not defined"));
@@ -43,7 +43,7 @@ mod_gl_view_init (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_init");
+      _warning (__FUNCTION__);
     }
 
   return backend->view_context ? 1 : 0;
@@ -59,7 +59,7 @@ mod_gl_view_quit (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_quit");
+      _warning ("view_quit");
     }
 }
 
@@ -75,7 +75,7 @@ mod_gl_view_display_preview (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_display_preview");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -93,7 +93,7 @@ mod_gl_view_display_zones (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_display_zones");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -111,7 +111,7 @@ mod_gl_view_display_gradient (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_display_gradient");
+      _warning (__FUNCTION__);
     }
 }
 
@@ -128,24 +128,23 @@ mod_gl_view_display_game (mod_gl_utils_context_t * utils_context,
     }
   else
     {
-      warning ("view_display_game");
+      _warning (__FUNCTION__);
     }
 }
 
 void
-mod_gl_view_pick_map_coord (mod_gl_utils_context_t * utils_context,
-			    mod_gl_view_backend_t * backend,
-			    lw6gui_look_t * look, int *map_x, int *map_y,
-			    lw6ker_game_state_t * game_state, int screen_x,
-			    int screen_y)
+mod_gl_view_display_cursors (mod_gl_utils_context_t * utils_context,
+			     mod_gl_view_backend_t * backend,
+			     lw6gui_look_t * look,
+			     lw6ker_game_state_t * game_state)
 {
-  if (backend->pick_map_coord)
+  if (backend->display_game)
     {
-      backend->pick_map_coord (utils_context, backend->view_context, look,
-			       map_x, map_y, game_state, screen_x, screen_y);
+      backend->display_cursors (utils_context, backend->view_context, look,
+				game_state);
     }
   else
     {
-      warning ("view_pick_map_coord");
+      _warning (__FUNCTION__);
     }
 }
