@@ -187,6 +187,19 @@ _send_quit (void *gfx_context)
     }
 }
 
+static void
+_get_default_keys_state (void *gfx_context, int *up, int *down, int *left,
+			 int *right, int *esc, int *enter)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      mod_gl_utils_get_default_keys_state (&(mod_gl_context->utils_context),
+					   up, down, left, right, esc, enter);
+    }
+}
+
 static int
 _get_key_state (void *gfx_context, int keysym)
 {
@@ -243,8 +256,7 @@ _poll_mouse_button_right (void *gfx_context)
     {
       ret =
 	mod_gl_utils_poll_mouse_button_right (&
-					      (mod_gl_context->
-					       utils_context));
+					      (mod_gl_context->utils_context));
     }
 
   return ret;
@@ -293,6 +305,31 @@ _get_mouse_state (void *gfx_context, int *x, int *y, int *button_left,
     }
 }
 
+static int
+_warp_mouse (void *gfx_context, int x, int y)
+{
+  int ret = 0;
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      ret = mod_gl_utils_warp_mouse (&(mod_gl_context->utils_context), x, y);
+    }
+
+  return ret;
+}
+
+static void
+_show_mouse (void *gfx_context, int state)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      mod_gl_utils_show_mouse (&(mod_gl_context->utils_context), state);
+    }
+}
+
 static int
 _poll_joystick_up (void *gfx_context, int i)
 {
@@ -372,15 +409,15 @@ _poll_joystick_button (void *gfx_context, int i, int b)
 }
 
 static void
-_get_joystick_state (void *gfx_context, int *x, int *y, int *button,
-		     int i, int b)
+_get_joystick_state (void *gfx_context, int *x, int *y, int *button_a,
+		     int *button_b, int i, int b1, int b2)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
   if (mod_gl_context)
     {
       mod_gl_utils_get_joystick_state (&(mod_gl_context->utils_context), x, y,
-				       button, i, b);
+				       button_a, button_b, i, b1, b2);
     }
 }
 
@@ -473,9 +510,8 @@ _display_game (void *gfx_context, lw6gui_look_t * look,
 }
 
 static void
-_pick_map_coord (void *gfx_context, lw6gui_look_t * look, int *map_x,
-		 int *map_y, lw6ker_game_state_t * game_state, int screen_x,
-		 int screen_y)
+_display_cursors (void *gfx_context, lw6gui_look_t * look,
+		  lw6ker_game_state_t * game_state)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -483,14 +519,15 @@ _pick_map_coord (void *gfx_context, lw6gui_look_t * look, int *map_x,
     {
       _mod_gl_set_backends (mod_gl_context, look);
 
-      mod_gl_view_pick_map_coord (&(mod_gl_context->utils_context),
-				  mod_gl_context->view_backend, look, map_x,
-				  map_y, game_state, screen_x, screen_y);
+      mod_gl_view_display_cursors (&(mod_gl_context->utils_context),
+				   mod_gl_context->view_backend, look,
+				   game_state);
     }
 }
 
 static void
-_display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu)
+_display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu,
+	       float progress)
 {
   _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
 
@@ -499,7 +536,8 @@ _display_menu (void *gfx_context, lw6gui_look_t * look, lw6gui_menu_t * menu)
       _mod_gl_set_backends (mod_gl_context, look);
 
       mod_gl_menu_display (&(mod_gl_context->utils_context),
-			   mod_gl_context->menu_backend, look, menu);
+			   mod_gl_context->menu_backend, look, menu,
+			   progress);
     }
 }
 
@@ -540,6 +578,21 @@ _warp_mouse_on_menuitem (void *gfx_context, lw6gui_look_t * look,
   return ret;
 }
 
+static void
+_center_menu (void *gfx_context, lw6gui_look_t * look,
+	      lw6gui_menu_t * menu, int position)
+{
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      _mod_gl_set_backends (mod_gl_context, look);
+
+      mod_gl_menu_center (&(mod_gl_context->utils_context),
+			  mod_gl_context->menu_backend, look, menu, position);
+    }
+}
+
 static void
 _prepare_buffer (void *gfx_context, lw6gui_look_t * look)
 {
@@ -565,15 +618,32 @@ _swap_buffers (void *gfx_context)
 static void *
 _init (int argc, char *argv[], int width, int height, int fullscreen,
        void (*resize_callback) (int width, int height, int fullscreen),
-       int ticks)
+       int ticks, int key_repeat_delay, int key_repeat_interval)
 {
   _mod_gl_context_t *mod_gl_context =
     _mod_gl_init (argc, argv, width, height, fullscreen, resize_callback,
-		  ticks);
+		  ticks, key_repeat_delay, key_repeat_interval);
 
   return (void *) mod_gl_context;
 }
 
+static int
+_set_key_repeat (void *gfx_context, int key_repeat_delay,
+		 int key_repeat_interval)
+{
+  int ret = 0;
+  _mod_gl_context_t *mod_gl_context = (_mod_gl_context_t *) gfx_context;
+
+  if (mod_gl_context)
+    {
+      ret =
+	mod_gl_utils_set_key_repeat (&(mod_gl_context->utils_context),
+				     key_repeat_delay, key_repeat_interval);
+    }
+
+  return ret;
+}
+
 static void
 _get_low_resolution (void *gfx_context, int *width, int *height)
 {
@@ -681,6 +751,33 @@ _get_ticks (void *gfx_context)
   return ret;
 }
 
+lw6sys_module_pedigree_t *
+mod_gl_get_pedigree ()
+{
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  module_pedigree =
+    (lw6sys_module_pedigree_t *)
+    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  if (module_pedigree)
+    {
+      module_pedigree->id = "gl";
+      module_pedigree->category = "gfx";
+      module_pedigree->name = _("OpenGL/SDL");
+      module_pedigree->readme =
+	_
+	("This is the most accomplished graphics backend for Liquid War 6. It uses OpenGL hardware acceleration if available, and uses SDL as a technical wrapper.");
+      module_pedigree->version = VERSION;
+      module_pedigree->copyright =
+	"Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
+      module_pedigree->date = __DATE__;
+      module_pedigree->time = __TIME__;
+    }
+
+  return module_pedigree;
+}
+
 lw6gfx_backend_t *
 mod_gl_create_backend ()
 {
@@ -701,12 +798,15 @@ mod_gl_create_backend ()
       backend->poll_quit = _poll_quit;
       backend->send_quit = _send_quit;
       backend->get_key_state = _get_key_state;
+      backend->get_default_keys_state = _get_default_keys_state;
       backend->poll_mouse_move = _poll_mouse_move;
       backend->poll_mouse_button_left = _poll_mouse_button_left;
       backend->poll_mouse_button_right = _poll_mouse_button_right;
       backend->poll_mouse_wheel_up = _poll_mouse_wheel_up;
       backend->poll_mouse_wheel_down = _poll_mouse_wheel_down;
       backend->get_mouse_state = _get_mouse_state;
+      backend->warp_mouse = _warp_mouse;
+      backend->show_mouse = _show_mouse;
       backend->poll_joystick_up = _poll_joystick_up;
       backend->poll_joystick_down = _poll_joystick_down;
       backend->poll_joystick_left = _poll_joystick_left;
@@ -719,13 +819,15 @@ mod_gl_create_backend ()
       backend->display_map_zones = _display_map_zones;
       backend->display_map_gradient = _display_map_gradient;
       backend->display_game = _display_game;
-      backend->pick_map_coord = _pick_map_coord;
+      backend->display_cursors = _display_cursors;
       backend->display_menu = _display_menu;
       backend->pick_menuitem = _pick_menuitem;
       backend->warp_mouse_on_menuitem = _warp_mouse_on_menuitem;
+      backend->center_menu = _center_menu;
       backend->prepare_buffer = _prepare_buffer;
       backend->swap_buffers = _swap_buffers;
       backend->init = _init;
+      backend->set_key_repeat = _set_key_repeat;
       backend->get_low_resolution = _get_low_resolution;
       backend->get_standard_resolution = _get_standard_resolution;
       backend->get_high_resolution = _get_high_resolution;
