@@ -49,7 +49,8 @@ extern _mod_gl_context_t *_mod_gl_init (int argc, char *argv[], int width,
 								 int height,
 								 int
 								 fullscreen),
-					int ticks);
+					int ticks, int key_repeat_delay,
+					int key_repeat_interval);
 extern void _mod_gl_quit (_mod_gl_context_t * gfx_context);
 extern int _mod_gl_set_backends (_mod_gl_context_t * gfx_context,
 				 lw6gui_look_t * look);
