@@ -231,7 +231,7 @@ _mod_gl_set_view_backend (_mod_gl_context_t * gfx_context, char *view_style)
 _mod_gl_context_t *
 _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 	      void (*resize_callback) (int width, int height, int fullscreen),
-	      int ticks)
+	      int ticks, int key_repeat_delay, int key_repeat_interval)
 {
   _mod_gl_context_t *gfx_context = NULL;
   int background_ok = 0;
@@ -248,7 +248,6 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
     {
       if (mod_gl_utils_path_init (&(gfx_context->utils_context), argc, argv))
 	{
-
 	  if (lw6sys_sdl_register ())
 	    {
 	      sdl_ok = !SDL_Init (0);
@@ -267,22 +266,30 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 	    {
 	      lw6sys_log (LW6SYS_LOG_ERROR, _("SDL init error: \"%s\""),
 			  SDL_GetError ());
+	      _mod_gl_quit (gfx_context);
+	      gfx_context = NULL;
 	    }
 
 	  SDL_EnableUNICODE (1);
 
-	  ttf_ok = (TTF_Init () != -1);
-	  if (ttf_ok)
+	  if (gfx_context)
 	    {
-	      lw6sys_log (LW6SYS_LOG_INFO, _("SDL_ttf Init"));
-	    }
-	  else
-	    {
-	      lw6sys_log (LW6SYS_LOG_ERROR,
-			  _("SDL_ttf init error: \"%s\""), TTF_GetError ());
+	      ttf_ok = (TTF_Init () != -1);
+	      if (ttf_ok)
+		{
+		  lw6sys_log (LW6SYS_LOG_INFO, _("SDL_ttf Init"));
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_ERROR,
+			      _("SDL_ttf init error: \"%s\""),
+			      TTF_GetError ());
+		  _mod_gl_quit (gfx_context);
+		  gfx_context = NULL;
+		}
 	    }
 
-	  if (sdl_ok && ttf_ok)
+	  if (gfx_context && sdl_ok && ttf_ok)
 	    {
 	      if (mod_gl_utils_set_video_mode
 		  (&(gfx_context->utils_context), width, height, fullscreen,
@@ -294,8 +301,7 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 		      lw6map_style_defaults (&map_style);
 		      background_ok =
 			_mod_gl_set_background_backend (gfx_context,
-							map_style.
-							background_style);
+							map_style.background_style);
 		      hud_ok =
 			_mod_gl_set_hud_backend (gfx_context,
 						 map_style.hud_style);
@@ -306,21 +312,23 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 			_mod_gl_set_view_backend (gfx_context,
 						  map_style.view_style);
 		      mod_gl_utils_update_team_color_map (&
-							  (gfx_context->
-							   utils_context.
-							   team_color_map),
+							  (gfx_context->utils_context.team_color_map),
 							  &map_style);
 		      lw6map_style_clear (&map_style);
 		    }
 		  else
 		    {
 		      lw6sys_log (LW6SYS_LOG_ERROR, _("unable to load data"));
+		      _mod_gl_quit (gfx_context);
+		      gfx_context = NULL;
 		    }
 		}
 	      else
 		{
 		  lw6sys_log (LW6SYS_LOG_ERROR,
 			      _("unable to set video mode"));
+		  _mod_gl_quit (gfx_context);
+		  gfx_context = NULL;
 		}
 	    }
 
@@ -331,8 +339,8 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 	      if (gfx_context->utils_context.joysticks_state.supported)
 		{
 		  mod_gl_utils_joystick_init (&
-					      (gfx_context->utils_context.
-					       joysticks_state));
+					      (gfx_context->
+					       utils_context.joysticks_state));
 		}
 	      else
 		{
@@ -346,7 +354,13 @@ _mod_gl_init (int argc, char *argv[], int width, int height, int fullscreen,
 	      gfx_context = NULL;
 	    }
 
-	  mod_gl_utils_timer_init (&(gfx_context->utils_context), ticks);
+	  if (gfx_context)
+	    {
+	      mod_gl_utils_timer_init (&(gfx_context->utils_context), ticks);
+	      mod_gl_utils_set_key_repeat (&(gfx_context->utils_context),
+					   key_repeat_delay,
+					   key_repeat_interval);
+	    }
 	}
       else
 	{
@@ -375,8 +389,8 @@ _mod_gl_quit (_mod_gl_context_t * gfx_context)
   if (gfx_context->utils_context.joysticks_state.supported)
     {
       mod_gl_utils_joystick_quit (&
-				  (gfx_context->utils_context.
-				   joysticks_state));
+				  (gfx_context->
+				   utils_context.joysticks_state));
     }
 
   clear_background_backend (gfx_context);
