@@ -38,7 +38,7 @@
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static int seq_id = 0;
+static u_int32_t seq_id = 0;
 
 /*
  * Creates a new default look.
@@ -52,7 +52,11 @@ lw6gui_look_new (lw6map_style_t * map_style)
 
   if (look)
     {
-      look->id = ++seq_id;
+      look->id = 0;
+      while (!look->id)
+	{
+	  look->id = ++seq_id;
+	}
 
       look->dynamic_zoom = DEFAULT_DYNAMIC_ZOOM;
       if (map_style)
@@ -100,7 +104,7 @@ lw6gui_look_repr (lw6gui_look_t * look)
 
   if (look)
     {
-      ret = lw6sys_new_sprintf ("id=%d", look->id);
+      ret = lw6sys_new_sprintf ("id=%u", look->id);
     }
   else
     {
