@@ -33,7 +33,7 @@
  * Theorically, there could be a race condition if several threads used
  * this, in practice, very rare, and, moreover, few consequences.
  */
-static int seq_id = 0;
+static u_int32_t seq_id = 0;
 
 /**
  * lw6gui_menu_new
@@ -57,7 +57,11 @@ lw6gui_menu_new (char *title)
       menu->title = lw6sys_str_copy (title);
       if (menu->title)
 	{
-	  menu->id = ++seq_id;
+	  menu->id = 0;
+	  while (!menu->id)
+	    {
+	      menu->id = ++seq_id;
+	    }
 	}
       else
 	{
@@ -164,7 +168,7 @@ lw6gui_menu_repr (lw6gui_menu_t * menu)
   char *repr;
 
   repr =
-    lw6sys_new_sprintf (_("%d \"%s\" (nb_items=%d)"), menu->id, menu->title,
+    lw6sys_new_sprintf (_("%u \"%s\" (nb_items=%d)"), menu->id, menu->title,
 			menu->nb_items);
 
   return repr;
@@ -244,26 +248,30 @@ lw6gui_menu_select (lw6gui_menu_t * menu, int position, int now)
   int ret = 0;
   int i = 0;
 
-  if (position >= 0 && position < menu->nb_items)
+  if (menu->nb_items > 0)
     {
-      menu->selected_item = position;
-      for (i = 0; i < menu->nb_items; ++i)
+      if (position >= 0 && position < menu->nb_items)
 	{
-	  if (i == position)
+	  menu->selected_item = position;
+	  for (i = 0; i < menu->nb_items; ++i)
 	    {
-	      lw6gui_menuitem_select (menu->items[i], now);
-	    }
-	  else
-	    {
-	      lw6gui_menuitem_unselect (menu->items[i], now);
+	      if (i == position)
+		{
+		  lw6gui_menuitem_select (menu->items[i], now);
+		}
+	      else
+		{
+		  lw6gui_menuitem_unselect (menu->items[i], now);
+		}
 	    }
+	  ret = 1;
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING,
+		      _("menu select out of range (%d/%d)"), position,
+		      menu->nb_items);
 	}
-      ret = 1;
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_WARNING, _("menu select out of range (%d/%d)"),
-		  position, menu->nb_items);
     }
 
   return ret;
@@ -318,6 +326,28 @@ lw6gui_menu_scroll_down (lw6gui_menu_t * menu)
   return ret;
 }
 
+/**
+ * lw6gui_menu_center
+ *
+ * @menu: the menu to center
+ * @position: the position of the menuitem to be put in the center
+ * @max_displayed_items: the maximum number of items displayed
+ *
+ * Centers the menu on a given menuitem. Typically used when pushing
+ * a menu with a menuitem selected 'anywhere' in the list.
+ *
+ * Return value: none.
+ */
+void
+lw6gui_menu_center (lw6gui_menu_t * menu, int position,
+		    int max_displayed_items)
+{
+  menu->first_item_displayed = position - (max_displayed_items / 2);
+  menu->first_item_displayed =
+    lw6sys_min (menu->first_item_displayed, menu->nb_items - 1);
+  menu->first_item_displayed = lw6sys_max (menu->first_item_displayed, 0);
+}
+
 /**
  * lw6gui_menu_insert
  *
