@@ -33,7 +33,7 @@
  * Theorically, there could be a race condition if several threads used
  * this, in practice, very rare, and, moreover, few consequences.
  */
-static int seq_id = 0;
+static u_int32_t seq_id = 0;
 
 /**
  * lw6gui_menuitem_new
@@ -66,7 +66,11 @@ lw6gui_menuitem_new (char *label, int value, int enabled, int selected,
       menuitem->label = lw6sys_str_copy (label);
       if (menuitem->label)
 	{
-	  menuitem->id = ++seq_id;
+	  menuitem->id = 0;
+	  while (!menuitem->id)
+	    {
+	      menuitem->id = ++seq_id;
+	    }
 	  menuitem->value = value;
 	  menuitem->enabled = enabled;
 	  menuitem->selected = selected;
@@ -160,7 +164,7 @@ lw6gui_menuitem_repr (lw6gui_menuitem_t * menuitem)
   char *repr;
 
   repr =
-    lw6sys_new_sprintf (_("%d \"%s\" (value=%d)"), menuitem->id,
+    lw6sys_new_sprintf (_("%u \"%s\" (value=%d)"), menuitem->id,
 			menuitem->label, menuitem->value);
 
   return repr;
