@@ -31,7 +31,7 @@
 
 typedef struct lw6gui_look_s
 {
-  int id;
+  u_int32_t id;
   int focus_id;
   float dynamic_zoom;
   lw6map_style_t style;
@@ -48,7 +48,7 @@ lw6gui_keypress_t;
 
 typedef struct lw6gui_menuitem_s
 {
-  int id;
+  u_int32_t id;
   char *label;
   int value;
   int enabled;
@@ -62,7 +62,7 @@ lw6gui_menuitem_t;
 
 typedef struct lw6gui_menu_s
 {
-  int id;
+  u_int32_t id;
   char *title;
   int nb_items;
   lw6gui_menuitem_t **items;
@@ -109,9 +109,11 @@ extern lw6gui_menuitem_t *lw6gui_menu_get_item (lw6gui_menu_t * menu,
 extern int lw6gui_menu_select (lw6gui_menu_t * menu, int position, int now);
 extern int lw6gui_menu_scroll_up (lw6gui_menu_t * menu);
 extern int lw6gui_menu_scroll_down (lw6gui_menu_t * menu);
+extern void lw6gui_menu_center (lw6gui_menu_t * menu, int position,
+				int max_displayed_items);
 extern int lw6gui_menu_insert (lw6gui_menu_t * menu,
-			       lw6gui_menuitem_t * menuitem,
-			       int position, int now);
+			       lw6gui_menuitem_t * menuitem, int position,
+			       int now);
 extern int lw6gui_menu_append (lw6gui_menu_t * menu,
 			       lw6gui_menuitem_t * menuitem, int now);
 extern int lw6gui_menu_remove (lw6gui_menu_t * menu, int position, int now);
