@@ -51,14 +51,14 @@ print_content_callback (void *func_data, void *data)
   char *entry = NULL;
   char *desc = NULL;
   char *about;
-  LW6HLP_TYPE type;
+  lw6hlp_type_t type;
 
   f = (FILE *) func_data;
   entry = (char *) data;
   if (entry)
     {
       about = lw6hlp_about (&type, entry);
-      if (lw6hlp_match (entry, "about"))
+      if (lw6hlp_match (entry, LW6DEF_ABOUT))
 	{
 	  /*
 	   * OK this is ugly, but so much less complicated than handling
