@@ -26,7 +26,7 @@
 
 #include "hlp.h"
 
-#define TEST_KEYWORD "prefix"
+#define TEST_KEYWORD LW6DEF_PREFIX
 
 /*
  * Testing about
