@@ -25,7 +25,13 @@
 
 #include "../sys/sys.h"
 
-typedef enum LW6HLP_TYPE_ENUM
+#define LW6HLP_MAIN_BEGIN {lw6hlp_reference_init();}
+#define LW6HLP_MAIN_END {lw6hlp_reference_quit();}
+
+// used to create hash tables for help & config
+#define LW6HLP_APPROX_NB_ENTRIES 421
+
+typedef enum lw6hlp_type_e
 {
   LW6HLP_TYPE_VOID = 0,
   LW6HLP_TYPE_STR = 1,
@@ -34,19 +40,17 @@ typedef enum LW6HLP_TYPE_ENUM
   LW6HLP_TYPE_BOOL = 4,
   LW6HLP_TYPE_COLOR = 5
 }
-LW6HLP_TYPE;
+lw6hlp_type_t;
 
 /* hlp-about.c */
 extern int lw6hlp_is_documented (char *keyword);
-extern char *lw6hlp_about (LW6HLP_TYPE * type, char *keyword);
-extern LW6HLP_TYPE lw6hlp_get_type (char *keyword);
+extern char *lw6hlp_about (lw6hlp_type_t * type, char *keyword);
+extern lw6hlp_type_t lw6hlp_get_type (char *keyword);
 
 /* hlp-keyword.c */
 extern int lw6hlp_match (char *keyword1, char *keyword2);
 
 /* hlp-list.c */
-extern int lw6hlp_is_listed (char *keyword);
-extern int lw6hlp_is_listed_here (lw6sys_list_t * list, char *keyword);
 extern lw6sys_list_t *lw6hlp_list_quick ();
 extern lw6sys_list_t *lw6hlp_list_doc ();
 extern lw6sys_list_t *lw6hlp_list_show ();
@@ -57,7 +61,8 @@ extern lw6sys_list_t *lw6hlp_list_graphics ();
 extern lw6sys_list_t *lw6hlp_list_sound ();
 extern lw6sys_list_t *lw6hlp_list_network ();
 extern lw6sys_list_t *lw6hlp_list_map ();
-extern lw6sys_list_t *lw6hlp_list_map_options ();
+extern lw6sys_list_t *lw6hlp_list_map_rules ();
+extern lw6sys_list_t *lw6hlp_list_map_hints ();
 extern lw6sys_list_t *lw6hlp_list_map_style ();
 extern lw6sys_list_t *lw6hlp_list_funcs ();
 extern lw6sys_list_t *lw6hlp_list_hooks ();
@@ -69,6 +74,10 @@ extern lw6sys_list_t *lw6hlp_list ();
 extern void lw6hlp_print_keyword (lw6sys_list_t ** list, FILE * f);
 extern void lw6hlp_print_content (lw6sys_list_t ** list, FILE * f);
 
+/* hlp-reference.c */
+extern int lw6hlp_reference_init ();
+extern void lw6hlp_reference_quit ();
+
 /* hlp-test.c */
 extern int lw6hlp_test ();
 
