@@ -24,15 +24,13 @@
 #include "config.h"
 #endif
 
-#include <string.h>
-
 #include "ker.h"
 #include "ker-internal.h"
 
 int
 _lw6ker_armies_init (lw6ker_armies_t * armies,
 		     lw6ker_map_struct_t * map_struct,
-		     lw6map_options_t * options)
+		     lw6map_rules_t * options)
 {
   int ret = 0;
 
@@ -40,8 +38,7 @@ _lw6ker_armies_init (lw6ker_armies_t * armies,
   ret = 1;
   armies->map_struct = map_struct;
   armies->max_fighters =
-    lw6ker_per1000 (map_struct->room_for_armies,
-		    options->total_armies_surface);
+    lw6ker_per100_2 (map_struct->room_for_armies, options->total_armies_size);
   armies->active_fighters = 0;
   armies->fighters =
     (lw6ker_fighter_t *) LW6SYS_CALLOC (armies->max_fighters *
@@ -73,12 +70,12 @@ _lw6ker_armies_clear (lw6ker_armies_t * armies)
 }
 
 int
-_lw6ker_armies_copy (lw6ker_armies_t * dst, lw6ker_armies_t * src)
+_lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src)
 {
   int ret = 0;
 
-  if (dst && src && dst->map_struct && src->map_struct
-      && dst->map_struct == src->map_struct)
+  if (dst && src
+      && _lw6ker_map_struct_lazy_compare (dst->map_struct, src->map_struct))
     {
       int i;
 
@@ -129,7 +126,7 @@ lw6ker_armies_add_fighter (lw6ker_armies_t * armies, lw6ker_fighter_t fighter)
     {
       new_id = armies->active_fighters;
       armies->fighters[new_id] = fighter;
-      armies->fighters_per_team[fighter.team_id]++;
+      armies->fighters_per_team[fighter.team_color]++;
       armies->active_fighters++;
     }
   else
@@ -158,7 +155,8 @@ lw6ker_armies_remove_fighter (lw6ker_armies_t * armies)
       int32_t last_fighter_id;
 
       last_fighter_id = armies->active_fighters - 1;
-      armies->fighters_per_team[armies->fighters[last_fighter_id].team_id]--;
+      armies->fighters_per_team[armies->
+				fighters[last_fighter_id].team_color]--;
       /*
        * This memset might not be truely needed but well, it can't harm,
        * and fighter addition/deletion is rare enough that we can take
