@@ -48,7 +48,7 @@ void
 _lw6ker_fighter_update_checksum (lw6ker_fighter_t * fighter,
 				 u_int32_t * checksum)
 {
-  lw6sys_checksum_update_int32 (checksum, fighter->team_id);
+  lw6sys_checksum_update_int32 (checksum, fighter->team_color);
   lw6sys_checksum_update_int32 (checksum, fighter->layer);
   lw6sys_checksum_update_int32 (checksum, fighter->last_direction);
   lw6sys_checksum_update_int32 (checksum, fighter->health);
@@ -60,8 +60,8 @@ _lw6ker_fighter_print_debug (lw6ker_fighter_t * fighter)
 {
   lw6sys_log (LW6SYS_LOG_DEBUG,
 	      _
-	      ("fighter team_id=%d, layer=%d, last_direction=%d, health=%d, x=%d, y=%d"),
-	      fighter->team_id, fighter->layer, fighter->last_direction,
+	      ("fighter team_color=%d, layer=%d, last_direction=%d, health=%d, x=%d, y=%d"),
+	      fighter->team_color, fighter->layer, fighter->last_direction,
 	      fighter->health, (int) fighter->pos.x, (int) fighter->pos.y);
 }
 
@@ -95,8 +95,8 @@ _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
       /*
        * Reflect changes in pre-calculated values
        */
-      (map_state->armies.fighters_per_team[fighter->team_id])++;
-      (map_state->armies.fighters_per_team[enemy->team_id])--;
+      (map_state->armies.fighters_per_team[fighter->team_color])++;
+      (map_state->armies.fighters_per_team[enemy->team_color])--;
       /*
        * Give the conquered enemy some health
        */
@@ -104,7 +104,7 @@ _lw6ker_fighter_attack (lw6ker_fighter_t * fighter,
       /*
        * Change it to our team
        */
-      enemy->team_id = fighter->team_id;
+      enemy->team_color = fighter->team_color;
     }
 }
 
