@@ -42,37 +42,43 @@ extern int32_t
  */
 extern int _lw6ker_armies_init (lw6ker_armies_t * armies,
 				lw6ker_map_struct_t * map_struct,
-				lw6map_options_t * options);
+				lw6map_rules_t * options);
 extern void _lw6ker_armies_clear (lw6ker_armies_t * armies);
-extern int _lw6ker_armies_copy (lw6ker_armies_t * dst, lw6ker_armies_t * src);
+extern int _lw6ker_armies_sync (lw6ker_armies_t * dst, lw6ker_armies_t * src);
 extern void _lw6ker_armies_update_checksum (lw6ker_armies_t * armies,
 					    u_int32_t * checksum);
 
-extern int _lw6ker_bot_init (lw6ker_bot_t * bot, lw6ker_cursor_t * cursor,
-			     int32_t rounds);
-extern void _lw6ker_bot_clear (lw6ker_bot_t * bot);
-extern void _lw6ker_bot_update_checksum (lw6ker_bot_t * bot,
-					 u_int32_t * checksum);
-extern void _lw6ker_bot_update_pos (lw6ker_bot_t * bot,
-				    lw6ker_game_state_t * game_state);
-
 /*
  * In cursor.c
  */
-extern int _lw6ker_cursor_init (lw6ker_cursor_t * cursor, lw6sys_xy_t pos);
+extern void _lw6ker_cursor_reset (lw6ker_cursor_t * cursor);
+extern void _lw6ker_cursor_init (lw6ker_cursor_t * cursor, char letter);
 extern void _lw6ker_cursor_update_checksum (lw6ker_cursor_t * cursor,
 					    u_int32_t * checksum);
-extern void _lw6ker_cursor_update_last_applied (lw6ker_cursor_t * cursor);
+extern int _lw6ker_cursor_check_server_id (lw6ker_cursor_t * cursor,
+					   u_int64_t server_id);
+extern int _lw6ker_cursor_get_start_xy (int32_t * x, int32_t * y,
+					int team_color,
+					lw6sys_wh_t * shape,
+					lw6map_rules_t * rules);
+extern void _lw6ker_cursor_update_apply_pos (lw6ker_cursor_t * cursor,
+					     lw6ker_map_struct_t *
+					     map_struct);
 
 /*
  * In cursorarray.c
  */
+extern void _lw6ker_cursor_array_reset (lw6ker_cursor_array_t * cursor_array);
+extern void _lw6ker_cursor_array_init (lw6ker_cursor_array_t * cursor_array);
 extern void _lw6ker_cursor_array_update_checksum (lw6ker_cursor_array_t *
 						  cursor_array,
 						  u_int32_t * checksum);
-extern void _lw6ker_cursor_array_activate (lw6ker_cursor_array_t *
-					   cursor_array, int32_t nb_cursors,
-					   lw6sys_xy_t pos);
+extern lw6ker_cursor_t *_lw6ker_cursor_array_find_free (lw6ker_cursor_array_t
+							* cursor_array);
+extern int _lw6ker_cursor_array_is_color_owned_by (lw6ker_cursor_array_t *
+						   cursor_array,
+						   u_int64_t server_id,
+						   int team_color);
 
 /*
  * In fighter.c
@@ -119,9 +125,9 @@ extern void _lw6ker_game_struct_update_checksum (lw6ker_game_struct_t *
 extern int _lw6ker_layer_init (lw6ker_layer_t * layer,
 			       lw6ker_map_struct_t * map_struct,
 			       lw6ker_armies_t * armies,
-			       lw6map_options_t * options);
+			       lw6map_rules_t * options);
 extern void _lw6ker_layer_clear (lw6ker_layer_t * layer);
-extern int _lw6ker_layer_copy (lw6ker_layer_t * dst, lw6ker_layer_t * src);
+extern int _lw6ker_layer_sync (lw6ker_layer_t * dst, lw6ker_layer_t * src);
 extern void _lw6ker_layer_update_checksum (lw6ker_layer_t * layer,
 					   u_int32_t * checksum);
 
@@ -139,9 +145,10 @@ extern int _lw6ker_map_metadata_rectangle (lw6map_metadata_t * metadata,
  */
 extern int _lw6ker_map_state_init (lw6ker_map_state_t * map_state,
 				   lw6ker_map_struct_t * map_struct,
-				   lw6map_options_t * options);
+				   lw6map_rules_t * options,
+				   lw6sys_progress_t * progress);
 extern void _lw6ker_map_state_clear (lw6ker_map_state_t * map_state);
-extern int _lw6ker_map_state_copy (lw6ker_map_state_t * dst,
+extern int _lw6ker_map_state_sync (lw6ker_map_state_t * dst,
 				   lw6ker_map_state_t * src);
 extern void _lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
 					       u_int32_t * checksum);
@@ -151,21 +158,51 @@ extern int _lw6ker_map_state_is_slot_free (lw6ker_map_state_t *
 					   int32_t x, int32_t y);
 extern int _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t *
 					     map_state,
-					     int32_t team_id,
+					     int32_t team_color,
 					     int32_t layer,
 					     int32_t x, int32_t y);
+extern int _lw6ker_map_state_is_ally_there (lw6ker_map_state_t *
+					    map_state,
+					    int32_t team_color,
+					    int32_t layer,
+					    int32_t x, int32_t y);
+extern int _lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state);
 
 /*
  * In mapstruct.c
  */
 extern int _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
-				    lw6map_level_t * level);
+				    lw6map_level_t * level,
+				    lw6sys_progress_t * progress);
 extern void _lw6ker_map_struct_clear (lw6ker_map_struct_t * map_struct);
 extern float _lw6ker_map_struct_get_compression (lw6ker_map_struct_t *
 						 map_struct);
 extern void _lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
 						map_struct,
 						u_int32_t * checksum);
+extern int _lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
+					    map_struct_a,
+					    lw6ker_map_struct_t *
+					    map_struct_b);
+
+/*
+ * In server.c
+ */
+extern void _lw6ker_server_reset (lw6ker_server_t * server);
+extern void _lw6ker_server_init (lw6ker_server_t * server);
+extern void _lw6ker_server_update_checksum (lw6ker_server_t * server,
+					    u_int32_t * checksum);
+
+/*
+ * In serverarray.c
+ */
+extern void _lw6ker_server_array_reset (lw6ker_server_array_t * server_array);
+extern void _lw6ker_server_array_init (lw6ker_server_array_t * server_array);
+extern void _lw6ker_server_array_update_checksum (lw6ker_server_array_t *
+						  server_array,
+						  u_int32_t * checksum);
+extern lw6ker_server_t *_lw6ker_server_array_find_free (lw6ker_server_array_t
+							* server_array);
 
 /*
  * In slotstruct.c
@@ -179,9 +216,9 @@ extern void _lw6ker_slot_struct_update_checksum (lw6ker_slot_struct_t *
  */
 extern int _lw6ker_team_init (lw6ker_team_t * team,
 			      lw6ker_map_struct_t * map_struct,
-			      lw6map_options_t * options);
+			      lw6map_rules_t * options);
 extern void _lw6ker_team_clear (lw6ker_team_t * team);
-extern int _lw6ker_team_copy (lw6ker_team_t * dst, lw6ker_team_t * src);
+extern int _lw6ker_team_sync (lw6ker_team_t * dst, lw6ker_team_t * src);
 extern void _lw6ker_team_update_checksum (lw6ker_team_t * team,
 					  u_int32_t * checksum);
 
