@@ -33,7 +33,7 @@
 int
 _lw6ker_layer_init (lw6ker_layer_t * layer,
 		    lw6ker_map_struct_t * map_struct,
-		    lw6ker_armies_t * armies, lw6map_options_t * options)
+		    lw6ker_armies_t * armies, lw6map_rules_t * options)
 {
   int ret = 0;
   int32_t i;
@@ -78,12 +78,12 @@ _lw6ker_layer_clear (lw6ker_layer_t * layer)
 }
 
 int
-_lw6ker_layer_copy (lw6ker_layer_t * dst, lw6ker_layer_t * src)
+_lw6ker_layer_sync (lw6ker_layer_t * dst, lw6ker_layer_t * src)
 {
   int ret = 0;
 
-  if (dst && src && dst->map_struct && src->map_struct
-      && dst->map_struct == src->map_struct)
+  if (dst && src
+      && _lw6ker_map_struct_lazy_compare (dst->map_struct, src->map_struct))
     {
       dst->nb_slots = src->nb_slots;
       memcpy (dst->slots, src->slots,
