@@ -30,45 +30,49 @@
 #include "ker.h"
 #include "ker-internal.h"
 
-typedef struct polarity_data_s
-{
-  int32_t fighter_x;
-  int32_t fighter_y;
-  int32_t map_w;
-  int32_t map_h;
-} polarity_data_t;
-
 int
 _lw6ker_map_state_init (lw6ker_map_state_t * map_state,
 			lw6ker_map_struct_t * map_struct,
-			lw6map_options_t * options)
+			lw6map_rules_t * rules, lw6sys_progress_t * progress)
 {
   int ret = 0;
   int32_t i;
+  int progress_i = 0;
+  int progress_n = 0;
+
+  lw6sys_progress_begin (progress);
+
+  progress_n = 1 + map_struct->max_depth + rules->max_nb_teams;
 
   map_state->map_struct = map_struct;
   map_state->shape = map_struct->shape;
 
   ret = 1;
 
-  ret = ret
-    && _lw6ker_armies_init (&(map_state->armies), map_struct, options);
+  _lw6ker_cursor_array_init (&(map_state->cursor_array));
+
+  ret = ret && _lw6ker_armies_init (&(map_state->armies), map_struct, rules);
+  lw6sys_progress_update (progress, 0, progress_n, progress_i++);
 
   map_state->nb_layers = map_struct->max_depth;
   for (i = 0; i < map_state->nb_layers; ++i)
     {
       ret = ret
 	&& _lw6ker_layer_init (&(map_state->layers[i]), map_state->map_struct,
-			       &(map_state->armies), options);
+			       &(map_state->armies), rules);
+      lw6sys_progress_update (progress, 0, progress_n, progress_i++);
     }
 
-  map_state->max_nb_teams = options->max_nb_teams;
+  map_state->max_nb_teams = rules->max_nb_teams;
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
       ret = ret
-	&& _lw6ker_team_init (&(map_state->teams[i]), map_struct, options);
+	&& _lw6ker_team_init (&(map_state->teams[i]), map_struct, rules);
+      lw6sys_progress_update (progress, 0, progress_n, progress_i++);
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
@@ -96,28 +100,30 @@ _lw6ker_map_state_clear (lw6ker_map_state_t * map_state)
 }
 
 int
-_lw6ker_map_state_copy (lw6ker_map_state_t * dst, lw6ker_map_state_t * src)
+_lw6ker_map_state_sync (lw6ker_map_state_t * dst, lw6ker_map_state_t * src)
 {
   int ret = 0;
 
-  if (dst && src && dst->map_struct && src->map_struct
-      && dst->map_struct == src->map_struct)
+  if (dst && src
+      && _lw6ker_map_struct_lazy_compare (dst->map_struct, src->map_struct))
     {
       int i;
 
       dst->shape = src->shape;
-      ret = _lw6ker_armies_copy (&(dst->armies), &(src->armies));
+      ret = _lw6ker_armies_sync (&(dst->armies), &(src->armies));
       dst->max_nb_teams = src->max_nb_teams;
       for (i = 0; i < src->max_nb_teams; ++i)
 	{
-	  ret = ret && _lw6ker_team_copy (&(dst->teams[i]), &(src->teams[i]));
+	  ret = ret && _lw6ker_team_sync (&(dst->teams[i]), &(src->teams[i]));
 	}
       dst->nb_layers = src->nb_layers;
       for (i = 0; i < src->nb_layers; ++i)
 	{
 	  ret = ret
-	    && _lw6ker_layer_copy (&(dst->layers[i]), &(src->layers[i]));
+	    && _lw6ker_layer_sync (&(dst->layers[i]), &(src->layers[i]));
 	}
+      memcpy (&(dst->cursor_array), &(src->cursor_array),
+	      sizeof (lw6ker_cursor_array_t));
     }
   else
     {
@@ -150,13 +156,14 @@ _lw6ker_map_state_update_checksum (lw6ker_map_state_t * map_state,
     {
       _lw6ker_layer_update_checksum (&(map_state->layers[i]), checksum);
     }
+  _lw6ker_cursor_array_update_checksum (&(map_state->cursor_array), checksum);
 }
 
-int32_t
-lw6ker_map_state_get_free_team_id (lw6ker_map_state_t * map_state)
+int
+lw6ker_map_state_get_free_team_color (lw6ker_map_state_t * map_state)
 {
   int32_t i;
-  int32_t ret = -1;
+  int32_t ret = LW6MAP_TEAM_COLOR_INVALID;
 
   for (i = 0; i < LW6MAP_MAX_NB_TEAMS && ret < 0; ++i)
     {
@@ -169,52 +176,12 @@ lw6ker_map_state_get_free_team_id (lw6ker_map_state_t * map_state)
   return ret;
 }
 
-void
-lw6ker_map_state_start_xy (lw6ker_map_state_t * map_state,
-			   lw6sys_xy_t * start_xy, int32_t team_id)
-{
-  int32_t angle;
-  int32_t team_ip, team_fp;
-
-  team_ip = (team_id / 2) * 2;	// unoptimized, but well, is "& 0xFFFFFFFE" cleaner? 
-  team_fp = team_id % 2;
-
-  angle =
-    (LW6KER_TRIGO_PI * team_ip) / LW6MAP_MAX_NB_TEAMS +
-    LW6KER_TRIGO_PI * team_fp + (5 * LW6KER_TRIGO_PI) / 4;
-  start_xy->x =
-    map_state->shape.w / 2 +
-    (lw6ker_cos (angle) * ((map_state->shape.w / 2) - 1)) /
-    LW6KER_TRIGO_RADIUS;
-  start_xy->y =
-    map_state->shape.h / 2 +
-    (lw6ker_sin (angle) * ((map_state->shape.h / 2) - 1)) /
-    LW6KER_TRIGO_RADIUS;
-}
-
-int32_t
-lw6ker_map_state_get_nb_active_teams (lw6ker_map_state_t * map_state)
-{
-  int32_t i;
-  int32_t ret = 0;
-
-  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
-    {
-      if (map_state->teams[i].active)
-	{
-	  ret++;
-	}
-    }
-
-  return ret;
-}
-
 int32_t
 lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
-				int32_t team_id,
+				int32_t team_color,
 				int32_t nb_fighters,
 				lw6sys_xy_t desired_center,
-				int32_t nb_cursors, lw6map_options_t options)
+				lw6map_rules_t * rules)
 {
   lw6sys_xy_t real_center;
   int32_t angle, radius;
@@ -225,78 +192,75 @@ lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
   int32_t layer;
   int32_t new_fighter_id;
   lw6ker_fighter_t new_fighter;
+  lw6sys_wh_t shape;
 
+  shape = map_state->shape;
   _lw6ker_fighter_clear (&new_fighter);
   lw6ker_map_struct_find_free_slot_near (map_state->map_struct, &real_center,
 					 desired_center);
-
-  max_radius = map_state->map_struct->shape.w + map_state->map_struct->shape.h;	// +, not *
+  max_radius = 2 * (map_state->map_struct->shape.w + map_state->map_struct->shape.h);	// +, not *
   for (radius = 1; radius < max_radius && nb_fighters_added < nb_fighters;
        ++radius)
     {
-      max_angle = radius * M_PI * 2;
+      max_angle = radius * M_PI * 4;
       for (angle = 0; angle < max_angle && nb_fighters_added < nb_fighters;
 	   ++angle)
 	{
 	  x =
 	    real_center.x +
 	    (lw6ker_cos ((angle * LW6KER_TRIGO_2PI) / max_angle) * radius) /
-	    LW6KER_TRIGO_RADIUS;
+	    (LW6KER_TRIGO_RADIUS * 2);
 	  y =
 	    real_center.y -
 	    (lw6ker_sin ((angle * LW6KER_TRIGO_2PI) / max_angle) * radius) /
-	    LW6KER_TRIGO_RADIUS;
-	  if (x >= 0 && x < map_state->map_struct->shape.w && y >= 0
-	      && y < map_state->map_struct->shape.h)
+	    (LW6KER_TRIGO_RADIUS * 2);
+
+	  lw6map_coords_fix (rules, &shape, &x, &y);
+
+	  depth = lw6ker_map_struct_get_depth (map_state->map_struct, x, y);
+	  for (layer = 0; layer < map_state->nb_layers && layer < depth;
+	       ++layer)
 	    {
-	      depth =
-		lw6ker_map_struct_get_depth (map_state->map_struct, x, y);
-	      for (layer = 0; layer < map_state->nb_layers && layer < depth;
-		   ++layer)
+	      if (lw6ker_map_state_get_fighter_id (map_state, layer, x, y)
+		  < 0)
 		{
-		  if (lw6ker_map_state_get_fighter_id (map_state, layer, x, y)
-		      < 0)
+		  new_fighter.team_color = team_color;
+		  new_fighter.layer = layer;
+		  new_fighter.pos.x = x;
+		  new_fighter.pos.y = y;
+		  new_fighter.health = LW6MAP_MAX_FIGHTER_HEALTH;
+		  new_fighter.last_direction = 0;
+		  new_fighter_id =
+		    lw6ker_armies_add_fighter (&(map_state->armies),
+					       new_fighter);
+		  if (new_fighter_id >= 0)
 		    {
-		      new_fighter.team_id = team_id;
-		      new_fighter.layer = layer;
-		      new_fighter.pos.x = x;
-		      new_fighter.pos.y = y;
-		      new_fighter.health = LW6MAP_MAX_FIGHTER_HEALTH;
-		      new_fighter.last_direction = 0;
-		      new_fighter_id =
-			lw6ker_armies_add_fighter (&(map_state->armies),
-						   new_fighter);
-		      if (new_fighter_id >= 0)
-			{
-			  nb_fighters_added++;
-			  lw6ker_map_state_set_fighter_id (map_state, layer,
-							   x, y,
-							   new_fighter_id);
-			}
+		      nb_fighters_added++;
+		      lw6ker_map_state_set_fighter_id (map_state, layer,
+						       x, y, new_fighter_id);
 		    }
 		}
 	    }
 	}
     }
 
-  lw6ker_team_activate (&(map_state->teams[team_id]), nb_cursors,
-			real_center);
+  lw6ker_team_activate (&(map_state->teams[team_color]), real_center);
 
   return nb_fighters_added;
 }
 
 int
 lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
-				    int32_t dst_team_id,
-				    int32_t src_team_id,
+				    int32_t dst_team_color,
+				    int32_t src_team_color,
 				    int32_t nb_fighters,
-				    lw6map_options_t options)
+				    lw6map_rules_t * rules)
 {
   int ret = 0;
   int32_t i, j;
   int32_t nb_fighters_redistributed = 0;
 
-  if (nb_fighters <= map_state->armies.fighters_per_team[src_team_id])
+  if (nb_fighters <= map_state->armies.fighters_per_team[src_team_color])
     {
       while (nb_fighters_redistributed < nb_fighters)
 	{
@@ -309,11 +273,13 @@ lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
 		   && nb_fighters_redistributed < nb_fighters;
 		   j += LW6MAP_MAX_NB_TEAMS)
 		{
-		  if (map_state->armies.fighters[j].team_id == src_team_id)
+		  if (map_state->armies.fighters[j].team_color ==
+		      src_team_color)
 		    {
-		      map_state->armies.fighters[j].team_id = dst_team_id;
-		      (map_state->armies.fighters_per_team[src_team_id])--;
-		      (map_state->armies.fighters_per_team[dst_team_id])++;
+		      map_state->armies.fighters[j].team_color =
+			dst_team_color;
+		      (map_state->armies.fighters_per_team[src_team_color])--;
+		      (map_state->armies.fighters_per_team[dst_team_color])++;
 		      map_state->armies.fighters[j].health =
 			LW6MAP_MAX_FIGHTER_HEALTH;
 		      nb_fighters_redistributed++;
@@ -328,36 +294,38 @@ lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _
 		  ("can't redistribute %d fighters from team %d which has only %d"),
-		  nb_fighters, src_team_id,
-		  map_state->armies.fighters_per_team[src_team_id]);
+		  nb_fighters, src_team_color,
+		  map_state->armies.fighters_per_team[src_team_color]);
     }
 
   return ret;
 }
 
 int
-lw6ker_map_state_cancel_team (lw6ker_map_state_t * map_state, int32_t team_id)
+lw6ker_map_state_cancel_team (lw6ker_map_state_t * map_state,
+			      int32_t team_color)
 {
   int ret = 0;
 
-  if (map_state->teams[team_id].active)
+  if (map_state->teams[team_color].active)
     {
-      if (map_state->armies.fighters_per_team[team_id] == 0)
+      if (map_state->armies.fighters_per_team[team_color] == 0)
 	{
-	  lw6ker_team_unactivate (&(map_state->teams[team_id]));
+	  lw6ker_team_unactivate (&(map_state->teams[team_color]));
 	}
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
 		      ("trying to cancel non-zeroed team %d, still has %d fighters"),
-		      team_id, map_state->armies.fighters_per_team[team_id]);
+		      team_color,
+		      map_state->armies.fighters_per_team[team_color]);
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("trying to cancel inactive team %d"), team_id);
+		  _("trying to cancel inactive team %d"), team_color);
     }
 
   return ret;
@@ -387,7 +355,7 @@ lw6ker_map_state_remove_fighter (lw6ker_map_state_t * map_state,
 	  /*
 	   * It's important to really *exchange* the fighters, for
 	   * deletion in the armies struct will read the last fighter's
-	   * team_id for instance, to maintain the list of active
+	   * team_color for instance, to maintain the list of active
 	   * fighters in each team. So affecting the remaining one
 	   * is not enough.
 	   */
@@ -457,14 +425,15 @@ lw6ker_map_state_remove_fighters (lw6ker_map_state_t * map_state,
 
 int
 lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t * map_state,
-				       int32_t team_id, int32_t nb_fighters)
+				       int32_t team_color,
+				       int32_t nb_fighters)
 {
   int ret = 0;
   int32_t nb_fighters_removed = 0;
   int32_t i, j;
 
   nb_fighters =
-    lw6sys_min (nb_fighters, map_state->armies.fighters_per_team[team_id]);
+    lw6sys_min (nb_fighters, map_state->armies.fighters_per_team[team_color]);
 
   while (nb_fighters_removed < nb_fighters)
     {
@@ -475,7 +444,7 @@ lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t * map_state,
 	       j < map_state->armies.active_fighters
 	       && nb_fighters_removed < nb_fighters; j += LW6MAP_MAX_NB_TEAMS)
 	    {
-	      if (map_state->armies.fighters[j].team_id == team_id)
+	      if (map_state->armies.fighters[j].team_color == team_color)
 		{
 		  lw6ker_map_state_remove_fighter (map_state, j);
 		  nb_fighters_removed++;
@@ -556,15 +525,15 @@ lw6ker_map_state_sanity_check (lw6ker_map_state_t * map_state)
   for (i = 0; i < map_state->armies.active_fighters; ++i)
     {
       fighter = map_state->armies.fighters[i];
-      if (fighter.team_id >= LW6MAP_MAX_NB_TEAMS)	// <0 check useless, unsigned
+      if (fighter.team_color >= LW6MAP_MAX_NB_TEAMS)	// <0 check useless, unsigned
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _
-		      ("fighter.team_id out of range (%d) for fighter %d"),
-		      fighter.team_id, i);
+		      ("fighter.team_color out of range (%d) for fighter %d"),
+		      fighter.team_color, i);
 	  ret = 0;
 	}
-      (real_fighters_per_team[fighter.team_id])++;
+      (real_fighters_per_team[fighter.team_color])++;
       fighter_id =
 	lw6ker_map_state_get_fighter_id (map_state, fighter.layer,
 					 fighter.pos.x, fighter.pos.y);
@@ -608,37 +577,22 @@ lw6ker_map_state_sanity_check (lw6ker_map_state_t * map_state)
  */
 void
 lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
-				  lw6map_options_t * options,
-				  int32_t nb_spreads)
+				  lw6map_rules_t * rules, int32_t nb_spreads,
+				  u_int32_t team_mask)
 {
   int i, j;
 
+  lw6ker_map_state_apply_cursors (map_state, rules, team_mask);
   for (i = 0; i < map_state->max_nb_teams; ++i)
     {
-      /*
-       * Ideas for optimization:
-       * - on SMP machines, the various spread_gradient fonctions
-       *   could be called in separated threads. One needs to
-       *   check wether the cost of creating the threads and
-       *   joigning them is worth it, but it could.
-       * - spread gradient could be called "less often" when
-       *   cursors do not move. Ideally if there's a big move,
-       *   we'd call it many times to have accurate results,
-       *   but if it didn't really move, well, we'll just spread
-       *   once in a while.
-       */
       if (map_state->teams[i].active)
 	{
-	  /*
-	   * Note for optimization: on SMP machines, one could decide
-	   * to fire several threads, say one per team, and compute
-	   * each team on a separate thread (possibly a separate CPU)
-	   * and this way one could use more than one single CPU.
-	   */
-	  lw6ker_team_apply_cursors (&(map_state->teams[i]), options);
-	  for (j = 0; j < nb_spreads; ++j)
+	  if (lw6ker_team_mask_is_concerned (i, team_mask))
 	    {
-	      lw6ker_team_spread_gradient (&(map_state->teams[i]));
+	      for (j = 0; j < nb_spreads; ++j)
+		{
+		  lw6ker_team_spread_gradient (&(map_state->teams[i]));
+		}
 	    }
 	}
     }
@@ -654,7 +608,7 @@ _lw6ker_map_state_is_slot_free (lw6ker_map_state_t * map_state,
 
 int
 _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
-				  int32_t team_id,
+				  int32_t team_color,
 				  int32_t layer, int32_t x, int32_t y)
 {
   int ret = 0;
@@ -666,7 +620,8 @@ _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
       enemy_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
       if (enemy_id >= 0)
 	{
-	  ret = (map_state->armies.fighters[enemy_id].team_id != team_id);
+	  ret =
+	    (map_state->armies.fighters[enemy_id].team_color != team_color);
 	}
     }
 
@@ -675,7 +630,7 @@ _lw6ker_map_state_is_enemy_there (lw6ker_map_state_t * map_state,
 
 int
 _lw6ker_map_state_is_ally_there (lw6ker_map_state_t * map_state,
-				 int32_t team_id,
+				 int32_t team_color,
 				 int32_t layer, int32_t x, int32_t y)
 {
   int ret = 0;
@@ -687,7 +642,25 @@ _lw6ker_map_state_is_ally_there (lw6ker_map_state_t * map_state,
       ally_id = lw6ker_map_state_get_fighter_id (map_state, layer, x, y);
       if (ally_id >= 0)
 	{
-	  ret = (map_state->armies.fighters[ally_id].team_id == team_id);
+	  ret =
+	    (map_state->armies.fighters[ally_id].team_color == team_color);
+	}
+    }
+
+  return ret;
+}
+
+int
+_lw6ker_map_state_get_nb_teams (lw6ker_map_state_t * map_state)
+{
+  int ret = 0;
+  int i;
+
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (map_state->teams[i].active)
+	{
+	  ret++;
 	}
     }
 
@@ -734,7 +707,7 @@ find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
     lw6ker_map_struct_get_zone_id (map_state->map_struct, fighter->pos.x,
 				   fighter->pos.y);
   lw6ker_zone_state_t *zone_states =
-    map_state->teams[fighter->team_id].gradient;
+    map_state->teams[fighter->team_color].gradient;
 
   if (zone_id >= 0)
     {
@@ -829,264 +802,17 @@ find_best_dir (lw6ker_map_state_t * map_state, lw6ker_fighter_t * fighter,
   return ret;
 }
 
-/*
- * All "polarity" functions follow a uniform scheme:
- * x means x is wrapped (left connected to right)
- * ix means x is wrapped and inversed
- * y means y is wrapped (top connected to bottom)
- * iy means y is wrapped and inversed
- */
 static void
-polarity_func_nowrap (int32_t * x, int32_t * y,
-		      polarity_data_t * polarity_data, int32_t move_dir)
+polarity_func (lw6map_rules_t * rules, lw6sys_wh_t * shape, int32_t * x,
+	       int32_t * y, int32_t move_dir)
 {
+  (*x) = (*x) + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
+  (*y) = (*y) + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
   /*
-   * Not that in this case there's no border check, in fact we
-   * rely on the fact that maps are "correctly built" and
-   * have walls at the right place, that is, in this case,
-   * on all borders.
+   * next line is need to stay within map boundaries,
+   * it will also handle polarity information
    */
-  (*x) = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  (*y) = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-}
-
-static void
-polarity_func_x (int32_t * x, int32_t * y,
-		 polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  (*y) = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_x < 0)
-    {
-      (*x) = polarity_data->map_w - 1;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      (*x) = 0;
-    }
-  else
-    {
-      (*x) = tmp_x;
-    }
-}
-
-static void
-polarity_func_y (int32_t * x, int32_t * y,
-		 polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_y;
-
-  (*x) = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_y < 0)
-    {
-      (*y) = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      (*y) = 0;
-    }
-  else
-    {
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_ix (int32_t * x, int32_t * y,
-		  polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_x < 0)
-    {
-      (*x) = polarity_data->map_w - 1;
-      (*y) = polarity_data->map_h - 1 - tmp_y;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      (*x) = 0;
-      (*y) = polarity_data->map_h - 1 - tmp_y;
-    }
-  else
-    {
-      (*x) = tmp_x;
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_iy (int32_t * x, int32_t * y,
-		  polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_y < 0)
-    {
-      (*x) = polarity_data->map_w - 1 - tmp_x;
-      (*y) = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      (*x) = polarity_data->map_w - 1 - tmp_x;
-      (*y) = 0;
-    }
-  else
-    {
-      (*x) = tmp_x;
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_x_y (int32_t * x, int32_t * y,
-		   polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_x < 0)
-    {
-      (*x) = polarity_data->map_w - 1;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      (*x) = 0;
-    }
-  else
-    {
-      (*x) = tmp_x;
-    }
-
-  if (tmp_y < 0)
-    {
-      (*y) = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      (*y) = 0;
-    }
-  else
-    {
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_ix_y (int32_t * x, int32_t * y,
-		    polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_y < 0)
-    {
-      tmp_y = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      tmp_y = 0;
-    }
-
-  if (tmp_x < 0)
-    {
-      (*x) = polarity_data->map_w - 1;
-      (*y) = polarity_data->map_h - 1 - tmp_y;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      (*x) = 0;
-      (*y) = polarity_data->map_h - 1 - tmp_y;
-    }
-  else
-    {
-      (*x) = tmp_x;
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_x_iy (int32_t * x, int32_t * y,
-		    polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_x < 0)
-    {
-      tmp_x = polarity_data->map_w - 1;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      tmp_x = 0;
-    }
-
-  if (tmp_y < 0)
-    {
-      (*x) = polarity_data->map_w - 1 - tmp_x;
-      (*y) = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      (*x) = polarity_data->map_w - 1 - tmp_x;
-      (*y) = 0;
-    }
-  else
-    {
-      (*x) = tmp_x;
-      (*y) = tmp_y;
-    }
-}
-
-static void
-polarity_func_ix_iy (int32_t * x, int32_t * y,
-		     polarity_data_t * polarity_data, int32_t move_dir)
-{
-  int32_t tmp_x, tmp_y;
-
-  tmp_x = polarity_data->fighter_x + _LW6KER_TABLES_MOVE_X_OFFSET[move_dir];
-  tmp_y = polarity_data->fighter_y + _LW6KER_TABLES_MOVE_Y_OFFSET[move_dir];
-
-  if (tmp_x < 0)
-    {
-      tmp_x = polarity_data->map_w - 1;
-      tmp_y = polarity_data->map_h - 1 - tmp_y;
-    }
-  else if (tmp_x >= polarity_data->map_w)
-    {
-      tmp_x = 0;
-      tmp_y = polarity_data->map_h - 1 - tmp_y;
-    }
-
-  if (tmp_y < 0)
-    {
-      tmp_x = polarity_data->map_w - 1 - tmp_x;
-      tmp_y = polarity_data->map_h - 1;
-    }
-  else if (tmp_y >= polarity_data->map_h)
-    {
-      tmp_x = polarity_data->map_w - 1 - tmp_x;
-      tmp_y = 0;
-    }
-
-  (*x) = tmp_x;
-  (*y) = tmp_y;
+  lw6map_coords_fix (rules, shape, x, y);
 }
 
 /*
@@ -1099,8 +825,8 @@ polarity_func_ix_iy (int32_t * x, int32_t * y,
  */
 void
 lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
-				int parity, lw6map_options_t * options,
-				int32_t nb_moves)
+				int parity, lw6map_rules_t * rules,
+				int32_t nb_moves, u_int32_t team_mask)
 {
   int i, j, k;
   lw6ker_armies_t *armies = &(map_state->armies);
@@ -1108,7 +834,7 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
   lw6ker_fighter_t *fighter = NULL;
   int32_t layer, x, y;
   int32_t best_dir, test_dir;
-  int32_t fighter_team_id, fighter_layer, fighter_x, fighter_y;
+  int32_t fighter_team_color, fighter_layer, fighter_x, fighter_y;
   int32_t loop_init, loop_step;
   int done_with_fighter;
   int32_t fighter_attack;
@@ -1121,70 +847,20 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
   int32_t nb_defense_tries;
   int32_t fighter_side_attack;
   int32_t fighter_side_defense;
-  polarity_data_t polarity_data;
-  void (*polarity_func) (int32_t * x, int32_t * y,
-			 polarity_data_t * polarity_data,
-			 int32_t move_dir) = NULL;
+  lw6sys_wh_t shape;
 
-  fighter_attack = options->fighter_attack;
-  fighter_defense = options->fighter_defense;
-  fighter_new_health = options->fighter_new_health;
-  side_attack_factor = options->side_attack_factor;
-  side_defense_factor = options->side_defense_factor;
-  nb_move_tries = options->nb_move_tries;
-  nb_attack_tries = options->nb_attack_tries;
-  nb_defense_tries = options->nb_defense_tries;
+  fighter_attack = rules->fighter_attack;
+  fighter_defense = rules->fighter_defense;
+  fighter_new_health = rules->fighter_new_health;
+  side_attack_factor = rules->side_attack_factor;
+  side_defense_factor = rules->side_defense_factor;
+  nb_move_tries = rules->nb_move_tries;
+  nb_attack_tries = rules->nb_attack_tries;
+  nb_defense_tries = rules->nb_defense_tries;
   fighter_side_attack = lw6ker_percent (fighter_attack, side_attack_factor);
   fighter_side_defense =
     lw6ker_percent (fighter_defense, side_defense_factor);
-
-  switch (options->y_polarity)
-    {
-    case 1:
-      switch (options->x_polarity)
-	{
-	case 1:
-	  polarity_func = polarity_func_x_y;
-	  break;
-	case -1:
-	  polarity_func = polarity_func_ix_y;
-	  break;
-	default:
-	  polarity_func = polarity_func_y;
-	  break;
-	}
-      break;
-    case -1:
-      switch (options->x_polarity)
-	{
-	case 1:
-	  polarity_func = polarity_func_x_iy;
-	  break;
-	case -1:
-	  polarity_func = polarity_func_ix_iy;
-	  break;
-	default:
-	  polarity_func = polarity_func_iy;
-	  break;
-	}
-      break;
-    default:
-      switch (options->x_polarity)
-	{
-	case 1:
-	  polarity_func = polarity_func_x;
-	  break;
-	case -1:
-	  polarity_func = polarity_func_ix;
-	  break;
-	default:
-	  polarity_func = polarity_func_nowrap;
-	  break;
-	}
-      break;
-    }
-  polarity_data.map_w = map_state->map_struct->shape.w;
-  polarity_data.map_h = map_state->map_struct->shape.h;
+  shape = map_state->shape;
 
   for (k = 0; k < nb_moves; ++k)
     {
@@ -1194,71 +870,222 @@ lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 	{
 	  done_with_fighter = 0;
 	  fighter = &(map_state->armies.fighters[i]);
-	  fighter_team_id = fighter->team_id;
-	  fighter_x = fighter->pos.x;
-	  fighter_y = fighter->pos.y;
-	  fighter_layer = fighter->layer;
-	  polarity_data.fighter_x = fighter_x;
-	  polarity_data.fighter_y = fighter_y;
-
-	  best_dir = find_best_dir (map_state, fighter, parity);
-	  // we assume best_dir is equal to something valid now
-
-	  layer = fighter_layer;	// not multilayer yet
-	  for (j = 0; j < nb_move_tries; ++j)
+	  fighter_team_color = fighter->team_color;
+	  if (lw6ker_team_mask_is_concerned (fighter_team_color, team_mask))
 	    {
-	      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-	      polarity_func (&x, &y, &polarity_data, test_dir);
-	      if (_lw6ker_map_state_is_slot_free
-		  (map_state, fighter_layer, x, y))
-		{
-		  done_with_fighter = 1;
-		  _lw6ker_fighter_move (fighter, i, fighter_layer, x, y,
-					map_state);
-		  break;
-		}
-	    }
+	      fighter_x = fighter->pos.x;
+	      fighter_y = fighter->pos.y;
+	      fighter_layer = fighter->layer;
 
-	  if (!done_with_fighter)
-	    {
-	      for (j = 0; j < nb_attack_tries; ++j)
+	      best_dir = find_best_dir (map_state, fighter, parity);
+	      // we assume best_dir is equal to something valid now
+
+	      layer = fighter_layer;	// not multilayer yet
+	      for (j = 0; j < nb_move_tries; ++j)
 		{
 		  test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-		  polarity_func (&x, &y, &polarity_data, test_dir);
-		  if (_lw6ker_map_state_is_enemy_there
-		      (map_state, fighter_team_id, fighter_layer, x, y))
+		  x = fighter_x;
+		  y = fighter_y;
+		  polarity_func (rules, &shape, &x, &y, test_dir);
+		  if (_lw6ker_map_state_is_slot_free
+		      (map_state, fighter_layer, x, y))
 		    {
 		      done_with_fighter = 1;
-		      _lw6ker_fighter_attack (fighter, i, fighter_layer, x, y,
-					      map_state,
-					      j >
-					      0 ? fighter_attack :
-					      fighter_side_attack,
-					      fighter_new_health);
+		      _lw6ker_fighter_move (fighter, i, fighter_layer, x, y,
+					    map_state);
 		      break;
 		    }
 		}
-	    }
 
-	  if (!done_with_fighter)
-	    {
-	      for (j = 0; j < nb_defense_tries; ++j)
+	      if (!done_with_fighter)
 		{
-		  test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
-		  polarity_func (&x, &y, &polarity_data, test_dir);
-		  if (_lw6ker_map_state_is_ally_there
-		      (map_state, fighter_team_id, fighter_layer, x, y))
+		  for (j = 0; j < nb_attack_tries; ++j)
 		    {
-		      done_with_fighter = 1;
-		      _lw6ker_fighter_defend (fighter, i, fighter_layer, x, y,
-					      map_state,
-					      j >
-					      0 ? fighter_defense :
-					      fighter_side_defense);
-		      break;
+		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
+		      x = fighter_x;
+		      y = fighter_y;
+		      polarity_func (rules, &shape, &x, &y, test_dir);
+		      if (_lw6ker_map_state_is_enemy_there
+			  (map_state, fighter_team_color, fighter_layer, x,
+			   y))
+			{
+			  done_with_fighter = 1;
+			  _lw6ker_fighter_attack (fighter, i, fighter_layer,
+						  x, y, map_state,
+						  j >
+						  0 ? fighter_attack :
+						  fighter_side_attack,
+						  fighter_new_health);
+			  break;
+			}
+		    }
+		}
+
+	      if (!done_with_fighter)
+		{
+		  for (j = 0; j < nb_defense_tries; ++j)
+		    {
+		      test_dir = _LW6KER_TABLES_MOVE_DIR[parity][best_dir][j];
+		      x = fighter_x;
+		      y = fighter_y;
+		      polarity_func (rules, &shape, &x, &y, test_dir);
+		      if (_lw6ker_map_state_is_ally_there
+			  (map_state, fighter_team_color, fighter_layer, x,
+			   y))
+			{
+			  done_with_fighter = 1;
+			  _lw6ker_fighter_defend (fighter, i, fighter_layer,
+						  x, y, map_state,
+						  j >
+						  0 ? fighter_defense :
+						  fighter_side_defense);
+			  break;
+			}
 		    }
 		}
 	    }
 	}
     }
 }
+
+void
+lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
+				lw6map_rules_t * rules, u_int32_t team_mask)
+{
+  int32_t i, team_color;
+  int32_t zone_id;
+  int32_t max_pot[LW6MAP_MAX_NB_TEAMS];
+  int32_t round_delta[LW6MAP_MAX_NB_TEAMS];
+
+  /*
+   * Wizardry to determine a new cursor_ref_pot. In most cases
+   * it will end with max_pot being the old cursor_ref_pot+1
+   * and delta being 1. But it's there for special cases, mostly
+   * at game startup and when one fiddles arround with cursors
+   * pot_offset fields..
+   */
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (lw6ker_team_mask_is_concerned (i, team_mask))
+	{
+	  max_pot[i] = map_state->teams[i].cursor_ref_pot;
+	  round_delta[i] = rules->round_delta;
+	}
+    }
+  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
+    {
+      if (map_state->cursor_array.cursors[i].enabled)
+	{
+	  team_color = map_state->cursor_array.cursors[i].team_color;
+	  if (lw6ker_team_mask_is_concerned (team_color, team_mask))
+	    {
+	      {
+		_lw6ker_cursor_update_apply_pos (&
+						 (map_state->
+						  cursor_array.cursors[i]),
+						 map_state->map_struct);
+		zone_id =
+		  lw6ker_map_struct_get_zone_id (map_state->map_struct,
+						 map_state->
+						 cursor_array.cursors[i].
+						 apply_pos.x,
+						 map_state->
+						 cursor_array.cursors[i].
+						 apply_pos.y);
+		if (zone_id >= 0)
+		  {
+		    max_pot[team_color] =
+		      lw6sys_max (max_pot[team_color],
+				  map_state->
+				  teams[team_color].gradient[zone_id].
+				  potential);
+		    round_delta[team_color] =
+		      lw6sys_max (round_delta[team_color],
+				  map_state->teams[team_color].
+				  cursor_ref_pot +
+				  map_state->cursor_array.cursors[i].
+				  pot_offset -
+				  map_state->
+				  teams[team_color].gradient[zone_id].
+				  potential);
+		    round_delta[team_color] =
+		      lw6sys_min (round_delta[team_color],
+				  rules->max_round_delta);
+		  }
+	      }
+	    }
+	}
+    }
+  for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+    {
+      if (lw6ker_team_mask_is_concerned (i, team_mask))
+	{
+	  /*
+	   * Following line is essential, it ensures that cursor potentials
+	   * will increase at each game turn. A consequence is that one
+	   * shouldn't call apply_cursors twice per game round. Indeed,
+	   * calling apply_cursors changes the map state (cursor_ref_pot)
+	   * so calling it twice isn't the same as calling it only once.
+	   */
+	  map_state->teams[i].cursor_ref_pot = max_pot[i] + round_delta[i];
+
+	  if (map_state->teams[i].cursor_ref_pot +
+	      rules->max_cursor_pot_offset > rules->max_cursor_pot)
+	    {
+	      lw6ker_team_normalize_pot (&(map_state->teams[i]), rules);
+	    }
+	}
+    }
+
+  /*
+   * We actually apply the cursors
+   */
+  for (i = 0; i < LW6MAP_MAX_NB_CURSORS; ++i)
+    {
+      if (map_state->cursor_array.cursors[i].enabled)
+	{
+	  team_color = map_state->cursor_array.cursors[i].team_color;
+	  if (lw6ker_team_mask_is_concerned (team_color, team_mask))
+	    {
+	      zone_id =
+		lw6ker_map_struct_get_zone_id (map_state->map_struct,
+					       map_state->
+					       cursor_array.cursors[i].
+					       apply_pos.x,
+					       map_state->
+					       cursor_array.cursors[i].
+					       apply_pos.y);
+	      if (zone_id >= 0)
+		{
+		  /*
+		   * Beware of multiple cursors, we check again if changing
+		   * the value is needed.
+		   */
+		  if (map_state->teams[team_color].gradient[zone_id].
+		      potential <
+		      map_state->teams[team_color].cursor_ref_pot +
+		      map_state->cursor_array.cursors[i].pot_offset)
+		    {
+		      map_state->teams[team_color].gradient[zone_id].
+			potential =
+			map_state->teams[team_color].cursor_ref_pot +
+			map_state->cursor_array.cursors[i].pot_offset;
+		      map_state->teams[team_color].gradient[zone_id].
+			closest_cursor_pos =
+			map_state->cursor_array.cursors[i].apply_pos;
+		    }
+		}
+	      else
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _
+			      ("unable to apply cursor, neither pos (%d,%d) nor apply_pos (%d,%d) seem to point on a valid zone"),
+			      map_state->cursor_array.cursors[i].pos.x,
+			      map_state->cursor_array.cursors[i].pos.y,
+			      map_state->cursor_array.cursors[i].apply_pos.x,
+			      map_state->cursor_array.cursors[i].apply_pos.y);
+		}
+	    }
+	}
+    }
+}
