@@ -83,87 +83,47 @@ _lw6ker_map_struct_update_checksum (lw6ker_map_struct_t *
     }
 }
 
+int
+_lw6ker_map_struct_lazy_compare (lw6ker_map_struct_t *
+				 map_struct_a, lw6ker_map_struct_t *
+				 map_struct_b)
+{
+  int ret = 0;
+
+  if (map_struct_a && map_struct_b)
+    {
+      if (map_struct_a == map_struct_b)
+	{
+	  ret = 1;
+	}
+      else
+	{
+	  ret = (map_struct_a->shape.w == map_struct_b->shape.w) &&
+	    (map_struct_a->shape.h == map_struct_b->shape.h) &&
+	    (map_struct_a->nb_zones == map_struct_b->nb_zones) &&
+	    (map_struct_a->nb_slots == map_struct_b->nb_slots) &&
+	    (map_struct_a->nb_usable_slots == map_struct_b->nb_usable_slots)
+	    && (map_struct_a->room_for_armies ==
+		map_struct_b->room_for_armies)
+	    && (map_struct_a->max_depth == map_struct_b->max_depth)
+	    && (map_struct_a->max_zone_size == map_struct_b->max_zone_size);
+	}
+    }
+
+  if (!ret)
+    {
+      lw6sys_log (LW6SYS_LOG_DEBUG, _("map_structs do not look the same"));
+    }
+
+  return ret;
+}
+
 static int32_t
 relative_index (lw6map_level_t * level, int32_t x, int32_t y)
 {
-  int32_t w, h;
+  lw6map_coords_fix (&(level->param.rules), &(level->depth.shape), &x, &y);
 
-  w = level->depth.shape.w;
-  h = level->depth.shape.h;
-
-  if (x >= w)
-    {
-      switch (level->param.options.x_polarity)
-	{
-	case 1:
-	  x = 0;
-	  break;
-	case -1:
-	  x = 0;
-	  y = h - 1 - y;
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("x too great (%d/%d) for a non wrapped map"), x, w);
-	  break;
-	}
-    }
-
-  if (y >= h)
-    {
-      switch (level->param.options.y_polarity)
-	{
-	case 1:
-	  y = 0;
-	  break;
-	case -1:
-	  x = w - 1 - x;
-	  y = 0;
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("y too great (%d/%d) for a non wrapped map"), y, h);
-	  break;
-	}
-    }
-
-  if (x < 0)
-    {
-      switch (level->param.options.x_polarity)
-	{
-	case 1:
-	  x = w - 1;
-	  break;
-	case -1:
-	  x = w - 1;
-	  y = h - 1 - y;
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("x too small (%d) for a non wrapped map"), x);
-	  break;
-	}
-    }
-
-  if (y < 0)
-    {
-      switch (level->param.options.y_polarity)
-	{
-	case 1:
-	  y = h - 1;
-	  break;
-	case -1:
-	  x = w - 1 - x;
-	  y = h - 1;
-	  break;
-	default:
-	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("y too small (%d) for a non wrapped map"), y);
-	  break;
-	}
-    }
-
-  return y * w + x;
+  return y * level->depth.shape.w + x;
 }
 
 /*
@@ -175,10 +135,12 @@ relative_index (lw6map_level_t * level, int32_t x, int32_t y)
  * optimized afterwards.
  */
 static draft_zones_t *
-draft_zones_new (lw6map_level_t * level)
+draft_zones_new (lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   draft_zones_t *ret;
 
+  lw6sys_progress_begin (progress);
+
   ret = (draft_zones_t *) LW6SYS_CALLOC (sizeof (draft_zones_t));
   if (ret)
     {
@@ -191,14 +153,14 @@ draft_zones_new (lw6map_level_t * level)
       h = ret->shape.h;
       size = w * h;
 
-      if (size >= level->param.options.min_map_surface)
+      if (size >= LW6MAP_MIN_SURFACE)
 	{
 	  ret->zones =
 	    (draft_zone_t *) LW6SYS_CALLOC (size * sizeof (draft_zone_t));
 
 	  if (ret->zones)
 	    {
-	      int32_t i, j, x, y, x1, x2, y1, y2;
+	      int32_t i, j, x, y;
 
 	      for (i = 0; i < size; ++i)
 		{
@@ -222,74 +184,55 @@ draft_zones_new (lw6map_level_t * level)
 		    }
 		}
 
-	      x1 = 0;
-	      x2 = w;
-	      y1 = 0;
-	      y2 = h;
-
-	      if (level->param.options.x_polarity != 1
-		  && level->param.options.x_polarity != -1)
+	      for (y = 0; y < h; ++y)
 		{
-		  x1++;
-		  x2--;
-		}
-
-	      if (level->param.options.y_polarity != 1
-		  && level->param.options.y_polarity != -1)
-		{
-		  y1++;
-		  y2--;
-		}
-
-	      for (y = y1; y < y2; ++y)
-		{
-		  for (x = x1; x < x2; ++x)
+		  for (x = 0; x < w; ++x)
 		    {
 		      i = relative_index (level, x, y);
 
 		      if (ret->zones[i].used)
 			{
 			  j = relative_index (level, x, y - 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NNW] =
 				ret->zones[i].link[LW6KER_DIR_NNE] = j;
 			    }
 			  j = relative_index (level, x + 1, y - 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NE] = j;
 			    }
 			  j = relative_index (level, x + 1, y);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_ENE] =
 				ret->zones[i].link[LW6KER_DIR_ESE] = j;
 			    }
 			  j = relative_index (level, x + 1, y + 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SE] = j;
 			    }
 			  j = relative_index (level, x, y + 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SSE] =
 				ret->zones[i].link[LW6KER_DIR_SSW] = j;
 			    }
 			  j = relative_index (level, x - 1, y + 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_SW] = j;
 			    }
 			  j = relative_index (level, x - 1, y);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_WSW] =
 				ret->zones[i].link[LW6KER_DIR_WNW] = j;
 			    }
 			  j = relative_index (level, x - 1, y - 1);
-			  if (ret->zones[j].used)
+			  if (ret->zones[j].used && i != j)
 			    {
 			      ret->zones[i].link[LW6KER_DIR_NW] = j;
 			    }
@@ -306,11 +249,13 @@ draft_zones_new (lw6map_level_t * level)
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING,
-		      _("map is too small, size=%d, MIN_MAP_SIZE=%d"),
-		      size, level->param.options.min_map_surface);
+		      _("map is too small, size=%d, LW6MAP_MIN_SURFACE=%d"),
+		      size, LW6MAP_MIN_SURFACE);
 	}
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
@@ -465,12 +410,15 @@ draft_zones_group (draft_zones_t * draft_zones, int32_t step)
  */
 static int
 draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
-			   draft_zones_t * draft_zones)
+			   draft_zones_t * draft_zones,
+			   lw6sys_progress_t * progress)
 {
   int ret = 0;
   int32_t w, h, size, nb_zones;
   int32_t i, j, k, temp;
 
+  lw6sys_progress_begin (progress);
+
   w = draft_zones->shape.w;
   h = draft_zones->shape.h;
   size = w * h;
@@ -533,6 +481,8 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
 		  _("unable to create zones for map struct"));
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
@@ -541,10 +491,13 @@ draft_zones_to_map_struct (lw6ker_map_struct_t * map_struct,
  * have a quick way to get the right zone for a given (x,y).
  */
 static int
-init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level)
+init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level,
+	    lw6sys_progress_t * progress)
 {
   int ret = 0;
 
+  lw6sys_progress_begin (progress);
+
   map_struct->slots =
     (lw6ker_slot_struct_t *) LW6SYS_CALLOC (map_struct->shape.w *
 					    map_struct->shape.h *
@@ -608,6 +561,8 @@ init_slots (lw6ker_map_struct_t * map_struct, lw6map_level_t * level)
 		  _("unable to create slots for map struct"));
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
@@ -635,31 +590,55 @@ _lw6ker_map_struct_get_compression (lw6ker_map_struct_t * map_struct)
  */
 int
 _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
-			 lw6map_level_t * level)
+			 lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   int ret = 0;
   draft_zones_t *draft_zones;
+  int progress_i;
+  int progress_n;
+  lw6sys_progress_t progress1;
+  lw6sys_progress_t progress2;
+  lw6sys_progress_t progress3;
+  lw6sys_progress_t progress4;
+
+  lw6sys_progress_begin (progress);
+  lw6sys_progress_split4 (&progress1, &progress2, &progress3, &progress4,
+			  progress);
 
   memset (map_struct, 0, sizeof (lw6ker_map_struct_t));
 
-  draft_zones = draft_zones_new (level);
+  draft_zones = draft_zones_new (level, &progress1);
   if (draft_zones)
     {
-      int32_t i = 1;
+      int32_t i;
 
+      lw6sys_progress_begin (&progress2);
       ret = 1;
 
-      while (i <= level->param.options.max_zone_size / 2
-	     && draft_zones_group (draft_zones, i))
+      i = 1;
+      progress_n = 0;
+      while (i <= level->param.rules.max_zone_size / 2)
 	{
+	  progress_n++;
 	  i *= 2;
 	}
 
-      ret = ret && draft_zones_to_map_struct (map_struct, draft_zones);
+      i = 1;
+      progress_i = 0;
+      while (i <= level->param.rules.max_zone_size / 2
+	     && draft_zones_group (draft_zones, i))
+	{
+	  lw6sys_progress_update (&progress2, 0, progress_n, progress_i++);
+	  i *= 2;
+	}
+      lw6sys_progress_end (&progress2);
+
+      ret = ret
+	&& draft_zones_to_map_struct (map_struct, draft_zones, &progress3);
 
       draft_zones_free (draft_zones);
 
-      ret = ret && init_slots (map_struct, level);
+      ret = ret && init_slots (map_struct, level, &progress4);
 
       if (ret)
 	{
@@ -673,6 +652,8 @@ _lw6ker_map_struct_init (lw6ker_map_struct_t * map_struct,
 	}
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
@@ -713,7 +694,7 @@ lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t * map_struct,
       int32_t x, y;
 
       max_radius = map_struct->shape.w + map_struct->shape.h;	// +, not *
-      for (radius = 1; radius < max_radius && !found; ++radius)
+      for (radius = 0; radius < max_radius && !found; ++radius)
 	{
 	  max_angle = radius * M_PI * 2;
 	  for (angle = 0; angle < max_angle && !found; ++angle)
