@@ -31,7 +31,7 @@
 
 int
 _lw6ker_team_init (lw6ker_team_t * team, lw6ker_map_struct_t * map_struct,
-		   lw6map_options_t * options)
+		   lw6map_rules_t * rules)
 {
   int ret = 0;
   int i;
@@ -41,9 +41,8 @@ _lw6ker_team_init (lw6ker_team_t * team, lw6ker_map_struct_t * map_struct,
   team->gradient =
     (lw6ker_zone_state_t *) LW6SYS_CALLOC (map_struct->nb_zones *
 					   sizeof (lw6ker_zone_state_t));
-  team->cursor_ref_pot = options->cursor_pot_init;
+  team->cursor_ref_pot = rules->cursor_pot_init;
   team->last_spread_dir = LW6KER_DIR_NNE;
-  lw6ker_cursor_array_clear (&(team->cursor_array));
 
   if (team->gradient)
     {
@@ -83,19 +82,18 @@ _lw6ker_team_clear (lw6ker_team_t * team)
 }
 
 int
-_lw6ker_team_copy (lw6ker_team_t * dst, lw6ker_team_t * src)
+_lw6ker_team_sync (lw6ker_team_t * dst, lw6ker_team_t * src)
 {
   int ret = 0;
 
-  if (dst && src && dst->map_struct && src->map_struct
-      && dst->map_struct == src->map_struct)
+  if (dst && src
+      && _lw6ker_map_struct_lazy_compare (dst->map_struct, src->map_struct))
     {
       dst->active = src->active;
       memcpy (dst->gradient, src->gradient,
 	      src->map_struct->nb_zones * sizeof (lw6ker_zone_state_t));
       dst->cursor_ref_pot = src->cursor_ref_pot;
       dst->last_spread_dir = src->last_spread_dir;
-      dst->cursor_array = src->cursor_array;
       ret = 1;
     }
   else
@@ -121,146 +119,18 @@ _lw6ker_team_update_checksum (lw6ker_team_t * team, u_int32_t * checksum)
     }
   lw6sys_checksum_update_int32 (checksum, team->cursor_ref_pot);
   lw6sys_checksum_update_int32 (checksum, team->last_spread_dir);
-  _lw6ker_cursor_array_update_checksum (&(team->cursor_array), checksum);
 }
 
 void
-lw6ker_team_activate (lw6ker_team_t * team, int32_t nb_cursors,
-		      lw6sys_xy_t pos)
+lw6ker_team_activate (lw6ker_team_t * team, lw6sys_xy_t pos)
 {
   team->active = 1;
-  _lw6ker_cursor_array_activate (&(team->cursor_array), nb_cursors, pos);
 }
 
 void
 lw6ker_team_unactivate (lw6ker_team_t * team)
 {
   team->active = 0;
-  lw6ker_cursor_array_clear (&(team->cursor_array));
-}
-
-void
-lw6ker_team_apply_cursors (lw6ker_team_t * team, lw6map_options_t * options)
-{
-  int32_t i;
-  int32_t zone_id;
-  int32_t max_pot = 0;
-  int32_t round_delta = options->round_delta;
-
-  /*
-   * Wizardry to determine a new cursor_ref_pot. In most cases
-   * it will end with max_pot being the old cursor_ref_pot+1
-   * and delta being 1. But it's there for special cases, mostly
-   * at game startup and when one fiddles arround with cursors
-   * pot_offset fields..
-   */
-  max_pot = team->cursor_ref_pot;
-  for (i = 0; i < team->cursor_array.nb_cursors; ++i)
-    {
-      zone_id =
-	lw6ker_map_struct_get_zone_id (team->map_struct,
-				       team->cursor_array.cursors[i].pos.x,
-				       team->cursor_array.cursors[i].pos.y);
-      if (zone_id < 0)
-	{
-	  zone_id =
-	    lw6ker_map_struct_get_zone_id (team->map_struct,
-					   team->cursor_array.cursors[i].
-					   last_applied_pos.x,
-					   team->cursor_array.cursors[i].
-					   last_applied_pos.y);
-	}
-      if (zone_id >= 0)
-	{
-	  max_pot = lw6sys_max (max_pot, team->gradient[zone_id].potential);
-
-	  round_delta =
-	    lw6sys_max (round_delta,
-			team->cursor_ref_pot +
-			team->cursor_array.cursors[i].pot_offset -
-			team->gradient[zone_id].potential);
-	  round_delta = lw6sys_min (round_delta, options->max_round_delta);
-	}
-    }
-
-  /*
-   * Following line is essential, it ensures that cursor potentials
-   * will increase at each game turn. A consequence is that one
-   * shouldn't call apply_cursors twice per game round. Indeed,
-   * calling apply_cursors changes the map state (cursor_ref_pot)
-   * so calling it twice isn't the same as calling it only once.
-   */
-  team->cursor_ref_pot = max_pot + round_delta;
-
-  if (team->cursor_ref_pot + options->max_cursor_pot_offset >
-      options->max_cursor_pot)
-    {
-      lw6ker_team_normalize_pot (team, options);
-    }
-
-  /*
-   * We actually apply the cursors
-   */
-  for (i = 0; i < team->cursor_array.nb_cursors; ++i)
-    {
-      zone_id =
-	lw6ker_map_struct_get_zone_id (team->map_struct,
-				       team->cursor_array.cursors[i].pos.x,
-				       team->cursor_array.cursors[i].pos.y);
-      if (zone_id >= 0)
-	{
-	  /*
-	   * Beware of multiple cursors, we check again if changing
-	   * the value is needed.
-	   */
-	  if (team->gradient[zone_id].potential <
-	      team->cursor_ref_pot + team->cursor_array.cursors[i].pot_offset)
-	    {
-	      team->gradient[zone_id].potential =
-		team->cursor_ref_pot +
-		team->cursor_array.cursors[i].pot_offset;
-	      _lw6ker_cursor_update_last_applied (&
-						  (team->cursor_array.
-						   cursors[i]));
-	      team->gradient[zone_id].closest_cursor_pos =
-		team->cursor_array.cursors[i].pos;
-	    }
-	}
-      else
-	{
-	  zone_id =
-	    lw6ker_map_struct_get_zone_id (team->map_struct,
-					   team->cursor_array.cursors[i].
-					   last_applied_pos.x,
-					   team->cursor_array.cursors[i].
-					   last_applied_pos.y);
-	  if (zone_id >= 0)
-	    {
-	      /*
-	       * Beware of multiple cursors, we check again if changing
-	       * the value is needed.
-	       */
-	      if (team->gradient[zone_id].potential <
-		  team->cursor_ref_pot +
-		  team->cursor_array.cursors[i].pot_offset)
-		{
-		  team->gradient[zone_id].potential =
-		    team->cursor_ref_pot +
-		    team->cursor_array.cursors[i].pot_offset;
-		}
-	    }
-	  else
-	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING,
-			  _
-			  ("unable to apply cursor, neither pos (%d,%d) nor last_applied_pos (%d,%d) seem to point on a valid zone"),
-			  team->cursor_array.cursors[i].pos.x,
-			  team->cursor_array.cursors[i].pos.y,
-			  team->cursor_array.cursors[i].last_applied_pos.x,
-			  team->cursor_array.cursors[i].last_applied_pos.y);
-	    }
-	}
-    }
 }
 
 static int32_t
@@ -354,11 +224,11 @@ lw6ker_team_spread_gradient (lw6ker_team_t * team)
 }
 
 void
-lw6ker_team_normalize_pot (lw6ker_team_t * team, lw6map_options_t * options)
+lw6ker_team_normalize_pot (lw6ker_team_t * team, lw6map_rules_t * rules)
 {
   int32_t i;
   int32_t n;
-  u_int32_t min_pot = options->max_cursor_pot;
+  u_int32_t min_pot = rules->max_cursor_pot;
   u_int32_t max_pot = 0;
   u_int32_t delta;
   lw6ker_zone_state_t *zone_states = team->gradient;
@@ -383,9 +253,9 @@ lw6ker_team_normalize_pot (lw6ker_team_t * team, lw6map_options_t * options)
     {
       zone_states[i].potential -= delta;
       if (zone_states[i].potential <= 0
-	  || zone_states[i].potential > options->max_cursor_pot)
+	  || zone_states[i].potential > rules->max_cursor_pot)
 	{
-	  zone_states[i].potential = options->cursor_pot_init;
+	  zone_states[i].potential = rules->cursor_pot_init;
 	}
       zone_states[i].direction_to_cursor = -1;
     }
@@ -396,6 +266,6 @@ lw6ker_team_normalize_pot (lw6ker_team_t * team, lw6map_options_t * options)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("inconsistent cursor_ref_pot=%d (max_pot=%d, delta=%d)"),
 		  team->cursor_ref_pot, max_pot, delta);
-      team->cursor_ref_pot = options->cursor_pot_init;
+      team->cursor_ref_pot = rules->cursor_pot_init;
     }
 }
