@@ -26,11 +26,56 @@
 
 #include "ker.h"
 
+#define TEST_MAP_WIDTH 72
+#define TEST_MAP_HEIGHT 24
 #define TEST_NB_ROUNDS 100
-#define TEST_GAME_STRUCT_CHECKSUM 0xe891c7fd
-#define TEST_GAME_STATE_CHECKSUM 0xacc0819b
-#define TEST_GAME_STATE_POPULATE_CHECKSUM 0xbe719809
-#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0xf51808ca
+#define TEST_GAME_STRUCT_CHECKSUM 0x024ccc4c
+#define TEST_GAME_STATE_CHECKSUM 0x17e3296f
+#define TEST_GAME_STATE_POPULATE_CHECKSUM 0x23283da7
+#define TEST_GAME_STATE_ALGORITHM_CHECKSUM 0xe041edba
+#define TEST_SERVER_ID 0x1234123412341234LL
+#define TEST_CURSOR1_ID 0x1234
+#define TEST_CURSOR2_ID 0x2345
+#define TEST_CURSOR3_ID 0x3456
+#define TEST_COLOR1 LW6MAP_TEAM_COLOR_RED
+#define TEST_COLOR2 LW6MAP_TEAM_COLOR_GREEN
+#define TEST_COLOR3 LW6MAP_TEAM_COLOR_BLUE
+#define TEST_TEAM_MASK_SEED 123
+
+static void
+print_game_struct_repr (lw6ker_game_struct_t * game_struct)
+{
+  char *repr = NULL;
+
+  repr = lw6ker_game_struct_repr (game_struct);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("game_struct repr is \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+}
+
+static void
+print_game_state_repr (lw6ker_game_state_t * game_state)
+{
+  char *repr = NULL;
+  char *capture = NULL;
+
+  repr = lw6ker_game_state_repr (game_state);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_NOTICE, _("game_state repr is \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+  lw6ker_map_state_print_debug (&(game_state->map_state));
+  capture = lw6ker_capture_str (game_state);
+  if (capture)
+    {
+      printf ("%s", capture);
+      fflush (stdout);
+      LW6SYS_FREE (capture);
+    }
+}
 
 static int
 test_struct ()
@@ -41,23 +86,16 @@ test_struct ()
   {
     lw6map_level_t *level;
     lw6ker_game_struct_t *game_struct;
-    char *repr;
     int checksum;
 
     ret = 0;
-    level = lw6map_defaults ();
+    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
     if (level)
       {
-	game_struct = lw6ker_game_struct_new (level);
+	game_struct = lw6ker_game_struct_new (level, NULL);
 	if (game_struct)
 	  {
-	    repr = lw6ker_game_struct_repr (game_struct);
-	    if (repr)
-	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("game_struct repr is \"%s\""), repr);
-		LW6SYS_FREE (repr);
-	      }
+	    print_game_struct_repr (game_struct);
 	    checksum = lw6ker_game_struct_checksum (game_struct);
 	    lw6sys_log (LW6SYS_LOG_NOTICE,
 			_
@@ -84,35 +122,20 @@ test_state ()
     lw6map_level_t *level;
     lw6ker_game_struct_t *game_struct;
     lw6ker_game_state_t *game_state;
-    char *repr;
     int checksum;
 
     ret = 0;
-    level = lw6map_defaults ();
+    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
     if (level)
       {
-	game_struct = lw6ker_game_struct_new (level);
+	game_struct = lw6ker_game_struct_new (level, NULL);
 	if (game_struct)
 	  {
-	    repr = lw6ker_game_struct_repr (game_struct);
-	    if (repr)
-	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("game_struct repr is \"%s\""), repr);
-		LW6SYS_FREE (repr);
-	      }
-
-	    game_state = lw6ker_game_state_new (game_struct);
+	    print_game_struct_repr (game_struct);
+	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
-		repr = lw6ker_game_state_repr (game_state);
-		if (repr)
-		  {
-		    lw6sys_log (LW6SYS_LOG_NOTICE,
-				_("game_state repr is \"%s\""), repr);
-		    LW6SYS_FREE (repr);
-		  }
-		lw6ker_map_state_print_debug (&(game_state->map_state));
+		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _
@@ -142,47 +165,35 @@ test_population ()
     lw6map_level_t *level;
     lw6ker_game_struct_t *game_struct;
     lw6ker_game_state_t *game_state;
-    char *repr;
     int checksum;
 
     ret = 0;
-    level = lw6map_defaults ();
+
+    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
     if (level)
       {
-	game_struct = lw6ker_game_struct_new (level);
+	game_struct = lw6ker_game_struct_new (level, NULL);
 	if (game_struct)
 	  {
-	    repr = lw6ker_game_struct_repr (game_struct);
-	    if (repr)
-	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("game_struct repr is \"%s\""), repr);
-		LW6SYS_FREE (repr);
-	      }
-
-	    game_state = lw6ker_game_state_new (game_struct);
+	    print_game_struct_repr (game_struct);
+	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
-		repr = lw6ker_game_state_repr (game_state);
-		if (repr)
-		  {
-		    lw6sys_log (LW6SYS_LOG_NOTICE,
-				_("game_state repr is \"%s\""), repr);
-		    LW6SYS_FREE (repr);
-		  }
-		lw6ker_map_state_print_debug (&(game_state->map_state));
-		lw6ker_game_state_add_team (game_state, 0, 1);
-		lw6ker_game_state_add_team (game_state, 1, 1);
-		lw6ker_game_state_add_team (game_state, 2, 1);
-		lw6ker_game_state_add_team (game_state, 3, 1);
-		lw6ker_game_state_add_team (game_state, 4, 1);
-		lw6ker_game_state_add_team (game_state, 5, 1);
-		lw6ker_game_state_add_team (game_state, 6, 1);
-		lw6ker_game_state_add_team (game_state, 7, 1);
-		lw6ker_map_state_print_debug (&(game_state->map_state));
-		lw6ker_game_state_remove_team (game_state, 2);
-		lw6ker_game_state_remove_team (game_state, 3);
-		lw6ker_map_state_print_debug (&(game_state->map_state));
+		print_game_state_repr (game_state);
+		lw6ker_game_state_register_server (game_state,
+						   TEST_SERVER_ID);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR1_ID, TEST_COLOR1);
+		print_game_state_repr (game_state);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR2_ID, TEST_COLOR2);
+		print_game_state_repr (game_state);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR3_ID, TEST_COLOR3);
+		print_game_state_repr (game_state);
+		lw6ker_game_state_remove_cursor (game_state, TEST_SERVER_ID,
+						 TEST_CURSOR2_ID);
+		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _
@@ -212,39 +223,42 @@ test_algorithm ()
     lw6map_level_t *level;
     lw6ker_game_struct_t *game_struct;
     lw6ker_game_state_t *game_state;
-    char *repr;
     int checksum;
     int i;
+    int cursor_x, cursor_y;
 
     ret = 0;
-    level = lw6map_defaults ();
+    level = lw6map_defaults (TEST_MAP_WIDTH, TEST_MAP_HEIGHT);
     if (level)
       {
-	game_struct = lw6ker_game_struct_new (level);
+	game_struct = lw6ker_game_struct_new (level, NULL);
 	if (game_struct)
 	  {
-	    repr = lw6ker_game_struct_repr (game_struct);
-	    if (repr)
-	      {
-		lw6sys_log (LW6SYS_LOG_NOTICE,
-			    _("game_struct repr is \"%s\""), repr);
-		LW6SYS_FREE (repr);
-	      }
-
-	    game_state = lw6ker_game_state_new (game_struct);
+	    print_game_struct_repr (game_struct);
+	    game_state = lw6ker_game_state_new (game_struct, NULL);
 	    if (game_state)
 	      {
-		repr = lw6ker_game_state_repr (game_state);
-		if (repr)
-		  {
-		    lw6sys_log (LW6SYS_LOG_NOTICE,
-				_("game_state repr is \"%s\""), repr);
-		    LW6SYS_FREE (repr);
-		  }
-		lw6ker_game_state_add_team (game_state, 0, 1);
-		lw6ker_game_state_add_team (game_state, 1, 1);
-		lw6ker_game_state_add_team (game_state, 2, 1);
-		lw6ker_map_state_print_debug (&(game_state->map_state));
+		print_game_state_repr (game_state);
+		lw6ker_game_state_register_server (game_state,
+						   TEST_SERVER_ID);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR1_ID, TEST_COLOR1);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR2_ID, TEST_COLOR2);
+		lw6ker_game_state_add_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR3_ID, TEST_COLOR3);
+		print_game_state_repr (game_state);
+		cursor_x = game_state->map_state.shape.w / 2;
+		cursor_y = game_state->map_state.shape.h / 2;
+		lw6ker_game_state_set_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR1_ID, cursor_x,
+					      cursor_y);
+		lw6ker_game_state_set_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR2_ID, cursor_x,
+					      cursor_y);
+		lw6ker_game_state_set_cursor (game_state, TEST_SERVER_ID,
+					      TEST_CURSOR3_ID, cursor_x,
+					      cursor_y);
 		for (i = 0; i < TEST_NB_ROUNDS; ++i)
 		  {
 		    lw6ker_game_state_do_round (game_state);
@@ -253,6 +267,7 @@ test_algorithm ()
 				game_state->rounds,
 				lw6ker_game_state_checksum (game_state));
 		  }
+		print_game_state_repr (game_state);
 		checksum = lw6ker_game_state_checksum (game_state);
 		lw6sys_log (LW6SYS_LOG_NOTICE,
 			    _
@@ -272,6 +287,43 @@ test_algorithm ()
   return ret;
 }
 
+static int
+test_team_mask ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    u_int32_t even = 0;
+    u_int32_t odd = 0;
+    int i;
+
+    lw6ker_team_mask_get (&even, &odd, TEST_TEAM_MASK_SEED);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("even team mask %x"), even);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("odd team mask %x"), odd);
+    for (i = 0; i < LW6MAP_MAX_NB_TEAMS; ++i)
+      {
+	if (lw6ker_team_mask_is_concerned (i, even))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("team %d is even"), i);
+	  }
+	else if (lw6ker_team_mask_is_concerned (i, odd))
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("team %d is odd"), i);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("team mask inconsistency for %d"), i);
+	    ret = 0;
+	  }
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 int
 lw6ker_test ()
 {
@@ -286,8 +338,8 @@ lw6ker_test ()
       lw6map_test ();
     }
 
-  ret = test_struct () && test_state () && test_population ()
-    && test_algorithm ();
+  ret = test_team_mask () && test_struct () && test_state ()
+    && test_population () && test_algorithm ();
 
   return ret;
 }
