@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -47,6 +46,18 @@
 #define LW6KER_PARITY_EVEN 0
 #define LW6KER_PARITY_ODD 1
 
+#define LW6KER_TEAM_MASK_RED 0x001
+#define LW6KER_TEAM_MASK_GREEN 0x002
+#define LW6KER_TEAM_MASK_BLUE 0x004
+#define LW6KER_TEAM_MASK_YELLOW 0x08
+#define LW6KER_TEAM_MASK_CYAN 0x10
+#define LW6KER_TEAM_MASK_MAGENTA 0x20
+#define LW6KER_TEAM_MASK_ORANGE 0x40
+#define LW6KER_TEAM_MASK_LIGHTBLUE 0x80
+#define LW6KER_TEAM_MASK_PURPLE 0x100
+#define LW6KER_TEAM_MASK_PINK 0x200
+#define LW6KER_TEAM_MASK_ALL 0x3ff
+
 #include "ker-trigo.h"
 
 typedef struct lw6ker_zone_struct_s
@@ -100,10 +111,10 @@ lw6ker_map_struct_t;
  */
 typedef struct lw6ker_game_struct_s
 {
-  int id;
+  u_int32_t id;
   lw6map_level_t *level;
   lw6ker_map_struct_t map_struct;
-  lw6map_options_t options;
+  lw6map_rules_t rules;
 }
 lw6ker_game_struct_t;
 
@@ -126,7 +137,7 @@ lw6ker_slot_state_t;
 
 typedef struct lw6ker_fighter_s
 {
-  u_int32_t team_id:4;
+  u_int32_t team_color:4;
   u_int32_t layer:4;
   u_int32_t last_direction:8;
   u_int32_t health:16;
@@ -136,8 +147,13 @@ lw6ker_fighter_t;
 
 typedef struct lw6ker_cursor_s
 {
+  u_int64_t server_id;
+  u_int16_t cursor_id;
+  char letter;
+  int enabled;
+  int team_color;
   lw6sys_xy_t pos;
-  lw6sys_xy_t last_applied_pos;
+  lw6sys_xy_t apply_pos;
   int32_t pot_offset;
 }
 lw6ker_cursor_t;
@@ -145,10 +161,25 @@ lw6ker_cursor_t;
 typedef struct lw6ker_cursor_array_s
 {
   int32_t nb_cursors;
-  lw6ker_cursor_t cursors[LW6MAP_MAX_CURSORS_PER_TEAM];
+  lw6ker_cursor_t cursors[LW6MAP_MAX_NB_CURSORS];
 }
 lw6ker_cursor_array_t;
 
+typedef struct lw6ker_server_s
+{
+  u_int64_t server_id;
+  int enabled;
+  u_int32_t last_command_round;
+}
+lw6ker_server_t;
+
+typedef struct lw6ker_server_array_s
+{
+  int32_t nb_servers;
+  lw6ker_server_t servers[LW6MAP_MAX_NB_SERVERS];
+}
+lw6ker_server_array_t;
+
 typedef struct lw6ker_team_s
 {
   int active;
@@ -156,7 +187,6 @@ typedef struct lw6ker_team_s
   lw6ker_zone_state_t *gradient;
   int32_t cursor_ref_pot;
   int32_t last_spread_dir;
-  lw6ker_cursor_array_t cursor_array;
 }
 lw6ker_team_t;
 
@@ -212,23 +242,12 @@ typedef struct lw6ker_map_state_s
   lw6ker_armies_t armies;
   int32_t max_nb_teams;
   lw6ker_team_t teams[LW6MAP_MAX_NB_TEAMS];
+  lw6ker_cursor_array_t cursor_array;
   int32_t nb_layers;
   lw6ker_layer_t layers[LW6MAP_MAX_DEPTH];
 }
 lw6ker_map_state_t;
 
-typedef struct lw6ker_bot_s
-{
-  int active;
-  lw6sys_xy_t pos;
-  int32_t rounds_at_end_of_last_move;
-  int moving;
-  int32_t move_nb_steps;
-  int32_t move_current_step;
-  lw6sys_xy_t move_pos_from;
-  lw6sys_xy_t move_pos_to;
-} lw6ker_bot_t;
-
 /*
  * Game state contains all the data which is verstatile, stuff that
  * changes, this includes "where fighters are" of course but also
@@ -237,13 +256,13 @@ typedef struct lw6ker_bot_s
  */
 typedef struct lw6ker_game_state_s
 {
-  int id;
+  u_int32_t id;
   lw6ker_game_struct_t *game_struct;
   lw6ker_map_state_t map_state;
+  lw6ker_server_array_t server_array;
   u_int32_t moves;
   u_int32_t spreads;
   u_int32_t rounds;
-  lw6ker_bot_t bots[LW6MAP_MAX_NB_TEAMS][LW6MAP_MAX_CURSORS_PER_TEAM];
 }
 lw6ker_game_state_t;
 
@@ -254,48 +273,114 @@ extern int32_t lw6ker_armies_add_fighter (lw6ker_armies_t * armies,
 					  lw6ker_fighter_t fighter);
 extern int lw6ker_armies_remove_fighter (lw6ker_armies_t * armies);
 
+/*
+ * in capture.c
+ */
+extern char *lw6ker_capture_str (lw6ker_game_state_t * game_state);
+
 /*
  * in cursor.c
  */
-extern int lw6ker_cursor_set (lw6ker_cursor_t * cursor, int32_t x,
-			      int32_t y, int32_t pot_offset,
-			      lw6ker_map_struct_t * map_struct,
-			      int32_t max_cursor_pot_offset);
-extern void lw6ker_cursor_clear (lw6ker_cursor_t * cursor);
+extern int lw6ker_cursor_enable (lw6ker_cursor_t * cursor,
+				 u_int64_t server_id,
+				 u_int16_t cursor_id,
+				 int team_color, int32_t x, int32_t y);
+extern int lw6ker_cursor_disable (lw6ker_cursor_t * cursor);
+extern int lw6ker_cursor_update (lw6ker_cursor_t * cursor, int32_t x,
+				 int32_t y, int32_t pot_offset,
+				 lw6sys_wh_t * shape, lw6map_rules_t * rules);
+extern int lw6ker_cursor_sanity_check (lw6ker_cursor_t * cursor,
+				       lw6sys_wh_t * shape,
+				       lw6map_rules_t * rules);
 
 /*
  * in cursorarray.c
  */
-extern void lw6ker_cursor_array_clear (lw6ker_cursor_array_t * cursor_array);
-extern int lw6ker_cursor_array_add (lw6ker_cursor_array_t *
-				    cursor_array, lw6ker_cursor_t * cursor);
-extern int lw6ker_cursor_array_set (lw6ker_cursor_array_t *
-				    cursor_array, int32_t i,
-				    int32_t x, int32_t y,
-				    int32_t pot_offset,
-				    lw6ker_map_struct_t * map_struct,
-				    int32_t max_cursor_pot_offset);
-extern int lw6ker_cursor_array_force_nb_cursors (lw6ker_cursor_array_t *
+extern lw6ker_cursor_t *lw6ker_cursor_array_get (lw6ker_cursor_array_t *
 						 cursor_array,
-						 int32_t nb_cursors);
+						 u_int16_t cursor_id);
+extern int lw6ker_cursor_array_enable (lw6ker_cursor_array_t * cursor_array,
+				       u_int64_t server_id,
+				       u_int16_t cursor_id, int team_color,
+				       int32_t x, int32_t y);
+extern int lw6ker_cursor_array_disable (lw6ker_cursor_array_t * cursor_array,
+					u_int64_t server_id,
+					u_int16_t cursor_id);
+extern int lw6ker_cursor_array_update (lw6ker_cursor_array_t * cursor_array,
+				       u_int64_t server_id,
+				       u_int16_t cursor_id, int32_t x,
+				       int32_t y, int32_t pot_offset,
+				       lw6sys_wh_t * shape,
+				       lw6map_rules_t * rules);
+extern int lw6ker_cursor_array_sanity_check (lw6ker_cursor_array_t *
+					     cursor_array,
+					     lw6sys_wh_t * shape,
+					     lw6map_rules_t * rules);
 
 /*
  * in gamestate.c
  */
 extern lw6ker_game_state_t *lw6ker_game_state_new (lw6ker_game_struct_t *
-						   game_struct);
+						   game_struct,
+						   lw6sys_progress_t *
+						   progress);
 extern void lw6ker_game_state_free (lw6ker_game_state_t * game_state);
+extern void lw6ker_game_state_point_to (lw6ker_game_state_t * game_state,
+					lw6ker_game_struct_t * game_struct);
 extern int lw6ker_game_state_memory_footprint (lw6ker_game_state_t *
 					       game_state);
 extern char *lw6ker_game_state_repr (lw6ker_game_state_t * game_state);
-extern int lw6ker_game_state_copy (lw6ker_game_state_t * dst,
+extern int lw6ker_game_state_sync (lw6ker_game_state_t * dst,
 				   lw6ker_game_state_t * src);
+extern lw6ker_game_state_t *lw6ker_game_state_dup (lw6ker_game_state_t *
+						   game_state);
 extern u_int32_t lw6ker_game_state_checksum (lw6ker_game_state_t *
 					     game_state);
+extern int lw6ker_game_state_register_server (lw6ker_game_state_t *
+					      game_state,
+					      u_int64_t server_id);
+extern int lw6ker_game_state_unregister_server (lw6ker_game_state_t *
+						game_state,
+						u_int64_t server_id);
+extern int lw6ker_game_state_server_exists (lw6ker_game_state_t * game_state,
+					    u_int64_t server_id);
+extern int lw6ker_game_state_get_server_info (lw6ker_game_state_t *
+					      game_state, u_int16_t server_id,
+					      u_int32_t * last_command_round);
+extern int lw6ker_game_state_add_cursor (lw6ker_game_state_t * game_state,
+					 u_int64_t server_id,
+					 u_int16_t cursor_id, int team_color);
+extern int lw6ker_game_state_remove_cursor (lw6ker_game_state_t * game_state,
+					    u_int64_t server_id,
+					    u_int16_t cursor_id);
+extern int lw6ker_game_state_cursor_exists (lw6ker_game_state_t * game_state,
+					    u_int16_t cursor_id);
+extern int lw6ker_game_state_get_cursor_info (lw6ker_game_state_t *
+					      game_state, u_int16_t cursor_id,
+					      u_int64_t * server_id,
+					      char *letter, int *team_color,
+					      int32_t * x, int32_t * y);
+extern int lw6ker_game_state_set_cursor (lw6ker_game_state_t * game_state,
+					 u_int64_t server_id,
+					 u_int16_t cursor_id, int32_t x,
+					 int32_t y);
 extern int lw6ker_game_state_add_team (lw6ker_game_state_t * game_state,
-				       int32_t team_id, int32_t nb_cursors);
+				       u_int64_t server_id, int team_color);
 extern int lw6ker_game_state_remove_team (lw6ker_game_state_t * game_state,
-					  int32_t team_id);
+					  u_int64_t server_id,
+					  int team_color);
+extern int lw6ker_game_state_team_exists (lw6ker_game_state_t * game_state,
+					  int team_color);
+extern int lw6ker_game_state_get_team_info (lw6ker_game_state_t * game_state,
+					    int team_color,
+					    int32_t * nb_cursors,
+					    int32_t * nb_fighters);
+extern int lw6ker_game_state_get_nb_teams (lw6ker_game_state_t * game_state);
+extern void lw6ker_game_state_do_spread (lw6ker_game_state_t *
+					 game_state, u_int32_t team_mask);
+extern void lw6ker_game_state_do_move (lw6ker_game_state_t *
+				       game_state, u_int32_t team_mask);
+extern void lw6ker_game_state_finish_round (lw6ker_game_state_t * game_state);
 extern void lw6ker_game_state_do_round (lw6ker_game_state_t * game_state);
 extern u_int32_t lw6ker_game_state_get_moves (lw6ker_game_state_t *
 					      game_state);
@@ -303,19 +388,23 @@ extern u_int32_t lw6ker_game_state_get_spreads (lw6ker_game_state_t *
 						game_state);
 extern u_int32_t lw6ker_game_state_get_rounds (lw6ker_game_state_t *
 					       game_state);
-extern int lw6ker_game_state_enable_bot (lw6ker_game_state_t * game_state,
-					 int32_t team_id);
-extern int lw6ker_game_state_disable_bot (lw6ker_game_state_t * game_state,
-					  int32_t team_id);
+extern int32_t lw6ker_game_state_get_nb_active_fighters (lw6ker_game_state_t *
+							 game_state);
 
 /*
  * In gamestruct.c
  */
-extern lw6ker_game_struct_t *lw6ker_game_struct_new (lw6map_level_t * level);
+extern lw6ker_game_struct_t *lw6ker_game_struct_new (lw6map_level_t * level,
+						     lw6sys_progress_t *
+						     progress);
 extern void lw6ker_game_struct_free (lw6ker_game_struct_t * game_struct);
+extern void lw6ker_game_struct_point_to (lw6ker_game_struct_t * game_struct,
+					 lw6map_level_t * level);
 extern int lw6ker_game_struct_memory_footprint (lw6ker_game_struct_t *
 						game_struct);
 extern char *lw6ker_game_struct_repr (lw6ker_game_struct_t * game_struct);
+extern lw6ker_game_struct_t *lw6ker_game_struct_dup (lw6ker_game_struct_t *
+						     game_struct);
 extern u_int32_t lw6ker_game_struct_checksum (lw6ker_game_struct_t *
 					      game_struct);
 
@@ -326,32 +415,27 @@ extern u_int32_t lw6ker_game_struct_checksum (lw6ker_game_struct_t *
 /*
  * in mapstate.c
  */
-extern int32_t lw6ker_map_state_get_free_team_id (lw6ker_map_state_t *
-						  map_state);
-extern void lw6ker_map_state_start_xy (lw6ker_map_state_t * map_state,
-				       lw6sys_xy_t * start_xy,
-				       int32_t team_id);
-extern int32_t lw6ker_map_state_get_nb_active_teams (lw6ker_map_state_t *
-						     map_state);;
+extern int lw6ker_map_state_get_free_team_color (lw6ker_map_state_t *
+						 map_state);
 extern int32_t lw6ker_map_state_populate_team (lw6ker_map_state_t * map_state,
-					       int32_t team_id,
+					       int32_t team_color,
 					       int32_t nb_fighters,
 					       lw6sys_xy_t desired_center,
-					       int32_t nb_cursors,
-					       lw6map_options_t options);
+					       lw6map_rules_t * rules);
 extern int lw6ker_map_state_redistribute_team (lw6ker_map_state_t * map_state,
-					       int32_t dst_team_id,
-					       int32_t src_team_id,
+					       int32_t dst_team_color,
+					       int32_t src_team_color,
 					       int32_t nb_fighters,
-					       lw6map_options_t options);
+					       lw6map_rules_t * rules);
 extern int lw6ker_map_state_cancel_team (lw6ker_map_state_t * map_state,
-					 int32_t team_id);
+					 int32_t team_color);
 extern int lw6ker_map_state_remove_fighter (lw6ker_map_state_t * map_state,
 					    int32_t fighter_id);
 extern int lw6ker_map_state_remove_fighters (lw6ker_map_state_t * map_state,
 					     int32_t nb_fighters);
 extern int lw6ker_map_state_remove_team_fighters (lw6ker_map_state_t *
-						  map_state, int32_t team_id,
+						  map_state,
+						  int32_t team_color,
 						  int32_t nb_fighters);
 static inline void
 lw6ker_map_state_set_fighter_id (lw6ker_map_state_t * map_state,
@@ -392,12 +476,17 @@ lw6ker_map_state_get_fighter_unsafe (lw6ker_map_state_t * map_state,
 extern void lw6ker_map_state_print_debug (lw6ker_map_state_t * map_state);
 extern int lw6ker_map_state_sanity_check (lw6ker_map_state_t * map_state);
 extern void lw6ker_map_state_spread_gradient (lw6ker_map_state_t * map_state,
-					      lw6map_options_t * options,
-					      int32_t nb_spreads);
+					      lw6map_rules_t * rules,
+					      int32_t nb_spreads,
+					      u_int32_t team_mask);
 extern void lw6ker_map_state_move_fighters (lw6ker_map_state_t * map_state,
 					    int parity,
-					    lw6map_options_t * options,
-					    int32_t nb_moves);
+					    lw6map_rules_t * rules,
+					    int32_t nb_moves,
+					    u_int32_t team_mask);
+extern void lw6ker_map_state_apply_cursors (lw6ker_map_state_t * map_state,
+					    lw6map_rules_t * rules,
+					    u_int32_t team_mask);
 
 /*
  * In mapstruct.c
@@ -435,17 +524,47 @@ extern void lw6ker_map_struct_find_free_slot_near (lw6ker_map_struct_t *
 						   lw6sys_xy_t * there,
 						   lw6sys_xy_t here);
 
+/*
+ * in server.c
+ */
+extern int lw6ker_server_enable (lw6ker_server_t * server,
+				 u_int64_t server_id);
+extern int lw6ker_server_disable (lw6ker_server_t * server);
+extern int lw6ker_server_sanity_check (lw6ker_server_t * server,
+				       lw6map_rules_t * rules);
+
+/*
+ * in serverarray.c
+ */
+extern lw6ker_server_t *lw6ker_server_array_get (lw6ker_server_array_t *
+						 server_array,
+						 u_int64_t server_id);
+extern int lw6ker_server_array_enable (lw6ker_server_array_t * server_array,
+				       u_int64_t server_id);
+extern int lw6ker_server_array_disable (lw6ker_server_array_t * server_array,
+					u_int64_t server_id);
+extern int lw6ker_server_array_sanity_check (lw6ker_server_array_t *
+					     server_array,
+					     lw6map_rules_t * rules);
+
 /*
  * In team.c
  */
-extern void lw6ker_team_activate (lw6ker_team_t * team,
-				  int32_t nb_cursors, lw6sys_xy_t pos);
+extern void lw6ker_team_activate (lw6ker_team_t * team, lw6sys_xy_t pos);
 extern void lw6ker_team_unactivate (lw6ker_team_t * team);
-extern void lw6ker_team_apply_cursors (lw6ker_team_t * team,
-				       lw6map_options_t * options);
 extern void lw6ker_team_spread_gradient (lw6ker_team_t * team);
 extern void lw6ker_team_normalize_pot (lw6ker_team_t * team,
-				       lw6map_options_t * options);
+				       lw6map_rules_t * rules);
+
+/*
+ * in teammask.c
+ */
+extern void lw6ker_team_mask_get (u_int32_t * even, u_int32_t * odd,
+				  int32_t round);
+extern void lw6ker_team_mask_best (u_int32_t * even, u_int32_t * odd,
+				   lw6ker_game_state_t * game_state);
+extern int lw6ker_team_mask_is_concerned (int team_color,
+					  u_int32_t team_mask);
 
 /*
  * In test.c
@@ -475,13 +594,20 @@ lw6ker_cos (int32_t alpha)
 static inline int32_t
 lw6ker_percent (int32_t n, int32_t percent)
 {
-  return (n * percent) / 100;
+  return (int32_t) ((((int64_t) n) * ((int64_t) percent)) / 100LL);
 }
 
 static inline int32_t
 lw6ker_per1000 (int32_t n, int32_t per1000)
 {
-  return (n * per1000) / 1000;
+  return (int32_t) ((((int64_t) n) * ((int64_t) per1000)) / 100LL);
+}
+
+static inline int32_t
+lw6ker_per100_2 (int32_t n, int32_t per100)
+{
+  return (int32_t) ((((int64_t) n) * ((int64_t) per100) *
+		     ((int64_t) per100)) / 10000LL);
 }
 
 #endif
