@@ -30,7 +30,8 @@
 #include "ldr-internal.h"
 
 int
-_lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file)
+_lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
+		 lw6sys_progress_t * progress)
 {
   png_structp png_ptr = NULL;
   png_infop info_ptr = NULL;
@@ -42,6 +43,8 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file)
   int ret = 0;
   FILE *f = NULL;
 
+  lw6sys_progress_begin (progress);
+
   png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
   if (png_ptr)
     {
@@ -141,7 +144,9 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file)
 
 		      if (memory_ok)
 			{
+			  lw6sys_progress_update (progress, 0, 3, 1);
 			  png_read_image (png_ptr, buf);
+			  lw6sys_progress_update (progress, 0, 3, 2);
 			  png_read_end (png_ptr, end_info);
 
 			  image->shape.w = width;
@@ -185,6 +190,8 @@ _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file)
       _lw6ldr_bw_clear (image);
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
