@@ -27,6 +27,8 @@
 #include "ldr.h"
 #include "ldr-internal.h"
 
+#include <math.h>
+
 #define GLOBAL_BEGIN 0.0f
 #define GLOBAL_END 1.0f
 #define DARK_BEGIN 0.0f
@@ -35,7 +37,10 @@
 #define LIGHT_END 1.0f
 #define DARKER_COEF 0.66f
 #define LIGHTER_COEF 0.66f
-#define STEP 7
+#define MIN_STEP 5
+#define MAX_STEP_NB 50
+#define SWAP_REGULAR_GOOFY_MAJ 1.5f
+#define SWAP_BASE_ALTERNATE_MAJ 2.0f
 
 typedef struct color_info_s
 {
@@ -89,11 +94,12 @@ average_color (color_info_t * ret, int size, color_info_t * color_info,
 }
 
 int
-_lw6ldr_guess_colors (lw6map_level_t * level)
+_lw6ldr_guess_colors (lw6map_level_t * level, lw6sys_progress_t * progress)
 {
   int ret = 0;
   int x, y, i_bg = 0, i_fg = 0;
-  int size = level->texture.shape.w * level->texture.shape.h;
+  int size;
+  int step;
   color_info_t *bg = NULL;
   color_info_t *fg = NULL;
   color_info_t global_bg;
@@ -112,7 +118,16 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
   float distance_base;
   float distance_alternate;
 
-  if (size)
+  step =
+    lw6sys_max (MIN_STEP,
+		(int)
+		sqrt ((((float) level->texture.shape.w) *
+		       ((float) level->texture.shape.h)) / (MAX_STEP_NB *
+							    MAX_STEP_NB)));
+  size =
+    ((level->texture.shape.w + 1) * (level->texture.shape.h +
+				     1)) / (step * step);
+  if (size > 0)
     {
       bg = (color_info_t *) LW6SYS_MALLOC (sizeof (color_info_t) * size);
       if (bg)
@@ -120,9 +135,15 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 	  fg = (color_info_t *) LW6SYS_MALLOC (sizeof (color_info_t) * size);
 	  if (fg)
 	    {
-	      for (y = 0; y < level->texture.shape.h; y += STEP)
+	      for (y = 0;
+		   y < level->texture.shape.h && i_bg < size && i_fg < size;
+		   y += step)
 		{
-		  for (x = 0; x < level->texture.shape.w; x += STEP)
+		  lw6sys_progress_update (progress, 0, level->texture.shape.h,
+					  y);
+		  for (x = 0;
+		       x < level->texture.shape.w && i_bg < size
+		       && i_fg < size; x += step)
 		    {
 		      if (lw6map_depth_get_with_texture_coord (level, x, y) >
 			  0)
@@ -131,6 +152,7 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 			    lw6map_texture_get (&level->texture, x, y);
 			  lw6sys_color_rgb_to_hsv (&(bg[i_bg].color_hsv),
 						   bg[i_bg].color_8);
+			  lw6sys_color_8_solid (&(bg[i_bg].color_8));
 			  i_bg++;
 			}
 		      else
@@ -139,6 +161,7 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 			    lw6map_texture_get (&level->texture, x, y);
 			  lw6sys_color_rgb_to_hsv (&(fg[i_fg].color_hsv),
 						   fg[i_fg].color_8);
+			  lw6sys_color_8_solid (&(fg[i_fg].color_8));
 			  i_fg++;
 			}
 		    }
@@ -189,7 +212,8 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 						light_fg.color_8));
 		  base_bg = dark_bg;
 		  alternate_bg = light_bg;
-		  if (distance_regular > distance_goofy)
+		  if (distance_regular <
+		      distance_goofy * SWAP_REGULAR_GOOFY_MAJ)
 		    {
 		      base_fg = dark_fg;
 		      alternate_fg = light_fg;
@@ -235,7 +259,8 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 		  distance_alternate =
 		    lw6sys_color_distance (alternate_bg.color_8,
 					   alternate_fg.color_8);
-		  if (distance_base > distance_alternate)
+		  if (distance_base >
+		      distance_alternate * SWAP_BASE_ALTERNATE_MAJ)
 		    {
 		      tmp = base_bg;
 		      base_bg = alternate_bg;
@@ -283,13 +308,57 @@ _lw6ldr_guess_colors (lw6map_level_t * level)
 }
 
 void
-_lw6ldr_auto_background (lw6map_level_t * level)
+_lw6ldr_apply_guessed_colors (lw6map_level_t * level)
 {
-  if (level->param.style.background_color_auto)
+  level->param.style.color_base = level->texture.guessed_color_base;
+  level->param.style.color_alternate = level->texture.guessed_color_alternate;
+}
+
+/**
+ * lw6ldr_auto_colors
+ *
+ * @style: the style structure to process.
+ * @hints: additionnal hints to know what to set automatically
+ *
+ * Deduces all colors from background color, if needed. The function
+ * will check color_auto parameters and replace all other colors
+ * by base and alternate colors if needed. Note that the background
+ * color itself is not changed by this function. Background can only
+ * be guessed from texture.
+ *
+ * Return value: none.
+ */
+void
+lw6ldr_auto_colors (lw6map_style_t * style, lw6ldr_hints_t * hints)
+{
+  if (hints->background_color_auto)
     {
-      level->param.style.background_color_base =
-	level->texture.guessed_color_base;
-      level->param.style.background_color_alternate =
-	level->texture.guessed_color_alternate;
+      style->background_color_root = style->color_base;
+      style->background_color_stuff = style->color_alternate;
+    }
+
+  if (hints->hud_color_auto)
+    {
+      style->hud_color_frame = style->color_base;
+      style->hud_color_text = style->color_alternate;
+    }
+
+  if (hints->menu_color_auto)
+    {
+      style->menu_color_default = style->color_alternate;
+      style->menu_color_selected = style->color_alternate;
+      lw6map_color_invert (&style->menu_color_selected);
+      style->menu_color_disabled = style->color_base;
+    }
+
+  if (hints->view_color_auto)
+    {
+      style->view_color_cursor = style->color_alternate;
+      style->view_color_map = style->color_base;
+    }
+
+  if (hints->system_color_auto)
+    {
+      style->system_color = style->color_alternate;
     }
 }
