@@ -31,19 +31,25 @@
 
 static int
 read_png (lw6map_depth_t * depth, char *map_dot_png,
-	  lw6map_options_t * options, lw6sys_wh_t * display_shape,
-	  float target_ratio, float fighter_scale)
+	  lw6map_param_t * param, lw6ldr_hints_t * hints,
+	  lw6sys_wh_t * display_shape, float target_ratio,
+	  lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_bw_t image;
 
   memset (&image, 0, sizeof (_lw6ldr_image_bw_t));
 
-  if (_lw6ldr_bw_read (&image, map_dot_png))
+  if (_lw6ldr_bw_read (&image, map_dot_png, progress))
     {
-      lw6map_resampler_t resampler;
-      lw6map_resampler_init (&resampler, options, &(image.shape),
-			     display_shape, target_ratio, fighter_scale);
+      lw6ldr_resampler_t resampler;
+
+      if (target_ratio <= 0.0f)
+	{
+	  target_ratio = ((float) image.shape.w) / ((float) image.shape.h);
+	}
+      lw6ldr_resampler_init (&resampler, param, hints, &(image.shape),
+			     display_shape, target_ratio);
 
       depth->shape = resampler.target_shape;
       depth->data =
@@ -57,9 +63,10 @@ read_png (lw6map_depth_t * depth, char *map_dot_png,
 
 	  for (row = 0; row < depth->shape.h; ++row)
 	    {
+	      lw6sys_progress_update (progress, 0, depth->shape.h, row);
 	      for (col = 0; col < depth->shape.w; ++col)
 		{
-		  lw6map_resampler_target2source (&resampler, &col2, &row2,
+		  lw6ldr_resampler_target2source (&resampler, &col2, &row2,
 						  col, row);
 
 		  value = image.data[row2][col2 * image.step];
@@ -102,8 +109,9 @@ read_png (lw6map_depth_t * depth, char *map_dot_png,
  */
 int
 lw6ldr_depth_read (lw6map_depth_t * depth, char *dirname,
-		   lw6map_options_t * options, lw6sys_wh_t * display_shape,
-		   float ratio, float fighter_scale)
+		   lw6map_param_t * param, lw6ldr_hints_t * hints,
+		   lw6sys_wh_t * display_shape, float ratio,
+		   lw6sys_progress_t * progress)
 {
   int ret = 0;
   char *map_dot_png;
@@ -116,20 +124,9 @@ lw6ldr_depth_read (lw6map_depth_t * depth, char *dirname,
       lw6sys_log (LW6SYS_LOG_INFO, _("reading \"%s\""), map_dot_png);
 
       ret =
-	read_png (depth, map_dot_png, options, display_shape, ratio,
-		  fighter_scale);
-      if (ret)
-	{
-	  if (options->x_polarity == 0)
-	    {
-	      lw6map_depth_block_left_right (depth);
-	    }
-	  if (options->y_polarity == 0)
-	    {
-	      lw6map_depth_block_up_down (depth);
-	    }
-	  ret = lw6map_depth_check_and_fix_holes (depth);
-	}
+	read_png (depth, map_dot_png, param, hints, display_shape, ratio,
+		  progress);
+      ret = ret && lw6map_depth_check_and_fix_holes (depth, &param->rules);
 
       LW6SYS_FREE (map_dot_png);
     }
