@@ -29,6 +29,14 @@
 #include "ldr.h"
 #include "ldr-internal.h"
 
+typedef struct for_all_entries_callback_data_s
+{
+  char *map_path;
+  int recursive;
+  lw6sys_list_callback_func_t callback_func;
+  void *func_data;
+} for_all_entries_callback_data_t;
+
 static lw6ldr_entry_t *
 new_entry (char *absolute_path, char *relative_path, char *entry_path)
 {
@@ -47,8 +55,15 @@ new_entry (char *absolute_path, char *relative_path, char *entry_path)
 	      if (lw6sys_dir_exists (entry->absolute_path))
 		{
 		  entry->title = lw6sys_str_copy (entry_path);
-		  entry->relative_path =
-		    lw6sys_path_concat (relative_path, entry_path);
+		  if (lw6sys_path_is_cwd (relative_path))
+		    {
+		      entry->relative_path = lw6sys_str_copy (entry_path);
+		    }
+		  else
+		    {
+		      entry->relative_path =
+			lw6sys_path_concat (relative_path, entry_path);
+		    }
 		  map_filename =
 		    lw6sys_path_concat (entry->absolute_path,
 					_LW6LDR_FILE_MAP_PNG);
@@ -103,6 +118,15 @@ free_entry_callback (void *data)
   lw6ldr_free_entry ((lw6ldr_entry_t *) data);
 }
 
+/**
+ * lw6ldr_free_entry
+ *
+ * @entry: the entry to free
+ *
+ * Frees a map entry.
+ *
+ * Return value: none.
+ */
 void
 lw6ldr_free_entry (lw6ldr_entry_t * entry)
 {
@@ -240,9 +264,44 @@ add_subdirs (lw6sys_list_t ** entries, lw6sys_assoc_t ** entries_index,
 #endif
 }
 
-/*
- * Returns a list of lw6ldr_entry_t elements, which
- * describe what maps are in a directory.
+static int
+entries_sort_callback (lw6sys_list_t ** list_a, lw6sys_list_t ** list_b)
+{
+  int ret = 0;
+  lw6ldr_entry_t *entry_a;
+  lw6ldr_entry_t *entry_b;
+
+  entry_a = (lw6ldr_entry_t *) ((*list_a)->data);
+  entry_b = (lw6ldr_entry_t *) ((*list_b)->data);
+
+  if (entry_a->has_subdirs && (!entry_b->has_subdirs))
+    {
+      ret = -1;
+    }
+  else if ((!entry_a->has_subdirs) && entry_b->has_subdirs)
+    {
+      ret = 1;
+    }
+  else
+    {
+      ret = strcmp (entry_a->title, entry_b->title);
+    }
+
+  return ret;
+}
+
+/**
+ * lw6ldr_get_entries
+ *
+ * @map_path: the map_path environment config variable, delimited path list
+ * @relative_path: the relative path to use to find the map directory
+ *
+ * Lists all maps in a given directory. Returns a list of lw6ldr_entry_t
+ * which can contain both directories with subdirs and actual maps. Maps
+ * are sorted before being returned, first directories, then maps, sorted
+ * in alphabetical order.
+ *
+ * Return value: a list of dynamically allocated lw6ldr_entry_t.
  */
 lw6sys_list_t *
 lw6ldr_get_entries (char *map_path, char *relative_path)
@@ -288,5 +347,78 @@ lw6ldr_get_entries (char *map_path, char *relative_path)
       lw6sys_assoc_free (entries_index);
     }
 
+  if (entries)
+    {
+      lw6sys_sort (&entries, entries_sort_callback);
+    }
+
   return entries;
 }
+
+static void
+for_all_entries_callback_func (void *func_data, void *data)
+{
+  for_all_entries_callback_data_t *callback_data =
+    (for_all_entries_callback_data_t *) func_data;
+  lw6ldr_entry_t *entry = (lw6ldr_entry_t *) data;
+  lw6sys_list_t *entries;
+
+  if (entry && callback_data)
+    {
+      if (entry->has_subdirs)
+	{
+	  if (callback_data->recursive)
+	    {
+	      entries =
+		lw6ldr_get_entries (callback_data->map_path,
+				    entry->relative_path);
+	      if (entries)
+		{
+		  lw6sys_list_map (entries, for_all_entries_callback_func,
+				   func_data);
+		  lw6sys_list_free (entries);
+		}
+	    }
+	}
+      else
+	{
+	  callback_data->callback_func (callback_data->func_data, data);
+	}
+    }
+}
+
+/**
+ * lw6ldr_for_all_entries
+ *
+ * @map_path: the map_path environment config variable, delimited path list
+ * @relative_path: the relative path to use to find the map directory
+ * @recursive: if non-zero, map search will recurse in subdirs
+ * @callback_func: the function which will be called on each entry
+ * @func_data: an extra pointer to pass data to callback_func
+ *
+ * Executes a given function on all maps in a given place, typically
+ * used in test programs.
+ *
+ * Return value: none.
+ */
+void
+lw6ldr_for_all_entries (char *map_path, char *relative_path, int recursive,
+			lw6sys_list_callback_func_t callback_func,
+			void *func_data)
+{
+  lw6sys_list_t *entries = NULL;
+  for_all_entries_callback_data_t callback_data;
+
+  memset (&callback_data, 0, sizeof (for_all_entries_callback_data_t));
+  entries = lw6ldr_get_entries (map_path, relative_path);
+  if (entries)
+    {
+      callback_data.map_path = map_path;
+      callback_data.recursive = recursive;
+      callback_data.callback_func = callback_func;
+      callback_data.func_data = func_data;
+      lw6sys_list_map (entries, for_all_entries_callback_func,
+		       (void *) &callback_data);
+      lw6sys_list_free (entries);
+    }
+}
