@@ -32,7 +32,8 @@
 #define _LW6LDR_FILE_TEXTURE_ALPHA_JPEG "texture-alpha.jpeg"
 #define _LW6LDR_FILE_TEXTURE_ALPHA_JPG "texture-alpha.jpg"
 
-#define _LW6LDR_FILE_OPTIONS_XML "options.xml"
+#define _LW6LDR_FILE_RULES_XML "rules.xml"
+#define _LW6LDR_FILE_HINTS_XML "hints.xml"
 #define _LW6LDR_FILE_STYLE_XML "style.xml"
 
 typedef struct _lw6ldr_image_bw_s
@@ -54,22 +55,26 @@ _lw6ldr_image_rgba_t;
 /*
  * In bw.c
  */
-extern int _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file);
+extern int _lw6ldr_bw_read (_lw6ldr_image_bw_t * image, char *png_file,
+			    lw6sys_progress_t * progress);
 extern void _lw6ldr_bw_clear (_lw6ldr_image_bw_t * image);
 
 /*
  * In color.c
  */
-extern int _lw6ldr_guess_colors (lw6map_level_t * level);
-extern void _lw6ldr_auto_background (lw6map_level_t * level);
+extern int _lw6ldr_guess_colors (lw6map_level_t * level,
+				 lw6sys_progress_t * progress);
+extern void _lw6ldr_apply_guessed_colors (lw6map_level_t * level);
 
 /*
  * In rgba.c
  */
 extern int _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image,
-				  char *png_file);
+				  char *png_file,
+				  lw6sys_progress_t * progress);
 extern int _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image,
-				   char *jpeg_file);
+				   char *jpeg_file,
+				   lw6sys_progress_t * progress);
 extern void _lw6ldr_rgba_clear (_lw6ldr_image_rgba_t * image);
 
 #endif
