@@ -46,7 +46,7 @@ lw6ldr_param_read (lw6map_param_t * param, char *dirname)
 {
   int ret = 0;
 
-  ret = lw6ldr_options_read (&(param->options), dirname) &&
+  ret = lw6ldr_rules_read (&(param->rules), dirname) &&
     lw6ldr_style_read (&(param->style), dirname);
 
   return ret;
@@ -71,7 +71,7 @@ lw6ldr_param_update (lw6map_param_t * param, lw6sys_assoc_t * values)
 {
   int ret = 0;
 
-  if (!lw6ldr_options_update (&(param->options), values))
+  if (!lw6ldr_rules_update (&(param->rules), values))
     {
       ret = 0;
     }
