@@ -35,12 +35,13 @@
  * @default_param: default parameters, as strings
  * @forced_param: forced parameters, as strings
  * @display_shape: the shape of the display output (resolution)
+ * @progress: information used to handle the progress bar
  *
  * Loads a map from dist. The default_param and forced_param can contain
- * values corresponding to options.xml and style.xml entries. Parameters
+ * values corresponding to rules.xml and style.xml entries. Parameters
  * are read in 4 steps. 1st, a default value is picked by the program.
  * 2nd, any value in @default_param replaces previous values. 3rd, any
- * value in options.xml or style.xml replaces previous values.
+ * value in rules.xml or style.xml replaces previous values.
  * 4th, any value in @forced_param replaces previous values. In practice,
  * the @default_param allows the user to set defaults which can still
  * be overwritten by the map, while @forced_param is a definitive 'ignore
@@ -51,36 +52,82 @@
  */
 lw6map_level_t *
 lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
-	     lw6sys_assoc_t * forced_param, lw6sys_wh_t * display_shape)
+	     lw6sys_assoc_t * forced_param, lw6sys_wh_t * display_shape,
+	     lw6sys_progress_t * progress)
 {
   lw6map_level_t *level = NULL;
   int ok = 0;
-  float ratio = 1.0f;
+  float ratio = 0.0f;		// important, in case texture isn't found/used
+  int texture_exists = 0;
+  lw6sys_progress_t progress_texture;
+  lw6sys_progress_t progress_depth;
+  lw6sys_progress_t progress_color;
+  lw6ldr_hints_t hints;
+  lw6ldr_use_t use;
 
   lw6sys_log (LW6SYS_LOG_INFO, _("loading map \"%s\""), dirname);
 
+  lw6sys_progress_split3 (&progress_texture, &progress_depth, &progress_color,
+			  progress);
+
   level = lw6map_new ();
   if (level)
     {
-      lw6map_param_defaults (&(level->param));
-
       ok = 1;
 
+      lw6map_rules_defaults (&(level->param.rules));
+      lw6ldr_hints_defaults (&hints);
+      lw6map_style_defaults (&(level->param.style));
+      lw6ldr_use_defaults (&use);
+
       ok = ok && lw6ldr_metadata_read (&level->metadata, dirname);
-      lw6ldr_param_update (&(level->param), default_param);
-      ok = ok && lw6ldr_param_read (&level->param, dirname);
-      lw6ldr_param_update (&(level->param), forced_param);
-      lw6map_auto_colors (&level->param.style);
+      lw6ldr_rules_update (&(level->param.rules), default_param);
+      lw6ldr_hints_update (&hints, default_param);
+      lw6ldr_style_update (&(level->param.style), default_param);
+      lw6ldr_use_update (&use, default_param);
+      if (use.use_rules_xml)
+	{
+	  ok = ok && lw6ldr_rules_read (&level->param.rules, dirname);
+	  lw6ldr_rules_update (&(level->param.rules), forced_param);
+	}
+      if (use.use_hints_xml)
+	{
+	  ok = ok && lw6ldr_hints_read (&hints, dirname);
+	  lw6ldr_hints_update ((&hints), forced_param);
+	}
+      if (use.use_style_xml)
+	{
+	  ok = ok && lw6ldr_style_read (&level->param.style, dirname);
+	  lw6ldr_style_update (&(level->param.style), forced_param);
+	}
+      if (use.use_texture)
+	{
+	  lw6ldr_auto_colors (&level->param.style, &hints);
+	  ok = ok
+	    && lw6ldr_texture_read (&level->texture, dirname,
+				    &(level->param), &hints, use.use_texture,
+				    display_shape, &ratio, &texture_exists,
+				    &progress_texture);
+	}
       ok = ok
-	&& lw6ldr_texture_read (&level->texture, dirname,
-				&(level->param.style), display_shape, &ratio);
-      ok = ok
-	&& lw6ldr_depth_read (&level->depth, dirname, &(level->param.options),
-			      display_shape, ratio,
-			      level->param.style.fighter_scale);
-      _lw6ldr_guess_colors (level);
-      _lw6ldr_auto_background (level);
-      lw6map_auto_colors (&level->param.style);
+	&& lw6ldr_depth_read (&level->depth, dirname, &(level->param), &hints,
+			      display_shape, ratio, &progress_depth);
+      if (!level->texture.data)
+	{
+	  ok = ok
+	    && lw6map_texture_from_depth (&level->texture, &level->depth,
+					  &(level->param.
+					    style.view_color_map));
+	}
+      if (ok && texture_exists)
+	{
+	  if (hints.guess_colors)
+	    {
+	      _lw6ldr_guess_colors (level, &progress_color);
+	      _lw6ldr_apply_guessed_colors (level);
+	    }
+	}
+      lw6ldr_auto_colors (&level->param.style, &hints);
     }
 
   if (!ok)
@@ -102,6 +149,7 @@ lw6ldr_read (char *dirname, lw6sys_assoc_t * default_param,
  * @default_param: default parameters, as strings
  * @forced_param: forced parameters, as strings
  * @display_shape: the shape of the display output (resolution)
+ * @progress: information used to handle the progress bar
  *
  * Reads a map from disk, using the map-path value, which is a collection
  * of paths defined by the command-line, the environment variables, and
@@ -114,7 +162,8 @@ lw6map_level_t *
 lw6ldr_read_relative (char *map_path, char *relative_path,
 		      lw6sys_assoc_t * default_param,
 		      lw6sys_assoc_t * forced_param,
-		      lw6sys_wh_t * display_shape)
+		      lw6sys_wh_t * display_shape,
+		      lw6sys_progress_t * progress)
 {
   lw6map_level_t *ret = NULL;
   lw6sys_list_t *dirs = NULL;
@@ -135,7 +184,7 @@ lw6ldr_read_relative (char *map_path, char *relative_path,
 		    {
 		      ret =
 			lw6ldr_read (full_dir, default_param, forced_param,
-				     display_shape);
+				     display_shape, progress);
 		    }
 		}
 	      LW6SYS_FREE (full_dir);
