@@ -36,7 +36,8 @@
 #include "ldr-internal.h"
 
 int
-_lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file)
+_lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file,
+		       lw6sys_progress_t * progress)
 {
   png_structp png_ptr = NULL;
   png_infop info_ptr = NULL;
@@ -48,6 +49,8 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file)
   int ret = 0;
   FILE *f = NULL;
 
+  lw6sys_progress_begin (progress);
+
   png_ptr = png_create_read_struct (PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
   if (png_ptr)
     {
@@ -143,7 +146,9 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file)
 
 		      if (memory_ok)
 			{
+			  lw6sys_progress_update (progress, 0, 3, 1);
 			  png_read_image (png_ptr, buf);
+			  lw6sys_progress_update (progress, 0, 3, 2);
 			  png_read_end (png_ptr, end_info);
 
 			  image->shape.w = width;
@@ -187,11 +192,14 @@ _lw6ldr_rgba_read_png (_lw6ldr_image_rgba_t * image, char *png_file)
       _lw6ldr_rgba_clear (image);
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
 int
-_lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file)
+_lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file,
+			lw6sys_progress_t * progress)
 {
   int ret = 0;
   FILE *f = NULL;
@@ -204,6 +212,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file)
   unsigned char **buf;
   int memory_ok;
 
+  lw6sys_progress_begin (progress);
+
   /*
    * This function probably lacks many error checks.
    */
@@ -250,6 +260,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file)
 		((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
 	      while (cinfo.output_scanline < cinfo.output_height)
 		{
+		  lw6sys_progress_update (progress, 0, cinfo.output_height,
+					  cinfo.output_scanline);
 		  j =
 		    lw6sys_max (lw6sys_min
 				(cinfo.output_scanline,
@@ -276,6 +288,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file)
 		((j_common_ptr) & cinfo, JPOOL_IMAGE, row_stride, 1);
 	      while (cinfo.output_scanline < cinfo.output_height)
 		{
+		  lw6sys_progress_update (progress, 0, cinfo.output_height,
+					  cinfo.output_scanline);
 		  j =
 		    lw6sys_max (lw6sys_min
 				(cinfo.output_scanline,
@@ -324,6 +338,8 @@ _lw6ldr_rgba_read_jpeg (_lw6ldr_image_rgba_t * image, char *jpeg_file)
       _lw6ldr_rgba_clear (image);
     }
 
+  lw6sys_progress_end (progress);
+
   return ret;
 }
 
