@@ -113,7 +113,7 @@ lw6ldr_style_set (lw6map_style_t * style, char *key, char *value)
   int ret = 0;
   char *about = NULL;
   char *element = NULL;
-  LW6HLP_TYPE type = LW6HLP_TYPE_VOID;
+  lw6hlp_type_t type = LW6HLP_TYPE_VOID;
 
   about = lw6hlp_about (&type, key);
   element = lw6cfg_xml_element (type);
