@@ -119,60 +119,8 @@ read_alpha_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image)
 }
 
 static int
-read_bicolor_image (lw6map_texture_t * texture, _lw6ldr_image_rgba_t * image,
-		    lw6map_color_couple_t * color)
-{
-  int ret = 0;
-
-  texture->shape.w = image->shape.w;
-  texture->shape.h = image->shape.h;
-  texture->data =
-    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->shape.w *
-					texture->shape.h *
-					sizeof (lw6sys_color_8_t *));
-
-  if (texture->data)
-    {
-      int row, col;
-      lw6sys_color_8_t value;
-
-      for (row = 0; row < texture->shape.h; ++row)
-	{
-	  for (col = 0; col < texture->shape.w; ++col)
-	    {
-	      if (image->data[row][col * 4] > 127)
-		{
-		  value = color->bg;
-		}
-	      else
-		{
-		  value = color->fg;
-		}
-
-	      lw6map_texture_set (texture, col, row, value);
-	    }
-	}
-
-      ret = 1;
-    }
-  else
-    {
-      lw6sys_log (LW6SYS_LOG_ERROR,
-		  _("unable to allocate memory for texture"));
-    }
-
-  _lw6ldr_rgba_clear (image);
-
-  if (!ret)
-    {
-      lw6map_texture_clear (texture);
-    }
-
-  return ret;
-}
-
-static int
-read_png (lw6map_texture_t * texture, char *texture_dot_png)
+read_png (lw6map_texture_t * texture, char *texture_dot_png,
+	  lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
@@ -182,7 +130,7 @@ read_png (lw6map_texture_t * texture, char *texture_dot_png)
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_png (&image, texture_dot_png))
+  if (_lw6ldr_rgba_read_png (&image, texture_dot_png, progress))
     {
       ret = read_image (texture, &image);
     }
@@ -191,7 +139,8 @@ read_png (lw6map_texture_t * texture, char *texture_dot_png)
 }
 
 static int
-read_jpeg (lw6map_texture_t * texture, char *texture_dot_jpeg)
+read_jpeg (lw6map_texture_t * texture, char *texture_dot_jpeg,
+	   lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
@@ -201,7 +150,7 @@ read_jpeg (lw6map_texture_t * texture, char *texture_dot_jpeg)
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_jpeg (&image, texture_dot_jpeg))
+  if (_lw6ldr_rgba_read_jpeg (&image, texture_dot_jpeg, progress))
     {
       ret = read_image (texture, &image);
     }
@@ -210,7 +159,8 @@ read_jpeg (lw6map_texture_t * texture, char *texture_dot_jpeg)
 }
 
 static int
-read_alpha_jpeg (lw6map_texture_t * texture, char *texture_alpha_dot_jpeg)
+read_alpha_jpeg (lw6map_texture_t * texture, char *texture_alpha_dot_jpeg,
+		 lw6sys_progress_t * progress)
 {
   int ret = 0;
   _lw6ldr_image_rgba_t image;
@@ -220,7 +170,7 @@ read_alpha_jpeg (lw6map_texture_t * texture, char *texture_alpha_dot_jpeg)
 
   memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
 
-  if (_lw6ldr_rgba_read_jpeg (&image, texture_alpha_dot_jpeg))
+  if (_lw6ldr_rgba_read_jpeg (&image, texture_alpha_dot_jpeg, progress))
     {
       ret = read_alpha_image (texture, &image);
     }
@@ -228,26 +178,6 @@ read_alpha_jpeg (lw6map_texture_t * texture, char *texture_alpha_dot_jpeg)
   return ret;
 }
 
-static int
-default_texture (lw6map_texture_t * texture, char *map_dot_png,
-		 lw6map_color_couple_t * color)
-{
-  int ret = 0;
-  _lw6ldr_image_rgba_t image;
-
-  lw6sys_log (LW6SYS_LOG_INFO,
-	      _("generating default texture from PNG \"%s\""), map_dot_png);
-
-  memset (&image, 0, sizeof (_lw6ldr_image_rgba_t));
-
-  if (_lw6ldr_rgba_read_png (&image, map_dot_png))
-    {
-      ret = read_bicolor_image (texture, &image, color);
-    }
-
-  return ret;
-}
-
 /*
  * Read the texture associated to a map. Pointer to texture must be valid,
  * it's modified in-place. The function will automatically figure out
@@ -256,14 +186,18 @@ default_texture (lw6map_texture_t * texture, char *map_dot_png,
  */
 int
 lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
-		     lw6map_style_t * style, lw6sys_wh_t * display_shape,
-		     float *ratio)
+		     lw6map_param_t * param, lw6ldr_hints_t * hints,
+		     int use_texture, lw6sys_wh_t * display_shape,
+		     float *ratio, int *texture_exists,
+		     lw6sys_progress_t * progress)
 {
   int ret = 0;
 
   lw6map_texture_clear (texture);
 
-  if (style->use_texture && !ret)
+  (*texture_exists) = 0;
+
+  if (use_texture && !ret)
     {
       /*
        * First, we try to read texture.png
@@ -276,13 +210,14 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	{
 	  if (lw6sys_file_exists (texture_dot_png))
 	    {
-	      ret = read_png (texture, texture_dot_png);
+	      ret = read_png (texture, texture_dot_png, progress);
+	      (*texture_exists) = ret;
 	    }
 	  LW6SYS_FREE (texture_dot_png);
 	}
     }
 
-  if (style->use_texture && !ret)
+  if (use_texture && !ret)
     {
       /*
        * Second, we try to read texture.jpeg
@@ -295,7 +230,8 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	{
 	  if (lw6sys_file_exists (texture_dot_jpeg))
 	    {
-	      ret = read_jpeg (texture, texture_dot_jpeg);
+	      ret = read_jpeg (texture, texture_dot_jpeg, progress);
+	      (*texture_exists) = ret;
 	    }
 	  LW6SYS_FREE (texture_dot_jpeg);
 	}
@@ -308,14 +244,15 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	    {
 	      if (lw6sys_file_exists (texture_dot_jpeg))
 		{
-		  ret = read_jpeg (texture, texture_dot_jpeg);
+		  ret = read_jpeg (texture, texture_dot_jpeg, progress);
+		  (*texture_exists) = ret;
 		}
 	      LW6SYS_FREE (texture_dot_jpeg);
 	    }
 	}
     }
 
-  if (style->use_texture && ret)
+  if (use_texture && ret)
     {
       /*
        * If texture is successfully loaded, apply separate
@@ -329,7 +266,7 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	{
 	  if (lw6sys_file_exists (texture_alpha_dot_jpeg))
 	    {
-	      ret = read_alpha_jpeg (texture, texture_alpha_dot_jpeg);
+	      ret = read_alpha_jpeg (texture, texture_alpha_dot_jpeg, NULL);
 	    }
 	  LW6SYS_FREE (texture_alpha_dot_jpeg);
 	}
@@ -341,36 +278,17 @@ lw6ldr_texture_read (lw6map_texture_t * texture, char *dirname,
 	    {
 	      if (lw6sys_file_exists (texture_alpha_dot_jpeg))
 		{
-		  ret = read_alpha_jpeg (texture, texture_alpha_dot_jpeg);
+		  ret =
+		    read_alpha_jpeg (texture, texture_alpha_dot_jpeg, NULL);
 		}
 	      LW6SYS_FREE (texture_alpha_dot_jpeg);
 	    }
 	}
     }
 
-  if (!ret)
-    {
-      /*
-       * Finally, we read map.png, which should always be here.
-       */
-      char *map_dot_png;
-
-      map_dot_png = lw6sys_path_concat (dirname, _LW6LDR_FILE_MAP_PNG);
-      if (map_dot_png)
-	{
-	  if (lw6sys_file_exists (map_dot_png))
-	    {
-	      ret =
-		default_texture (texture, map_dot_png,
-				 &(style->view_color_map));
-	    }
-	  LW6SYS_FREE (map_dot_png);
-	}
-    }
-
   if (ret && texture->shape.w > 0 && texture->shape.h > 0)
     {
-      if (style->keep_ratio)
+      if (param->style.keep_ratio)
 	{
 	  (*ratio) = ((float) texture->shape.w) / ((float) texture->shape.h);
 	}
