@@ -27,7 +27,7 @@
  * This is the main Liquid War 6 header file.
  */
 
-#define LW6_VERSION "0.0.4beta"
+#define LW6_VERSION "0.0.5beta"
 
 #include <pthread.h>
 #include <libguile.h>
@@ -39,12 +39,14 @@
 #include "cfg/cfg.h"
 #include "map/map.h"
 #include "ker/ker.h"
+#include "bot/bot.h"
 #include "ldr/ldr.h"
 #include "tsk/tsk.h"
 #include "gui/gui.h"
 #include "gfx/gfx.h"
 #include "snd/snd.h"
 #include "img/img.h"
+#include "pil/pil.h"
 #include "net/net.h"
 #include "cli/cli.h"
 #include "srv/srv.h"
@@ -56,6 +58,8 @@ typedef struct lw6_smob_types_s
   scm_t_bits menu;
   scm_t_bits game_struct;
   scm_t_bits game_state;
+  scm_t_bits pilot;
+  scm_t_bits bot;
   scm_t_bits look;
   scm_t_bits loader;
 }
@@ -87,6 +91,19 @@ typedef struct lw6_game_state_smob_s
 }
 lw6_game_state_smob_t;
 
+typedef struct lw6_pilot_smob_s
+{
+  lw6pil_pilot_t *c_pilot;
+}
+lw6_pilot_smob_t;
+
+typedef struct lw6_bot_smob_s
+{
+  lw6bot_backend_t *c_bot;
+  SCM game_state;
+}
+lw6_bot_smob_t;
+
 typedef struct lw6_look_smob_s
 {
   lw6gui_look_t *c_look;
@@ -113,11 +130,14 @@ typedef struct lw6_global_s
   int start_time;
   int argc;
   char **argv;
+  float progress;
   lw6_smob_types_t smob_types;
   lw6sys_assoc_t *map_smobs;
   lw6sys_assoc_t *menu_smobs;
   lw6sys_assoc_t *game_struct_smobs;
   lw6sys_assoc_t *game_state_smobs;
+  lw6sys_assoc_t *pilot_smobs;
+  lw6sys_assoc_t *bot_smobs;
   lw6sys_assoc_t *look_smobs;
   lw6sys_assoc_t *loader_smobs;
 }
@@ -167,6 +187,7 @@ extern void lw6_print_help ();
 extern void lw6_print_version ();
 extern void lw6_print_short_copyright ();
 extern void lw6_print_long_copyright ();
+extern void lw6_print_bench (float bench_result);
 extern void lw6_print_pedigree ();
 extern void lw6_print_audit (int argc, char *argv[]);
 extern void lw6_print_modules ();
@@ -180,7 +201,8 @@ extern void lw6_print_list_graphics ();
 extern void lw6_print_list_sound ();
 extern void lw6_print_list_network ();
 extern void lw6_print_list_map ();
-extern void lw6_print_list_map_options ();
+extern void lw6_print_list_map_hints ();
+extern void lw6_print_list_map_rules ();
 extern void lw6_print_list_map_style ();
 extern void lw6_print_list_funcs ();
 extern void lw6_print_list_hooks ();
@@ -210,6 +232,12 @@ extern SCM lw6_make_scm_game_state (lw6ker_game_state_t * c_game_state,
 extern lw6ker_game_state_t *lw6_scm_to_game_state (SCM game_state);
 extern void lw6_free_game_state_smob (lw6_game_state_smob_t *
 				      game_state_smob);
+extern SCM lw6_make_scm_pilot (lw6pil_pilot_t * c_pilot);
+extern lw6pil_pilot_t *lw6_scm_to_pilot (SCM pilot);
+extern void lw6_free_pilot_smob (lw6_pilot_smob_t * pilot_smob);
+extern SCM lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state);
+extern lw6bot_backend_t *lw6_scm_to_bot (SCM bot);
+extern void lw6_free_bot_smob (lw6_bot_smob_t * bot_smob);
 extern SCM lw6_make_scm_look (lw6gui_look_t * c_look);
 extern lw6gui_look_t *lw6_scm_to_look (SCM look);
 extern void lw6_free_look_smob (lw6_look_smob_t * look_smob);
