@@ -41,9 +41,9 @@ lw6_resize_callback (int width, int height, int fullscreen)
 {
   if (lw6_global.cfg_context)
     {
-      lw6cfg_set_option_int (lw6_global.cfg_context, "width", width);
-      lw6cfg_set_option_int (lw6_global.cfg_context, "height", height);
-      lw6cfg_set_option_bool (lw6_global.cfg_context, "fullscreen",
+      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_WIDTH, width);
+      lw6cfg_set_option_int (lw6_global.cfg_context, LW6DEF_HEIGHT, height);
+      lw6cfg_set_option_bool (lw6_global.cfg_context, LW6DEF_FULLSCREEN,
 			      fullscreen);
     }
 }
