@@ -56,6 +56,7 @@ lw6_init_global (int argc, char *argv[])
   lw6_global.start_time = time (NULL);
   lw6_global.argc = argc;
   lw6_global.argv = argv;
+  lw6_global.progress = 0.0f;
 
   LW6_MUTEX_LOCK;
 
@@ -71,6 +72,12 @@ lw6_init_global (int argc, char *argv[])
     ((lw6_global.game_state_smobs =
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_game_state_smob)) != NULL)
     &&
+    ((lw6_global.pilot_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_pilot_smob)) != NULL)
+    &&
+    ((lw6_global.bot_smobs =
+      lw6sys_assoc_new ((void (*)(void *)) lw6_free_bot_smob)) != NULL)
+    &&
     ((lw6_global.look_smobs =
       lw6sys_assoc_new ((void (*)(void *)) lw6_free_look_smob)) != NULL)
     &&
@@ -158,6 +165,8 @@ lw6_quit_global ()
 
   lw6sys_assoc_free (lw6_global.loader_smobs);
   lw6sys_assoc_free (lw6_global.look_smobs);
+  lw6sys_assoc_free (lw6_global.bot_smobs);
+  lw6sys_assoc_free (lw6_global.pilot_smobs);
   lw6sys_assoc_free (lw6_global.game_state_smobs);
   lw6sys_assoc_free (lw6_global.game_struct_smobs);
   lw6sys_assoc_free (lw6_global.menu_smobs);
