@@ -78,8 +78,16 @@ guile_main (void *data)
   script = lw6sys_get_script_file (lw6_global.argc, lw6_global.argv);
   if (script)
     {
-      lw6sys_log (LW6SYS_LOG_INFO, _("loading \"%s\""), script);
-      scm_c_primitive_load (script);
+      if (lw6sys_file_exists (script))
+	{
+	  lw6sys_log (LW6SYS_LOG_INFO, _("loading \"%s\""), script);
+	  scm_c_primitive_load (script);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_ERROR,
+		      _("unable to read main script file \"%s\""), script);
+	}
       LW6SYS_FREE (script);
     }
 
@@ -125,14 +133,14 @@ lw6_main (int argc, char *argv[])
   ret = lw6_process_non_run_options (argc, argv, &run_game);
   if (run_game)
     {
-      debug_str = lw6sys_arg_get_value_with_env (argc, argv, "debug");
+      debug_str = lw6sys_arg_get_value_with_env (argc, argv, LW6DEF_DEBUG);
       if (debug_str)
 	{
 	  debug = lw6sys_atob (debug_str);
 	  lw6sys_debug_set (debug);
 	  LW6SYS_FREE (debug_str);
 	}
-      log_level_str = lw6cfg_unified_get_value (argc, argv, "log-level");
+      log_level_str = lw6cfg_unified_get_value (argc, argv, LW6DEF_LOG_LEVEL);
       if (log_level_str)
 	{
 	  log_level = lw6sys_atoi (log_level_str);
@@ -149,7 +157,13 @@ lw6_main (int argc, char *argv[])
 	{
 	  lw6sys_log_critical (_("can't determine log file"));
 	}
-
+      lw6sys_log (LW6SYS_LOG_NOTICE, "v%s \"%s\" #%s (%s) %s/%s",
+		  lw6sys_build_get_version (),
+		  lw6sys_build_get_codename (),
+		  lw6sys_build_get_stamp (),
+		  lw6sys_build_get_date (),
+		  lw6sys_build_get_target_os (),
+		  lw6sys_build_get_target_cpu ());
       lw6_print_hello (argc, argv);
       if (lw6_init_global (argc, argv))
 	{
