@@ -25,6 +25,7 @@
 #endif
 
 #include <time.h>
+#include <math.h>
 
 #include "liquidwar6.h"
 
@@ -100,6 +101,13 @@ lw6_print_long_copyright ()
   fflush (stdout);
 }
 
+void
+lw6_print_bench (float bench_result)
+{
+  printf ("%d\n", (int) ceil (bench_result));
+  fflush (stdout);
+}
+
 void
 lw6_print_pedigree ()
 {
@@ -136,7 +144,6 @@ lw6_print_audit (int argc, char *argv[])
    * compared with other path values.
    */
   printf ("top-srcdir: %s\n", lw6sys_build_get_top_srcdir ());
-  printf ("prefix: %s\n", lw6sys_build_get_prefix ());
   printf ("datadir: %s\n", lw6sys_build_get_datadir ());
   printf ("libdir: %s\n", lw6sys_build_get_libdir ());
   printf ("includedir: %s\n", lw6sys_build_get_includedir ());
@@ -311,9 +318,11 @@ lw6_print_modules ()
   printf ("enable-mod-csound: %s\n", lw6sys_build_get_enable_mod_csound ());
   printf ("enable-mod-ogg: %s\n", lw6sys_build_get_enable_mod_ogg ());
   printf ("enable-mod-http: %s\n", lw6sys_build_get_enable_mod_http ());
+  printf ("enable-optimize: %s\n", lw6sys_build_get_enable_optimize ());
   printf ("enable-allinone: %s\n", lw6sys_build_get_enable_allinone ());
   printf ("enable-fullstatic: %s\n", lw6sys_build_get_enable_fullstatic ());
   printf ("enable-gprof: %s\n", lw6sys_build_get_enable_gprof ());
+  printf ("enable-gcov: %s\n", lw6sys_build_get_enable_gcov ());
   printf ("enable-valgrind: %s\n", lw6sys_build_get_enable_valgrind ());
 
   fflush (stdout);
@@ -450,11 +459,24 @@ lw6_print_list_map ()
 }
 
 void
-lw6_print_list_map_options ()
+lw6_print_list_map_rules ()
 {
   lw6sys_list_t *list;
 
-  list = lw6hlp_list_map_options ();
+  list = lw6hlp_list_map_rules ();
+  if (list)
+    {
+      lw6hlp_print_keyword (&list, stdout);
+      lw6sys_list_free (list);
+    }
+}
+
+void
+lw6_print_list_map_hints ()
+{
+  lw6sys_list_t *list;
+
+  list = lw6hlp_list_map_hints ();
   if (list)
     {
       lw6hlp_print_keyword (&list, stdout);
@@ -543,17 +565,50 @@ lw6_print_list ()
 void
 lw6_print_about (char *keyword)
 {
-  char *doc;
+  char *doc_str = NULL;
+  lw6hlp_type_t type = LW6HLP_TYPE_VOID;
+  char *type_str = NULL;
+  char *type_str2 = NULL;
 
-  doc =
-    lw6sys_str_reformat (lw6hlp_about (NULL, keyword),
+  doc_str =
+    lw6sys_str_reformat (lw6hlp_about (&type, keyword),
 			 LW6SYS_REFORMAT_DEFAULT_PREFIX,
 			 LW6SYS_REFORMAT_DEFAULT_NB_COLUMNS);
-  if (doc)
+  if (doc_str)
     {
-      printf ("%s", doc);
+      switch (type)
+	{
+	case LW6HLP_TYPE_STR:
+	  type_str = _("string");
+	  break;
+	case LW6HLP_TYPE_INT:
+	  type_str = _("integer");
+	  break;
+	case LW6HLP_TYPE_FLOAT:
+	  type_str = _("float");
+	  break;
+	case LW6HLP_TYPE_BOOL:
+	  type_str = _("boolean");
+	  break;
+	case LW6HLP_TYPE_COLOR:
+	  type_str = _("color");
+	  break;
+	default:
+	  // stay NULL
+	  break;
+	}
+      if (type_str && type != LW6HLP_TYPE_VOID)
+	{
+	  type_str2 = lw6sys_new_sprintf (_("Type: %s."), type_str);
+	  if (type_str2)
+	    {
+	      printf ("%s\n\n", type_str2);
+	      LW6SYS_FREE (type_str2);
+	    }
+	}
+      printf ("%s", doc_str);
       fflush (stdout);
-      LW6SYS_FREE (doc);
+      LW6SYS_FREE (doc_str);
     }
 }
 
