@@ -26,6 +26,25 @@
 
 #include "liquidwar6.h"
 
+#define SMOB_TYPE_MAP "lw6map-level"
+#define SMOB_TYPE_MENU "lw6gui-menu"
+#define SMOB_TYPE_GAME_STRUCT "lw6ker-game-struct"
+#define SMOB_TYPE_GAME_STATE "lw6ker-game-state"
+#define SMOB_TYPE_PILOT "lw6pil-pilot"
+#define SMOB_TYPE_BOT "lw6bot-backend"
+#define SMOB_TYPE_LOOK "lw6gui-look"
+#define SMOB_TYPE_LOADER "lw6tsk-loader"
+
+static char *
+smob_id (char *type, int id)
+{
+  char *ret = NULL;
+
+  ret = lw6sys_new_sprintf ("%s %d", type, id);
+
+  return ret;
+}
+
 /*
  * Map smob
  */
@@ -38,27 +57,17 @@ mark_map (SCM map)
 static size_t
 free_map (SCM map)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_map_smob_t *map_smob = (lw6_map_smob_t *) SCM_SMOB_DATA (map);
 
-  repr = lw6map_repr (map_smob->c_map);
-  if (repr)
+  id = smob_id (SMOB_TYPE_MAP, map_smob->c_map->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.map_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.map_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated map is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing map smob which isn't in global assoc"));
-      lw6_free_map_smob (map_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -72,7 +81,7 @@ print_map (SCM map, SCM port, scm_print_state * pstate)
 
   repr = lw6map_repr (c_map);
 
-  scm_puts ("#<lw6map-map ", port);
+  scm_puts ("#<" SMOB_TYPE_MAP " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -87,6 +96,7 @@ SCM
 lw6_make_scm_map (lw6map_level_t * c_map)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_map_smob_t *map_smob = NULL;
 
   /*
@@ -104,14 +114,20 @@ lw6_make_scm_map (lw6map_level_t * c_map)
   if (map_smob)
     {
       map_smob->c_map = c_map;
-      repr = lw6map_repr (c_map);
-      if (repr)
+      id = smob_id (SMOB_TYPE_MAP, c_map->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating map smob \"%s\""), repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.map_smobs, repr, (void *) map_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6map_repr (c_map);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating map smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.map_smobs, id, (void *) map_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -161,27 +177,17 @@ mark_menu (SCM menu)
 static size_t
 free_menu (SCM menu)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_menu_smob_t *menu_smob = (lw6_menu_smob_t *) SCM_SMOB_DATA (menu);
 
-  repr = lw6gui_menu_repr (menu_smob->c_menu);
-  if (repr)
+  id = smob_id (SMOB_TYPE_MENU, menu_smob->c_menu->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.menu_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.menu_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated menu is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing menu smob which isn't in global assoc"));
-      lw6_free_menu_smob (menu_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -195,7 +201,7 @@ print_menu (SCM menu, SCM port, scm_print_state * pstate)
 
   repr = lw6gui_menu_repr (c_menu);
 
-  scm_puts ("#<lw6gui-menu ", port);
+  scm_puts ("#<" SMOB_TYPE_MENU " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -210,6 +216,7 @@ SCM
 lw6_make_scm_menu (lw6gui_menu_t * c_menu)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_menu_smob_t *menu_smob = NULL;
 
   scm_gc ();
@@ -218,14 +225,21 @@ lw6_make_scm_menu (lw6gui_menu_t * c_menu)
   if (menu_smob)
     {
       menu_smob->c_menu = c_menu;
-      repr = lw6gui_menu_repr (c_menu);
-      if (repr)
+      id = smob_id (SMOB_TYPE_MENU, c_menu->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating menu smob \"%s\""), repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.menu_smobs, repr, (void *) menu_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6gui_menu_repr (c_menu);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating menu smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.menu_smobs, id,
+				(void *) menu_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -280,28 +294,18 @@ mark_game_struct (SCM game_struct)
 static size_t
 free_game_struct (SCM game_struct)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_game_struct_smob_t *game_struct_smob =
     (lw6_game_struct_smob_t *) SCM_SMOB_DATA (game_struct);
 
-  repr = lw6ker_game_struct_repr (game_struct_smob->c_game_struct);
-  if (repr)
+  id = smob_id (SMOB_TYPE_GAME_STRUCT, game_struct_smob->c_game_struct->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.game_struct_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.game_struct_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated game_struct is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing game_struct smob which isn't in global assoc"));
-      lw6_free_game_struct_smob (game_struct_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -315,7 +319,7 @@ print_game_struct (SCM game_struct, SCM port, scm_print_state * pstate)
 
   repr = lw6ker_game_struct_repr (c_game_struct);
 
-  scm_puts ("#<lw6ker-game-struct ", port);
+  scm_puts ("#<" SMOB_TYPE_GAME_STRUCT " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -330,6 +334,7 @@ SCM
 lw6_make_scm_game_struct (lw6ker_game_struct_t * c_game_struct, SCM map)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_game_struct_smob_t *game_struct_smob = NULL;
 
   scm_gc ();
@@ -341,16 +346,21 @@ lw6_make_scm_game_struct (lw6ker_game_struct_t * c_game_struct, SCM map)
     {
       game_struct_smob->c_game_struct = c_game_struct;
       game_struct_smob->map = map;
-      repr = lw6ker_game_struct_repr (c_game_struct);
-      if (repr)
+      id = smob_id (SMOB_TYPE_GAME_STRUCT, c_game_struct->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating game struct smob \"%s\""),
-		      repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.game_struct_smobs, repr,
-			    (void *) game_struct_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6ker_game_struct_repr (c_game_struct);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _("creating game struct smob \"%s\""), repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.game_struct_smobs, id,
+				(void *) game_struct_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -407,28 +417,18 @@ mark_game_state (SCM game_state)
 static size_t
 free_game_state (SCM game_state)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_game_state_smob_t *game_state_smob =
     (lw6_game_state_smob_t *) SCM_SMOB_DATA (game_state);
 
-  repr = lw6ker_game_state_repr (game_state_smob->c_game_state);
-  if (repr)
+  id = smob_id (SMOB_TYPE_GAME_STATE, game_state_smob->c_game_state->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.game_state_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.game_state_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated game_state is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing game_state smob which isn't in global assoc"));
-      lw6_free_game_state_smob (game_state_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -442,7 +442,7 @@ print_game_state (SCM game_state, SCM port, scm_print_state * pstate)
 
   repr = lw6ker_game_state_repr (c_game_state);
 
-  scm_puts ("#<lw6ker-game-state ", port);
+  scm_puts ("#<" SMOB_TYPE_GAME_STATE " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -457,6 +457,7 @@ SCM
 lw6_make_scm_game_state (lw6ker_game_state_t * c_game_state, SCM game_struct)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_game_state_smob_t *game_state_smob = NULL;
 
   scm_gc ();
@@ -467,16 +468,21 @@ lw6_make_scm_game_state (lw6ker_game_state_t * c_game_state, SCM game_struct)
     {
       game_state_smob->c_game_state = c_game_state;
       game_state_smob->game_struct = game_struct;
-      repr = lw6ker_game_state_repr (c_game_state);
-      if (repr)
+      id = smob_id (SMOB_TYPE_GAME_STATE, c_game_state->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating game state smob \"%s\""),
-		      repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.game_state_smobs, repr,
-			    (void *) game_state_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6ker_game_state_repr (c_game_state);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _("creating game state smob \"%s\""), repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.game_state_smobs, id,
+				(void *) game_state_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -515,6 +521,236 @@ lw6_free_game_state_smob (lw6_game_state_smob_t * game_state_smob)
   LW6SYS_FREE (game_state_smob);
 }
 
+/*
+ * Game pilot smob
+ */
+static SCM
+mark_pilot (SCM pilot)
+{
+  return SCM_BOOL_F;
+}
+
+static size_t
+free_pilot (SCM pilot)
+{
+  char *id = NULL;
+  lw6_pilot_smob_t *pilot_smob = (lw6_pilot_smob_t *) SCM_SMOB_DATA (pilot);
+
+  id = smob_id (SMOB_TYPE_PILOT, pilot_smob->c_pilot->id);
+  if (id)
+    {
+      LW6_MUTEX_LOCK;
+      lw6sys_assoc_unset (lw6_global.pilot_smobs, id);
+      LW6_MUTEX_UNLOCK;
+
+      LW6SYS_FREE (id);
+    }
+
+  return 0;
+}
+
+static int
+print_pilot (SCM pilot, SCM port, scm_print_state * pstate)
+{
+  lw6pil_pilot_t *c_pilot = lw6_scm_to_pilot (pilot);
+  char *repr = NULL;
+
+  repr = lw6pil_pilot_repr (c_pilot);
+
+  scm_puts ("#<" SMOB_TYPE_PILOT " ", port);
+  if (repr)
+    {
+      scm_display (scm_makfrom0str (repr), port);
+      LW6SYS_FREE (repr);
+    }
+  scm_puts (">", port);
+
+  return 1;
+}
+
+SCM
+lw6_make_scm_pilot (lw6pil_pilot_t * c_pilot)
+{
+  char *repr = NULL;
+  char *id = NULL;
+  lw6_pilot_smob_t *pilot_smob = NULL;
+
+  scm_gc ();
+
+  pilot_smob = (lw6_pilot_smob_t *) LW6SYS_CALLOC (sizeof (lw6_pilot_smob_t));
+  if (pilot_smob)
+    {
+      pilot_smob->c_pilot = c_pilot;
+      id = smob_id (SMOB_TYPE_PILOT, c_pilot->id);
+      if (id)
+	{
+	  repr = lw6pil_pilot_repr (c_pilot);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating pilot smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.pilot_smobs, id,
+				(void *) pilot_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create pilot smob, expect trouble"));
+    }
+
+  SCM_RETURN_NEWSMOB (lw6_global.smob_types.pilot, pilot_smob);
+}
+
+lw6pil_pilot_t *
+lw6_scm_to_pilot (SCM pilot)
+{
+  lw6pil_pilot_t *c_pilot;
+
+  c_pilot = ((lw6_pilot_smob_t *) SCM_SMOB_DATA (pilot))->c_pilot;
+
+  return c_pilot;
+}
+
+void
+lw6_free_pilot_smob (lw6_pilot_smob_t * pilot_smob)
+{
+  char *repr = NULL;
+
+  repr = lw6pil_pilot_repr (pilot_smob->c_pilot);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("freeing pilot smob \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+
+  lw6pil_pilot_free (pilot_smob->c_pilot);
+  LW6SYS_FREE (pilot_smob);
+}
+
+/*
+ * Game bot smob
+ */
+static SCM
+mark_bot (SCM bot)
+{
+  lw6_bot_smob_t *bot_smob = (lw6_bot_smob_t *) SCM_SMOB_DATA (bot);
+
+  scm_gc_mark (bot_smob->game_state);
+
+  return SCM_BOOL_F;
+}
+
+static size_t
+free_bot (SCM bot)
+{
+  char *id = NULL;
+  lw6_bot_smob_t *bot_smob = (lw6_bot_smob_t *) SCM_SMOB_DATA (bot);
+
+  id = smob_id (SMOB_TYPE_BOT, bot_smob->c_bot->id);
+  if (id)
+    {
+      LW6_MUTEX_LOCK;
+      lw6sys_assoc_unset (lw6_global.bot_smobs, id);
+      LW6_MUTEX_UNLOCK;
+
+      LW6SYS_FREE (id);
+    }
+
+  return 0;
+}
+
+static int
+print_bot (SCM bot, SCM port, scm_print_state * pstate)
+{
+  lw6bot_backend_t *c_bot = lw6_scm_to_bot (bot);
+  char *repr = NULL;
+
+  repr = lw6bot_repr (c_bot);
+
+  scm_puts ("#<" SMOB_TYPE_BOT " ", port);
+  if (repr)
+    {
+      scm_display (scm_makfrom0str (repr), port);
+      LW6SYS_FREE (repr);
+    }
+  scm_puts (">", port);
+
+  return 1;
+}
+
+// c_bot is supposed to have been initialized with lw6bot_init()
+SCM
+lw6_make_scm_bot (lw6bot_backend_t * c_bot, SCM game_state)
+{
+  char *repr = NULL;
+  char *id = NULL;
+  lw6_bot_smob_t *bot_smob = NULL;
+
+  scm_gc ();
+
+  bot_smob = (lw6_bot_smob_t *) LW6SYS_CALLOC (sizeof (lw6_bot_smob_t));
+  if (bot_smob)
+    {
+      bot_smob->c_bot = c_bot;
+      bot_smob->game_state = game_state;
+      id = smob_id (SMOB_TYPE_BOT, c_bot->id);
+      if (id)
+	{
+	  repr = lw6bot_repr (c_bot);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating bot smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.bot_smobs, id, (void *) bot_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
+	}
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to create bot smob, expect trouble"));
+    }
+
+  SCM_RETURN_NEWSMOB (lw6_global.smob_types.bot, bot_smob);
+}
+
+lw6bot_backend_t *
+lw6_scm_to_bot (SCM bot)
+{
+  lw6bot_backend_t *c_bot;
+
+  c_bot = ((lw6_bot_smob_t *) SCM_SMOB_DATA (bot))->c_bot;
+
+  return c_bot;
+}
+
+void
+lw6_free_bot_smob (lw6_bot_smob_t * bot_smob)
+{
+  char *repr = NULL;
+
+  repr = lw6bot_repr (bot_smob->c_bot);
+  if (repr)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO, _("freeing bot smob \"%s\""), repr);
+      LW6SYS_FREE (repr);
+    }
+
+  lw6bot_quit (bot_smob->c_bot);
+  lw6bot_destroy_backend (bot_smob->c_bot);
+  LW6SYS_FREE (bot_smob);
+}
+
 /*
  * Game look smob
  */
@@ -527,27 +763,17 @@ mark_look (SCM look)
 static size_t
 free_look (SCM look)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_look_smob_t *look_smob = (lw6_look_smob_t *) SCM_SMOB_DATA (look);
 
-  repr = lw6gui_look_repr (look_smob->c_look);
-  if (repr)
+  id = smob_id (SMOB_TYPE_LOOK, look_smob->c_look->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.look_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.look_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated look is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing look smob which isn't in global assoc"));
-      lw6_free_look_smob (look_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -561,7 +787,7 @@ print_look (SCM look, SCM port, scm_print_state * pstate)
 
   repr = lw6gui_look_repr (c_look);
 
-  scm_puts ("#<lw6gui-look ", port);
+  scm_puts ("#<" SMOB_TYPE_LOOK " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -576,6 +802,7 @@ SCM
 lw6_make_scm_look (lw6gui_look_t * c_look)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_look_smob_t *look_smob = NULL;
 
   scm_gc ();
@@ -584,14 +811,21 @@ lw6_make_scm_look (lw6gui_look_t * c_look)
   if (look_smob)
     {
       look_smob->c_look = c_look;
-      repr = lw6gui_look_repr (c_look);
-      if (repr)
+      id = smob_id (SMOB_TYPE_LOOK, c_look->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating look smob \"%s\""), repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.look_smobs, repr, (void *) look_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6gui_look_repr (c_look);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating look smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.look_smobs, id,
+				(void *) look_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -641,28 +875,18 @@ mark_loader (SCM loader)
 static size_t
 free_loader (SCM loader)
 {
-  char *repr = NULL;
+  char *id = NULL;
   lw6_loader_smob_t *loader_smob =
     (lw6_loader_smob_t *) SCM_SMOB_DATA (loader);
 
-  repr = lw6tsk_loader_repr (loader_smob->c_loader);
-  if (repr)
+  id = smob_id (SMOB_TYPE_LOADER, loader_smob->c_loader->id);
+  if (id)
     {
       LW6_MUTEX_LOCK;
-      lw6sys_assoc_unset (lw6_global.loader_smobs, repr);
+      lw6sys_assoc_unset (lw6_global.loader_smobs, id);
       LW6_MUTEX_UNLOCK;
-      LW6SYS_FREE (repr);
-    }
-  else
-    {
-      /*
-       * Normally we should never get there, for any smob
-       * allocated loader is in the global assoc. But well,
-       * who knows...
-       */
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("freeing loader smob which isn't in global assoc"));
-      lw6_free_loader_smob (loader_smob);
+
+      LW6SYS_FREE (id);
     }
 
   return 0;
@@ -676,7 +900,7 @@ print_loader (SCM loader, SCM port, scm_print_state * pstate)
 
   repr = lw6tsk_loader_repr (c_loader);
 
-  scm_puts ("#<lw6tsk-loader ", port);
+  scm_puts ("#<" SMOB_TYPE_LOADER " ", port);
   if (repr)
     {
       scm_display (scm_makfrom0str (repr), port);
@@ -691,6 +915,7 @@ SCM
 lw6_make_scm_loader (lw6tsk_loader_t * c_loader)
 {
   char *repr = NULL;
+  char *id = NULL;
   lw6_loader_smob_t *loader_smob = NULL;
 
   scm_gc ();
@@ -700,16 +925,21 @@ lw6_make_scm_loader (lw6tsk_loader_t * c_loader)
   if (loader_smob)
     {
       loader_smob->c_loader = c_loader;
-      repr = lw6tsk_loader_repr (c_loader);
-      if (repr)
+      id = smob_id (SMOB_TYPE_LOADER, c_loader->id);
+      if (id)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, _("creating loader smob \"%s\""),
-		      repr);
-	  LW6_MUTEX_LOCK;
-	  lw6sys_assoc_set (&lw6_global.loader_smobs, repr,
-			    (void *) loader_smob);
-	  LW6_MUTEX_UNLOCK;
-	  LW6SYS_FREE (repr);
+	  repr = lw6tsk_loader_repr (c_loader);
+	  if (repr)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO, _("creating loader smob \"%s\""),
+			  repr);
+	      LW6_MUTEX_LOCK;
+	      lw6sys_assoc_set (&lw6_global.loader_smobs, id,
+				(void *) loader_smob);
+	      LW6_MUTEX_UNLOCK;
+	      LW6SYS_FREE (repr);
+	    }
+	  LW6SYS_FREE (id);
 	}
     }
   else
@@ -756,37 +986,50 @@ lw6_register_smobs ()
   int ret = 1;
 
   lw6_global.smob_types.map =
-    scm_make_smob_type ("lw6map-map", sizeof (lw6map_level_t));
+    scm_make_smob_type (SMOB_TYPE_MAP, sizeof (lw6_map_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.map, mark_map);
   scm_set_smob_free (lw6_global.smob_types.map, free_map);
   scm_set_smob_print (lw6_global.smob_types.map, print_map);
 
   lw6_global.smob_types.menu =
-    scm_make_smob_type ("lw6gui-menu", sizeof (lw6gui_menu_t));
+    scm_make_smob_type (SMOB_TYPE_MENU, sizeof (lw6_menu_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.menu, mark_menu);
   scm_set_smob_free (lw6_global.smob_types.menu, free_menu);
   scm_set_smob_print (lw6_global.smob_types.menu, print_menu);
 
   lw6_global.smob_types.game_struct =
-    scm_make_smob_type ("lw6ker-game-struct", sizeof (lw6ker_game_struct_t));
+    scm_make_smob_type (SMOB_TYPE_GAME_STRUCT,
+			sizeof (lw6_game_struct_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.game_struct, mark_game_struct);
   scm_set_smob_free (lw6_global.smob_types.game_struct, free_game_struct);
   scm_set_smob_print (lw6_global.smob_types.game_struct, print_game_struct);
 
   lw6_global.smob_types.game_state =
-    scm_make_smob_type ("lw6ker-game-state", sizeof (lw6ker_game_state_t));
+    scm_make_smob_type (SMOB_TYPE_GAME_STATE, sizeof (lw6_game_state_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.game_state, mark_game_state);
   scm_set_smob_free (lw6_global.smob_types.game_state, free_game_state);
   scm_set_smob_print (lw6_global.smob_types.game_state, print_game_state);
 
+  lw6_global.smob_types.pilot =
+    scm_make_smob_type (SMOB_TYPE_PILOT, sizeof (lw6_pilot_smob_t));
+  scm_set_smob_mark (lw6_global.smob_types.pilot, mark_pilot);
+  scm_set_smob_free (lw6_global.smob_types.pilot, free_pilot);
+  scm_set_smob_print (lw6_global.smob_types.pilot, print_pilot);
+
+  lw6_global.smob_types.bot =
+    scm_make_smob_type (SMOB_TYPE_BOT, sizeof (lw6_bot_smob_t));
+  scm_set_smob_mark (lw6_global.smob_types.bot, mark_bot);
+  scm_set_smob_free (lw6_global.smob_types.bot, free_bot);
+  scm_set_smob_print (lw6_global.smob_types.bot, print_bot);
+
   lw6_global.smob_types.look =
-    scm_make_smob_type ("lw6gui-look", sizeof (lw6gui_look_t));
+    scm_make_smob_type (SMOB_TYPE_LOOK, sizeof (lw6_look_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.look, mark_look);
   scm_set_smob_free (lw6_global.smob_types.look, free_look);
   scm_set_smob_print (lw6_global.smob_types.look, print_look);
 
   lw6_global.smob_types.loader =
-    scm_make_smob_type ("lw6tsk-loader", sizeof (lw6tsk_loader_t));
+    scm_make_smob_type (SMOB_TYPE_LOADER, sizeof (lw6_loader_smob_t));
   scm_set_smob_mark (lw6_global.smob_types.loader, mark_loader);
   scm_set_smob_free (lw6_global.smob_types.loader, free_loader);
   scm_set_smob_print (lw6_global.smob_types.loader, print_loader);
