@@ -28,33 +28,6 @@
 
 #include "map.h"
 
-#define DEFAULT_WIDTH 100
-#define DEFAULT_HEIGHT 75
-
-void
-lw6map_depth_block_up_down (lw6map_depth_t * depth)
-{
-  int x;
-
-  for (x = 0; x < depth->shape.w; ++x)
-    {
-      lw6map_depth_set (depth, x, 0, 0);
-      lw6map_depth_set (depth, x, depth->shape.h - 1, 0);
-    }
-}
-
-void
-lw6map_depth_block_left_right (lw6map_depth_t * depth)
-{
-  int y;
-
-  for (y = 0; y < depth->shape.h; ++y)
-    {
-      lw6map_depth_set (depth, 0, y, 0);
-      lw6map_depth_set (depth, depth->shape.w - 1, y, 0);
-    }
-}
-
 static int
 find_first_free_point (lw6map_depth_t * depth, int *found_x, int *found_y)
 {
@@ -101,17 +74,18 @@ update_if_needed (lw6map_depth_t * dst, lw6map_depth_t * src, int x, int y)
  * be connected with the main area, and fills them with walls.
  */
 int
-lw6map_depth_check_and_fix_holes (lw6map_depth_t * depth)
+lw6map_depth_check_and_fix_holes (lw6map_depth_t * depth,
+				  lw6map_rules_t * rules)
 {
   int ret = 0;
   lw6map_depth_t fixed_depth;
-  int x, y;
+  int x, y, tx, ty;
 
   fixed_depth.shape.w = depth->shape.w;
   fixed_depth.shape.h = depth->shape.h;
   fixed_depth.data =
     (unsigned char *) LW6SYS_CALLOC (depth->shape.w * depth->shape.h *
-				     sizeof (unsigned char *));
+				     sizeof (unsigned char));
   fixed_depth.max = depth->max;
 
   if (fixed_depth.data)
@@ -129,38 +103,54 @@ lw6map_depth_check_and_fix_holes (lw6map_depth_t * depth)
 	{
 	  found = 0;
 
-	  for (y = 1; y < depth->shape.h - 1; ++y)
+	  for (y = 0; y < depth->shape.h; ++y)
 	    {
-	      for (x = 1; x < depth->shape.w - 1; ++x)
+	      for (x = 0; x < depth->shape.w; ++x)
 		{
 		  if (lw6map_depth_get (&fixed_depth, x, y) > 0)
 		    {
-		      found +=
-			update_if_needed (&fixed_depth, depth, x + 1, y);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x + 1, y + 1);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x, y + 1);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x - 1, y + 1);
+		      tx = x + 1;
+		      ty = y;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x + 1;
+		      ty = y + 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x;
+		      ty = y + 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x - 1;
+		      ty = y + 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
 		    }
 		}
 	    }
 
-	  for (y = depth->shape.h - 2; y >= 1; --y)
+	  for (y = depth->shape.h - 1; y >= 0; --y)
 	    {
-	      for (x = depth->shape.w - 2; x >= 1; --x)
+	      for (x = depth->shape.w - 1; x >= 0; --x)
 		{
 		  if (lw6map_depth_get (&fixed_depth, x, y) > 0)
 		    {
-		      found +=
-			update_if_needed (&fixed_depth, depth, x - 1, y);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x - 1, y - 1);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x, y - 1);
-		      found +=
-			update_if_needed (&fixed_depth, depth, x + 1, y - 1);
+		      tx = x - 1;
+		      ty = y;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x - 1;
+		      ty = y - 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x;
+		      ty = y - 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
+		      tx = x + 1;
+		      ty = y - 1;
+		      lw6map_coords_fix (rules, &depth->shape, &tx, &ty);
+		      found += update_if_needed (&fixed_depth, depth, tx, ty);
 		    }
 		}
 	    }
@@ -182,7 +172,7 @@ rectangle (lw6map_depth_t * depth, int width, int height)
   depth->shape.h = height;
   depth->data =
     (unsigned char *) LW6SYS_CALLOC (depth->shape.w * depth->shape.h *
-				     sizeof (unsigned char *));
+				     sizeof (unsigned char));
 
   if (depth->data)
     {
@@ -208,11 +198,11 @@ rectangle (lw6map_depth_t * depth, int width, int height)
 }
 
 void
-lw6map_depth_defaults (lw6map_depth_t * depth)
+lw6map_depth_defaults (lw6map_depth_t * depth, int w, int h)
 {
   lw6map_depth_clear (depth);
 
-  if (!rectangle (depth, DEFAULT_WIDTH, DEFAULT_HEIGHT))
+  if (!rectangle (depth, w, h))
     {
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to construct default map depth"));
