@@ -84,19 +84,19 @@ push_texture (lw6sys_hexa_serializer_t * hexa_serializer,
 	}
     }
   ret = ret && lw6sys_hexa_serializer_push_color (hexa_serializer,
-						  texture->guessed_color_base.
-						  bg);
+						  texture->
+						  guessed_color_base.bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
 					  texture->guessed_color_base.fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  texture->guessed_color_alternate.
-					  bg);
+					  texture->
+					  guessed_color_alternate.bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  texture->guessed_color_alternate.
-					  fg);
+					  texture->
+					  guessed_color_alternate.fg);
 
   return ret;
 }
@@ -109,9 +109,9 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
   int i, value;
   char *key;
 
-  for (i = 0; (key = LW6MAP_OPTIONS_LIST[i]) != NULL && ret; ++i)
+  for (i = 0; (key = LW6MAP_RULES_LIST[i]) != NULL && ret; ++i)
     {
-      value = lw6map_options_get_int (&(param->options), key);
+      value = lw6map_rules_get_int (&(param->rules), key);
       ret = ret && lw6sys_hexa_serializer_push_int32 (hexa_serializer, value);
     }
 
@@ -120,12 +120,6 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					  param->style.keep_ratio);
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer, param->style.zoom);
-  ret = ret
-    && lw6sys_hexa_serializer_push_float (hexa_serializer,
-					  param->style.fighter_scale);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.use_texture);
   ret = ret
     && lw6sys_hexa_serializer_push_str (hexa_serializer,
 					param->style.background_style);
@@ -140,44 +134,41 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					param->style.view_style);
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer,
-					  param->style.background_density);
+					  param->style.animation_density);
   ret = ret
     && lw6sys_hexa_serializer_push_float (hexa_serializer,
-					  param->style.background_speed);
+					  param->style.animation_speed);
   ret = ret
     && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.colorize_background);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.background_color_auto);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.hud_color_auto);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.menu_color_auto);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.view_color_auto);
-  ret = ret
-    && lw6sys_hexa_serializer_push_int32 (hexa_serializer,
-					  param->style.system_color_auto);
+					  param->style.colorize);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_base.
+					  param->style.color_base.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_base.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_alternate.bg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.color_alternate.fg);
+  ret = ret
+    && lw6sys_hexa_serializer_push_color (hexa_serializer,
+					  param->style.background_color_root.
 					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.background_color_base.
+					  param->style.background_color_root.
 					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  background_color_alternate.bg);
+					  param->style.background_color_stuff.
+					  bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.
-					  background_color_alternate.fg);
+					  param->style.background_color_stuff.
+					  fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
 					  param->style.hud_color_frame.bg);
@@ -198,20 +189,20 @@ push_param (lw6sys_hexa_serializer_t * hexa_serializer,
 					  param->style.menu_color_default.fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_selected.
-					  bg);
+					  param->style.
+					  menu_color_selected.bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_selected.
-					  fg);
+					  param->style.
+					  menu_color_selected.fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_disabled.
-					  bg);
+					  param->style.
+					  menu_color_disabled.bg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
-					  param->style.menu_color_disabled.
-					  fg);
+					  param->style.
+					  menu_color_disabled.fg);
   ret = ret
     && lw6sys_hexa_serializer_push_color (hexa_serializer,
 					  param->style.view_color_cursor.bg);
@@ -298,10 +289,12 @@ pop_depth (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_depth_t * depth)
 
   ret = ret
     && lw6sys_hexa_serializer_pop_wh (hexa_serializer, &(depth->shape));
-  if (depth->shape.w >= LW6MAP_OPTIONS_MIN_MIN_MAP_WIDTH
-      && depth->shape.w <= LW6MAP_OPTIONS_MAX_MAX_MAP_WIDTH
-      && depth->shape.h >= LW6MAP_OPTIONS_MIN_MIN_MAP_HEIGHT
-      && depth->shape.h <= LW6MAP_OPTIONS_MAX_MAX_MAP_HEIGHT)
+  if (depth->shape.w >= LW6MAP_MIN_SIDE
+      && depth->shape.w <= LW6MAP_MAX_SIDE
+      && depth->shape.h >= LW6MAP_MIN_SIDE
+      && depth->shape.h <= LW6MAP_MAX_SIDE
+      && depth->shape.w * depth->shape.h >= LW6MAP_MIN_SURFACE
+      && depth->shape.w * depth->shape.h <= LW6MAP_MAX_SURFACE)
     {
       depth->data =
 	(u_int8_t *) LW6SYS_CALLOC (depth->shape.w * depth->shape.h);
@@ -344,10 +337,12 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
 
   ret = ret
     && lw6sys_hexa_serializer_pop_wh (hexa_serializer, &(texture->shape));
-  if (texture->shape.w >= LW6MAP_OPTIONS_MIN_MIN_MAP_WIDTH
-      && texture->shape.w <= LW6MAP_OPTIONS_MAX_MAX_MAP_WIDTH
-      && texture->shape.h >= LW6MAP_OPTIONS_MIN_MIN_MAP_HEIGHT
-      && texture->shape.h <= LW6MAP_OPTIONS_MAX_MAX_MAP_HEIGHT)
+  if (texture->shape.w >= LW6MAP_MIN_SIDE
+      && texture->shape.w <= LW6MAP_MAX_SIDE
+      && texture->shape.h >= LW6MAP_MIN_SIDE
+      && texture->shape.h <= LW6MAP_MAX_SIDE
+      && texture->shape.w * texture->shape.h >= LW6MAP_MIN_SURFACE
+      && texture->shape.w * texture->shape.h <= LW6MAP_MAX_SURFACE)
     {
       texture->data =
 	(lw6sys_color_8_t *) LW6SYS_CALLOC (texture->shape.w *
@@ -385,12 +380,12 @@ pop_texture (lw6sys_hexa_serializer_t * hexa_serializer,
 					 &(texture->guessed_color_base.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(texture->guessed_color_alternate.
-					   bg));
+					 &(texture->
+					   guessed_color_alternate.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(texture->guessed_color_alternate.
-					   fg));
+					 &(texture->
+					   guessed_color_alternate.fg));
 
   return ret;
 }
@@ -403,12 +398,12 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   int i;
   char *key;
 
-  for (i = 0; (key = LW6MAP_OPTIONS_LIST[i]) != NULL && ret; ++i)
+  for (i = 0; (key = LW6MAP_RULES_LIST[i]) != NULL && ret; ++i)
     {
       ret = ret && lw6sys_hexa_serializer_pop_int32 (hexa_serializer, &value);
       if (ret)
 	{
-	  lw6map_options_set_int (&(param->options), key, value);
+	  lw6map_rules_set_int (&(param->rules), key, value);
 	}
     }
 
@@ -418,12 +413,6 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
 					 &(param->style.zoom));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_float (hexa_serializer,
-					 &(param->style.fighter_scale));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.use_texture));
   ret = ret
     && lw6sys_hexa_serializer_pop_str (hexa_serializer,
 				       &(param->style.background_style));
@@ -438,45 +427,41 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
 				       &(param->style.view_style));
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
-					 &(param->style.background_density));
+					 &(param->style.animation_density));
   ret = ret
     && lw6sys_hexa_serializer_pop_float (hexa_serializer,
-					 &(param->style.background_speed));
+					 &(param->style.animation_speed));
   ret = ret
     && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.colorize_background));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.
-					   background_color_auto));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.hud_color_auto));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.menu_color_auto));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.view_color_auto));
-  ret = ret
-    && lw6sys_hexa_serializer_pop_int32 (hexa_serializer,
-					 &(param->style.system_color_auto));
+					 &(param->style.colorize));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.background_color_base.
+					 &(param->style.color_base.bg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_base.fg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_alternate.bg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.color_alternate.fg));
+  ret = ret
+    && lw6sys_hexa_serializer_pop_color (hexa_serializer,
+					 &(param->style.background_color_root.
 					   bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.background_color_base.
+					 &(param->style.background_color_root.
 					   fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
 					 &(param->style.
-					   background_color_alternate.bg));
+					   background_color_stuff.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
 					 &(param->style.
-					   background_color_alternate.fg));
+					   background_color_stuff.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
 					 &(param->style.hud_color_frame.bg));
@@ -491,36 +476,36 @@ pop_param (lw6sys_hexa_serializer_t * hexa_serializer, lw6map_param_t * param)
 					 &(param->style.hud_color_text.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_default.
-					   bg));
+					 &(param->style.
+					   menu_color_default.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_default.
-					   fg));
+					 &(param->style.
+					   menu_color_default.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_selected.
-					   bg));
+					 &(param->style.
+					   menu_color_selected.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_selected.
-					   fg));
+					 &(param->style.
+					   menu_color_selected.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_disabled.
-					   bg));
+					 &(param->style.
+					   menu_color_disabled.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.menu_color_disabled.
-					   fg));
+					 &(param->style.
+					   menu_color_disabled.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.view_color_cursor.
-					   bg));
+					 &(param->style.
+					   view_color_cursor.bg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
-					 &(param->style.view_color_cursor.
-					   fg));
+					 &(param->style.
+					   view_color_cursor.fg));
   ret = ret
     && lw6sys_hexa_serializer_pop_color (hexa_serializer,
 					 &(param->style.view_color_map.bg));
