@@ -36,7 +36,7 @@
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static int seq_id = 0;
+static u_int32_t seq_id = 0;
 
 /**
  * lw6map_new
@@ -58,7 +58,11 @@ lw6map_new ()
 
   if (level)
     {
-      level->id = ++seq_id;
+      level->id = 0;
+      while (!level->id)
+	{
+	  level->id = ++seq_id;
+	}
     }
 
   return level;
@@ -67,6 +71,9 @@ lw6map_new ()
 /**
  * lw6map_defaults
  *
+ * @w: the width of the map
+ * @h: the height of the map
+ *
  * Creates a map, set to defaults. This is usefull mostly for testing,
  * it will just create a dull rectangle plain and uninteresting map,
  * however it's a quick way to have a working object and test stuff on it.
@@ -74,7 +81,7 @@ lw6map_new ()
  * Return value: a newly allocated map. 
  */
 lw6map_level_t *
-lw6map_defaults ()
+lw6map_defaults (int w, int h)
 {
   lw6map_level_t *level = NULL;
 
@@ -82,10 +89,14 @@ lw6map_defaults ()
 
   if (level)
     {
-      level->id = ++seq_id;
+      level->id = 0;
+      while (!level->id)
+	{
+	  level->id = ++seq_id;
+	}
 
       lw6map_texture_defaults (&level->texture);
-      lw6map_depth_defaults (&level->depth);
+      lw6map_depth_defaults (&level->depth, w, h);
       lw6map_param_defaults (&level->param);
       lw6map_metadata_defaults (&level->metadata);
     }
@@ -182,7 +193,7 @@ lw6map_repr (lw6map_level_t * level)
 	}
 
       ret =
-	lw6sys_new_sprintf ("%d \"%s\" (%dx%d)", level->id, title,
+	lw6sys_new_sprintf ("%u \"%s\" (%dx%d)", level->id, title,
 			    level->depth.shape.w, level->depth.shape.h);
     }
   else
