@@ -41,7 +41,7 @@
 void
 lw6map_param_defaults (lw6map_param_t * param)
 {
-  lw6map_options_defaults (&(param->options));
+  lw6map_rules_defaults (&(param->rules));
   lw6map_style_defaults (&(param->style));
 }
 
@@ -61,7 +61,7 @@ lw6map_param_clear (lw6map_param_t * param)
 {
   if (param)
     {
-      lw6map_options_clear (&(param->options));
+      lw6map_rules_clear (&(param->rules));
       lw6map_style_clear (&(param->style));
 
       /*
@@ -85,7 +85,7 @@ lw6map_param_clear (lw6map_param_t * param)
 void
 lw6map_param_copy (lw6map_param_t * dst, lw6map_param_t * src)
 {
-  lw6map_options_copy (&(dst->options), &(src->options));
+  lw6map_rules_copy (&(dst->rules), &(src->rules));
   lw6map_style_copy (&(dst->style), &(src->style));
 }
 
@@ -99,7 +99,7 @@ lw6map_param_copy (lw6map_param_t * dst, lw6map_param_t * src)
  * Sets an entry in a param struct. All values must be submitted
  * as strings, internally, the function will call atoi to convert
  * to integers if needed, for instance. It will also dispatch
- * automatically between options and style.
+ * automatically between rules and style.
  *
  * Return value: 1 if parameter successfully set, 0 on error.
  */
@@ -115,8 +115,7 @@ lw6map_param_set (lw6map_param_t * param, char *key, char *value)
     }
   else
     {
-      ret =
-	lw6map_options_set_int (&param->options, key, lw6sys_atoi (value));
+      ret = lw6map_rules_set_int (&param->rules, key, lw6sys_atoi (value));
     }
 
   return ret;
