@@ -28,19 +28,23 @@
 
 #include "map.h"
 
-void
+#define DEFAULT_TEXTURE_WIDTH 64
+#define DEFAULT_TEXTURE_HEIGHT 48
+
+int
 lw6map_texture_defaults (lw6map_texture_t * texture)
 {
   int x, y;
+  int ret = 0;
 
   lw6map_texture_clear (texture);
 
-  texture->shape.w = LW6MAP_OPTIONS_DEFAULT_MIN_MAP_WIDTH;
-  texture->shape.h = LW6MAP_OPTIONS_DEFAULT_MIN_MAP_HEIGHT;
+  texture->shape.w = DEFAULT_TEXTURE_WIDTH;
+  texture->shape.h = DEFAULT_TEXTURE_HEIGHT;
   texture->data =
     (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->shape.w *
 					texture->shape.h *
-					sizeof (lw6sys_color_8_t *));
+					sizeof (lw6sys_color_8_t));
 
   if (texture->data)
     {
@@ -51,6 +55,7 @@ lw6map_texture_defaults (lw6map_texture_t * texture)
 	      lw6map_texture_set (texture, x, y, LW6SYS_COLOR_8_WHITE);
 	    }
 	}
+      ret = 1;
     }
   else
     {
@@ -59,6 +64,49 @@ lw6map_texture_defaults (lw6map_texture_t * texture)
       texture->shape.w = 0;
       texture->shape.h = 0;
     }
+
+  return ret;
+}
+
+int
+lw6map_texture_from_depth (lw6map_texture_t * texture, lw6map_depth_t * depth,
+			   lw6map_color_couple_t * color)
+{
+  int ret = 0;
+  int x, y;
+
+  lw6map_texture_clear (texture);
+
+  texture->shape.w = depth->shape.w;
+  texture->shape.h = depth->shape.h;
+  texture->data =
+    (lw6sys_color_8_t *) LW6SYS_MALLOC (texture->shape.w *
+					texture->shape.h *
+					sizeof (lw6sys_color_8_t));
+
+  if (texture->data)
+    {
+      for (y = 0; y < texture->shape.h; ++y)
+	{
+	  for (x = 0; x < texture->shape.w; ++x)
+	    {
+	      lw6map_texture_set (texture, x, y,
+				  lw6map_depth_get (depth, x,
+						    y) >
+				  0 ? color->bg : color->fg);
+	    }
+	}
+      ret = 1;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("unable to construct texture from depth"));
+      texture->shape.w = 0;
+      texture->shape.h = 0;
+    }
+
+  return ret;
 }
 
 /*
