@@ -23,11 +23,21 @@
 #ifndef LIQUIDWAR6NET_INTERNAL_H
 #define LIQUIDWAR6NET_INTERNAL_H
 
-#include <pthread.h>
-#include <netinet/in.h>		// struct in_addr
-
 #include "net.h"
 
+#include <pthread.h>
+#ifdef LW6_MS_WINDOWS
+#include <winsock.h>
+typedef u_int32_t in_addr_t;
+typedef int socklen_t;
+#else
+#include <sys/types.h>
+#include <netinet/in.h>
+#include <arpa/inet.h>
+#include <sys/socket.h>
+#include <sys/signal.h>
+#endif
+
 #define _LW6NET_IP_SIZE 20	// only 15 required but...
 #define _LW6NET_FLAG_VACUUM  0x01
 
@@ -121,6 +131,11 @@ extern char *_lw6net_inet_ntoa (struct in_addr in);
 extern int _lw6net_const_init (int argc, char *argv[]);
 extern void _lw6net_const_quit ();
 
+// net-error.c
+#ifdef LW6_MS_WINDOWS
+extern char *_lw6net_wsa_str (int wsa_int);
+#endif
+
 /*
  * In socket.c
  */
