@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,17 +20,15 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <sys/socket.h>
-#include <sys/signal.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <fcntl.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
 
-#include "config.h"
 #include "net.h"
 #include "net-internal.h"
 
@@ -89,7 +86,11 @@ _lw6net_socket_bind (char *ip, int port, int protocol)
 	{
 	  name.sin_family = AF_INET;
 	  name.sin_addr.s_addr = INADDR_ANY;
+#ifdef LW6_MS_WINDOWS
+	  name.sin_addr.s_addr = inet_addr (ip);
+#else
 	  if (inet_aton (ip, &name.sin_addr) != 0)
+#endif
 	    {
 	      name.sin_port = htons (port);
 	      if (bind (sock, (struct sockaddr *) &name, sizeof name) >= 0)
@@ -102,28 +103,40 @@ _lw6net_socket_bind (char *ip, int port, int protocol)
 	      else
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING, _("bind() failed"));
+		  lw6net_last_error ();
 		}
 	    }
+#ifndef LW6_MS_WINDOWS
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, _("inetaton() failed"));
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _("inetaton() failed, ip=\"%s\""), ip);
+	      lw6net_last_error ();
 	    }
+#endif
 	}
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("setsockopt() failed"));
+	  lw6net_last_error ();
 	}
     }
   else
     {
       lw6sys_log (LW6SYS_LOG_WARNING, _("socket() failed"));
+      lw6net_last_error ();
     }
 
   if (sock >= 0 && !binded)
     {
+#ifdef LW6_MS_WINDOWS
+      if (closesocket (sock))
+#else
       if (close (sock))
+#endif
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6net_last_error ();
 	}
       sock = -1;
     }
@@ -138,9 +151,14 @@ lw6net_socket_close (int sock)
     {
       lw6sys_log (LW6SYS_LOG_INFO, _("close socket %d"), sock);
       _lw6net_global_context->socket_counters.close_counter++;
+#ifdef LW6_MS_WINDOWS
+      if (closesocket (sock))
+#else
       if (close (sock))
+#endif
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6net_last_error ();
 	}
     }
   else
