@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,17 +20,15 @@
   Contact author        : ufoot@ufoot.org
 */
 
-#include <sys/types.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <sys/socket.h>
-#include <sys/signal.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <fcntl.h>
 #include <unistd.h>
 #include <string.h>
 #include <errno.h>
 
-#include "config.h"
 #include "net.h"
 #include "net-internal.h"
 
@@ -49,6 +46,7 @@ lw6net_tcp_listen (char *ip, int port)
     {
       if (listen (sock, backlog) < 0)
 	{
+	  lw6net_last_error ();
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("listen() failed"));
 
 	  lw6net_socket_close (sock);
@@ -106,16 +104,19 @@ lw6net_tcp_accept (char **incoming_ip,
 			      (char *) &enable, sizeof (int)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING, _("setsockopt() failed"));
+		  lw6net_last_error ();
 		}
 	      if (setsockopt (new_sock, SOL_SOCKET, SO_OOBINLINE,
 			      (char *) &disable, sizeof (int)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING, _("setsockopt() failed"));
+		  lw6net_last_error ();
 		}
 	      if (setsockopt (new_sock, SOL_SOCKET, SO_LINGER,
 			      (char *) &li, sizeof (struct linger)))
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING, _("setsockopt() failed"));
+		  lw6net_last_error ();
 		}
 
 	      //fcntl (new_sock, F_SETFL, O_NONBLOCK, 0);
@@ -144,6 +145,7 @@ lw6net_tcp_accept (char **incoming_ip,
 	  else
 	    {
 	      lw6sys_log (LW6SYS_LOG_WARNING, _("accept() failed"));
+	      lw6net_last_error ();
 	    }
 
 	}
@@ -163,9 +165,14 @@ lw6net_tcp_accept (char **incoming_ip,
 	{
 	  (*incoming_port) = 0;
 	}
+#ifdef LW6_MS_WINDOWS
+      if (closesocket (new_sock))
+#else
       if (close (new_sock))
+#endif
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6net_last_error ();
 	}
       new_sock = -1;
     }
@@ -192,7 +199,11 @@ lw6net_tcp_connect (char *ip, int port)
       if (bind (sock, (struct sockaddr *) &name, sizeof (name)) >= 0)
 	{
 	  name.sin_family = AF_INET;
+#ifdef LW6_MS_WINDOWS
+	  if ((name.sin_addr.s_addr = inet_addr (ip)) != 0)
+#else
 	  if (inet_aton (ip, &name.sin_addr) != 0)
+#endif
 	    {
 	      name.sin_port = htons (port);
 	      if (connect (sock, (struct sockaddr *) &name, sizeof (name)) >=
@@ -209,18 +220,21 @@ lw6net_tcp_connect (char *ip, int port)
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _("setsockopt() failed"));
+		      lw6net_last_error ();
 		    }
 		  if (setsockopt (sock, SOL_SOCKET, SO_OOBINLINE,
 				  (char *) &disable, sizeof (int)))
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _("setsockopt() failed"));
+		      lw6net_last_error ();
 		    }
 		  if (setsockopt (sock, SOL_SOCKET, SO_LINGER,
 				  (char *) &li, sizeof (struct linger)))
 		    {
 		      lw6sys_log (LW6SYS_LOG_WARNING,
 				  _("setsockopt() failed"));
+		      lw6net_last_error ();
 		    }
 
 		  //fcntl (sock, F_SETFL, O_NONBLOCK, 0);
@@ -244,12 +258,21 @@ lw6net_tcp_connect (char *ip, int port)
 	    }
 	  else
 	    {
-	      lw6sys_log (LW6SYS_LOG_WARNING, _("inet_aton() failed"));
+#ifdef LW6_MS_WINDOWS
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _("inet_addr() failed, ip=\"%s\""), ip);
+	      lw6net_last_error ();
+#else
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _("inet_aton() failed, ip=\"%s\""), ip);
+	      lw6net_last_error ();
+#endif
 	    }
 	}
       else
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("bind() failed"));
+	  lw6net_last_error ();
 	}
     }
 
@@ -258,6 +281,7 @@ lw6net_tcp_connect (char *ip, int port)
       if (close (sock))
 	{
 	  lw6sys_log (LW6SYS_LOG_WARNING, _("close() failed"));
+	  lw6net_last_error ();
 	}
       sock = -1;
     }
@@ -385,6 +409,9 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
   int total_sent;
   int sent = 0;
   int chunk_size;
+#ifdef LW6_MS_WINDOWS
+  int winerr = 0;
+#endif
 
   if (sock >= 0)
     {
@@ -404,11 +431,23 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 	  switch (select_ret)
 	    {
 	    case -1:
+#ifdef LW6_MS_WINDOWS
+	      winerr = WSAGetLastError ();
+	      if (winerr != WSAEINTR && winerr != WSAENOBUFS)
+		{
+		  lw6sys_log (LW6SYS_LOG_WARNING,
+			      _("select() failed, code=%d"), winerr);
+		  lw6net_last_error ();
+		  ret = 0;
+		}
+#else
 	      if (errno != EINTR && errno != ENOBUFS)
 		{
 		  lw6sys_log (LW6SYS_LOG_WARNING, _("select() failed"));
+		  lw6net_last_error ();
 		  ret = 0;
 		}
+#endif
 	      break;
 	    case 1:
 	      if (FD_ISSET (sock, &write))
@@ -418,13 +457,16 @@ lw6net_tcp_send (int sock, char *buf, int len, float delay, int loop)
 			       lw6sys_min (len - total_sent, chunk_size), 0);
 		  if (sent > 0 && sent <= len - total_sent)
 		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _("%d bytes sent on TCP socket %d"), sent,
+				  sock);
 		      total_sent += sent;
 		    }
 		  else
 		    {
 		      lw6sys_log (LW6SYS_LOG_INFO,
 				  _
-				  ("can't send data on socket %d (%d bytes put)"),
+				  ("can't send data on TCP socket %d (%d bytes put)"),
 				  sock, sent);
 		      ret = 0;
 		    }
@@ -484,6 +526,9 @@ lw6net_tcp_peek (int sock, char *buf, int len, float delay)
 	      if (FD_ISSET (sock, &read))
 		{
 		  available = recv (sock, buf2, len, MSG_PEEK);
+		  lw6sys_log (LW6SYS_LOG_DEBUG,
+			      _("%d bytes available on TCP socket %d"),
+			      available, sock);
 		}
 	    }
 
@@ -537,6 +582,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 			      _
 			      ("error receiving data on socket %d (select error %d)"),
 			      sock, errno);
+		  lw6net_last_error ();
 		  ret = 0;
 		}
 	      break;
@@ -549,6 +595,9 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 					       chunk_size), 0);
 		  if (received > 0 && received <= len - total_received)
 		    {
+		      lw6sys_log (LW6SYS_LOG_DEBUG,
+				  _("%d bytes received on TCP socket %d"),
+				  received, sock);
 		      total_received += received;
 		    }
 		  else
@@ -557,6 +606,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 				  _
 				  ("can't recv data on socket %d (got %d bytes)"),
 				  sock, received);
+		      lw6net_last_error ();
 		      ret = 0;
 		    }
 		}
@@ -566,6 +616,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 			  _
 			  ("can't recv data on socket %d (select returned %d)"),
 			  sock, select_ret);
+	      lw6net_last_error ();
 	      ret = 0;
 	    }
 
@@ -574,6 +625,7 @@ lw6net_tcp_recv (int sock, char *buf, int len, float delay, int loop)
 	      lw6sys_log (LW6SYS_LOG_WARNING,
 			  _("can't recv data on socket %d (%d/%d)"), sock,
 			  total_received, len);
+	      lw6net_last_error ();
 	      ret = 0;
 	    }
 	}
@@ -586,10 +638,12 @@ int
 lw6net_tcp_is_alive (int sock)
 {
   int ret = 0;
-
   fd_set write;
   struct timeval tv;
   int select_ret;
+#ifdef LW6_MS_WINDOWS
+  int winerr = 0;
+#endif
 
   if (sock >= 0)
     {
@@ -605,7 +659,12 @@ lw6net_tcp_is_alive (int sock)
       switch (select_ret)
 	{
 	case -1:
+#ifdef LW6_MS_WINDOWS
+	  winerr = WSAGetLastError ();
+	  if (winerr != WSAEINTR && winerr != WSAENOBUFS)
+#else
 	  if (errno != EINTR && errno != ENOBUFS)
+#endif
 	    {
 	      // socket is closed...
 	      ret = 0;
