@@ -32,9 +32,12 @@ main (int argc, char *argv[])
   int ret = 1;
 
   LW6SYS_MAIN_BEGIN;
+  LW6HLP_MAIN_BEGIN;
 
+  lw6sys_log_clear (NULL);
   ret = lw6p2p_test ();
 
+  LW6HLP_MAIN_END;
   LW6SYS_MAIN_END;
 
   return (!ret);
