@@ -101,6 +101,33 @@ _quit (void *snd_context)
     }
 }
 
+lw6sys_module_pedigree_t *
+mod_ogg_get_pedigree ()
+{
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  module_pedigree =
+    (lw6sys_module_pedigree_t *)
+    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  if (module_pedigree)
+    {
+      module_pedigree->id = "ogg";
+      module_pedigree->category = "snd";
+      module_pedigree->name = _("Ogg Vorbis");
+      module_pedigree->readme =
+	_
+	("This sound backend uses Ogg Vorbis (through SDL) to handle sound effects and music. This is the only working sound backend for now.");
+      module_pedigree->version = VERSION;
+      module_pedigree->copyright =
+	"Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
+      module_pedigree->date = __DATE__;
+      module_pedigree->time = __TIME__;
+    }
+
+  return module_pedigree;
+}
+
 lw6snd_backend_t *
 mod_ogg_create_backend ()
 {
