@@ -1,4 +1,3 @@
-
 /*
   Liquid War 6 is a unique multiplayer wargame.
   Copyright (C)  2005, 2006, 2007, 2008  Christian Mauduit <ufoot@ufoot.org>
@@ -21,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../snd.h"
 #include "mod-ogg-internal.h"
 
@@ -45,14 +47,14 @@ _mod_ogg_play_sound (_mod_ogg_context_t * snd_context, int sound_id)
 	}
       else
 	{
-	  lw6sys_log (LW6SYS_LOG_WARNING, "snd-mod-ogg",
+	  lw6sys_log (LW6SYS_LOG_WARNING,
 		      _("unable to play sound %d, was not correctly loaded"),
 		      sound_id);
 	}
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING, "snd-mod-ogg",
+      lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to play sound %d, index out of range"), sound_id);
     }
 
@@ -75,9 +77,15 @@ load_sound (_mod_ogg_context_t * ogg_context, char *key)
       path2 = lw6sys_path_concat (ogg_context->path.data_dir, path1);
       if (path2)
 	{
-	  lw6sys_log (LW6SYS_LOG_INFO, "snd-mod-ogg", "loading sound \"%s\"",
-		      path2);
+	  lw6sys_log (LW6SYS_LOG_INFO, _("loading sound \"%s\""), path2);
 	  ret = Mix_LoadWAV (path2);
+	  if (!ret)
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _
+			  ("unable to load sound \"%s\" Mix_GetError returned \"%s\""),
+			  path2, Mix_GetError ());
+	    }
 	  LW6SYS_FREE (path2);
 	}
       LW6SYS_FREE (path1);
