@@ -27,7 +27,7 @@
 #include "snd.h"
 
 static void
-_warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("snd backend function \"%s\" is not defined"), func_name);
@@ -38,7 +38,7 @@ lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->play_sound)
     {
@@ -46,10 +46,10 @@ lw6snd_play_sound (lw6snd_backend_t * backend, int sound_id)
     }
   else
     {
-      _warning ("play_sound");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -59,7 +59,7 @@ lw6snd_play_music (lw6snd_backend_t * backend, char *music_name)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->play_music)
     {
@@ -67,10 +67,10 @@ lw6snd_play_music (lw6snd_backend_t * backend, char *music_name)
     }
   else
     {
-      _warning ("play_music");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -79,7 +79,7 @@ int
 lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
 	     float music_volume)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
@@ -89,10 +89,10 @@ lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
     }
   else
     {
-      _warning ("init");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return backend->snd_context ? 1 : 0;
 }
@@ -100,7 +100,7 @@ lw6snd_init (lw6snd_backend_t * backend, float sound_volume,
 void
 lw6snd_set_sound_volume (lw6snd_backend_t * backend, float volume)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->set_sound_volume)
     {
@@ -108,16 +108,16 @@ lw6snd_set_sound_volume (lw6snd_backend_t * backend, float volume)
     }
   else
     {
-      _warning ("set_sound_volume");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6snd_set_music_volume (lw6snd_backend_t * backend, float volume)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->set_music_volume)
     {
@@ -125,16 +125,16 @@ lw6snd_set_music_volume (lw6snd_backend_t * backend, float volume)
     }
   else
     {
-      _warning ("set_music_volume");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 void
 lw6snd_quit (lw6snd_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->quit)
     {
@@ -143,8 +143,8 @@ lw6snd_quit (lw6snd_backend_t * backend)
     }
   else
     {
-      _warning ("quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
