@@ -27,29 +27,44 @@
 #include <string.h>
 
 #include "snd.h"
+#ifdef LW6_ALLINONE
+#include "mod-csound/mod-csound.h"
+#include "mod-ogg/mod-ogg.h"
+#endif
 
 lw6sys_assoc_t *
 lw6snd_get_backends (int argc, char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
-  char *path;
 
-  ret = lw6sys_assoc_new (NULL);
+#ifdef LW6_ALLINONE
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  ret = lw6sys_assoc_new (lw6sys_free_callback);
   if (ret)
     {
-      path = lw6dyn_path_find_backend (argc, argv, "snd", "ogg");
-      if (path)
+#ifdef MOD_CSOUND
+      module_pedigree = mod_csound_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "ogg", (void *) _("Ogg Vorbis"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
-      path = lw6dyn_path_find_backend (argc, argv, "snd", "csound");
-      if (path)
+#endif
+#ifdef MOD_OGG
+      module_pedigree = mod_ogg_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "csound", (void *) _("Csound"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
+#endif
     }
+#else
+  ret = lw6dyn_list_backends (argc, argv, "snd");
+#endif
 
   return ret;
 }
@@ -58,6 +73,31 @@ lw6snd_backend_t *
 lw6snd_create_backend (int argc, char *argv[], char *name)
 {
   lw6snd_backend_t *backend = NULL;
+#ifdef LW6_ALLINONE
+#ifdef MOD_CSOUND
+  if (name && !strcmp (name, "csound"))
+    {
+      backend = mod_csound_create_backend ();
+    }
+#endif
+#ifdef MOD_OGG
+  if (name && !strcmp (name, "ogg"))
+    {
+      backend = mod_ogg_create_backend ();
+    }
+#endif
+
+  if (backend)
+    {
+      backend->argc = argc;
+      backend->argv = argv;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("sound backend \"%s\" does not exist"), name);
+    }
+#else
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
   backend_handle = lw6dyn_dlopen_backend (argc, argv, "snd", name);
@@ -67,7 +107,8 @@ lw6snd_create_backend (int argc, char *argv[], char *name)
       char *init_func_name;
       lw6snd_backend_t *(*init_func) ();
 
-      init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
+      init_func_name =
+	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
 	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
@@ -99,6 +140,18 @@ lw6snd_create_backend (int argc, char *argv[], char *name)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to open sound backend \"%s\""), name);
     }
+#endif
+
+  if (backend)
+    {
+      static u_int32_t seq_id = 0;
+
+      backend->id = 0;
+      while (!(backend->id))
+	{
+	  backend->id = ++seq_id;
+	}
+    }
 
   return backend;
 }
@@ -106,6 +159,8 @@ lw6snd_create_backend (int argc, char *argv[], char *name)
 void
 lw6snd_destroy_backend (lw6snd_backend_t * backend)
 {
+#ifndef LW6_ALLINONE
   lw6dyn_dlclose_backend (backend->dl_handle);
+#endif
   LW6SYS_FREE (backend);
 }
