@@ -28,14 +28,14 @@
 #include "../cfg/cfg.h"
 
 #define LW6SND_NB_SOUNDS 4
-typedef enum LW6SND_SOUND_ENUM
+typedef enum lw6snd_sound_enum_e
 {
   LW6SND_SOUND_SPLASH = 0,
   LW6SND_SOUND_BEEP_VALID = 1,
   LW6SND_SOUND_BEEP_SELECT = 2,
   LW6SND_SOUND_START = 3
 }
-LW6SND_SOUND;
+lw6snd_sound_enum_t;
 
 
 typedef struct lw6snd_backend_s
@@ -44,6 +44,7 @@ typedef struct lw6snd_backend_s
   void *snd_context;
   int argc;
   char **argv;
+  u_int32_t id;
 
   int (*play_sound) (void *snd_context, int sound_id);
   int (*play_music) (void *snd_context, char *music_name);
