@@ -216,6 +216,32 @@ _error (void *srv_context, lw6srv_connection_t * connection)
   return ret;
 }
 
+lw6sys_module_pedigree_t *
+mod_tcpd_get_pedigree ()
+{
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  module_pedigree =
+    (lw6sys_module_pedigree_t *)
+    LW6SYS_CALLOC (sizeof (lw6sys_module_pedigree_t));
+  if (module_pedigree)
+    {
+      module_pedigree->id = "tcpd";
+      module_pedigree->category = "srv";
+      module_pedigree->name = _("TCPD");
+      module_pedigree->readme =
+	_("Basic TCP/IP server, the most reliable way to communicate.");
+      module_pedigree->version = VERSION;
+      module_pedigree->copyright =
+	"Copyright (C)  2008  Christian Mauduit <ufoot@ufoot.org>";
+      module_pedigree->license = "GPLv3+ (GNU GPL version 3 or later)";
+      module_pedigree->date = __DATE__;
+      module_pedigree->time = __TIME__;
+    }
+
+  return module_pedigree;
+}
+
 lw6srv_backend_t *
 mod_tcpd_create_backend ()
 {
