@@ -20,7 +20,10 @@
   Contact author        : ufoot@ufoot.org
 */
 
+#ifdef HAVE_CONFIG_H
 #include "config.h"
+#endif
+
 #include "../srv.h"
 #include "mod-tcpd-internal.h"
 
