@@ -27,7 +27,7 @@
 #include "srv.h"
 
 static void
-_warning (char *func_name)
+_warning (const char *func_name)
 {
   lw6sys_log (LW6SYS_LOG_WARNING,
 	      _("srv backend function \"%s\" is not defined"), func_name);
@@ -36,7 +36,7 @@ _warning (char *func_name)
 int
 lw6srv_init (lw6srv_backend_t * backend, lw6srv_listener_t * listener)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->init)
     {
@@ -45,10 +45,10 @@ lw6srv_init (lw6srv_backend_t * backend, lw6srv_listener_t * listener)
     }
   else
     {
-      _warning ("init");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return backend->srv_context ? 1 : 0;
 }
@@ -56,7 +56,7 @@ lw6srv_init (lw6srv_backend_t * backend, lw6srv_listener_t * listener)
 void
 lw6srv_quit (lw6srv_backend_t * backend)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->quit)
     {
@@ -65,10 +65,10 @@ lw6srv_quit (lw6srv_backend_t * backend)
     }
   else
     {
-      _warning ("quit");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -77,7 +77,7 @@ lw6srv_can_handle_tcp (lw6srv_backend_t * backend,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->can_handle_tcp)
     {
@@ -85,10 +85,10 @@ lw6srv_can_handle_tcp (lw6srv_backend_t * backend,
     }
   else
     {
-      _warning ("can_handle_tcp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -99,7 +99,7 @@ lw6srv_can_handle_udp (lw6srv_backend_t * backend,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->can_handle_udp)
     {
@@ -107,10 +107,10 @@ lw6srv_can_handle_udp (lw6srv_backend_t * backend,
     }
   else
     {
-      _warning ("can_handle_udp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -121,7 +121,7 @@ lw6srv_accept_tcp (lw6srv_backend_t * backend,
 {
   lw6srv_connection_t *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->accept_tcp)
     {
@@ -130,10 +130,10 @@ lw6srv_accept_tcp (lw6srv_backend_t * backend,
     }
   else
     {
-      _warning ("accept_tcp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -144,7 +144,7 @@ lw6srv_new_udp (lw6srv_backend_t * backend, lw6srv_udp_buffer_t * udp_buffer,
 {
   lw6srv_connection_t *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->new_udp)
     {
@@ -152,10 +152,10 @@ lw6srv_new_udp (lw6srv_backend_t * backend, lw6srv_udp_buffer_t * udp_buffer,
     }
   else
     {
-      _warning ("new_udp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -167,7 +167,7 @@ lw6srv_is_associated_with_udp (lw6srv_backend_t * backend,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_associated_with_udp)
     {
@@ -177,10 +177,10 @@ lw6srv_is_associated_with_udp (lw6srv_backend_t * backend,
     }
   else
     {
-      _warning ("is_associated_with_udp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -192,7 +192,7 @@ lw6srv_update_with_udp (lw6srv_backend_t * backend,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->update_with_udp)
     {
@@ -202,10 +202,10 @@ lw6srv_update_with_udp (lw6srv_backend_t * backend,
     }
   else
     {
-      _warning ("update_with_udp");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -213,7 +213,7 @@ lw6srv_update_with_udp (lw6srv_backend_t * backend,
 void
 lw6srv_close (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 {
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->close)
     {
@@ -221,10 +221,10 @@ lw6srv_close (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
     }
   else
     {
-      _warning ("close");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 }
 
 int
@@ -233,7 +233,7 @@ lw6srv_send (lw6srv_backend_t * backend, lw6srv_connection_t * connection,
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->send)
     {
@@ -241,10 +241,10 @@ lw6srv_send (lw6srv_backend_t * backend, lw6srv_connection_t * connection,
     }
   else
     {
-      _warning ("send");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -254,7 +254,7 @@ lw6srv_recv (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->recv)
     {
@@ -262,10 +262,10 @@ lw6srv_recv (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
     }
   else
     {
-      _warning ("recv");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -275,7 +275,7 @@ lw6srv_is_alive (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 {
   int ret = 0;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->is_alive)
     {
@@ -283,10 +283,10 @@ lw6srv_is_alive (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
     }
   else
     {
-      _warning ("is_alive");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -296,7 +296,7 @@ lw6srv_repr (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->repr)
     {
@@ -304,10 +304,10 @@ lw6srv_repr (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
     }
   else
     {
-      _warning ("repr");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
@@ -317,7 +317,7 @@ lw6srv_error (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
 {
   char *ret = NULL;
 
-  LW6SYS_BACKEND_FUNCION_BEGIN;
+  LW6SYS_BACKEND_FUNCTION_BEGIN;
 
   if (backend->error)
     {
@@ -325,10 +325,10 @@ lw6srv_error (lw6srv_backend_t * backend, lw6srv_connection_t * connection)
     }
   else
     {
-      _warning ("error");
+      _warning (__FUNCTION__);
     }
 
-  LW6SYS_BACKEND_FUNCION_END;
+  LW6SYS_BACKEND_FUNCTION_END;
 
   return ret;
 }
