@@ -27,35 +27,48 @@
 #include <string.h>
 
 #include "srv.h"
+#ifdef LW6_ALLINONE
+#include "mod-tcpd/mod-tcpd.h"
+#include "mod-udpd/mod-udpd.h"
+#include "mod-httpd/mod-httpd.h"
+#endif
 
 lw6sys_assoc_t *
 lw6srv_get_backends (int argc, char *argv[])
 {
   lw6sys_assoc_t *ret = NULL;
-  char *path;
 
-  ret = lw6sys_assoc_new (NULL);
+#ifdef LW6_ALLINONE
+  lw6sys_module_pedigree_t *module_pedigree = NULL;
+
+  ret = lw6sys_assoc_new (lw6sys_free_callback);
   if (ret)
     {
-      path = lw6dyn_path_find_backend (argc, argv, "srv", "tcpd");
-      if (path)
+      module_pedigree = mod_tcpd_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "tcpd", (void *) _("TCP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
-      path = lw6dyn_path_find_backend (argc, argv, "srv", "udpd");
-      if (path)
+      module_pedigree = mod_udpd_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "udpd", (void *) _("UDP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
-      path = lw6dyn_path_find_backend (argc, argv, "srv", "httpd");
-      if (path)
+      module_pedigree = mod_httpd_get_pedigree ();
+      if (module_pedigree)
 	{
-	  lw6sys_assoc_set (&ret, "httpd", (void *) _("HTTP"));
-	  LW6SYS_FREE (path);
+	  lw6sys_assoc_set (&ret, module_pedigree->id,
+			    lw6sys_str_copy (module_pedigree->name));
+	  LW6SYS_FREE (module_pedigree);
 	}
     }
+#else
+  ret = lw6dyn_list_backends (argc, argv, "srv");
+#endif
 
   return ret;
 }
@@ -64,6 +77,31 @@ lw6srv_backend_t *
 lw6srv_create_backend (int argc, char *argv[], char *name)
 {
   lw6srv_backend_t *backend = NULL;
+#ifdef LW6_ALLINONE
+  if (name && !strcmp (name, "tcpd"))
+    {
+      backend = mod_tcpd_create_backend ();
+    }
+  if (name && !strcmp (name, "udpd"))
+    {
+      backend = mod_udpd_create_backend ();
+    }
+  if (name && !strcmp (name, "httpd"))
+    {
+      backend = mod_httpd_create_backend ();
+    }
+
+  if (backend)
+    {
+      backend->argc = argc;
+      backend->argv = argv;
+    }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING,
+		  _("server backend \"%s\" does not exist"), name);
+    }
+#else
   lw6dyn_dl_handle_t *backend_handle = NULL;
 
   backend_handle = lw6dyn_dlopen_backend (argc, argv, "srv", name);
@@ -73,7 +111,8 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
       char *init_func_name;
       lw6srv_backend_t *(*init_func) ();
 
-      init_func_name = lw6sys_new_sprintf ("mod_%s_create_backend", name);
+      init_func_name =
+	lw6sys_new_sprintf (LW6DYN_CREATE_BACKEND_FUNC_FORMAT, name);
       if (init_func_name)
 	{
 	  init_func = lw6dyn_dlsym (backend_handle, init_func_name);
@@ -105,6 +144,18 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
       lw6sys_log (LW6SYS_LOG_WARNING,
 		  _("unable to open server backend \"%s\""), name);
     }
+#endif
+
+  if (backend)
+    {
+      static u_int32_t seq_id = 0;
+
+      backend->id = 0;
+      while (!(backend->id))
+	{
+	  backend->id = ++seq_id;
+	}
+    }
 
   return backend;
 }
@@ -112,6 +163,8 @@ lw6srv_create_backend (int argc, char *argv[], char *name)
 void
 lw6srv_destroy_backend (lw6srv_backend_t * backend)
 {
+#ifndef LW6_ALLINONE
   lw6dyn_dlclose_backend (backend->dl_handle);
+#endif
   LW6SYS_FREE (backend);
 }
