@@ -31,7 +31,7 @@
 typedef struct assoc_dup_callback_data_s
 {
   lw6sys_assoc_t *assoc;
-  LW6SYS_DUP_FUNC dup_func;
+  lw6sys_dup_func_t dup_func;
 } assoc_dup_callback_data_t;
 
 /**
@@ -53,7 +53,7 @@ typedef struct assoc_dup_callback_data_s
  *   array. Must be freed with @lw6sys_assoc_free.
  */
 lw6sys_assoc_t *
-lw6sys_assoc_new (LW6SYS_FREE_FUNC free_func)
+lw6sys_assoc_new (lw6sys_free_func_t free_func)
 {
   lw6sys_assoc_t *ret = NULL;
 
@@ -314,7 +314,7 @@ lw6sys_assoc_unset (lw6sys_assoc_t * assoc, char *key)
  *
  * Returns a list containing all the keys of the assoc. The
  * list must be free with lw6sys_list_free by the caller.
- * This lisst copies all the keys of the assoc, so it is
+ * This list copies all the keys of the assoc, so it is
  * safe to use it once the assoc is deleted. However the
  * keys will of course be of little interest in this case.
  * But the program won't segfault.
@@ -333,7 +333,7 @@ lw6sys_assoc_keys (lw6sys_assoc_t * assoc)
 	{
 	  while (assoc)
 	    {
-	      if (assoc->key)
+	      if (assoc->key && keys)
 		{
 		  lw6sys_lifo_push (&keys, lw6sys_str_copy (assoc->key));
 		}
@@ -366,7 +366,7 @@ lw6sys_assoc_keys (lw6sys_assoc_t * assoc)
  */
 void
 lw6sys_assoc_map (lw6sys_assoc_t * assoc,
-		  lw6sys_assoc_t_CALLBACK_FUNC func, void *func_data)
+		  lw6sys_assoc_callback_func_t func, void *func_data)
 {
   if (assoc)
     {
@@ -402,7 +402,7 @@ lw6sys_assoc_map (lw6sys_assoc_t * assoc,
  * lw6sys_assoc_sort_and_map:
  *
  * @assoc: the assoc to work on
- * @func: a callback to call on each entry
+ * @func: a callback to call on each entry, may be NULL
  * @func_data: a pointer on some data which will be passed to the callback
  *
  * Executes a function on all assoc items, like @lw6sys_assoc_sort_and_map
@@ -412,7 +412,7 @@ lw6sys_assoc_map (lw6sys_assoc_t * assoc,
  */
 void
 lw6sys_assoc_sort_and_map (lw6sys_assoc_t * assoc,
-			   lw6sys_assoc_t_CALLBACK_FUNC func, void *func_data)
+			   lw6sys_assoc_callback_func_t func, void *func_data)
 {
   lw6sys_list_t *keys;
   lw6sys_list_t *current_key;
@@ -432,8 +432,11 @@ lw6sys_assoc_sort_and_map (lw6sys_assoc_t * assoc,
 		  str_key = (char *) current_key->data;
 		  if (str_key)
 		    {
-		      func (func_data, str_key,
-			    lw6sys_assoc_get (assoc, str_key));
+		      if (func)
+			{
+			  func (func_data, str_key,
+				lw6sys_assoc_get (assoc, str_key));
+			}
 		    }
 		  current_key = lw6sys_list_next (current_key);
 		}
@@ -485,7 +488,7 @@ assoc_dup_callback (void *func_data, char *key, void *value)
  * Returned value: a newly allocated assoc.
  */
 lw6sys_assoc_t *
-lw6sys_assoc_dup (lw6sys_assoc_t * assoc, LW6SYS_DUP_FUNC dup_func)
+lw6sys_assoc_dup (lw6sys_assoc_t * assoc, lw6sys_dup_func_t dup_func)
 {
   assoc_dup_callback_data_t assoc_dup_callback_data;
   lw6sys_assoc_t *ret = NULL;
@@ -499,6 +502,10 @@ lw6sys_assoc_dup (lw6sys_assoc_t * assoc, LW6SYS_DUP_FUNC dup_func)
 
       ret = assoc_dup_callback_data.assoc;
     }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("calling dup on NULL assoc"));
+    }
 
   return ret;
 }
