@@ -30,6 +30,7 @@
 #include "sys.h"
 #include "sys-internal.h"
 
+#ifndef LW6_OPTIMIZE
 #define BAZOOKA_ERASER_MALLOC 'M'
 #define BAZOOKA_ERASER_REALLOC_1 'E'
 #define BAZOOKA_ERASER_REALLOC_2 'R'
@@ -84,6 +85,97 @@ bazooka_free_data ()
   bazooka_data = NULL;
 }
 
+static void
+bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
+{
+#ifndef LW6_OPTIMIZE
+  bazooka_lock ();
+  bazooka_malloc_counter++;
+  if (bazooka_data)
+    {
+      int i;
+      char *file_only;
+
+      if (erase)
+	{
+	  memset (ptr, BAZOOKA_ERASER_MALLOC, size);
+	}
+
+      for (i = 0; i < bazooka_size; ++i)
+	{
+	  if (bazooka_data[i].ptr == NULL)
+	    {
+	      memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
+	      bazooka_data[i].ptr = ptr;
+	      bazooka_data[i].size = size;
+	      file_only = strrchr (file, '/');
+	      if (file_only && *file_only)
+		{
+		  file_only++;
+		}
+	      else
+		{
+		  file_only = file;
+		}
+	      strncpy (bazooka_data[i].file, file_only,
+		       _LW6SYS_BAZOOKA_FILE_SIZE - 1);
+	      bazooka_data[i].line = line;
+	      bazooka_data[i].timestamp = lw6sys_timestamp ();
+	      break;		// important to leave loop, else serious perfomance problem
+	    }
+	}
+      if (i == bazooka_size)
+	{
+	  // OK, we're full, big cleanup...
+	  memset (bazooka_data, 0, bazooka_size * sizeof (_lw6sys_bazooka_t));
+	}
+    }
+  bazooka_unlock ();
+#endif
+}
+
+static void
+report_line (_lw6sys_bazooka_t * bazooka)
+{
+  _lw6sys_bazooka_t local_bazooka;
+  int sample_int = 0;
+  char sample_str[_LW6SYS_BAZOOKA_SAMPLE_SIZE];
+  char *pos;
+  char ctime_buf[_LW6SYS_LOG_CTIME_BUF_SIZE];
+  time_t t;
+
+  // make a local copy, log functions can modify our data...
+  memcpy (&local_bazooka, bazooka, sizeof (_lw6sys_bazooka_t));
+
+  memset (sample_str, 0, _LW6SYS_BAZOOKA_SAMPLE_SIZE);
+  if (local_bazooka.size > 0)
+    {
+      memcpy (sample_str, local_bazooka.ptr,
+	      lw6sys_min (local_bazooka.size - 1,
+			  _LW6SYS_BAZOOKA_SAMPLE_SIZE - 1));
+    }
+  sample_int = *((int *) sample_str);
+  for (pos = sample_str; *pos; pos++)
+    {
+      // get rid of stange system characters
+      if ((*pos) < 32)
+	{
+	  (*pos) = ' ';
+	}
+    }
+
+  t = time (NULL);
+  ctime_r (&t, ctime_buf);
+  ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
+
+  lw6sys_log (LW6SYS_LOG_NOTICE,
+	      _
+	      ("memory bazooka found unfreed data ptr=%p size=%d file:line=\"%s:%d\" time=\"%s\" sample_int=%d sample_str=\"%s\""),
+	      local_bazooka.ptr, local_bazooka.size, local_bazooka.file,
+	      local_bazooka.line, ctime_buf, sample_int, sample_str);
+}
+#endif
+
 /**
  * lw6sys_default_memory_bazooka
  *
@@ -99,7 +191,11 @@ lw6sys_default_memory_bazooka ()
 {
   int ret = 0;
 
+#ifdef LW6_OPTIMIZE
+  ret = 1;
+#else
   ret = lw6sys_set_memory_bazooka_size (_LW6SYS_BAZOOKA_DEFAULT_SIZE);
+#endif
 
   return ret;
 }
@@ -114,7 +210,9 @@ lw6sys_default_memory_bazooka ()
 void
 lw6sys_clear_memory_bazooka ()
 {
+#ifndef LW6_OPTIMIZE
   lw6sys_set_memory_bazooka_size (0);
+#endif
 }
 
 /**
@@ -138,6 +236,8 @@ int
 lw6sys_set_memory_bazooka_size (int size)
 {
   int ret = 0;
+
+#ifndef LW6_OPTIMIZE
   int i;
 
   if (size == bazooka_size)
@@ -211,6 +311,7 @@ lw6sys_set_memory_bazooka_size (int size)
 	  ret = 1;
 	}
     }
+#endif
 
   return ret;
 }
@@ -229,10 +330,12 @@ lw6sys_get_memory_bazooka_size ()
 {
   int ret = 0;
 
+#ifndef LW6_OPTIMIZE
   if (bazooka_data)
     {
       ret = bazooka_size;
     }
+#endif
 
   return ret;
 }
@@ -251,187 +354,142 @@ lw6sys_get_memory_bazooka_size ()
 int
 lw6sys_set_memory_bazooka_eraser (int state)
 {
-  bazooka_eraser = state ? 1 : 0;
+  int ret = 0;
 
-  return lw6sys_get_memory_bazooka_eraser ();
+#ifndef LW6_OPTIMIZE
+  bazooka_eraser = state ? 1 : 0;
+  ret = lw6sys_get_memory_bazooka_eraser ();
+#endif
+
+  return ret;
 }
 
 int
 lw6sys_get_memory_bazooka_eraser ()
 {
-  return (bazooka_eraser && bazooka_data && bazooka_size > 0);
-}
+  int ret = 0;
 
-static void
-bazooka_register_malloc (char *ptr, int size, char *file, int line, int erase)
-{
-  if (bazooka_data)
-    {
-      bazooka_lock ();
+#ifndef LW6_OPTIMIZE
+  ret = (bazooka_eraser && bazooka_data && bazooka_size > 0);
+#endif
 
-      {
-	int i;
-	char *file_only;
-
-	bazooka_malloc_counter++;
-
-	if (erase)
-	  {
-	    memset (ptr, BAZOOKA_ERASER_MALLOC, size);
-	  }
-
-	for (i = 0; i < bazooka_size; ++i)
-	  {
-	    if (bazooka_data[i].ptr == NULL)
-	      {
-		memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
-		bazooka_data[i].ptr = ptr;
-		bazooka_data[i].size = size;
-		file_only = strrchr (file, '/');
-		if (file_only && *file_only)
-		  {
-		    file_only++;
-		  }
-		else
-		  {
-		    file_only = file;
-		  }
-		strncpy (bazooka_data[i].file, file_only,
-			 _LW6SYS_BAZOOKA_FILE_SIZE - 1);
-		bazooka_data[i].line = line;
-		bazooka_data[i].timestamp = lw6sys_timestamp ();
-		break;		// important to leave loop, else serious perfomance problem
-	      }
-	  }
-	if (i == bazooka_size)
-	  {
-	    // OK, we're full, big cleanup...
-	    memset (bazooka_data, 0,
-		    bazooka_size * sizeof (_lw6sys_bazooka_t));
-	  }
-      }
-
-      bazooka_unlock ();
-    }
+  return ret;
 }
 
 void
 _lw6sys_bazooka_register_malloc (char *ptr, int size, char *file, int line)
 {
+#ifndef LW6_OPTIMIZE
   bazooka_register_malloc (ptr, size, file, line, bazooka_eraser);
+#endif
 }
 
 void
 _lw6sys_bazooka_register_calloc (char *ptr, int size, char *file, int line)
 {
+#ifndef LW6_OPTIMIZE
   bazooka_register_malloc (ptr, size, file, line, 0);
+#endif
 }
 
 void
 _lw6sys_bazooka_register_realloc_1 (char *ptr, int size, char *file, int line)
 {
+#ifndef LW6_OPTIMIZE
+  bazooka_lock ();
   if (bazooka_data)
     {
-      bazooka_lock ();
+      int i;
 
-      {
-	int i;
-
-	for (i = 0; i < bazooka_size; ++i)
-	  {
-	    if (bazooka_data[i].ptr == ptr)
-	      {
-		if (bazooka_eraser && bazooka_data[i].size > size)
-		  {
-		    memset (bazooka_data[i].ptr + size,
-			    BAZOOKA_ERASER_REALLOC_1,
-			    bazooka_data[i].size - size);
-		  }
-		break;		// important to leave loop, else serious perfomance problem
-	      }
-	  }
-      }
-
-      bazooka_unlock ();
+      for (i = 0; i < bazooka_size; ++i)
+	{
+	  if (bazooka_data[i].ptr == ptr)
+	    {
+	      if (bazooka_eraser && bazooka_data[i].size > size)
+		{
+		  memset (bazooka_data[i].ptr + size,
+			  BAZOOKA_ERASER_REALLOC_1,
+			  bazooka_data[i].size - size);
+		}
+	      break;		// important to leave loop, else serious perfomance problem
+	    }
+	}
     }
+  bazooka_unlock ();
+#endif
 }
 
 void
 _lw6sys_bazooka_register_realloc_2 (char *ptr, char *ptr2, int size,
 				    char *file, int line)
 {
+#ifndef LW6_OPTIMIZE
+  bazooka_lock ();
   if (bazooka_data)
     {
-      bazooka_lock ();
+      int i;
+      char *file_only;
 
-      {
-	int i;
-	char *file_only;
-
-	for (i = 0; i < bazooka_size; ++i)
-	  {
-	    if (bazooka_data[i].ptr == ptr)
-	      {
-		if (bazooka_eraser && bazooka_data[i].size < size)
-		  {
-		    memset (ptr2 + bazooka_data[i].size,
-			    BAZOOKA_ERASER_REALLOC_2,
-			    size - bazooka_data[i].size);
-		  }
-		memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
-		bazooka_data[i].ptr = ptr2;
-		bazooka_data[i].size = size;
-		file_only = strrchr (file, '/');
-		if (file_only && *file_only)
-		  {
-		    file_only++;
-		  }
-		else
-		  {
-		    file_only = file;
-		  }
-		strncpy (bazooka_data[i].file, file_only,
-			 _LW6SYS_BAZOOKA_FILE_SIZE - 1);
-		bazooka_data[i].line = line;
-		bazooka_data[i].timestamp = lw6sys_timestamp ();
-		break;		// important to leave loop, else serious perfomance problem
-	      }
-	  }
-      }
-
-      bazooka_unlock ();
+      for (i = 0; i < bazooka_size; ++i)
+	{
+	  if (bazooka_data[i].ptr == ptr)
+	    {
+	      if (bazooka_eraser && bazooka_data[i].size < size)
+		{
+		  memset (ptr2 + bazooka_data[i].size,
+			  BAZOOKA_ERASER_REALLOC_2,
+			  size - bazooka_data[i].size);
+		}
+	      memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
+	      bazooka_data[i].ptr = ptr2;
+	      bazooka_data[i].size = size;
+	      file_only = strrchr (file, '/');
+	      if (file_only && *file_only)
+		{
+		  file_only++;
+		}
+	      else
+		{
+		  file_only = file;
+		}
+	      strncpy (bazooka_data[i].file, file_only,
+		       _LW6SYS_BAZOOKA_FILE_SIZE - 1);
+	      bazooka_data[i].line = line;
+	      bazooka_data[i].timestamp = lw6sys_timestamp ();
+	      break;		// important to leave loop, else serious perfomance problem
+	    }
+	}
     }
+  bazooka_unlock ();
+#endif
 }
 
 void
 _lw6sys_bazooka_register_free (char *ptr)
 {
+#ifndef LW6_OPTIMIZE
+  bazooka_lock ();
+  bazooka_free_counter++;
   if (bazooka_data)
     {
-      bazooka_lock ();
+      int i;
 
-      {
-	int i;
-
-	bazooka_free_counter++;
-
-	for (i = 0; i < bazooka_size; ++i)
-	  {
-	    if (bazooka_data[i].ptr == ptr)
-	      {
-		if (bazooka_eraser)
-		  {
-		    memset (bazooka_data[i].ptr, BAZOOKA_ERASER_FREE,
-			    bazooka_data[i].size);
-		  }
-		memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
-		break;		// important to leave loop, else serious perfomance problem
-	      }
-	  }
-      }
-
-      bazooka_unlock ();
+      for (i = 0; i < bazooka_size; ++i)
+	{
+	  if (bazooka_data[i].ptr == ptr)
+	    {
+	      if (bazooka_eraser)
+		{
+		  memset (bazooka_data[i].ptr, BAZOOKA_ERASER_FREE,
+			  bazooka_data[i].size);
+		}
+	      memset (&(bazooka_data[i]), 0, sizeof (_lw6sys_bazooka_t));
+	      break;		// important to leave loop, else serious perfomance problem
+	    }
+	}
     }
+  bazooka_unlock ();
+#endif
 }
 
 /**
@@ -447,7 +505,13 @@ _lw6sys_bazooka_register_free (char *ptr)
 int
 lw6sys_get_memory_bazooka_malloc_count ()
 {
-  return bazooka_malloc_counter;
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
+  ret = bazooka_malloc_counter;
+#endif
+
+  return ret;
 }
 
 /**
@@ -462,48 +526,13 @@ lw6sys_get_memory_bazooka_malloc_count ()
 int
 lw6sys_get_memory_bazooka_free_count ()
 {
+  int ret = 0;
+
+#ifndef LW6_OPTIMIZE
   return bazooka_free_counter;
-}
+#endif
 
-static void
-report_line (_lw6sys_bazooka_t * bazooka)
-{
-  _lw6sys_bazooka_t local_bazooka;
-  int sample_int = 0;
-  char sample_str[_LW6SYS_BAZOOKA_SAMPLE_SIZE];
-  char *pos;
-  char ctime_buf[_LW6SYS_LOG_CTIME_BUF_SIZE];
-  time_t t;
-
-  // make a local copy, log functions can modify our data...
-  memcpy (&local_bazooka, bazooka, sizeof (_lw6sys_bazooka_t));
-
-  memset (sample_str, 0, _LW6SYS_BAZOOKA_SAMPLE_SIZE);
-  if (local_bazooka.size > 0)
-    {
-      memcpy (sample_str, local_bazooka.ptr,
-	      lw6sys_min (local_bazooka.size - 1,
-			  _LW6SYS_BAZOOKA_SAMPLE_SIZE - 1));
-    }
-  sample_int = *((int *) sample_str);
-  for (pos = sample_str; *pos; pos++)
-    {
-      // get rid of stange system characters
-      if ((*pos) < 32)
-	{
-	  (*pos) = ' ';
-	}
-    }
-
-  t = time (NULL);
-  ctime_r (&t, ctime_buf);
-  ctime_buf[_LW6SYS_LOG_CTIME_ZERO] = '\0';
-
-  lw6sys_log (LW6SYS_LOG_NOTICE,
-	      _
-	      ("memory bazooka found unfreed data ptr=%p size=%d file:line=\"%s:%d\" time=\"%s\" sample_int=%d sample_str=\"%s\""),
-	      local_bazooka.ptr, local_bazooka.size, local_bazooka.file,
-	      local_bazooka.line, ctime_buf, sample_int, sample_str);
+  return ret;
 }
 
 /**
@@ -519,6 +548,10 @@ int
 lw6sys_memory_bazooka_report ()
 {
   int ret = 1;
+
+#ifdef LW6_OPTIMIZE
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("no memory check"));
+#else
   int recreate_mutex = 0;
   int i;
   int malloc_counter;
@@ -566,6 +599,7 @@ lw6sys_memory_bazooka_report ()
     {
       bazooka_mutex = lw6sys_mutex_create ();
     }
+#endif
 
   return ret;
 }
