@@ -590,6 +590,23 @@ lw6sys_build_get_enable_mod_http ()
 #endif
 }
 
+/**
+ * lw6sys_build_get_enable_optimize
+ *
+ * Tells wether the game was compiled in optimize mode.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_optimize ()
+{
+#ifdef LW6_OPTIMIZE
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
 /**
  * lw6sys_build_get_enable_allinone
  *
@@ -641,6 +658,23 @@ lw6sys_build_get_enable_gprof ()
 #endif
 }
 
+/**
+ * lw6sys_build_get_enable_gcov
+ *
+ * Tells wether the game was compiled with suitable informations for gcov.
+ *
+ * Return value: "yes" or "no", must no be freed.
+ */
+char *
+lw6sys_build_get_enable_gcov ()
+{
+#ifdef LW6_GCOV
+  return "yes";			// do not translate this, could be interpreted by a script
+#else
+  return "no";			// do not translate this, could be interpreted by a script
+#endif
+}
+
 /**
  * lw6sys_build_get_enable_valgrind
  *
@@ -729,12 +763,16 @@ lw6sys_build_log_pedigree ()
 	      lw6sys_build_get_enable_mod_ogg ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable mod-http is \"%s\""),
 	      lw6sys_build_get_enable_mod_http ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable optimize is \"%s\""),
+	      lw6sys_build_get_enable_optimize ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable allinone is \"%s\""),
 	      lw6sys_build_get_enable_allinone ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable fullstatic is \"%s\""),
 	      lw6sys_build_get_enable_fullstatic ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable gprof is \"%s\""),
 	      lw6sys_build_get_enable_gprof ());
+  lw6sys_log (LW6SYS_LOG_INFO, _("build enable gcov is \"%s\""),
+	      lw6sys_build_get_enable_gcov ());
   lw6sys_log (LW6SYS_LOG_INFO, _("build enable valgrind is \"%s\""),
 	      lw6sys_build_get_enable_valgrind ());
 }
