@@ -59,6 +59,27 @@ lw6sys_checksum (unsigned char *data, int len)
   return ret;
 }
 
+/**
+ * lw6sys_checksum_str
+ *
+ * @value: the string to process
+ *
+ * Creates a checksum from a string. This is a convenience
+ * function to save the programmer the hassle of calling strlen
+ * before any checksum calculation.
+ *
+ * Return value: the checksum, as an integer.
+ */
+u_int32_t
+lw6sys_checksum_str (char *value)
+{
+  u_int32_t ret = 0;
+
+  lw6sys_checksum_update_str (&ret, value);
+
+  return ret;
+}
+
 /**
  * lw6sys_checksum_int32
  *
@@ -82,6 +103,28 @@ lw6sys_checksum_int32 (u_int32_t value)
   return ret;
 }
 
+/**
+ * lw6sys_checksum_int64
+ *
+ * @value: the integer to process
+ *
+ * Creates a checksum from an integer. This is a convenience
+ * function to save the programmer the hassle of passing a pointer
+ * to the integer with the size of it each time there's a checksum
+ * to do. This function handles 64-bit long long integers..
+ *
+ * Return value: the checksum, as an integer.
+ */
+u_int32_t
+lw6sys_checksum_int64 (u_int64_t value)
+{
+  u_int32_t ret = 0;
+
+  lw6sys_checksum_update_int64 (&ret, value);
+
+  return ret;
+}
+
 /**
  * lw6sys_checksum_wh
  *
@@ -161,6 +204,31 @@ lw6sys_checksum_update (u_int32_t * checksum, unsigned char *data, int len)
     }
 }
 
+/**
+ * lw6sys_checksum_update_str
+ *
+ * @checksum: a pointer to the previous checksum
+ * @value: the string to process
+ *
+ * Creates a checksum from the given string. The difference
+ * with @lw6sys_checksum_str is that this one updates an existing
+ * checksum, thus enabling the programmer to call it sequentially
+ * and get a global checksum on different sources.
+ *
+ * Return value: none. 
+ */
+void
+lw6sys_checksum_update_str (u_int32_t * checksum, char *value)
+{
+  int len = 0;
+
+  len = strlen (value);
+  if (len > 0)
+    {
+      lw6sys_checksum_update (checksum, (unsigned char *) value, len);
+    }
+}
+
 /**
  * lw6sys_checksum_update_int32
  *
@@ -183,6 +251,28 @@ lw6sys_checksum_update_int32 (u_int32_t * checksum, int32_t value)
   lw6sys_checksum_update (checksum, buffer, LW6SYS_SIZEOF_INT32);
 }
 
+/**
+ * lw6sys_checksum_update_int64
+ *
+ * @checksum: a pointer to the previous checksum
+ * @value: the integer to process
+ *
+ * Creates a checksum from the given integer. The difference
+ * with @lw6sys_checksum_int64 is that this one updates an existing
+ * checksum, thus enabling the programmer to call it sequentially
+ * and get a global checksum on different sources.
+ *
+ * Return value: none. 
+ */
+void
+lw6sys_checksum_update_int64 (u_int32_t * checksum, int64_t value)
+{
+  unsigned char buffer[LW6SYS_SIZEOF_INT64];
+
+  lw6sys_serialize_int64 (buffer, value);
+  lw6sys_checksum_update (checksum, buffer, LW6SYS_SIZEOF_INT64);
+}
+
 /**
  * lw6sys_checksum_update_wh
  *
