@@ -640,10 +640,10 @@ lw6sys_color_ponderate (lw6sys_color_8_t color1, lw6sys_color_8_t color2,
 	{
 	  color1_hsv.h += 360.0f;
 	}
-      ret_hsv.h = coeff * color1_hsv.h + (1.0f - coeff) * color2_hsv.h;
-      ret_hsv.s = coeff * color1_hsv.s + (1.0f - coeff) * color2_hsv.s;
-      ret_hsv.v = coeff * color1_hsv.s + (1.0f - coeff) * color2_hsv.v;
-      ret_hsv.a = coeff * color1_hsv.s + (1.0f - coeff) * color2_hsv.a;
+      ret_hsv.h = (1.0f - coeff) * color1_hsv.h + coeff * color2_hsv.h;
+      ret_hsv.s = (1.0f - coeff) * color1_hsv.s + coeff * color2_hsv.s;
+      ret_hsv.v = (1.0f - coeff) * color1_hsv.v + coeff * color2_hsv.v;
+      ret_hsv.a = (1.0f - coeff) * color1_hsv.a + coeff * color2_hsv.a;
       ret = lw6sys_color_hsv_to_rgb (&ret_hsv);
     }
 
@@ -703,3 +703,33 @@ lw6sys_color_distance (lw6sys_color_8_t color1, lw6sys_color_8_t color2)
 
   return distance;
 }
+
+/**
+ * lw6sys_color_8_solid
+ *
+ * color: the color to modify
+ *
+ * Make a color "solid" that is make it not transparent at all.
+ *
+ * Return value: none.
+ */
+void
+lw6sys_color_8_solid (lw6sys_color_8_t * color)
+{
+  color->a = 0xFF;
+}
+
+/**
+ * lw6sys_color_f_solid
+ *
+ * color: the color to modify
+ *
+ * Make a color "solid" that is make it not transparent at all.
+ *
+ * Return value: none.
+ */
+void
+lw6sys_color_f_solid (lw6sys_color_f_t * color)
+{
+  color->a = 1.0f;
+}
