@@ -47,7 +47,7 @@ lw6sys_atoi (char *str)
  * @str: string to convert
  *
  * Transform a string into a boolean value. Accepts "0"/"1" in input,
- * but also yes/no, true/false, on/off.
+ * but also y/n, yes/no, true/false, on/off.
  *
  * Return value: an integer, 0 or 1.
  */
@@ -57,6 +57,7 @@ lw6sys_atob (char *str)
   int ret = 0;
 
   ret = (strcasecmp (str, "true") == 0
+	 || strcasecmp (str, "y") == 0
 	 || strcasecmp (str, "yes") == 0
 	 || strcasecmp (str, "on") == 0 || strlen (str) == 0
 	 || lw6sys_atoi (str) > 0);
