@@ -248,13 +248,20 @@ pop_raw (lw6sys_hexa_serializer_t * hexa_serializer, u_int8_t * buf, int size)
   int ret = 0;
   int i;
   int j;
+  char hexa2[3] = { 0, 0, 0 };	// third 0 is *very* important
 
   if (check_size (hexa_serializer, size * 2))
     {
       for (i = 0; i < size; ++i, hexa_serializer->pos += 2)
 	{
 	  j = 0;
-	  sscanf (hexa_serializer->buf + hexa_serializer->pos, "%02x", &j);
+	  memcpy (hexa2, hexa_serializer->buf + hexa_serializer->pos, 2);
+	  /*
+	   * Performing sscanf on long strings is a performance killer
+	   * for sscanf calls strlen internally to get the length
+	   * of the string...
+	   */
+	  sscanf (hexa2, "%02x", &j);
 	  buf[i] = (u_int8_t) j;
 	}
       if (hexa_serializer->pos < hexa_serializer->buf_size &&
