@@ -30,7 +30,7 @@
 
 #define _LW6SYS_EXIT_CRITICAL 1
 
-#define _LW6SYS_BAZOOKA_DEFAULT_SIZE 10000
+#define _LW6SYS_BAZOOKA_DEFAULT_SIZE 1000
 #define _LW6SYS_BAZOOKA_FILE_SIZE 50
 #define _LW6SYS_BAZOOKA_SAMPLE_SIZE 100
 
@@ -57,7 +57,7 @@ typedef struct _lw6sys_mutex_s
 typedef struct _lw6sys_thread_handler_s
 {
   pthread_t thread;
-  int id;
+  u_int32_t id;
   int callback_done;
   int can_join;
   void (*callback_func) (void *callback_data);
