@@ -36,7 +36,7 @@
 static int
 is_sep (char c)
 {
-  return (c == ' ' || c == '-' || c == '_' || c == '/');
+  return (c == ' ' || c == '\t' || c == '-' || c == '_' || c == '/');
 }
 
 static int
@@ -46,6 +46,12 @@ is_c (char c)
     || (c >= '0' && c <= '9') || (c == '?');
 }
 
+static int
+is_equal (char c)
+{
+  return (c == '=');
+}
+
 static void
 skip_prefix (char **keyword)
 {
@@ -103,6 +109,10 @@ lw6sys_keyword_as_key (char *keyword)
 	    {
 	      pos[0] = '-';
 	    }
+	  else if (is_equal (pos[0]))
+	    {
+	      pos[0] = '\0';
+	    }
 	  else
 	    {
 	      lw6sys_log_critical (_
@@ -177,6 +187,10 @@ lw6sys_keyword_as_env (char *keyword)
 	    {
 	      pos[0] = '_';
 	    }
+	  else if (is_equal (pos[0]))
+	    {
+	      pos[0] = '\0';
+	    }
 	  else
 	    {
 	      lw6sys_log_critical (_
