@@ -31,7 +31,7 @@
 typedef struct list_dup_callback_data_s
 {
   lw6sys_list_t *list;
-  LW6SYS_DUP_FUNC dup_func;
+  lw6sys_dup_func_t dup_func;
 } list_dup_callback_data_t;
 
 /**
@@ -47,7 +47,7 @@ typedef struct list_dup_callback_data_s
  * Return value: a pointer to the created object, may be NULL.
  */
 lw6sys_list_t *
-lw6sys_list_new (LW6SYS_FREE_FUNC free_func)
+lw6sys_list_new (lw6sys_free_func_t free_func)
 {
   lw6sys_list_t *ret = NULL;
 
@@ -221,7 +221,7 @@ lw6sys_list_length (lw6sys_list_t * list)
  */
 void
 lw6sys_list_map (lw6sys_list_t * list,
-		 lw6sys_list_t_CALLBACK_FUNC func, void *func_data)
+		 lw6sys_list_callback_func_t func, void *func_data)
 {
   if (list)
     {
@@ -508,7 +508,7 @@ list_dup_callback (void *func_data, void *data)
  * Returned value: a newly allocated list.
  */
 lw6sys_list_t *
-lw6sys_list_dup (lw6sys_list_t * list, LW6SYS_DUP_FUNC dup_func)
+lw6sys_list_dup (lw6sys_list_t * list, lw6sys_dup_func_t dup_func)
 {
   list_dup_callback_data_t list_dup_callback_data;
   lw6sys_list_t *ret = NULL;
@@ -522,6 +522,10 @@ lw6sys_list_dup (lw6sys_list_t * list, LW6SYS_DUP_FUNC dup_func)
 
       ret = list_dup_callback_data.list;
     }
+  else
+    {
+      lw6sys_log (LW6SYS_LOG_WARNING, _("calling dup on NULL list"));
+    }
 
   return ret;
 }
