@@ -33,6 +33,8 @@
 #include <time.h>
 #include <errno.h>
 
+#define HISTORY_LENGTH 256
+
 #define MSGBOX_LENGTH 4096
 #define MSGBOX_WIDTH 128
 
@@ -489,19 +491,38 @@ lw6sys_log_set_file (char *filename)
  * @filename: the name of the log file.
  *
  * Clears the log file, this function would typically be called
- * at the beginning of the program.
+ * at the beginning of the program. If filename is NULL, then the
+ * default log file is cleared.
  *
  * Return value: void
  */
 void
 lw6sys_log_clear (char *filename)
 {
-  lw6sys_log_set_file (filename);
+  char *default_log_file = NULL;
 
-  lw6sys_clear_file (filename);
-  if (!lw6sys_file_exists (filename))
+  if (filename)
     {
-      lw6sys_log_critical (_("can't open log file \"%s\""), filename);
+      lw6sys_log_set_file (filename);
+    }
+  else
+    {
+      default_log_file = lw6sys_get_default_log_file ();
+      filename = default_log_file;
+    }
+
+  if (filename)
+    {
+      lw6sys_clear_file (filename);
+      if (!lw6sys_file_exists (filename))
+	{
+	  lw6sys_log_critical (_("can't open log file \"%s\""), filename);
+	}
+    }
+
+  if (default_log_file)
+    {
+      LW6SYS_FREE (default_log_file);
     }
 }
 
@@ -559,6 +580,24 @@ log_to_console (FILE * f, char *level_str, char *fmt, va_list ap)
   fflush (f);
 }
 
+static void
+log_to_history (char *level_str, char *fmt, va_list ap)
+{
+  char *msg, *full_msg;
+
+  msg = _lw6sys_new_vsnprintf (HISTORY_LENGTH, fmt, ap);
+  if (msg)
+    {
+      full_msg = lw6sys_str_concat (level_str, msg);
+      if (full_msg)
+	{
+	  lw6sys_history_register (full_msg);
+	  LW6SYS_FREE (full_msg);
+	}
+      LW6SYS_FREE (msg);
+    }
+}
+
 static void
 msgbox_alert (char *fmt, va_list ap)
 {
@@ -644,7 +683,12 @@ msgbox_alert (char *fmt, va_list ap)
 void
 lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 {
+#ifdef LW6_OPTIMIZE
+  if ((level_id <= LW6SYS_LOG_NOTICE_ID
+       && level_id <= lw6sys_log_get_level ()) || lw6sys_debug_get ())
+#else
   if (level_id <= lw6sys_log_get_level () || lw6sys_debug_get ())
+#endif
     {
       char *level_str = NULL;
 #ifdef HAVE_SYSLOG_H
@@ -720,9 +764,14 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	      log_to_console (stderr, level_str, fmt, ap2);
 	      va_end (ap2);
 	    }
+	  if (level_id <= LW6SYS_LOG_WARNING_ID)
+	    {
+	      va_copy (ap2, ap);
+	      log_to_history (level_str, fmt, ap2);
+	      va_end (ap2);
+	    }
 #ifdef HAVE_SYSLOG_H
-	  // exclude INFO & DEBUG from syslog
-	  if (level_id <= LW6SYS_LOG_NOTICE_ID)
+	  if (level_id <= LW6SYS_LOG_WARNING_ID)
 	    {
 	      va_copy (ap2, ap);
 	      vsyslog (syslog_priority, fmt, ap2);
@@ -751,13 +800,13 @@ lw6sys_log (int level_id, char *file, int line, char *fmt, ...)
 	{
 	  LW6SYS_FREE (level_str);
 	}
-
-      /*
-       * We reset errno to avoid getting pointless errno in logs,
-       * the idea is to print errno when needed...
-       */
-      errno = 0;
     }
+
+  /*
+   * We reset errno to avoid getting pointless errno in logs,
+   * the idea is to print errno when needed...
+   */
+  errno = 0;
 }
 
 /**
