@@ -61,12 +61,15 @@ lw6sys_malloc (int size, char *file, int line)
 
   if (ptr != NULL)
     {
+#ifndef LW6_OPTIMIZE
       _lw6sys_bazooka_register_malloc (ptr, size, file, line);
+#endif
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("malloc %d bytes failed in %s:%d"), size, file, size);
+      lw6sys_log (LW6SYS_LOG_ERROR,
+		  _("Out of memory malloc(%d) failed in %s:%d)"), size, file,
+		  line);
     }
 
   return ptr;
@@ -97,12 +100,15 @@ lw6sys_calloc (int size, char *file, int line)
 
   if (ptr != NULL)
     {
+#ifndef LW6_OPTIMIZE
       _lw6sys_bazooka_register_calloc (ptr, size, file, line);
+#endif
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("calloc %d bytes failed in %s:%d"), size, file, size);
+      lw6sys_log (LW6SYS_LOG_ERROR,
+		  _("Out of memory calloc(%d) failed in %s:%d)"), size, file,
+		  line);
     }
 
   return ptr;
@@ -129,18 +135,23 @@ lw6sys_realloc (void *ptr, int size, char *file, int line)
 {
   void *ptr2;
 
+#ifndef LW6_OPTIMIZE
   _lw6sys_bazooka_register_realloc_1 (ptr, size, file, line);
+#endif
 
   ptr2 = realloc (ptr, size);
 
   if (ptr2)
     {
+#ifndef LW6_OPTIMIZE
       _lw6sys_bazooka_register_realloc_2 (ptr, ptr2, size, file, line);
+#endif
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("realloc %d bytes failed in %s:%d"), size, file, size);
+      lw6sys_log (LW6SYS_LOG_ERROR,
+		  _("Out of memory realloc(%d) failed in %s:%d)"), size, file,
+		  line);
     }
 
   return ptr2;
@@ -167,7 +178,9 @@ lw6sys_free (void *ptr, char *file, int line)
 {
   if (ptr != NULL)
     {
+#ifndef LW6_OPTIMIZE
       _lw6sys_bazooka_register_free (ptr);
+#endif
       /*
        * It's important to free the pointer after registering, since
        * the later might overwrite memory in some cases.
@@ -176,8 +189,8 @@ lw6sys_free (void *ptr, char *file, int line)
     }
   else
     {
-      lw6sys_log (LW6SYS_LOG_WARNING,
-		  _("trying to free null pointer in %s:%d"), file, line);
+      lw6sys_log (LW6SYS_LOG_ERROR,
+		  _("Trying to free NULL pointer in %s:%d)"), file, line);
     }
 }
 
