@@ -836,7 +836,7 @@ lw6sys_get_user_dir (int argc, char *argv[])
 {
   char *user_dir = NULL;
 
-  user_dir = get_command_arg_with_env (argc, argv, "user-dir");
+  user_dir = get_command_arg_with_env (argc, argv, LW6DEF_USER_DIR);
   if (user_dir == NULL)
     {
       user_dir = lw6sys_get_default_user_dir ();
@@ -875,7 +875,7 @@ lw6sys_get_config_file (int argc, char *argv[])
   char *config_file = NULL;
   char *user_dir = NULL;
 
-  config_file = get_command_arg_with_env (argc, argv, "config-file");
+  config_file = get_command_arg_with_env (argc, argv, LW6DEF_CONFIG_FILE);
   if (config_file == NULL)
     {
       user_dir = lw6sys_get_user_dir (argc, argv);
@@ -907,7 +907,7 @@ lw6sys_get_log_file (int argc, char *argv[])
   char *log_file = NULL;
   char *user_dir = NULL;
 
-  log_file = get_command_arg_with_env (argc, argv, "log-file");
+  log_file = get_command_arg_with_env (argc, argv, LW6DEF_LOG_FILE);
   if (log_file == NULL)
     {
       user_dir = lw6sys_get_user_dir (argc, argv);
@@ -938,7 +938,7 @@ lw6sys_get_prefix (int argc, char *argv[])
 {
   char *prefix = NULL;
 
-  prefix = get_command_arg_with_env (argc, argv, "prefix");
+  prefix = get_command_arg_with_env (argc, argv, LW6DEF_PREFIX);
   if (prefix == NULL)
     {
       prefix = lw6sys_get_default_prefix ();
@@ -966,7 +966,7 @@ lw6sys_get_mod_dir (int argc, char *argv[])
   char *mod_dir = NULL;
   char *prefix = NULL;
 
-  mod_dir = get_command_arg_with_env (argc, argv, "mod-dir");
+  mod_dir = get_command_arg_with_env (argc, argv, LW6DEF_MOD_DIR);
   if (mod_dir == NULL)
     {
       prefix = lw6sys_get_prefix (argc, argv);
@@ -998,7 +998,7 @@ lw6sys_get_data_dir (int argc, char *argv[])
   char *data_dir = NULL;
   char *prefix = NULL;
 
-  data_dir = get_command_arg_with_env (argc, argv, "data-dir");
+  data_dir = get_command_arg_with_env (argc, argv, LW6DEF_DATA_DIR);
   if (data_dir == NULL)
     {
       prefix = lw6sys_get_prefix (argc, argv);
@@ -1032,7 +1032,7 @@ lw6sys_get_map_dir (int argc, char *argv[])
   char *map_dir = NULL;
   char *prefix = NULL;
 
-  map_dir = get_command_arg_with_env (argc, argv, "map-dir");
+  map_dir = get_command_arg_with_env (argc, argv, LW6DEF_MAP_DIR);
   if (map_dir == NULL)
     {
       prefix = lw6sys_get_prefix (argc, argv);
@@ -1081,7 +1081,7 @@ lw6sys_get_map_path (int argc, char *argv[])
 					    ("This is your Liquid War 6 user map directory. You can put your own maps here, they will be automatically loaded by the game, and appear in the menus. To create maps, you need to 1) read the documentation 2) study existing map to see how things work in practice and 3) be creative. FYI the Liquid War 6 map format is rather simple and hopefully well documented, the general idea is that a map is a directory containing files, the most important of them being 'map.png'. Again, read the documentation. I repeat: 'Read the docs!'. http://www.gnu.org/software/liquidwar6/manual/"));
 	  if (map_path)
 	    {
-	      map_path_env = lw6sys_getenv ("map-path");
+	      map_path_env = lw6sys_getenv (LW6DEF_MAP_PATH);
 	      if (map_path && map_path_env)
 		{
 		  tmp = map_path;
@@ -1089,7 +1089,8 @@ lw6sys_get_map_path (int argc, char *argv[])
 		  LW6SYS_FREE (tmp);
 		  LW6SYS_FREE (map_path_env);
 		}
-	      map_path_cmd = lw6sys_arg_get_value (argc, argv, "map-path");
+	      map_path_cmd =
+		lw6sys_arg_get_value (argc, argv, LW6DEF_MAP_PATH);
 	      if (map_path && map_path_cmd)
 		{
 		  tmp = map_path;
@@ -1124,7 +1125,7 @@ lw6sys_get_script_file (int argc, char *argv[])
   char *script_file = NULL;
   char *prefix = NULL;
 
-  script_file = get_command_arg_with_env (argc, argv, "script-file");
+  script_file = get_command_arg_with_env (argc, argv, LW6DEF_SCRIPT_FILE);
   if (script_file == NULL)
     {
       prefix = lw6sys_get_prefix (argc, argv);
