@@ -279,11 +279,18 @@ lw6sys_path_concat (char *path1, char *path2)
 	    {
 	      path2_start++;
 	    }
-	  if (strlen (path2_start) > 0 && strcmp (path2_start, ".") != 0)
+	  if (!lw6sys_path_is_cwd (path2_start))
 	    {
-	      ret =
-		lw6sys_new_sprintf ("%s" DIR_SEP_STR "%s", path1_stripped,
-				    path2_start);
+	      if (strlen (path1_stripped) > 0)
+		{
+		  ret =
+		    lw6sys_new_sprintf ("%s" DIR_SEP_STR "%s", path1_stripped,
+					path2_start);
+		}
+	      else
+		{
+		  ret = lw6sys_str_copy (path2_start);
+		}
 	    }
 	  else
 	    {
@@ -302,6 +309,34 @@ lw6sys_path_concat (char *path1, char *path2)
   return ret;
 }
 
+/**
+ * lw6sys_path_split
+ *
+ * @path: a path
+ *
+ * Splits a path into all its parts. For instance /boo/bar/foo2/bar2
+ * returns a 4 elements list. This is more than a plain split, for
+ * heading and tailing slashes will be ignored, and various path
+ * separators will be interpreted (depends on platform).
+ *
+ * Return value: a list containing 0-terminated strings.
+ */
+lw6sys_list_t *
+lw6sys_path_split (char *path)
+{
+  char *stripped_path = NULL;
+  lw6sys_list_t *ret = NULL;
+
+  stripped_path = lw6sys_path_strip_slash (path);
+  if (stripped_path)
+    {
+      ret = lw6sys_str_split_no_0 (stripped_path, DIR_SEP_CHAR);
+      LW6SYS_FREE (stripped_path);
+    }
+
+  return ret;
+}
+
 /**
  * lw6sys_path_is_relative
  *
@@ -328,6 +363,31 @@ lw6sys_path_is_relative (char *path)
   return ret;
 }
 
+/**
+ * lw6sys_path_is_cwd
+ *
+ * @path: a path
+ *
+ * Checks wether a path is "." or not. Will also trap "" and "./".
+ *
+ * Return value: 1 if relative, 0 if absolute.
+ */
+int
+lw6sys_path_is_cwd (char *path)
+{
+  int ret = 0;
+
+  if (strcmp ("", path) == 0 ||
+      strcmp (".", path) == 0 ||
+      strcmp ("." DIR_SEP_STR_UNIX, path) == 0 ||
+      strcmp ("." DIR_SEP_STR_MS_WINDOWS, path) == 0)
+    {
+      ret = 1;
+    }
+
+  return ret;
+}
+
 /**
  * lw6sys_path_parent
  *
