@@ -222,7 +222,7 @@ lw6sys_sort_str_desc_callback (lw6sys_list_t ** list_a,
  * any callback, provided it has the right prototype.
  */
 void
-lw6sys_sort (lw6sys_list_t ** list, LW6SYS_SORT_CALLBACK_FUNC sort_func)
+lw6sys_sort (lw6sys_list_t ** list, lw6sys_sort_callback_func_t sort_func)
 {
   int length, i;
   lw6sys_list_t **array;
