@@ -122,7 +122,11 @@ _lw6sys_new_vsnprintf (int n, char *fmt, va_list ap)
   return ret;
 }
 
-
+static int
+more_mem (int n)
+{
+  return (((n * 15) / 10) + 1);	// +50%+1
+}
 
 /**
  * lw6sys_new_sprintf
@@ -151,7 +155,7 @@ lw6sys_new_sprintf (char *fmt, ...)
     {
       va_start (ap, fmt);
 
-      int n = strlen (fmt);
+      int n = more_mem (strlen (fmt));
 
       while (ret == NULL)
 	{
@@ -168,7 +172,7 @@ lw6sys_new_sprintf (char *fmt, ...)
 	   * memory for a simple, game and possibly machine
 	   * will collapse anyway...
 	   */
-	  n = ((n * 11) / 10) + 1;	// + 10% + 1 char
+	  n = more_mem (n);
 	}
 
       va_end (ap);
@@ -407,3 +411,115 @@ lw6sys_eol ()
 {
   return STR_EOL;
 }
+
+/**
+ * lw6sys_str_split
+ *
+ * @str: a string
+ * @c: the delimiter to split with
+ *
+ * Splits a string, for instance 'foo,bar' splited with 'o' will
+ * return 'f', '' and ',bar'.
+ *
+ * Return value: a list containing 0-terminated strings.
+ */
+lw6sys_list_t *
+lw6sys_str_split (char *str, char c)
+{
+  lw6sys_list_t *ret = NULL;
+  char *found = NULL;
+  char *pos = NULL;
+  char *copy = NULL;
+  char *part = NULL;
+
+  copy = lw6sys_str_copy (str);
+  if (copy)
+    {
+      ret = lw6sys_list_new (lw6sys_free_callback);
+      if (ret)
+	{
+	  pos = copy;
+	  while ((found = strchr (pos, c)) != NULL)
+	    {
+	      (*found) = '\0';
+	      part = lw6sys_str_copy (pos);
+	      if (part)
+		{
+		  lw6sys_list_push_back (&ret, part);
+		}
+	      pos = found + 1;
+	    }
+	  part = lw6sys_str_copy (pos);
+	  if (part)
+	    {
+	      lw6sys_list_push_back (&ret, part);
+	    }
+	}
+      LW6SYS_FREE (copy);
+    }
+
+  return ret;
+}
+
+/**
+ * lw6sys_str_split_no_0
+ *
+ * @str: a string
+ * @c: the delimiter to split with
+ *
+ * Splits a string, ignoring empty '0-length' members. For instance 
+ * 'foo,bar' splited with 'o' will return 'f' and ',bar'.
+ *
+ * Return value: a list containing 0-terminated strings.
+ */
+lw6sys_list_t *
+lw6sys_str_split_no_0 (char *str, char c)
+{
+  lw6sys_list_t *ret = NULL;
+  char *found = NULL;
+  char *pos = NULL;
+  char *copy = NULL;
+  char *part = NULL;
+
+  copy = lw6sys_str_copy (str);
+  if (copy)
+    {
+      ret = lw6sys_list_new (lw6sys_free_callback);
+      if (ret)
+	{
+	  pos = copy;
+	  while ((found = strchr (pos, c)) != NULL)
+	    {
+	      (*found) = '\0';
+	      part = lw6sys_str_copy (pos);
+	      if (part)
+		{
+		  if ((*part) != '\0')
+		    {
+		      lw6sys_list_push_back (&ret, part);
+		    }
+		  else
+		    {
+		      LW6SYS_FREE (part);
+		    }
+		}
+	      pos = found + 1;
+	    }
+	  part = lw6sys_str_copy (pos);
+	  if (part)
+	    {
+	      if ((*part) != '\0')
+		{
+		  lw6sys_list_push_back (&ret, part);
+		}
+	      else
+		{
+		  LW6SYS_FREE (part);
+		}
+	    }
+	}
+      LW6SYS_FREE (copy);
+    }
+
+  return ret;
+}
