@@ -29,8 +29,12 @@
 #define TEST_KEYWORD_AS "--this-is_a_TEST-KeYWord"
 #define TEST_ARG_KEYWORD "my-option"
 #define TEST_ARG_ARGV_STRING "--my-option=my-value"
-#define CHECKSUM_INT32_DATA 1234
-#define CHECKSUM_INT32_RESULT 0x5d3d512e
+#define TEST_CHECKSUM_STR_DATA "abc"
+#define TEST_CHECKSUM_STR_RESULT 0x2c17398c
+#define TEST_CHECKSUM_INT32_DATA 1234
+#define TEST_CHECKSUM_INT32_RESULT 0x5d3d512e
+#define TEST_CHECKSUM_INT64_DATA 0x1234567890abcdefLL
+#define TEST_CHECKSUM_INT64_RESULT 0x5fb58579
 #define COLOR_ASCII "#12345678"
 #define COLOR_8_R 0x12
 #define COLOR_8_G 0x34
@@ -51,12 +55,16 @@
 #define PATH_RELATIVE "../../foo/bar"
 #define PATH_RELATIVE_UNPARENT "../foo/bar"
 #endif
+#define TEST_PATH_CWD "./"
+#define TEST_PATH_SPLIT "/foo/\\bar\\"
 #define MALLOC_SIZE 1048576
 #define THREAD_N 5
 #define THREAD_SLEEP_MAIN 0.66f
 #define THREAD_SLEEP_CALLBACK 0.2f
 #define THREAD_TEXT "foo bar"
-#define SLEEP_TIME 3
+#define THREAD_STRESS_DURATION 3.0f
+#define TEST_SLEEP_TIME 3
+#define TEST_SLEEP_TIME_SHORT_STEP 0.001f
 #define BLANK_STR "\t "
 #define ASCII_STR "foo,bar"
 #define TEST_ARGC 4
@@ -82,7 +90,7 @@
 #define TEST_HEXA_WH {1,2}
 #define TEST_HEXA_XY {3,4}
 #define TEST_HEXA_COLOR {25,50,75,100}
-#define TEST_KEYWORD "prefix"
+#define TEST_KEYWORD LW6DEF_PREFIX
 #ifdef LW6_MS_WINDOWS
 #define TEST_ENV_CONCAT1 "\\my\\path\\1"
 #define TEST_ENV_CONCAT2 "\\my\\path\\2"
@@ -102,6 +110,8 @@
 #define TEST_REFORMAT_STR2 "this is a very long string it should be cut in some places but wherever there is a very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very-very long word it won't be cut.\n\nIt should even handle newlines in some places but well, this is not absolutely necessary"
 #define TEST_REFORMAT_PREFIX "# "
 #define TEST_REFORMAT_COLUMNS 40
+#define TEST_SPLIT_STR "/foo/bar"
+#define TEST_SPLIT_CHAR 'o'
 #define TEST_SERIALIZE 12345
 #define TEST_SORT_LENGTH 10
 #define TEST_SORT_INT {9,3,4,5,6,8,7,2,0,1};
@@ -119,6 +129,20 @@
 #define TEST_RANDOM_RANGE 1000
 #define TEST_RANDOM_FLOAT_MIN 100.0f
 #define TEST_RANDOM_FLOAT_MAX 101.0f
+#define TEST_PROGRESS_N 7
+#define TEST_HISTORY_MSG1 "1 too old"
+#define TEST_HISTORY_MSG2 "2 too old 2"
+#define TEST_HISTORY_MSG3 "3 oldest"
+#define TEST_HISTORY_MSG4 "4 message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated message this is long and should be truncated"
+#define TEST_HISTORY_MSG5 "5 most recent"
+#define TEST_HISTORY_SLEEP 5.0
+#define TEST_HISTORY_TIMEOUT 2
+#define TEST_SHAPE_W 640
+#define TEST_SHAPE_H 480
+#define TEST_SHAPE_X 123
+#define TEST_SHAPE_Y 456
+#define TEST_SHAPE_MIN 10
+#define TEST_SHAPE_MAX 1000
 
 /*
  * Testing functions in arg.c
@@ -250,7 +274,8 @@ test_assoc ()
     lw6sys_assoc_set (&assoc, "3", (void *) str3);
     lw6sys_assoc_unset (assoc, "1");
     lw6sys_assoc_unset (assoc, "3");
-    assoc_copy = lw6sys_assoc_dup (assoc, (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+    assoc_copy =
+      lw6sys_assoc_dup (assoc, (lw6sys_dup_func_t) lw6sys_str_copy);
     ret = ret && !lw6sys_assoc_has_key (assoc_copy, "1");
     ret = ret && lw6sys_assoc_has_key (assoc_copy, "2");
     ret = ret && !lw6sys_assoc_has_key (assoc_copy, "3");
@@ -311,11 +336,31 @@ test_checksum ()
   {
     u_int32_t checksum = 0;
 
-    lw6sys_checksum_update_int32 (&checksum, CHECKSUM_INT32_DATA);
+    checksum = lw6sys_checksum_str (TEST_CHECKSUM_STR_DATA);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("checksum for \"%s\" is %08x (should be %08x)"),
+		TEST_CHECKSUM_STR_DATA, checksum, TEST_CHECKSUM_STR_RESULT);
+    if (checksum != TEST_CHECKSUM_STR_RESULT)
+      {
+	ret = 0;
+      }
+
+    checksum = lw6sys_checksum_int32 (TEST_CHECKSUM_INT32_DATA);
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("checksum for %d is %08x (should be %08x)"),
-		CHECKSUM_INT32_DATA, checksum, CHECKSUM_INT32_RESULT);
-    if (checksum != CHECKSUM_INT32_RESULT)
+		TEST_CHECKSUM_INT32_DATA, checksum,
+		TEST_CHECKSUM_INT32_RESULT);
+    if (checksum != TEST_CHECKSUM_INT32_RESULT)
+      {
+	ret = 0;
+      }
+
+    checksum = lw6sys_checksum_int64 (TEST_CHECKSUM_INT64_DATA);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("checksum for %lld is %08x (should be %08x)"),
+		TEST_CHECKSUM_INT64_DATA, checksum,
+		TEST_CHECKSUM_INT64_RESULT);
+    if (checksum != TEST_CHECKSUM_INT64_RESULT)
       {
 	ret = 0;
       }
@@ -373,7 +418,7 @@ test_color ()
     rgb_to_hsv_to_rgb ("red", LW6SYS_COLOR_8_RED);
     rgb_to_hsv_to_rgb ("green", LW6SYS_COLOR_8_GREEN);
     rgb_to_hsv_to_rgb ("blue", LW6SYS_COLOR_8_BLUE);
-    rgb_to_hsv_to_rgb ("test", color_8);
+    rgb_to_hsv_to_rgb (LW6DEF_TEST, color_8);
 
     color_8 =
       lw6sys_color_ponderate (LW6SYS_COLOR_8_RED, LW6SYS_COLOR_8_BLUE, 0.5f);
@@ -392,6 +437,9 @@ test_color ()
       lw6sys_color_distance (LW6SYS_COLOR_8_GREEN, LW6SYS_COLOR_8_BLUE);
     lw6sys_log (LW6SYS_LOG_NOTICE,
 		_("distance between green and blue is %.2f"), distance);
+
+    lw6sys_color_8_solid (&color_8);
+    lw6sys_color_f_solid (&color_f);
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -670,6 +718,91 @@ test_file ()
   return ret;
 }
 
+/*
+ * Testing functions in hash.c
+ */
+static int
+test_hash ()
+{
+  int ret = 1;
+  lw6sys_hash_t *hash;
+  lw6sys_hash_t *hash_copy;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("new/delete on hash"));
+    hash = lw6sys_hash_new (NULL, 7);
+    lw6sys_hash_free (hash);
+  }
+
+  {
+    int a = 3, b = 5, c = 7;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("set/unset/has_key/get/map on int hash"));
+    hash = lw6sys_hash_new (NULL, 7);
+    lw6sys_hash_set (hash, "a", (void *) &a);
+    lw6sys_hash_set (hash, "b", (void *) &b);
+    lw6sys_hash_set (hash, "c", (void *) &a);
+    lw6sys_hash_set (hash, "c", (void *) &c);
+    lw6sys_hash_unset (hash, "b");
+    lw6sys_hash_map (hash, &assoc_map_func, &ret);
+    lw6sys_hash_sort_and_map (hash, &assoc_map_func, &ret);
+    ret = ret && lw6sys_hash_has_key (hash, "a");
+    ret = ret && !lw6sys_hash_has_key (hash, "b");
+    ret = ret && !lw6sys_hash_has_key (hash, "this key does not exist");
+    ret = ret && (*((int *) lw6sys_hash_get (hash, "a")) == 3);
+    ret = ret && ((int *) lw6sys_hash_get (hash, "b") == NULL);
+    ret = ret && (*((int *) lw6sys_hash_get (hash, "c")) == 7);
+    lw6sys_hash_free (hash);
+  }
+
+  {
+    char *str1, *str2, *str3;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("testing free_func callback and dup on string hash"));
+    hash = lw6sys_hash_new (&lw6sys_free_callback, 7);
+    str1 = LW6SYS_MALLOC (5);
+    strncpy (str1, "str1", 5);
+    lw6sys_hash_set (hash, "1", (void *) str1);
+    str2 = LW6SYS_MALLOC (5);
+    strncpy (str2, "str2", 5);
+    lw6sys_hash_set (hash, "2", (void *) str2);
+    str3 = LW6SYS_MALLOC (5);
+    strncpy (str3, "str3", 5);
+    lw6sys_hash_set (hash, "3", (void *) str3);
+    lw6sys_hash_unset (hash, "1");
+    lw6sys_hash_unset (hash, "3");
+    hash_copy = lw6sys_hash_dup (hash, (lw6sys_dup_func_t) lw6sys_str_copy);
+    ret = ret && !lw6sys_hash_has_key (hash_copy, "1");
+    ret = ret && lw6sys_hash_has_key (hash_copy, "2");
+    ret = ret && !lw6sys_hash_has_key (hash_copy, "3");
+    ret = ret
+      && strcmp ((char *) lw6sys_hash_get (hash_copy, "2"), "str2") == 0;
+    lw6sys_hash_free (hash_copy);
+    lw6sys_hash_free (hash);
+  }
+
+  {
+    int a = 3, b = 5;
+    lw6sys_list_t *keys;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("testing keys on int hash"));
+    hash = lw6sys_hash_new (NULL, 7);
+    lw6sys_hash_set (hash, "a", (void *) &a);
+    lw6sys_hash_set (hash, "b", (void *) &b);
+    lw6sys_hash_set (hash, "b", (void *) &b);
+    keys = lw6sys_hash_keys (hash);
+    lw6sys_hash_free (hash);
+    ret = ret && lw6sys_list_length (keys) == 2;
+    lw6sys_list_free (keys);
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static int
 test_hexa ()
 {
@@ -857,6 +990,42 @@ test_hexa ()
   return ret;
 }
 
+/*
+ * Testing functions in history.c
+ */
+static int
+test_history ()
+{
+  int ret = 0;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    char **history;
+    char **i;
+
+    lw6sys_history_init ();
+    lw6sys_history_register (TEST_HISTORY_MSG1);
+    lw6sys_history_register (TEST_HISTORY_MSG2);
+    lw6sys_sleep (TEST_HISTORY_SLEEP);
+    lw6sys_history_register (TEST_HISTORY_MSG3);
+    lw6sys_history_register (TEST_HISTORY_MSG4);
+    lw6sys_history_register (TEST_HISTORY_MSG5);
+    history = lw6sys_history_get (TEST_HISTORY_TIMEOUT);
+    if (history)
+      {
+	for (i = history; i[0]; ++i)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE, _("history msg \"%s\""), i[0]);
+	    ret = 1;
+	  }
+	lw6sys_history_free (history);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in i18n.c
  */
@@ -888,6 +1057,91 @@ test_i18n ()
   return ret;
 }
 
+/*
+ * Testing functions in id.c
+ */
+static int
+test_id ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    u_int16_t id_16 = 0;
+    u_int32_t id_32 = 0;
+    u_int64_t id_64 = 0;
+    char *id_str = NULL;
+    u_int64_t id_long = 0;
+
+    id_16 = lw6sys_generate_id_16 ();
+    id_str = lw6sys_id_ltoa (id_16);
+    if (id_str)
+      {
+	id_long = lw6sys_id_atol (id_str);
+	if (id_long == id_16)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("here's a random 16-bit id \"%s\""), id_str);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("erreur converting id, src=%" LW6SYS_PRINTF_LL
+			  "x, dst=%" LW6SYS_PRINTF_LL "x"), (u_int64_t) id_16,
+			id_long);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (id_str);
+      }
+
+    id_32 = lw6sys_generate_id_32 ();
+    id_str = lw6sys_id_ltoa (id_32);
+    if (id_str)
+      {
+	id_long = lw6sys_id_atol (id_str);
+	if (id_long == id_32)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("here's a random 32-bit id \"%s\""), id_str);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("erreur converting id, src=%" LW6SYS_PRINTF_LL
+			  "x, dst=%" LW6SYS_PRINTF_LL "x"), (u_int64_t) id_32,
+			id_long);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (id_str);
+      }
+
+    id_64 = lw6sys_generate_id_64 ();
+    id_str = lw6sys_id_ltoa (id_64);
+    if (id_str)
+      {
+	id_long = lw6sys_id_atol (id_str);
+	if (id_long == id_64)
+	  {
+	    lw6sys_log (LW6SYS_LOG_NOTICE,
+			_("here's a random 64-bit id \"%s\""), id_str);
+	  }
+	else
+	  {
+	    lw6sys_log (LW6SYS_LOG_WARNING,
+			_("erreur converting id, src=%" LW6SYS_PRINTF_LL
+			  "x, dst=%" LW6SYS_PRINTF_LL "x"), (u_int64_t) id_64,
+			id_long);
+	    ret = 0;
+	  }
+	LW6SYS_FREE (id_str);
+      }
+
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 /*
  * Testing functions in keyword.c
  */
@@ -1028,7 +1282,7 @@ test_list ()
     lw6sys_lifo_push (&list, (void *) str3);
     str4 = lw6sys_str_copy ("str4");
     lw6sys_fifo_push (&list, (void *) str4);
-    list_copy = lw6sys_list_dup (list, (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+    list_copy = lw6sys_list_dup (list, (lw6sys_dup_func_t) lw6sys_str_copy);
     ret = ret && lw6sys_list_length (list_copy) == 4;
     lw6sys_list_free (list_copy);
     lw6sys_list_free (list);
@@ -1113,6 +1367,21 @@ test_mem ()
   ptr = (char *) LW6SYS_MALLOC (MALLOC_SIZE * sizeof (char));
   ret = ret && (ptr != NULL);
   LW6SYS_FREE (ptr);
+  // same tests without using macros, fixes link when LW6_OPTIMZE is defined
+  ptr = (char *) lw6sys_malloc (MALLOC_SIZE, __FILE__, __LINE__);
+  if (ptr)
+    {
+      lw6sys_free (ptr, __FILE__, __LINE__);
+    }
+  ptr = (char *) lw6sys_calloc (MALLOC_SIZE, __FILE__, __LINE__);
+  if (ptr)
+    {
+      ptr = lw6sys_realloc (ptr, MALLOC_SIZE + 1, __FILE__, __LINE__);
+      if (ptr)
+	{
+	  lw6sys_free (ptr, __FILE__, __LINE__);
+	}
+    }
   lw6sys_log (LW6SYS_LOG_NOTICE, _("%d megs"), lw6sys_megabytes_available ());
   if (lw6sys_is_big_endian ())
     {
@@ -1254,6 +1523,17 @@ test_nop ()
   LW6SYS_TEST_FUNCTION_END return ret;
 }
 
+/*
+ * Used to test lw6sys_path_split
+ */
+static void
+path_split_func (void *func_data, void *data)
+{
+  char *str = (char *) data;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("path part \"%s\""), str);
+}
+
 /*
  * Testing functions in path.c
  */
@@ -1264,8 +1544,10 @@ test_path ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    char *path;
-    int relative;
+    char *path = NULL;
+    int relative = 0;
+    int cwd = 0;
+    lw6sys_list_t *list = NULL;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("add/strip slash"));
     path = lw6sys_path_add_slash (PATH_WITHOUT_SLASH);
@@ -1289,12 +1571,29 @@ test_path ()
 	LW6SYS_FREE (path);
       }
     relative = lw6sys_path_is_relative (PATH_RELATIVE);
-    if (!relative)
+    if (relative)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("path \"%s\" is relative"), PATH_RELATIVE);
+      }
+    else
       {
 	lw6sys_log (LW6SYS_LOG_WARNING,
 		    _("path \"%s\" not considered relative"), PATH_RELATIVE);
 	ret = 0;
       }
+    cwd = lw6sys_path_is_cwd (TEST_PATH_CWD);
+    if (cwd)
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("path \"%s\" is cwd"), TEST_PATH_CWD);
+      }
+    else
+      {
+	lw6sys_log (LW6SYS_LOG_WARNING,
+		    _("path \"%s\" not considered being cwd"), TEST_PATH_CWD);
+	ret = 0;
+      }
     path = lw6sys_path_parent (PATH_CONCAT);
     if (path)
       {
@@ -1312,6 +1611,65 @@ test_path ()
     path = lw6sys_path_unparent_no_malloc (PATH_RELATIVE);
     lw6sys_log (LW6SYS_LOG_NOTICE, _("unparent path = \"%s\""), path);
     ret = ret && (strcmp (path, PATH_RELATIVE_UNPARENT) == 0);
+
+    list = lw6sys_path_split (TEST_PATH_SPLIT);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("splitting \"%s\""), TEST_PATH_SPLIT);
+    if (list)
+      {
+	lw6sys_list_map (list, path_split_func, NULL);
+	lw6sys_list_free (list);
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
+/*
+ * Testing functions in progress.c
+ */
+static int
+test_progress ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_progress_t progress;
+    lw6sys_progress_t progress1;
+    lw6sys_progress_t progress2;
+    lw6sys_progress_t progress3;
+    lw6sys_progress_t progress4;
+    float value = 0.0f;
+    int i = 0;
+
+    lw6sys_progress_default (&progress, &value);
+    for (i = 0; i < TEST_PROGRESS_N; ++i)
+      {
+	lw6sys_progress_update (&progress, 0, TEST_PROGRESS_N, i);
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("progress=%0.2f"),
+		    *(progress.value));
+      }
+    lw6sys_progress_begin (&progress);
+    lw6sys_progress_half (&progress);
+    lw6sys_progress_end (&progress);
+    lw6sys_progress_split (&progress1, &progress2, &progress);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f"),
+		progress1.min, progress1.max, progress2.min, progress2.max);
+    lw6sys_progress_split3 (&progress1, &progress2, &progress3, &progress);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_
+		("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f progress3 %0.2f/%0.2f"),
+		progress1.min, progress1.max, progress2.min, progress2.max,
+		progress3.min, progress3.max);
+    lw6sys_progress_split4 (&progress1, &progress2, &progress3, &progress4,
+			    &progress);
+    lw6sys_log (LW6SYS_LOG_NOTICE,
+		_
+		("progress1 %0.2f/%0.2f progress2 %0.2f/%0.2f progress3 %0.2f/%0.2f progress4 %0.2f/%0.2f"),
+		progress1.min, progress1.max, progress2.min, progress2.max,
+		progress3.min, progress3.max, progress4.min, progress4.max);
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1328,8 +1686,8 @@ test_random ()
   LW6SYS_TEST_FUNCTION_BEGIN;
 
   {
-    int i;
-    float f;
+    int i = 0;
+    float f = 0.0f;
 
     i = lw6sys_random (TEST_RANDOM_RANGE);
     lw6sys_log (LW6SYS_LOG_NOTICE,
@@ -1539,6 +1897,17 @@ test_sort ()
   return ret;
 }
 
+/*
+ * Used to test lw6sys_split...
+ */
+static void
+str_split_func (void *func_data, void *data)
+{
+  char *str = (char *) data;
+
+  lw6sys_log (LW6SYS_LOG_NOTICE, _("split part \"%s\""), str);
+}
+
 /*
  * Testing functions in str.c
  */
@@ -1550,6 +1919,7 @@ test_str ()
 
   {
     char *str;
+    lw6sys_list_t *list;
 
     lw6sys_log (LW6SYS_LOG_NOTICE, _("testing is_blank on \"%s\""),
 		BLANK_STR);
@@ -1581,6 +1951,20 @@ test_str ()
       {
 	ret = 0;
       }
+
+    list = lw6sys_str_split (TEST_SPLIT_STR, TEST_SPLIT_CHAR);
+    if (list)
+      {
+	lw6sys_list_map (list, str_split_func, NULL);
+	lw6sys_list_free (list);
+      }
+
+    list = lw6sys_str_split_no_0 (TEST_SPLIT_STR, TEST_SPLIT_CHAR);
+    if (list)
+      {
+	lw6sys_list_map (list, str_split_func, NULL);
+	lw6sys_list_free (list);
+      }
   }
 
   LW6SYS_TEST_FUNCTION_END;
@@ -1655,6 +2039,45 @@ test_serial ()
   return ret;
 }
 
+/*
+ * Testing functions in shape.c
+ */
+static int
+test_shape ()
+{
+  int ret = 1;
+  LW6SYS_TEST_FUNCTION_BEGIN;
+
+  {
+    lw6sys_wh_t shape = { TEST_SHAPE_W, TEST_SHAPE_H };
+    lw6sys_xy_t pos = { TEST_SHAPE_X, TEST_SHAPE_Y };
+
+    if (lw6sys_shape_check_min_max (&shape, TEST_SHAPE_MIN, TEST_SHAPE_MAX))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE,
+		    _("shape %dx%d respects [%d-%d] constraints"),
+		    (int) shape.w, (int) shape.h, TEST_SHAPE_MIN,
+		    TEST_SHAPE_MAX);
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (lw6sys_shape_check_pos (&shape, &pos))
+      {
+	lw6sys_log (LW6SYS_LOG_NOTICE, _("pos %d,%d is inside shape %d,%d"),
+		    (int) pos.x, (int) pos.y, (int) shape.w, (int) shape.h);
+      }
+    else
+      {
+	ret = 0;
+      }
+  }
+
+  LW6SYS_TEST_FUNCTION_END;
+  return ret;
+}
+
 static void
 thread_func (void *callback_data)
 {
@@ -1673,13 +2096,40 @@ thread_func (void *callback_data)
 static void
 thread_join (void *callback_data)
 {
-  /*
-   * A more complex example would process more complex
-   * freeing of resources here.
-   */
   LW6SYS_FREE (callback_data);
 }
 
+typedef struct thread_stress_data_s
+{
+  int run;
+  int count;
+  int ret;
+} thread_stress_data_t;
+
+static void
+thread_stress_func (void *callback_data)
+{
+  thread_stress_data_t *thread_stress_data = NULL;
+  void *child;
+
+  thread_stress_data = (thread_stress_data_t *) callback_data;
+
+  while (thread_stress_data->run)
+    {
+      child = lw6sys_thread_create (NULL, NULL, NULL, 0);
+      if (child)
+	{
+	  lw6sys_thread_join (child);
+	}
+      else
+	{
+	  lw6sys_log (LW6SYS_LOG_WARNING, _("unable to create child"));
+	  thread_stress_data->ret = 0;
+	}
+      thread_stress_data->count++;
+    }
+}
+
 /*
  * Testing functions in thread.c
  */
@@ -1693,8 +2143,9 @@ test_thread ()
     void *thread_handler = NULL;
     char *text = lw6sys_str_copy (THREAD_TEXT);
     int i = 0;
+    thread_stress_data_t thread_stress_data;
 
-    ret = 0;
+    ret = 1;
     if (text)
       {
 	thread_handler =
@@ -1710,7 +2161,41 @@ test_thread ()
 	      }
 
 	    lw6sys_thread_join (thread_handler);
-	    ret = 1;
+	  }
+	else
+	  {
+	    ret = 0;
+	  }
+      }
+    else
+      {
+	ret = 0;
+      }
+    if (ret)
+      {
+	thread_stress_data.run = 1;
+	thread_stress_data.count = 0;
+	thread_stress_data.ret = 1;
+	thread_handler =
+	  lw6sys_thread_create (&thread_stress_func, NULL,
+				&thread_stress_data, 0);
+	if (thread_handler)
+	  {
+	    lw6sys_sleep (THREAD_STRESS_DURATION);
+	    thread_stress_data.run = 0;
+	    lw6sys_thread_join (thread_handler);
+	    ret = ret && thread_stress_data.ret;
+	    if (ret)
+	      {
+		lw6sys_log (LW6SYS_LOG_NOTICE, _("%d threads (%0.1f/sec)"),
+			    thread_stress_data.count,
+			    (float) (((float) thread_stress_data.count) /
+				     THREAD_STRESS_DURATION));
+	      }
+	  }
+	else
+	  {
+	    ret = 0;
 	  }
       }
   }
@@ -1728,11 +2213,29 @@ test_time ()
   int ret = 1;
   LW6SYS_TEST_FUNCTION_BEGIN;
 
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %lld"), lw6sys_timestamp ());
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %lld"), lw6sys_uptime ());
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), SLEEP_TIME);
-  lw6sys_sleep (SLEEP_TIME);
-  lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %lld"), lw6sys_uptime ());
+  {
+    int i = 0;
+    int nb_steps = 0;
+    int last_uptime;
+
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("timestamp %lld"), lw6sys_timestamp ());
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("uptime %d"), lw6sys_uptime ());
+    last_uptime = lw6sys_uptime ();
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds"), TEST_SLEEP_TIME);
+    lw6sys_sleep (TEST_SLEEP_TIME);
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %d"),
+		lw6sys_uptime () - last_uptime);
+    last_uptime = lw6sys_uptime ();
+    nb_steps = TEST_SLEEP_TIME / TEST_SLEEP_TIME_SHORT_STEP;
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("sleep %d seconds using %d %0.6f steps"),
+		TEST_SLEEP_TIME, nb_steps, TEST_SLEEP_TIME_SHORT_STEP);
+    for (i = 0; i < nb_steps; ++i)
+      {
+	lw6sys_sleep (TEST_SLEEP_TIME_SHORT_STEP);
+      }
+    lw6sys_log (LW6SYS_LOG_NOTICE, _("lasted %d"),
+		lw6sys_uptime () - last_uptime);
+  }
 
   LW6SYS_TEST_FUNCTION_END;
   return ret;
@@ -1755,11 +2258,12 @@ lw6sys_test ()
 
   ret = test_arg () && test_assoc () && test_build () && test_checksum ()
     && test_color () && test_convert () && test_dump () && test_env ()
-    && test_file () && test_hexa () && test_i18n () && test_keyword ()
-    && test_list () && test_log () && test_mem () && test_mutex ()
-    && test_options () && test_nop () && test_path () && test_random ()
-    && test_sdl () && test_serial () && test_sort () && test_str ()
-    && test_thread () && test_time ();
+    && test_file () && test_hash () && test_hexa () && test_history ()
+    && test_i18n () && test_id () && test_keyword () && test_list ()
+    && test_log () && test_mem () && test_mutex () && test_options ()
+    && test_nop () && test_path () && test_progress () && test_random ()
+    && test_sdl () && test_serial () && test_shape () && test_sort ()
+    && test_str () && test_thread () && test_time ();
 
   return ret;
 }
