@@ -84,13 +84,29 @@ typedef unsigned long long u_int64_t;
 #endif
 #endif // MS_WINDOWS
 
-#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_default_memory_bazooka(); }
+#ifndef char_ptr_t
+typedef char *char_ptr_t;
+#endif
+
+/*
+ * Yet another MS-windows hack, printf %ll doesn't work
+ * one needs to use a special "%I64" instead...
+ */
+#ifdef LW6_MS_WINDOWS
+#define LW6SYS_PRINTF_LL "I64"
+#else
+#define LW6SYS_PRINTF_LL "ll"
+#endif
+
+#include "../def/def.h"
+
+#define LW6SYS_MAIN_BEGIN { setlocale (LC_ALL, ""); bindtextdomain (lw6sys_build_get_package_tarname (), lw6sys_build_get_localedir ()); textdomain (lw6sys_build_get_package_tarname ()); lw6sys_time_init(); lw6sys_history_init(); lw6sys_default_memory_bazooka(); }
 #define LW6SYS_MAIN_END { ret = lw6sys_check_thread_count () && ret; ret = lw6sys_memory_bazooka_report() && ret; lw6sys_clear_memory_bazooka(); }
 
 #define LW6SYS_TEST_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_NOTICE,_("running tests in function \"%s\""),__FUNCTION__); }
 #define LW6SYS_TEST_FUNCTION_END   if (ret) { lw6sys_log(LW6SYS_LOG_NOTICE,_("tests in \"%s\" OK"),__FUNCTION__); } else { lw6sys_log(LW6SYS_LOG_WARNING,_("tests in \"%s\" failed"),__FUNCTION__); }
-#define LW6SYS_BACKEND_FUNCION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin backend function \"%s\""),__FUNCTION__); }
-#define LW6SYS_BACKEND_FUNCION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end backend function \"%s\""),__FUNCTION__); }
+#define LW6SYS_BACKEND_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin backend function \"%s\""),__FUNCTION__); }
+#define LW6SYS_BACKEND_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end backend function \"%s\""),__FUNCTION__); }
 
 #define LW6SYS_SCRIPT_FUNCTION_BEGIN { lw6sys_log(LW6SYS_LOG_DEBUG,_("begin script function \"%s\""),__FUNCTION__); }
 #define LW6SYS_SCRIPT_FUNCTION_END { lw6sys_log(LW6SYS_LOG_DEBUG,_("end script function \"%s\""),__FUNCTION__); }
@@ -173,34 +189,65 @@ typedef struct lw6sys_color_hsv_s
 }
 lw6sys_color_hsv_t;
 
+typedef struct lw6sys_progress_s
+{
+  float min;
+  float max;
+  float *value;
+} lw6sys_progress_t;
+
+typedef struct lw6sys_module_pedigree_s
+{
+  char *id;
+  char *category;
+  char *name;
+  char *readme;
+  char *version;
+  char *copyright;
+  char *license;
+  char *date;
+  char *time;
+} lw6sys_module_pedigree_t;
+
 #define LW6SYS_SIZEOF_INT64 8
 #define LW6SYS_SIZEOF_INT32 4
 #define LW6SYS_SIZEOF_INT16 2
 
-typedef void (*LW6SYS_FREE_FUNC) (void *data);
-typedef void (*lw6sys_assoc_t_CALLBACK_FUNC) (void *func_data, char *key,
+typedef void (*lw6sys_free_func_t) (void *data);
+typedef void (*lw6sys_assoc_callback_func_t) (void *func_data, char *key,
 					      void *value);
-typedef void (*lw6sys_list_t_CALLBACK_FUNC) (void *func_data, void *data);
-typedef void *(*LW6SYS_DUP_FUNC) (void *data);
-typedef void (*LW6SYS_THREAD_CALLBACK_FUNC) (void *callback_data);
+typedef void (*lw6sys_list_callback_func_t) (void *func_data, void *data);
+typedef void *(*lw6sys_dup_func_t) (void *data);
+typedef void (*lw6sys_thread_callback_func_t) (void *callback_data);
 
 typedef struct lw6sys_assoc_s
 {
   char *key;
   void *value;
-  LW6SYS_FREE_FUNC free_func;
+  lw6sys_free_func_t free_func;
   void *next_item;		// lw6sys_assoc_t *
 }
 lw6sys_assoc_t;
 
+typedef struct lw6sys_hash_s
+{
+  int size;
+  lw6sys_assoc_t **entries;
+  lw6sys_free_func_t free_func;
+}
+lw6sys_hash_t;
+
 typedef struct lw6sys_list_s
 {
   void *data;
-  LW6SYS_FREE_FUNC free_func;
+  lw6sys_free_func_t free_func;
   void *next_item;		// lw6sys_list_t *
 }
 lw6sys_list_t;
 
+typedef int (*lw6sys_sort_callback_func_t) (lw6sys_list_t ** list_a,
+					    lw6sys_list_t ** list_b);
+
 typedef struct lw6sys_hexa_serializer_s
 {
   char *buf;
@@ -209,9 +256,6 @@ typedef struct lw6sys_hexa_serializer_s
 }
 lw6sys_hexa_serializer_t;
 
-typedef int (*LW6SYS_SORT_CALLBACK_FUNC) (lw6sys_list_t ** list_a,
-					  lw6sys_list_t ** list_b);
-
 extern lw6sys_color_f_t LW6SYS_COLOR_F_WHITE;
 extern lw6sys_color_f_t LW6SYS_COLOR_F_BLACK;
 extern lw6sys_color_f_t LW6SYS_COLOR_F_RED;
@@ -272,7 +316,7 @@ extern char *lw6sys_arg_get_value_with_env (int argc, char *argv[],
 					    char *keyword);
 
 /* sys-assoc.c */
-extern lw6sys_assoc_t *lw6sys_assoc_new (LW6SYS_FREE_FUNC free_func);
+extern lw6sys_assoc_t *lw6sys_assoc_new (lw6sys_free_func_t free_func);
 extern void lw6sys_assoc_free (lw6sys_assoc_t * assoc);
 extern int lw6sys_assoc_has_key (lw6sys_assoc_t * assoc, char *key);
 extern void *lw6sys_assoc_get (lw6sys_assoc_t * assoc, char *key);
@@ -281,13 +325,13 @@ extern void lw6sys_assoc_set (lw6sys_assoc_t ** assoc, char *key,
 extern void lw6sys_assoc_unset (lw6sys_assoc_t * assoc, char *key);
 extern lw6sys_list_t *lw6sys_assoc_keys (lw6sys_assoc_t * assoc);
 extern void lw6sys_assoc_map (lw6sys_assoc_t * assoc,
-			      lw6sys_assoc_t_CALLBACK_FUNC func,
+			      lw6sys_assoc_callback_func_t func,
 			      void *func_data);
 extern void lw6sys_assoc_sort_and_map (lw6sys_assoc_t * assoc,
-				       lw6sys_assoc_t_CALLBACK_FUNC func,
+				       lw6sys_assoc_callback_func_t func,
 				       void *func_data);
 extern lw6sys_assoc_t *lw6sys_assoc_dup (lw6sys_assoc_t * assoc,
-					 LW6SYS_DUP_FUNC dup_func);
+					 lw6sys_dup_func_t dup_func);
 
 /* sys-bazooka.c */
 extern int lw6sys_default_memory_bazooka ();
@@ -332,21 +376,28 @@ extern char *lw6sys_build_get_enable_mod_gl ();
 extern char *lw6sys_build_get_enable_mod_csound ();
 extern char *lw6sys_build_get_enable_mod_ogg ();
 extern char *lw6sys_build_get_enable_mod_http ();
+extern char *lw6sys_build_get_enable_optimize ();
 extern char *lw6sys_build_get_enable_allinone ();
 extern char *lw6sys_build_get_enable_fullstatic ();
 extern char *lw6sys_build_get_enable_gprof ();
+extern char *lw6sys_build_get_enable_gcov ();
 extern char *lw6sys_build_get_enable_valgrind ();
 extern void lw6sys_build_log_pedigree ();
 
 /* sys-checksum.c */
 extern u_int32_t lw6sys_checksum (unsigned char *data, int len);
+extern u_int32_t lw6sys_checksum_str (char *value);
 extern u_int32_t lw6sys_checksum_int32 (u_int32_t value);
+extern u_int32_t lw6sys_checksum_int64 (u_int64_t value);
 extern u_int32_t lw6sys_checksum_wh (lw6sys_wh_t * wh);
 extern u_int32_t lw6sys_checksum_xy (lw6sys_xy_t * xy);
 extern void lw6sys_checksum_update (u_int32_t * checksum,
 				    unsigned char *data, int len);
+extern void lw6sys_checksum_update_str (u_int32_t * checksum, char *value);
 extern void lw6sys_checksum_update_int32 (u_int32_t * checksum,
 					  int32_t value);
+extern void lw6sys_checksum_update_int64 (u_int32_t * checksum,
+					  int64_t value);
 extern void lw6sys_checksum_update_wh (u_int32_t * checksum,
 				       lw6sys_wh_t * wh);
 extern void lw6sys_checksum_update_xy (u_int32_t * checksum,
@@ -377,6 +428,8 @@ extern lw6sys_color_8_t lw6sys_color_ponderate (lw6sys_color_8_t color1,
 						float coeff);
 extern float lw6sys_color_distance (lw6sys_color_8_t color1,
 				    lw6sys_color_8_t color2);
+extern void lw6sys_color_8_solid (lw6sys_color_8_t * color);
+extern void lw6sys_color_f_solid (lw6sys_color_f_t * color);
 
 /* sys-convert.c */
 extern int lw6sys_atoi (char *str);
@@ -411,6 +464,24 @@ extern int lw6sys_clear_file (char *filename);
 extern char *lw6sys_read_file_content (char *filename);
 extern int lw6sys_write_file_content (char *filename, char *content);
 
+/* sys-hash.c */
+extern lw6sys_hash_t *lw6sys_hash_new (lw6sys_free_func_t free_func,
+				       int size);
+extern void lw6sys_hash_free (lw6sys_hash_t * hash);
+extern int lw6sys_hash_has_key (lw6sys_hash_t * hash, char *key);
+extern void *lw6sys_hash_get (lw6sys_hash_t * hash, char *key);
+extern void lw6sys_hash_set (lw6sys_hash_t * hash, char *key, void *value);
+extern void lw6sys_hash_unset (lw6sys_hash_t * hash, char *key);
+extern lw6sys_list_t *lw6sys_hash_keys (lw6sys_hash_t * hash);
+extern void lw6sys_hash_map (lw6sys_hash_t * hash,
+			     lw6sys_assoc_callback_func_t func,
+			     void *func_data);
+extern void lw6sys_hash_sort_and_map (lw6sys_hash_t * hash,
+				      lw6sys_assoc_callback_func_t func,
+				      void *func_data);
+extern lw6sys_hash_t *lw6sys_hash_dup (lw6sys_hash_t * hash,
+				       lw6sys_dup_func_t dup_func);
+
 /* sys-hexa.c */
 extern lw6sys_hexa_serializer_t *lw6sys_hexa_serializer_new (char
 							     *hexa_string);
@@ -467,10 +538,26 @@ extern int lw6sys_hexa_serializer_pop_wh (lw6sys_hexa_serializer_t *
 extern int lw6sys_hexa_serializer_pop_color (lw6sys_hexa_serializer_t *
 					     hexa_serializer,
 					     lw6sys_color_8_t * value);
+/* sys-history.c */
+extern void lw6sys_history_init ();
+extern void lw6sys_history_register (char *msg);
+extern char **lw6sys_history_get (int64_t timeout);
+extern void lw6sys_history_free (char **history);
 
 /* sys-i18n.c */
 extern char *lw6sys_locale_to_utf8 (char *string);
 
+/* sys-id.c */
+extern u_int16_t lw6sys_generate_id_16 ();
+extern u_int32_t lw6sys_generate_id_32 ();
+extern u_int64_t lw6sys_generate_id_64 ();
+extern int lw6sys_check_id_16 (u_int16_t id_16);
+extern int lw6sys_check_id_32 (u_int32_t id_32);
+extern int lw6sys_check_id_64 (u_int64_t id_64);
+extern int lw6sys_check_id (u_int64_t id_64);
+extern char *lw6sys_id_ltoa (u_int64_t id);
+extern u_int64_t lw6sys_id_atol (char *id);
+
 /* sys-keyword.c */
 extern char *lw6sys_keyword_as_key (char *keyword);
 extern char *lw6sys_keyword_as_arg (char *keyword);
@@ -478,13 +565,13 @@ extern char *lw6sys_keyword_as_env (char *keyword);
 extern char *lw6sys_keyword_as_xml (char *keyword);
 
 /* sys-list.c */
-extern lw6sys_list_t *lw6sys_list_new (LW6SYS_FREE_FUNC free_func);
+extern lw6sys_list_t *lw6sys_list_new (lw6sys_free_func_t free_func);
 extern void lw6sys_list_free (lw6sys_list_t * list);
 extern lw6sys_list_t *lw6sys_list_next (lw6sys_list_t * list);
 extern int lw6sys_list_is_empty (lw6sys_list_t * list);
 extern int lw6sys_list_length (lw6sys_list_t * list);
 extern void lw6sys_list_map (lw6sys_list_t * list,
-			     lw6sys_list_t_CALLBACK_FUNC func,
+			     lw6sys_list_callback_func_t func,
 			     void *func_data);
 extern void lw6sys_list_push_front (lw6sys_list_t ** list, void *data);
 extern void *lw6sys_list_pop_front (lw6sys_list_t ** list);
@@ -495,7 +582,7 @@ extern void *lw6sys_lifo_pop (lw6sys_list_t ** list);
 extern void lw6sys_fifo_push (lw6sys_list_t ** list, void *data);
 extern void *lw6sys_fifo_pop (lw6sys_list_t ** list);
 extern lw6sys_list_t *lw6sys_list_dup (lw6sys_list_t * list,
-				       LW6SYS_DUP_FUNC dup_func);
+				       lw6sys_dup_func_t dup_func);
 
 /* sys-log.c */
 extern void lw6sys_log_set_file (char *filename);
@@ -506,10 +593,17 @@ extern int lw6sys_log_get_level ();
 extern void lw6sys_log_set_level (int level);
 
 /* sys-mem.c */
-#define LW6SYS_MALLOC(SIZE) lw6sys_malloc((SIZE),__FILE__,__LINE__);
-#define LW6SYS_CALLOC(SIZE) lw6sys_calloc((SIZE),__FILE__,__LINE__);
-#define LW6SYS_REALLOC(PTR,SIZE) lw6sys_realloc((PTR),(SIZE),__FILE__,__LINE__);
-#define LW6SYS_FREE(PTR) lw6sys_free((PTR),__FILE__,__LINE__);
+#ifdef LW6_OPTIMIZE
+#define LW6SYS_MALLOC(SIZE) malloc(SIZE)
+#define LW6SYS_CALLOC(SIZE) calloc(SIZE)
+#define LW6SYS_REALLOC(SIZE) realloc(SIZE)
+#define LW6SYS_FREE(PTR) free(PTR)
+#else
+#define LW6SYS_MALLOC(SIZE) lw6sys_malloc((SIZE),__FILE__,__LINE__)
+#define LW6SYS_CALLOC(SIZE) lw6sys_calloc((SIZE),__FILE__,__LINE__)
+#define LW6SYS_REALLOC(PTR,SIZE) lw6sys_realloc((PTR),(SIZE),__FILE__,__LINE__)
+#define LW6SYS_FREE(PTR) lw6sys_free((PTR),__FILE__,__LINE__)
+#endif
 
 extern void *lw6sys_malloc (int size, char *file, int line);
 extern void *lw6sys_calloc (int size, char *file, int line);
@@ -566,15 +660,38 @@ extern int lw6sys_create_dir_silent (char *dirname);
 extern char *lw6sys_path_add_slash (char *path);
 extern char *lw6sys_path_strip_slash (char *path);
 extern char *lw6sys_path_concat (char *path1, char *path2);
-int lw6sys_path_is_relative (char *path);
-char *lw6sys_path_parent (char *path);
-char *lw6sys_path_unparent (char *path);
-char *lw6sys_path_unparent_no_malloc (char *path);
+extern lw6sys_list_t *lw6sys_path_split (char *path);
+extern int lw6sys_path_is_relative (char *path);
+extern int lw6sys_path_is_cwd (char *path);
+extern char *lw6sys_path_parent (char *path);
+extern char *lw6sys_path_unparent (char *path);
+extern char *lw6sys_path_unparent_no_malloc (char *path);
 
 /* sys-print.c */
 extern void lw6sys_print_xml_header (FILE * f, char *comment);
 extern void lw6sys_print_xml_footer (FILE * f);
 
+/* sys-progress.c */
+extern void lw6sys_progress_default (lw6sys_progress_t * progress,
+				     float *value);
+extern void lw6sys_progress_update (lw6sys_progress_t * progress, int min,
+				    int max, int current);
+extern void lw6sys_progress_split (lw6sys_progress_t * progress1,
+				   lw6sys_progress_t * progress2,
+				   lw6sys_progress_t * progress_src);
+extern void lw6sys_progress_split3 (lw6sys_progress_t * progress1,
+				    lw6sys_progress_t * progress2,
+				    lw6sys_progress_t * progress3,
+				    lw6sys_progress_t * progress_src);
+extern void lw6sys_progress_split4 (lw6sys_progress_t * progress1,
+				    lw6sys_progress_t * progress2,
+				    lw6sys_progress_t * progress3,
+				    lw6sys_progress_t * progress4,
+				    lw6sys_progress_t * progress_src);
+extern void lw6sys_progress_begin (lw6sys_progress_t * progress);
+extern void lw6sys_progress_half (lw6sys_progress_t * progress);
+extern void lw6sys_progress_end (lw6sys_progress_t * progress);
+
 /* sys-random.c */
 extern u_int32_t lw6sys_random (u_int32_t range);
 extern float lw6sys_random_float (float min, float max);
@@ -591,20 +708,26 @@ extern int32_t lw6sys_unserialize_int32 (unsigned char *data);
 extern void lw6sys_serialize_int16 (unsigned char *data, int16_t value);
 extern int16_t lw6sys_unserialize_int16 (unsigned char *data);
 
+/* sys-shape.c */
+extern int lw6sys_shape_check_min_max (lw6sys_wh_t * shape, int min,
+				       int max);;
+extern int lw6sys_shape_check_pos (lw6sys_wh_t * shape, lw6sys_xy_t * pos);
+
 /* sys-sort.c */
-int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
-			      lw6sys_list_t ** list_b);
-int lw6sys_sort_int_desc_callback (lw6sys_list_t ** list_a,
-				   lw6sys_list_t ** list_b);
-int lw6sys_sort_float_callback (lw6sys_list_t ** list_a,
-				lw6sys_list_t ** list_b);
-int lw6sys_sort_float_desc_callback (lw6sys_list_t ** list_a,
+extern int lw6sys_sort_int_callback (lw6sys_list_t ** list_a,
 				     lw6sys_list_t ** list_b);
-int lw6sys_sort_str_callback (lw6sys_list_t ** list_a,
-			      lw6sys_list_t ** list_b);
-int lw6sys_sort_str_desc_callback (lw6sys_list_t ** list_a,
-				   lw6sys_list_t ** list_b);
-void lw6sys_sort (lw6sys_list_t ** list, LW6SYS_SORT_CALLBACK_FUNC sort_func);
+extern int lw6sys_sort_int_desc_callback (lw6sys_list_t ** list_a,
+					  lw6sys_list_t ** list_b);
+extern int lw6sys_sort_float_callback (lw6sys_list_t ** list_a,
+				       lw6sys_list_t ** list_b);
+extern int lw6sys_sort_float_desc_callback (lw6sys_list_t ** list_a,
+					    lw6sys_list_t ** list_b);
+extern int lw6sys_sort_str_callback (lw6sys_list_t ** list_a,
+				     lw6sys_list_t ** list_b);
+extern int lw6sys_sort_str_desc_callback (lw6sys_list_t ** list_a,
+					  lw6sys_list_t ** list_b);
+extern void lw6sys_sort (lw6sys_list_t ** list,
+			 lw6sys_sort_callback_func_t sort_func);
 
 /* sys-str.c */
 extern char *lw6sys_str_copy (char *src);
@@ -615,14 +738,16 @@ extern int lw6sys_skip_blanks (char **str_ptr);
 extern void lw6sys_str_cleanup (char *str);
 extern char *lw6sys_str_reformat (char *str, char *prefix, int nb_columns);
 extern char *lw6sys_eol ();
+extern lw6sys_list_t *lw6sys_str_split (char *str, char c);
+extern lw6sys_list_t *lw6sys_str_split_no_0 (char *str, char c);
 
 /* sys-test.c */
 extern int lw6sys_test ();
 
 /* sys-thread.c */
 extern void
-  *lw6sys_thread_create (LW6SYS_THREAD_CALLBACK_FUNC callback_func,
-			 LW6SYS_THREAD_CALLBACK_FUNC callback_join,
+  *lw6sys_thread_create (lw6sys_thread_callback_func_t callback_func,
+			 lw6sys_thread_callback_func_t callback_join,
 			 void *callback_data, int flag);
 extern int lw6sys_thread_is_callback_done (void *thread_handler);
 extern int lw6sys_thread_get_id (void *thread_handler);
@@ -635,7 +760,7 @@ extern int lw6sys_check_thread_count ();
 
 /* sys-time.c */
 extern int64_t lw6sys_timestamp ();
-extern int64_t lw6sys_uptime ();
+extern int32_t lw6sys_uptime ();
 extern void lw6sys_sleep (float seconds);
 extern void lw6sys_time_init ();
 
