@@ -25,6 +25,17 @@
 
 #include "tsk.h"
 
+#define _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN 0.01f
+#define _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP 0.02f
+#define _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP 0.65f
+#define _LW6TSK_LOADER_PROGRESS_STAGE1_END 0.66f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN 0.67f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT 0.70f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT 0.89f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE 0.90f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE 0.99f
+#define _LW6TSK_LOADER_PROGRESS_STAGE2_END 1.0f
+
 typedef struct _lw6tsk_loader_stage1_s
 {
   char *map_path;
@@ -38,18 +49,12 @@ _lw6tsk_loader_stage1_t;
 
 typedef struct _lw6tsk_loader_stage2_s
 {
-  lw6map_level_t *level;
-  lw6ker_game_struct_t *game_struct;
-}
-_lw6tsk_loader_stage2_t;
-
-typedef struct _lw6tsk_loader_stage3_s
-{
+  lw6map_level_t *src;
   lw6map_level_t *level;
   lw6ker_game_struct_t *game_struct;
   lw6ker_game_state_t *game_state;
 }
-_lw6tsk_loader_stage3_t;
+_lw6tsk_loader_stage2_t;
 
 typedef struct _lw6tsk_loader_data_s
 {
@@ -58,9 +63,9 @@ typedef struct _lw6tsk_loader_data_s
   void *mutex;
   int stage;
   int request_number;
+  float *progress;
   _lw6tsk_loader_stage1_t stage1;
   _lw6tsk_loader_stage2_t stage2;
-  _lw6tsk_loader_stage3_t stage3;
 }
 _lw6tsk_loader_data_t;
 
