@@ -101,41 +101,46 @@ stage1_clear (_lw6tsk_loader_stage1_t * stage1)
 }
 
 static void
-stage2_clear (_lw6tsk_loader_stage2_t * stage2)
+stage2_clear_request (_lw6tsk_loader_stage2_t * stage2)
 {
+  if (stage2->src)
+    {
+      lw6map_free (stage2->src);
+      stage2->src = NULL;
+    }
+}
+
+static void
+stage2_clear_response (_lw6tsk_loader_stage2_t * stage2)
+{
+  if (stage2->game_state)
+    {
+      lw6ker_game_state_free (stage2->game_state);
+      stage2->game_state = NULL;
+    }
   if (stage2->game_struct)
     {
       lw6ker_game_struct_free (stage2->game_struct);
+      stage2->game_struct = NULL;
     }
   if (stage2->level)
     {
       lw6map_free (stage2->level);
+      stage2->level = NULL;
     }
-  memset (stage2, 0, sizeof (_lw6tsk_loader_stage2_t));
 }
 
 static void
-stage3_clear (_lw6tsk_loader_stage3_t * stage3)
+stage2_clear (_lw6tsk_loader_stage2_t * stage2)
 {
-  if (stage3->game_state)
-    {
-      lw6ker_game_state_free (stage3->game_state);
-    }
-  if (stage3->game_struct)
-    {
-      lw6ker_game_struct_free (stage3->game_struct);
-    }
-  if (stage3->level)
-    {
-      lw6map_free (stage3->level);
-    }
-  memset (stage3, 0, sizeof (_lw6tsk_loader_stage3_t));
+  stage2_clear_request (stage2);
+  stage2_clear_response (stage2);
+  memset (stage2, 0, sizeof (_lw6tsk_loader_stage2_t));
 }
 
 static void
 clear (_lw6tsk_loader_data_t * loader_data)
 {
-  stage3_clear (&(loader_data->stage3));
   stage2_clear (&(loader_data->stage2));
   stage1_clear (&(loader_data->stage1));
 }
@@ -150,47 +155,75 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
   lw6sys_assoc_t *forced_param = NULL;
   lw6map_level_t *level = NULL;
   lw6sys_wh_t display_shape = { 0, 0 };
+  lw6map_level_t *src2 = NULL;
+  lw6sys_progress_t progress;
+  float dummy = 0.0f;
+  int ok = 0;
+
+  progress.value = loader_data->progress;
+  if (!(progress.value))
+    {
+      progress.value = &dummy;
+    }
 
   LOADER_LOCK;
   request_number = loader_data->request_number;
 
   if (loader_data->stage1.map_path && loader_data->stage1.relative_path)
     {
+      lw6sys_log (LW6SYS_LOG_INFO,
+		  _
+		  ("async load stage1, request_number %d, level \"%s\""),
+		  request_number, loader_data->stage1.relative_path);
+
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN;
       map_path = lw6sys_str_copy (loader_data->stage1.map_path);
       relative_path = lw6sys_str_copy (loader_data->stage1.relative_path);
       default_param =
 	lw6sys_assoc_dup (loader_data->stage1.default_param,
-			  (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+			  (lw6sys_dup_func_t) lw6sys_str_copy);
       forced_param =
 	lw6sys_assoc_dup (loader_data->stage1.forced_param,
-			  (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+			  (lw6sys_dup_func_t) lw6sys_str_copy);
       display_shape = loader_data->stage1.display_shape;
+
       stage1_clear_request (&(loader_data->stage1));
     }
   LOADER_UNLOCK;
 
   if (map_path && relative_path)
     {
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
+      progress.min = _LW6TSK_LOADER_PROGRESS_STAGE1_BEGIN_MAP;
+      progress.max = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
       level =
 	lw6ldr_read_relative (map_path, relative_path, default_param,
-			      forced_param, &display_shape);
+			      forced_param, &display_shape, &progress);
+      if (level)
+	{
+	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_END_MAP;
+	}
     }
 
   if (map_path)
     {
       LW6SYS_FREE (map_path);
+      map_path = NULL;
     }
   if (relative_path)
     {
       LW6SYS_FREE (relative_path);
+      relative_path = NULL;
     }
   if (default_param)
     {
       lw6sys_assoc_free (default_param);
+      default_param = NULL;
     }
   if (forced_param)
     {
       lw6sys_assoc_free (forced_param);
+      forced_param = NULL;
     }
 
   if (level)
@@ -200,6 +233,7 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
       repr = lw6map_repr (level);
       if (repr)
 	{
+	  src2 = lw6map_dup (level);
 	  LOADER_LOCK;
 	  if (request_number == loader_data->request_number)
 	    {
@@ -209,7 +243,9 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 			  _
 			  ("async load stage1 done, request_number %d, level \"%s\""),
 			  request_number, repr);
-	      // todo: push request to stage2...
+	      stage2_clear_request (&(loader_data->stage2));
+	      loader_data->stage2.src = src2;
+	      ok = 1;
 	    }
 	  else if (request_number < loader_data->request_number)
 	    {
@@ -217,7 +253,13 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 			  _
 			  ("async load stage1 abort, request number %d < %d, level \"%s\""),
 			  request_number, loader_data->request_number, repr);
+	      if (src2)
+		{
+		  lw6map_free (src2);
+		  src2 = NULL;
+		}
 	      lw6map_free (level);
+	      level = NULL;
 	    }
 	  else
 	    {
@@ -228,18 +270,132 @@ stage1 (_lw6tsk_loader_data_t * loader_data)
 	    }
 	  LOADER_UNLOCK;
 	  LW6SYS_FREE (repr);
+	  repr = NULL;
 	}
     }
+  if (ok)
+    {
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE1_END;
+    }
 }
 
 static void
 stage2 (_lw6tsk_loader_data_t * loader_data)
 {
-}
+  int request_number = 0;
+  lw6map_level_t *level = NULL;
+  lw6ker_game_struct_t *game_struct = NULL;
+  lw6ker_game_state_t *game_state = NULL;
+  lw6sys_progress_t progress;
+  float dummy = 0.0f;
+  int ok = 0;
 
-static void
-stage3 (_lw6tsk_loader_data_t * loader_data)
-{
+  progress.value = loader_data->progress;
+  if (!(progress.value))
+    {
+      progress.value = &dummy;
+    }
+
+  LOADER_LOCK;
+  request_number = loader_data->request_number;
+
+  if (loader_data->stage2.src)
+    {
+      lw6sys_log (LW6SYS_LOG_INFO,
+		  _("async load stage2, request_number %d"), request_number);
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN;
+
+      level = lw6map_dup (loader_data->stage2.src);
+
+      stage2_clear_request (&(loader_data->stage2));
+    }
+  LOADER_UNLOCK;
+
+  if (level)
+    {
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT;
+      progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STRUCT;
+      progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT;
+      game_struct = lw6ker_game_struct_new (level, &progress);
+      if (game_struct)
+	{
+	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STRUCT;
+	}
+      else
+	{
+	  lw6map_free (level);
+	  level = NULL;
+	}
+    }
+  if (level && game_struct)
+    {
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE;
+      progress.min = _LW6TSK_LOADER_PROGRESS_STAGE2_BEGIN_STATE;
+      progress.max = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE;
+      game_state = lw6ker_game_state_new (game_struct, &progress);
+      if (game_state)
+	{
+	  (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_END_STATE;
+	}
+      else
+	{
+	  lw6ker_game_struct_free (game_struct);
+	  game_struct = NULL;
+	  lw6map_free (level);
+	  level = NULL;
+	}
+    }
+
+  if (level && game_struct && game_state)
+    {
+      char *repr = NULL;
+
+      repr = lw6ker_game_state_repr (game_state);
+      if (repr)
+	{
+	  LOADER_LOCK;
+	  if (request_number == loader_data->request_number)
+	    {
+	      stage1_clear_response (&(loader_data->stage1));
+	      stage2_clear_response (&(loader_data->stage2));
+	      loader_data->stage2.level = level;
+	      loader_data->stage2.game_struct = game_struct;
+	      loader_data->stage2.game_state = game_state;
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _
+			  ("async load stage2 done, request_number %d, game_state \"%s\""),
+			  request_number, repr);
+	      ok = 1;
+	    }
+	  else if (request_number < loader_data->request_number)
+	    {
+	      lw6sys_log (LW6SYS_LOG_INFO,
+			  _
+			  ("async load stage2 abort, request number %d < %d, game_state \"%s\""),
+			  request_number, loader_data->request_number, repr);
+	      lw6ker_game_state_free (game_state);
+	      game_state = NULL;
+	      lw6ker_game_struct_free (game_struct);
+	      game_struct = NULL;
+	      lw6map_free (level);
+	      level = NULL;
+	    }
+	  else
+	    {
+	      lw6sys_log (LW6SYS_LOG_WARNING,
+			  _
+			  ("async load stage2, inconsistent request number %d > %d, game_state \"%s\""),
+			  request_number, loader_data->request_number, repr);
+	    }
+	  LOADER_UNLOCK;
+	  LW6SYS_FREE (repr);
+	  repr = NULL;
+	}
+    }
+  if (ok)
+    {
+      (*(progress.value)) = _LW6TSK_LOADER_PROGRESS_STAGE2_END;
+    }
 }
 
 void
@@ -249,9 +405,11 @@ _lw6tsk_loader_poll (_lw6tsk_loader_data_t * loader_data)
   stage1 (loader_data);
   loader_data->stage = 2;
   stage2 (loader_data);
-  loader_data->stage = 3;
-  stage3 (loader_data);
   loader_data->stage = 0;
+  if (loader_data->progress)
+    {
+      (*(loader_data->progress)) = 0.0f;
+    }
 }
 
 void
@@ -271,9 +429,9 @@ lw6tsk_loader_push (lw6tsk_loader_t * loader, char *map_path,
   loader_data->stage1.map_path = lw6sys_str_copy (map_path);
   loader_data->stage1.relative_path = lw6sys_str_copy (relative_path);
   loader_data->stage1.default_param =
-    lw6sys_assoc_dup (default_param, (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+    lw6sys_assoc_dup (default_param, (lw6sys_dup_func_t) lw6sys_str_copy);
   loader_data->stage1.forced_param =
-    lw6sys_assoc_dup (forced_param, (LW6SYS_DUP_FUNC) lw6sys_str_copy);
+    lw6sys_assoc_dup (forced_param, (lw6sys_dup_func_t) lw6sys_str_copy);
   loader_data->stage1.display_shape = *display_shape;
 
   LOADER_UNLOCK;
@@ -295,12 +453,6 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
   if (level)
     {
       (*level) = NULL;
-      if (loader_data->stage1.level)
-	{
-	  (*level) = loader_data->stage1.level;
-	  loader_data->stage1.level = NULL;
-	  ret = 1;
-	}
     }
   if (game_struct)
     {
@@ -311,6 +463,30 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
       (*game_state) = NULL;
     }
 
+  if (level)
+    {
+      if (loader_data->stage1.level)
+	{
+	  (*level) = loader_data->stage1.level;
+	  loader_data->stage1.level = NULL;	// do not free!
+	  ret = 1;
+	}
+    }
+  if (level && game_struct && game_state)
+    {
+      if (loader_data->stage2.level && loader_data->stage2.game_struct
+	  && loader_data->stage2.game_state && (!(*level)))
+	{
+	  (*level) = loader_data->stage2.level;
+	  (*game_struct) = loader_data->stage2.game_struct;
+	  (*game_state) = loader_data->stage2.game_state;
+	  loader_data->stage2.level = NULL;	// do not free!
+	  loader_data->stage2.game_struct = NULL;	// do not free!
+	  loader_data->stage2.game_state = NULL;	// do not free!
+	  ret = 1;
+	}
+    }
+
   LOADER_UNLOCK;
 
   return ret;
@@ -324,7 +500,7 @@ lw6tsk_loader_pop (lw6map_level_t ** level,
  * try and identify the objects in their on per-process lists,
  * structures, Guile object, whatever they use.
  */
-static int seq_id = 0;
+static u_int32_t seq_id = 0;
 
 static void
 loader_data_free (_lw6tsk_loader_data_t * loader_data)
@@ -379,7 +555,7 @@ loader_join (void *data)
  * Return value: a pointer to the loader, NULL if failed.
  */
 lw6tsk_loader_t *
-lw6tsk_loader_new (float sleep)
+lw6tsk_loader_new (float sleep, float *progress)
 {
   lw6tsk_loader_t *loader;
   _lw6tsk_loader_data_t *loader_data;
@@ -387,7 +563,11 @@ lw6tsk_loader_new (float sleep)
   loader = (lw6tsk_loader_t *) LW6SYS_CALLOC (sizeof (lw6tsk_loader_t));
   if (loader)
     {
-      loader->id = ++seq_id;
+      loader->id = 0;
+      while (!loader->id)
+	{
+	  loader->id = ++seq_id;
+	}
       loader_data =
 	(_lw6tsk_loader_data_t *)
 	LW6SYS_CALLOC (sizeof (_lw6tsk_loader_data_t));
@@ -395,6 +575,7 @@ lw6tsk_loader_new (float sleep)
       if (loader->data)
 	{
 	  loader_data->sleep = sleep;
+	  loader_data->progress = progress;
 	  loader_data->mutex = lw6sys_mutex_create ();
 	  if (loader_data->mutex)
 	    {
@@ -473,13 +654,19 @@ lw6tsk_loader_repr (lw6tsk_loader_t * loader)
 {
   char *ret = NULL;
   _lw6tsk_loader_data_t *loader_data;
+  float progress = 0.0f;
 
   if (loader)
     {
       loader_data = (_lw6tsk_loader_data_t *) loader->data;
+      if (loader_data->progress)
+	{
+	  progress = *(loader_data->progress);
+	}
       ret =
-	lw6sys_new_sprintf (_("%d request_number=%d stage=%d"), loader->id,
-			    loader_data->request_number, loader_data->stage);
+	lw6sys_new_sprintf (_("%u request_number=%d stage=%d progress=%0.2f"),
+			    loader->id, loader_data->request_number,
+			    loader_data->stage, progress);
     }
   else
     {
@@ -489,3 +676,25 @@ lw6tsk_loader_repr (lw6tsk_loader_t * loader)
 
   return ret;
 }
+
+/**
+ * lw6tsk_loader_get_stage
+ *
+ * @loader: the loader to query.
+ *
+ * Returns the current stage of the loader.
+ *
+ * Return value: 0 if idle, 1 if loading the map from disk, 2 if build
+ *               dynamic stuff such as game_state.
+ */
+int
+lw6tsk_loader_get_stage (lw6tsk_loader_t * loader)
+{
+  int ret = 0;
+  _lw6tsk_loader_data_t *loader_data;
+
+  loader_data = (_lw6tsk_loader_data_t *) loader->data;
+  ret = loader_data->stage;
+
+  return ret;
+}
