@@ -27,12 +27,12 @@
 #include "tsk.h"
 
 #define TEST_MANAGER_SLEEP 1.0f
-#define TEST_LOOP_SLEEP 0.05f
-#define TEST_LOOP_N 60
+#define TEST_LOOP_SLEEP 0.1f
+#define TEST_LOOP_N 600
 #define TEST_LOAD_MAP "strange-new-world"
-#define TEST_OPTION_KEY1 "total-time"
+#define TEST_OPTION_KEY1 LW6DEF_TOTAL_TIME
 #define TEST_OPTION_VALUE1 "250"
-#define TEST_OPTION_KEY2 "background-style"
+#define TEST_OPTION_KEY2 LW6DEF_BACKGROUND_STYLE
 #define TEST_OPTION_VALUE2 "air"
 #define TEST_DISPLAY_WIDTH 640
 #define TEST_DISPLAY_HEIGHT 480
@@ -57,8 +57,10 @@ test_manager ()
     lw6map_level_t *level = NULL;
     lw6ker_game_struct_t *game_struct = NULL;
     lw6ker_game_state_t *game_state = NULL;
+    int done = 0;
+    float progress = 0.0f;
 
-    manager = lw6tsk_loader_new (TEST_MANAGER_SLEEP);
+    manager = lw6tsk_loader_new (TEST_MANAGER_SLEEP, &progress);
     if (manager)
       {
 	map_path = lw6sys_get_default_map_path ();
@@ -79,7 +81,7 @@ test_manager ()
 		lw6tsk_loader_push (manager, map_path, TEST_LOAD_MAP,
 				    default_param, forced_param,
 				    &display_shape);
-		for (i = 0; i < TEST_LOOP_N && !level; i++)
+		for (i = 0; i < TEST_LOOP_N && !done; i++)
 		  {
 		    lw6sys_sleep (TEST_LOOP_SLEEP);
 		    repr = lw6tsk_loader_repr (manager);
@@ -92,6 +94,32 @@ test_manager ()
 		    if (lw6tsk_loader_pop
 			(&level, &game_struct, &game_state, manager))
 		      {
+			if (level && game_struct && game_state)
+			  {
+			    done = 1;
+			    repr = lw6ker_game_struct_repr (game_struct);
+			    if (repr)
+			      {
+				lw6sys_log (LW6SYS_LOG_NOTICE,
+					    _("loaded game_struct \"%s\""),
+					    repr);
+				LW6SYS_FREE (repr);
+			      }
+			    repr = lw6ker_game_state_repr (game_state);
+			    if (repr)
+			      {
+				lw6sys_log (LW6SYS_LOG_NOTICE,
+					    _("loaded game_state \"%s\""),
+					    repr);
+				LW6SYS_FREE (repr);
+			      }
+			    lw6ker_game_state_free (game_state);
+			    game_state = NULL;
+			    lw6ker_game_struct_free (game_struct);
+			    game_struct = NULL;
+			    lw6map_free (level);
+			    level = NULL;
+			  }
 			if (level)
 			  {
 			    repr = lw6map_repr (level);
@@ -101,10 +129,8 @@ test_manager ()
 					    _("loaded map \"%s\""), repr);
 				LW6SYS_FREE (repr);
 			      }
-			  }
-			else
-			  {
-			    ret = 0;
+			    lw6map_free (level);
+			    level = NULL;
 			  }
 		      }
 		  }
@@ -115,11 +141,6 @@ test_manager ()
 	    LW6SYS_FREE (map_path);
 	  }
 	lw6tsk_loader_free (manager);
-
-	if (level)
-	  {
-	    lw6map_free (level);
-	  }
       }
     else
       {
