@@ -32,9 +32,11 @@ main (int argc, char *argv[])
   int ret = 0;
 
   LW6SYS_MAIN_BEGIN;
+  LW6HLP_MAIN_BEGIN;
 
   ret = lw6_main (argc, argv);
 
+  LW6HLP_MAIN_END;
   LW6SYS_MAIN_END;
 
   return (!ret);
