@@ -31,12 +31,21 @@ find $SCRIPT_DIR -type f -a -name "*.scm" \
     | grep scriptpo-update.sh \
     > $C_FILE
 
-# Additionnally, we automatically fill ../po/POTFILES.in
+## Additionnally, we automatically fill ../po/POTFILES.in
+#cd ..
+#find src -type f -a -name "*.c" \
+#    > po/POTFILES.in
+#find src -type f -a -name "*.c.inc" \
+#    >> po/POTFILES.in
+#cd src
+
+# Translating all the source files requires too much time, only
+# some specific cherry-picked files are translated.
 cd ..
-find src -type f -a -name "*.c" \
-    > po/POTFILES.in
-find src -type f -a -name "*.c.inc" \
-    >> po/POTFILES.in
+rm po/POTFILES.in
+for i in src/scriptpo.c src/lib/hlp/hlp-reference.c src/lib/sys/sys-log.c src/lib/sys/sys-mem.c src/lib/lw6-print.c src/lib/ldr/ldr-print.c src/lib/*/mod-*/mod-*-backend.c ; do
+    echo "$i" >> po/POTFILES.in
+done
 cd src
 
 indent $C_FILE
